@@ -16,13 +16,13 @@
  */
 package org.apache.seata.common.util;
 
+import org.apache.seata.common.exception.NotSupportYetException;
+
 import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import java.util.Date;
 import java.util.List;
 
-import org.apache.seata.common.exception.NotSupportYetException;
-
 /**
  * db page util
  *
@@ -67,8 +67,8 @@ public class PageUtil {
     /**
      * The constant LIMIT_TEMPLAGE.
      */
-    private static final String LIMIT_TEMPLATE = SOURCE_SQL_PLACE_HOLD + " limit " + LIMIT_PLACE_HOLD + " offset "
-            + OFFSET_PLACE_HOLD;
+    private static final String LIMIT_TEMPLATE =
+            SOURCE_SQL_PLACE_HOLD + " limit " + LIMIT_PLACE_HOLD + " offset " + OFFSET_PLACE_HOLD;
     /**
      * The constant ORACLE_PAGE_TEMPLATE.
      */
@@ -78,8 +78,10 @@ public class PageUtil {
     /**
      * The constant SQLSERVER_PAGE_TEMPLATE. Currently, it only works for order-by condition of "ORDER BY gmt_create desc"
      */
-    private static final String SQLSERVER_PAGE_TEMPLATE = "select * from (select temp.*, ROW_NUMBER() OVER(ORDER BY gmt_create desc) AS rowId from ("
-            + SOURCE_SQL_PLACE_HOLD + ") temp ) t where t.rowId between " + START_PLACE_HOLD + " and " + END_PLACE_HOLD;
+    private static final String SQLSERVER_PAGE_TEMPLATE =
+            "select * from (select temp.*, ROW_NUMBER() OVER(ORDER BY gmt_create desc) AS rowId from ("
+                    + SOURCE_SQL_PLACE_HOLD + ") temp ) t where t.rowId between " + START_PLACE_HOLD + " and "
+                    + END_PLACE_HOLD;
     /**
      * check page parm
      *
@@ -113,15 +115,18 @@ public class PageUtil {
             case "oceanbase":
             case "dm":
             case "oscar":
-                return LIMIT_TEMPLATE.replace(SOURCE_SQL_PLACE_HOLD, sourceSql)
+                return LIMIT_TEMPLATE
+                        .replace(SOURCE_SQL_PLACE_HOLD, sourceSql)
                         .replace(LIMIT_PLACE_HOLD, String.valueOf(pageSize))
                         .replace(OFFSET_PLACE_HOLD, String.valueOf((pageNum - 1) * pageSize));
             case "oracle":
-                return ORACLE_PAGE_TEMPLATE.replace(SOURCE_SQL_PLACE_HOLD, sourceSql)
+                return ORACLE_PAGE_TEMPLATE
+                        .replace(SOURCE_SQL_PLACE_HOLD, sourceSql)
                         .replace(START_PLACE_HOLD, String.valueOf(pageSize * (pageNum - 1) + 1))
                         .replace(END_PLACE_HOLD, String.valueOf(pageSize * pageNum));
             case "sqlserver":
-                return SQLSERVER_PAGE_TEMPLATE.replace(SOURCE_SQL_PLACE_HOLD, sourceSql)
+                return SQLSERVER_PAGE_TEMPLATE
+                        .replace(SOURCE_SQL_PLACE_HOLD, sourceSql)
                         .replace(START_PLACE_HOLD, String.valueOf(pageSize * (pageNum - 1) + 1))
                         .replace(END_PLACE_HOLD, String.valueOf(pageSize * pageNum));
             default:
@@ -150,7 +155,9 @@ public class PageUtil {
             case "sqlserver":
                 int lastIndexOfOrderBy = sourceSql.toLowerCase().lastIndexOf("order by");
                 if (lastIndexOfOrderBy != -1) {
-                    return sourceSql.substring(0, lastIndexOfOrderBy).replaceAll("(?i)(?<=select)(.*)(?=from)", " count(1) ");
+                    return sourceSql
+                            .substring(0, lastIndexOfOrderBy)
+                            .replaceAll("(?i)(?<=select)(.*)(?=from)", " count(1) ");
                 }
                 return sourceSql.replaceAll("(?i)(?<=select)(.*)(?=from)", " count(1) ");
             default:
