@@ -18,13 +18,14 @@ package org.apache.seata.common.metadata.namingserver;
 
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.ObjectMapper;
-import java.util.HashMap;
-import java.util.Map;
 import org.apache.seata.common.metadata.ClusterRole;
 import org.apache.seata.common.metadata.Instance;
 import org.apache.seata.common.metadata.Node;
 import org.junit.jupiter.api.Test;
 
+import java.util.HashMap;
+import java.util.Map;
+
 import static org.apache.seata.common.util.CollectionUtils.mapToJsonString;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
@@ -95,8 +96,12 @@ class InstanceTest {
         assertEquals(instance.getNamespace(), deserializedInstance.getNamespace());
         assertEquals(instance.getClusterName(), deserializedInstance.getClusterName());
         assertEquals(instance.getUnit(), deserializedInstance.getUnit());
-        assertEquals(instance.getControl().getPort(), deserializedInstance.getControl().getPort());
-        assertEquals(instance.getTransaction().getPort(), deserializedInstance.getTransaction().getPort());
+        assertEquals(
+                instance.getControl().getPort(),
+                deserializedInstance.getControl().getPort());
+        assertEquals(
+                instance.getTransaction().getPort(),
+                deserializedInstance.getTransaction().getPort());
         assertEquals(instance.getWeight(), deserializedInstance.getWeight(), 0.0);
         assertEquals(instance.isHealthy(), deserializedInstance.isHealthy());
         assertEquals(instance.getTerm(), deserializedInstance.getTerm());
@@ -201,4 +206,4 @@ class InstanceTest {
         instanceC.setTransaction(new Node.Endpoint("127.0.0.1", 9090));
         assertTrue(instanceA.equals(instanceC));
     }
-}
\ No newline at end of file
+}
