@@ -43,22 +43,17 @@ public class DurationUtilTest {
                 Arguments.of(183840L, "P2DT3H4M"),
                 Arguments.of(-21420L, "PT-6H3M"),
                 Arguments.of(-21780L, "-PT6H3M"),
-                Arguments.of(21420L, "-PT-6H+3M")
-        );
+                Arguments.of(21420L, "-PT-6H+3M"));
     }
 
     @ParameterizedTest
     @MethodSource("provideValueSetsTestParseGetSeconds")
     public void testParseGetSeconds(long expected, String str) {
-        Assertions.assertEquals(expected,DurationUtil.parse(str).getSeconds());
+        Assertions.assertEquals(expected, DurationUtil.parse(str).getSeconds());
     }
 
     private static Stream<Arguments> provideValueSetsTestParseToMillis() {
-        return Stream.of(
-                Arguments.of(8L, "8"),
-                Arguments.of(8L, "8ms"),
-                Arguments.of(20345L, "PT20.345S")
-        );
+        return Stream.of(Arguments.of(8L, "8"), Arguments.of(8L, "8ms"), Arguments.of(20345L, "PT20.345S"));
     }
 
     @ParameterizedTest
@@ -75,14 +70,12 @@ public class DurationUtilTest {
                 Arguments.of("h"),
                 Arguments.of("m"),
                 Arguments.of("s"),
-                Arguments.of("ms")
-        );
+                Arguments.of("ms"));
     }
 
     @ParameterizedTest
     @MethodSource("provideValueSetsTestParseThrowException")
     public void testParseThrowException(String str) {
-        Assertions.assertThrows(UnsupportedOperationException.class,
-                () -> DurationUtil.parse(str));
+        Assertions.assertThrows(UnsupportedOperationException.class, () -> DurationUtil.parse(str));
     }
 }
