@@ -16,11 +16,9 @@
  */
 package io.seata.core.context;
 
-
 /**
  * The interface Context core.
  * Notes: used for io.seata SPI interface
  */
 @Deprecated
-public interface ContextCore extends org.apache.seata.core.context.ContextCore {
-}
+public interface ContextCore extends org.apache.seata.core.context.ContextCore {}
