@@ -16,12 +16,10 @@
  */
 package io.seata.core.model;
 
-
 import org.apache.seata.common.loader.EnhancedServiceLoader;
 
 /**
  * @see EnhancedServiceLoader.InnerEnhancedServiceLoader#findAllExtensionDefinition(ClassLoader)
  */
 @Deprecated
-public interface ResourceManager extends org.apache.seata.core.model.ResourceManager {
-}
+public interface ResourceManager extends org.apache.seata.core.model.ResourceManager {}
