@@ -20,6 +20,4 @@ package io.seata.integration.http;
  * The type Seata web mvc configurer.
  */
 @Deprecated
-public class SeataWebMvcConfigurer extends org.apache.seata.integration.http.SeataWebMvcConfigurer {
-
-}
+public class SeataWebMvcConfigurer extends org.apache.seata.integration.http.SeataWebMvcConfigurer {}
