@@ -20,5 +20,4 @@ package io.seata.rm.tcc.api;
  * The type Business action context.
  */
 @Deprecated
-public class BusinessActionContext extends org.apache.seata.rm.tcc.api.BusinessActionContext {
-}
+public class BusinessActionContext extends org.apache.seata.rm.tcc.api.BusinessActionContext {}
