@@ -26,5 +26,4 @@ import java.lang.annotation.Target;
 @Retention(RetentionPolicy.RUNTIME)
 @Target(ElementType.TYPE)
 @Inherited
-public @interface LocalTCC {
-}
+public @interface LocalTCC {}
