@@ -16,7 +16,6 @@
  */
 package io.seata.saga.engine.pcext;
 
-
 import org.apache.seata.saga.engine.pcext.StateRouter;
 
 /**
@@ -25,5 +24,4 @@ import org.apache.seata.saga.engine.pcext.StateRouter;
  * @see StateRouter
  */
 @Deprecated
-public interface StateRouterInterceptor extends org.apache.seata.saga.engine.pcext.StateRouterInterceptor {
-}
+public interface StateRouterInterceptor extends org.apache.seata.saga.engine.pcext.StateRouterInterceptor {}
