@@ -16,11 +16,9 @@
  */
 package io.seata.saga.engine.mock;
 
-
 public class DemoException extends RuntimeException {
 
-    public DemoException() {
-    }
+    public DemoException() {}
 
     public DemoException(String message) {
         super(message);
