@@ -16,20 +16,6 @@
  */
 package org.apache.seata.config.consul;
 
-import java.io.IOException;
-import java.net.InetSocketAddress;
-import java.util.Enumeration;
-import java.util.Map;
-import java.util.Objects;
-import java.util.Properties;
-import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-
 import com.ecwid.consul.v1.ConsulClient;
 import com.ecwid.consul.v1.QueryParams;
 import com.ecwid.consul.v1.Response;
@@ -49,6 +35,20 @@ import org.apache.seata.config.processor.ConfigProcessor;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.io.IOException;
+import java.net.InetSocketAddress;
+import java.util.Enumeration;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Properties;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+
 import static org.apache.seata.config.ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR;
 import static org.apache.seata.config.ConfigurationKeys.FILE_ROOT_CONFIG;
 
@@ -57,8 +57,8 @@ import static org.apache.seata.config.ConfigurationKeys.FILE_ROOT_CONFIG;
  *
  */
 public class ConsulConfiguration extends AbstractConfiguration {
-    private volatile static ConsulConfiguration instance;
-    private volatile static ConsulClient client;
+    private static volatile ConsulConfiguration instance;
+    private static volatile ConsulClient client;
 
     private static final Logger LOGGER = LoggerFactory.getLogger(ConsulConfiguration.class);
     private static final Configuration FILE_CONFIG = ConfigurationFactory.CURRENT_FILE_INSTANCE;
@@ -67,24 +67,29 @@ public class ConsulConfiguration extends AbstractConfiguration {
     private static final String CONFIG_TYPE = "consul";
     private static final String ACL_TOKEN = "aclToken";
     private static final String DEFAULT_CONSUL_CONFIG_KEY_VALUE = "seata.properties";
-    private static final String FILE_CONFIG_KEY_PREFIX = FILE_ROOT_CONFIG + FILE_CONFIG_SPLIT_CHAR + CONFIG_TYPE
-            + FILE_CONFIG_SPLIT_CHAR;
+    private static final String FILE_CONFIG_KEY_PREFIX =
+            FILE_ROOT_CONFIG + FILE_CONFIG_SPLIT_CHAR + CONFIG_TYPE + FILE_CONFIG_SPLIT_CHAR;
     private static final int THREAD_POOL_NUM = 1;
     private static final int MAP_INITIAL_CAPACITY = 8;
     private ExecutorService consulNotifierExecutor;
-    private static final ConcurrentMap<String, Set<ConfigurationChangeListener>> CONFIG_LISTENERS_MAP
-            = new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
+    private static final ConcurrentMap<String, Set<ConfigurationChangeListener>> CONFIG_LISTENERS_MAP =
+            new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
     private static volatile Properties seataConfig = new Properties();
 
     /**
      * default watch timeout in second
      */
     private static final int DEFAULT_WATCH_TIMEOUT = 60;
+
     private static final long CAS = 0L;
 
     private ConsulConfiguration() {
-        consulNotifierExecutor = new ThreadPoolExecutor(THREAD_POOL_NUM, THREAD_POOL_NUM, Integer.MAX_VALUE,
-                TimeUnit.MILLISECONDS, new LinkedBlockingQueue<>(),
+        consulNotifierExecutor = new ThreadPoolExecutor(
+                THREAD_POOL_NUM,
+                THREAD_POOL_NUM,
+                Integer.MAX_VALUE,
+                TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(),
                 new NamedThreadFactory("consul-config-executor", THREAD_POOL_NUM));
         initSeataConfig();
     }
@@ -110,9 +115,10 @@ public class ConsulConfiguration extends AbstractConfiguration {
         String value = seataConfig.getProperty(dataId);
 
         if (value == null) {
-            ConfigFuture configFuture = new ConfigFuture(dataId, defaultValue, ConfigFuture.ConfigOperation.GET,
-                    timeoutMills);
-            consulNotifierExecutor.execute(() -> complete(getConsulClient().getKVValue(dataId, getAclToken()), configFuture));
+            ConfigFuture configFuture =
+                    new ConfigFuture(dataId, defaultValue, ConfigFuture.ConfigOperation.GET, timeoutMills);
+            consulNotifierExecutor.execute(
+                    () -> complete(getConsulClient().getKVValue(dataId, getAclToken()), configFuture));
             value = (String) configFuture.get();
         }
 
@@ -124,9 +130,12 @@ public class ConsulConfiguration extends AbstractConfiguration {
         ConfigFuture configFuture = new ConfigFuture(dataId, content, ConfigFuture.ConfigOperation.PUT, timeoutMills);
         if (!seataConfig.isEmpty()) {
             seataConfig.put(dataId, content);
-            consulNotifierExecutor.execute(() -> complete(getConsulClient().setKVValue(getConsulConfigKey(), getSeataConfigStr(), getAclToken(), null), configFuture));
+            consulNotifierExecutor.execute(() -> complete(
+                    getConsulClient().setKVValue(getConsulConfigKey(), getSeataConfigStr(), getAclToken(), null),
+                    configFuture));
         } else {
-            consulNotifierExecutor.execute(() -> complete(getConsulClient().setKVValue(dataId, content, getAclToken(), null), configFuture));
+            consulNotifierExecutor.execute(
+                    () -> complete(getConsulClient().setKVValue(dataId, content, getAclToken(), null), configFuture));
         }
 
         return (Boolean) configFuture.get();
@@ -134,21 +143,24 @@ public class ConsulConfiguration extends AbstractConfiguration {
 
     @Override
     public boolean putConfigIfAbsent(String dataId, String content, long timeoutMills) {
-        ConfigFuture configFuture = new ConfigFuture(dataId, content, ConfigFuture.ConfigOperation.PUTIFABSENT,
-                timeoutMills);
+        ConfigFuture configFuture =
+                new ConfigFuture(dataId, content, ConfigFuture.ConfigOperation.PUTIFABSENT, timeoutMills);
         if (!seataConfig.isEmpty()) {
             String property = seataConfig.getProperty(dataId);
             if (null == property) {
                 seataConfig.put(dataId, content);
                 PutParams putParams = new PutParams();
-                //Setting CAS to 0 means that this is an atomic operation, created when key does not exist.
+                // Setting CAS to 0 means that this is an atomic operation, created when key does not exist.
                 putParams.setCas(CAS);
-                consulNotifierExecutor.execute(() -> complete(getConsulClient().setKVValue(getConsulConfigKey(), getSeataConfigStr(), getAclToken(), putParams), configFuture));
+                consulNotifierExecutor.execute(() -> complete(
+                        getConsulClient()
+                                .setKVValue(getConsulConfigKey(), getSeataConfigStr(), getAclToken(), putParams),
+                        configFuture));
             }
         } else {
             consulNotifierExecutor.execute(() -> {
                 PutParams putParams = new PutParams();
-                //Setting CAS to 0 means that this is an atomic operation, created when key does not exist.
+                // Setting CAS to 0 means that this is an atomic operation, created when key does not exist.
                 putParams.setCas(CAS);
                 complete(getConsulClient().setKVValue(dataId, content, getAclToken(), putParams), configFuture);
             });
@@ -161,9 +173,12 @@ public class ConsulConfiguration extends AbstractConfiguration {
         ConfigFuture configFuture = new ConfigFuture(dataId, null, ConfigFuture.ConfigOperation.REMOVE, timeoutMills);
         if (!seataConfig.isEmpty()) {
             seataConfig.remove(dataId);
-            consulNotifierExecutor.execute(() -> complete(getConsulClient().setKVValue(getConsulConfigKey(), getSeataConfigStr(), getAclToken(), null), configFuture));
+            consulNotifierExecutor.execute(() -> complete(
+                    getConsulClient().setKVValue(getConsulConfigKey(), getSeataConfigStr(), getAclToken(), null),
+                    configFuture));
         } else {
-            consulNotifierExecutor.execute(() -> complete(getConsulClient().deleteKVValue(dataId, getAclToken()), configFuture));
+            consulNotifierExecutor.execute(
+                    () -> complete(getConsulClient().deleteKVValue(dataId, getAclToken()), configFuture));
         }
         return (Boolean) configFuture.get();
     }
@@ -174,7 +189,8 @@ public class ConsulConfiguration extends AbstractConfiguration {
             return;
         }
         ConsulListener consulListener = new ConsulListener(dataId, listener);
-        CONFIG_LISTENERS_MAP.computeIfAbsent(dataId, key -> ConcurrentHashMap.newKeySet())
+        CONFIG_LISTENERS_MAP
+                .computeIfAbsent(dataId, key -> ConcurrentHashMap.newKeySet())
                 .add(consulListener);
 
         // Start config change listener for the dataId.
@@ -234,7 +250,8 @@ public class ConsulConfiguration extends AbstractConfiguration {
      * @return acl-token
      */
     private static String getAclToken() {
-        String aclToken = StringUtils.isNotBlank(System.getProperty(ACL_TOKEN)) ? System.getProperty(ACL_TOKEN)
+        String aclToken = StringUtils.isNotBlank(System.getProperty(ACL_TOKEN))
+                ? System.getProperty(ACL_TOKEN)
                 : FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + ACL_TOKEN);
         return StringUtils.isNotBlank(aclToken) ? aclToken : null;
     }
@@ -303,8 +320,12 @@ public class ConsulConfiguration extends AbstractConfiguration {
         private final ConfigurationChangeListener listener;
         private final String dataId;
         private long consulIndex;
-        private final ExecutorService executor = new ThreadPoolExecutor(CORE_LISTENER_THREAD, MAX_LISTENER_THREAD, 0L,
-                TimeUnit.MILLISECONDS, new LinkedBlockingQueue<>(),
+        private final ExecutorService executor = new ThreadPoolExecutor(
+                CORE_LISTENER_THREAD,
+                MAX_LISTENER_THREAD,
+                0L,
+                TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(),
                 new NamedThreadFactory("consulListener", MAX_LISTENER_THREAD));
 
         /**
@@ -316,7 +337,8 @@ public class ConsulConfiguration extends AbstractConfiguration {
         public ConsulListener(String dataId, ConfigurationChangeListener listener) {
             this.dataId = dataId;
             this.listener = listener;
-            this.consulIndex = getConsulClient().getKVValue(dataId, getAclToken()).getConsulIndex();
+            this.consulIndex =
+                    getConsulClient().getKVValue(dataId, getAclToken()).getConsulIndex();
         }
 
         @Override
@@ -332,20 +354,22 @@ public class ConsulConfiguration extends AbstractConfiguration {
                         // The new config change listener
                         Properties seataConfigNew;
                         try {
-                            seataConfigNew  = ConfigProcessor.processConfig(value, getConsulDataType());
+                            seataConfigNew = ConfigProcessor.processConfig(value, getConsulDataType());
                         } catch (IOException e) {
                             LOGGER.error("load config properties error", e);
                             continue;
                         }
 
-                        for (Map.Entry<String, Set<ConfigurationChangeListener>> entry : CONFIG_LISTENERS_MAP.entrySet()) {
+                        for (Map.Entry<String, Set<ConfigurationChangeListener>> entry :
+                                CONFIG_LISTENERS_MAP.entrySet()) {
                             String key = entry.getKey();
                             String valueOld = seataConfig.getProperty(key, "");
                             String valueNew = seataConfigNew.getProperty(key, "");
                             if (!valueOld.equals(valueNew)) {
                                 for (ConfigurationChangeListener changeListener : entry.getValue()) {
                                     event.setDataId(key).setNewValue(valueNew);
-                                    ConfigurationChangeListener listener = ((ConsulListener) changeListener).getTargetListener();
+                                    ConfigurationChangeListener listener =
+                                            ((ConsulListener) changeListener).getTargetListener();
                                     listener.onProcessEvent(event);
                                 }
                             }
@@ -383,10 +407,10 @@ public class ConsulConfiguration extends AbstractConfiguration {
                 return false;
             }
             ConsulListener that = (ConsulListener) o;
-            return consulIndex == that.consulIndex &&
-                    Objects.equals(listener, that.listener) &&
-                    Objects.equals(dataId, that.dataId) &&
-                    Objects.equals(executor, that.executor);
+            return consulIndex == that.consulIndex
+                    && Objects.equals(listener, that.listener)
+                    && Objects.equals(dataId, that.dataId)
+                    && Objects.equals(executor, that.executor);
         }
 
         @Override
