@@ -22,14 +22,12 @@ import org.junit.jupiter.api.Test;
 import java.io.IOException;
 import java.util.Properties;
 
-
 class ProcessorPropertiesTest {
 
     @Test
     void processor() throws IOException {
-        String properties = "registry.type=file\n" +
-                "registry.file.name=file-test-pro.conf";
-        
+        String properties = "registry.type=file\n" + "registry.file.name=file-test-pro.conf";
+
         Properties processor = new ProcessorProperties().processor(properties);
         Assertions.assertEquals("file", processor.get("registry.type"));
         // not exist
