@@ -16,23 +16,6 @@
  */
 package org.apache.seata.config.etcd3;
 
-import java.io.IOException;
-
-import java.nio.charset.StandardCharsets;
-import java.util.Enumeration;
-import java.util.List;
-import java.util.Map;
-import java.util.Objects;
-import java.util.Properties;
-import java.util.Set;
-import java.util.concurrent.CompletableFuture;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-
 import io.etcd.jetcd.ByteSequence;
 import io.etcd.jetcd.Client;
 import io.etcd.jetcd.KeyValue;
@@ -61,6 +44,22 @@ import org.apache.seata.config.processor.ConfigProcessor;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.io.IOException;
+import java.nio.charset.StandardCharsets;
+import java.util.Enumeration;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Properties;
+import java.util.Set;
+import java.util.concurrent.CompletableFuture;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+
 import static io.netty.util.CharsetUtil.UTF_8;
 import static org.apache.seata.config.ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR;
 import static org.apache.seata.config.ConfigurationKeys.FILE_ROOT_CONFIG;
@@ -79,20 +78,24 @@ public class EtcdConfiguration extends AbstractConfiguration {
     private static final String ETCD_CONFIG_KEY = "key";
     private static final String CONFIG_TYPE = "etcd3";
     private static final String DEFAULT_ETCD_CONFIG_KEY_VALUE = "seata.properties";
-    private static final String FILE_CONFIG_KEY_PREFIX = FILE_ROOT_CONFIG + FILE_CONFIG_SPLIT_CHAR + CONFIG_TYPE
-        + FILE_CONFIG_SPLIT_CHAR;
+    private static final String FILE_CONFIG_KEY_PREFIX =
+            FILE_ROOT_CONFIG + FILE_CONFIG_SPLIT_CHAR + CONFIG_TYPE + FILE_CONFIG_SPLIT_CHAR;
     private static final int THREAD_POOL_NUM = 1;
     private static final int MAP_INITIAL_CAPACITY = 8;
     private ExecutorService etcdConfigExecutor;
-    private static final ConcurrentMap<String, Set<ConfigurationChangeListener>> CONFIG_LISTENERS_MAP = new ConcurrentHashMap<>(
-            MAP_INITIAL_CAPACITY);
+    private static final ConcurrentMap<String, Set<ConfigurationChangeListener>> CONFIG_LISTENERS_MAP =
+            new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
     private static volatile Properties seataConfig = new Properties();
 
     private static final long VERSION_NOT_EXIST = 0;
 
     private EtcdConfiguration() {
-        etcdConfigExecutor = new ThreadPoolExecutor(THREAD_POOL_NUM, THREAD_POOL_NUM, Integer.MAX_VALUE,
-                TimeUnit.MILLISECONDS, new LinkedBlockingQueue<>(),
+        etcdConfigExecutor = new ThreadPoolExecutor(
+                THREAD_POOL_NUM,
+                THREAD_POOL_NUM,
+                Integer.MAX_VALUE,
+                TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(),
                 new NamedThreadFactory("etcd-config-executor", THREAD_POOL_NUM));
         initSeataConfig();
     }
@@ -124,11 +127,11 @@ public class EtcdConfiguration extends AbstractConfiguration {
         if (value != null) {
             return value;
         }
-        ConfigFuture configFuture = new ConfigFuture(dataId, defaultValue, ConfigFuture.ConfigOperation.GET,
-            timeoutMills);
+        ConfigFuture configFuture =
+                new ConfigFuture(dataId, defaultValue, ConfigFuture.ConfigOperation.GET, timeoutMills);
         etcdConfigExecutor.execute(
-            () -> complete(getClient().getKVClient().get(ByteSequence.from(dataId, UTF_8)), configFuture));
-        return (String)configFuture.get();
+                () -> complete(getClient().getKVClient().get(ByteSequence.from(dataId, UTF_8)), configFuture));
+        return (String) configFuture.get();
     }
 
     @Override
@@ -137,18 +140,21 @@ public class EtcdConfiguration extends AbstractConfiguration {
             seataConfig.setProperty(dataId, content);
             String etcdConfigKey = getEtcdConfigKey();
             String seataConfigStr = getSeataConfigStr();
-            ConfigFuture configFuture = new ConfigFuture(etcdConfigKey, seataConfigStr, ConfigFuture.ConfigOperation.PUT, timeoutMills);
+            ConfigFuture configFuture =
+                    new ConfigFuture(etcdConfigKey, seataConfigStr, ConfigFuture.ConfigOperation.PUT, timeoutMills);
             etcdConfigExecutor.execute(() -> complete(
-                    getClient().getKVClient().put(ByteSequence.from(etcdConfigKey, UTF_8), ByteSequence.from(seataConfigStr, UTF_8)),
+                    getClient()
+                            .getKVClient()
+                            .put(ByteSequence.from(etcdConfigKey, UTF_8), ByteSequence.from(seataConfigStr, UTF_8)),
                     configFuture));
             return (Boolean) configFuture.get();
         }
 
         ConfigFuture configFuture = new ConfigFuture(dataId, content, ConfigFuture.ConfigOperation.PUT, timeoutMills);
         etcdConfigExecutor.execute(() -> complete(
-            getClient().getKVClient().put(ByteSequence.from(dataId, UTF_8), ByteSequence.from(content, UTF_8)),
-            configFuture));
-        return (Boolean)configFuture.get();
+                getClient().getKVClient().put(ByteSequence.from(dataId, UTF_8), ByteSequence.from(content, UTF_8)),
+                configFuture));
+        return (Boolean) configFuture.get();
     }
 
     @Override
@@ -161,18 +167,27 @@ public class EtcdConfiguration extends AbstractConfiguration {
             }
         }
 
-        ConfigFuture configFuture = new ConfigFuture(dataId, content, ConfigFuture.ConfigOperation.PUTIFABSENT,
-            timeoutMills);
+        ConfigFuture configFuture =
+                new ConfigFuture(dataId, content, ConfigFuture.ConfigOperation.PUTIFABSENT, timeoutMills);
         etcdConfigExecutor.execute(() -> {
-            //use etcd transaction to ensure the atomic operation
-            complete(client.getKVClient().txn()
-                //whether the key exists
-                .If(new Cmp(ByteSequence.from(dataId, UTF_8), Cmp.Op.EQUAL, CmpTarget.version(VERSION_NOT_EXIST)))
-                //not exist,then will create
-                .Then(Op.put(ByteSequence.from(dataId, UTF_8), ByteSequence.from(content, UTF_8), PutOption.DEFAULT))
-                .commit(), configFuture);
+            // use etcd transaction to ensure the atomic operation
+            complete(
+                    client.getKVClient()
+                            .txn()
+                            // whether the key exists
+                            .If(new Cmp(
+                                    ByteSequence.from(dataId, UTF_8),
+                                    Cmp.Op.EQUAL,
+                                    CmpTarget.version(VERSION_NOT_EXIST)))
+                            // not exist,then will create
+                            .Then(Op.put(
+                                    ByteSequence.from(dataId, UTF_8),
+                                    ByteSequence.from(content, UTF_8),
+                                    PutOption.DEFAULT))
+                            .commit(),
+                    configFuture);
         });
-        return (Boolean)configFuture.get();
+        return (Boolean) configFuture.get();
     }
 
     @Override
@@ -181,16 +196,20 @@ public class EtcdConfiguration extends AbstractConfiguration {
             seataConfig.remove(dataId);
             String etcdConfigKey = getEtcdConfigKey();
             String seataConfigStr = getSeataConfigStr();
-            ConfigFuture configFuture = new ConfigFuture(etcdConfigKey, seataConfigStr, ConfigFuture.ConfigOperation.PUT, timeoutMills);
+            ConfigFuture configFuture =
+                    new ConfigFuture(etcdConfigKey, seataConfigStr, ConfigFuture.ConfigOperation.PUT, timeoutMills);
             etcdConfigExecutor.execute(() -> complete(
-                    getClient().getKVClient().put(ByteSequence.from(etcdConfigKey, UTF_8), ByteSequence.from(seataConfigStr, UTF_8)),
+                    getClient()
+                            .getKVClient()
+                            .put(ByteSequence.from(etcdConfigKey, UTF_8), ByteSequence.from(seataConfigStr, UTF_8)),
                     configFuture));
             return (Boolean) configFuture.get();
         }
 
         ConfigFuture configFuture = new ConfigFuture(dataId, null, ConfigFuture.ConfigOperation.REMOVE, timeoutMills);
-        etcdConfigExecutor.execute(() -> complete(getClient().getKVClient().delete(ByteSequence.from(dataId, UTF_8)), configFuture));
-        return (Boolean)configFuture.get();
+        etcdConfigExecutor.execute(
+                () -> complete(getClient().getKVClient().delete(ByteSequence.from(dataId, UTF_8)), configFuture));
+        return (Boolean) configFuture.get();
     }
 
     @Override
@@ -199,7 +218,8 @@ public class EtcdConfiguration extends AbstractConfiguration {
             return;
         }
         EtcdListener etcdListener = new EtcdListener(dataId, listener);
-        CONFIG_LISTENERS_MAP.computeIfAbsent(dataId, key -> ConcurrentHashMap.newKeySet())
+        CONFIG_LISTENERS_MAP
+                .computeIfAbsent(dataId, key -> ConcurrentHashMap.newKeySet())
                 .add(etcdListener);
         etcdListener.onProcessEvent(new ConfigurationChangeEvent());
     }
@@ -213,7 +233,7 @@ public class EtcdConfiguration extends AbstractConfiguration {
         if (CollectionUtils.isNotEmpty(configListeners)) {
             ConfigurationChangeListener target;
             for (ConfigurationChangeListener entry : configListeners) {
-                target = ((EtcdListener)entry).getTargetListener();
+                target = ((EtcdListener) entry).getTargetListener();
                 if (listener.equals(target)) {
                     entry.onShutDown();
                     configListeners.remove(entry);
@@ -237,8 +257,9 @@ public class EtcdConfiguration extends AbstractConfiguration {
         if (client == null) {
             synchronized (EtcdConfiguration.class) {
                 if (client == null) {
-                    client = Client.builder().endpoints(FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + SERVER_ADDR_KEY))
-                        .build();
+                    client = Client.builder()
+                            .endpoints(FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + SERVER_ADDR_KEY))
+                            .build();
                 }
             }
         }
@@ -256,7 +277,7 @@ public class EtcdConfiguration extends AbstractConfiguration {
         try {
             T response = completableFuture.get();
             if (response instanceof GetResponse) {
-                List<KeyValue> keyValues = ((GetResponse)response).getKvs();
+                List<KeyValue> keyValues = ((GetResponse) response).getKvs();
                 if (CollectionUtils.isNotEmpty(keyValues)) {
                     ByteSequence value = keyValues.get(0).getValue();
                     if (value != null) {
@@ -266,8 +287,8 @@ public class EtcdConfiguration extends AbstractConfiguration {
             } else if (response instanceof PutResponse) {
                 configFuture.setResult(Boolean.TRUE);
             } else if (response instanceof TxnResponse) {
-                boolean result = ((TxnResponse)response).isSucceeded();
-                //create key if file does not exist)
+                boolean result = ((TxnResponse) response).isSucceeded();
+                // create key if file does not exist)
                 if (result) {
                     configFuture.setResult(Boolean.TRUE);
                 }
@@ -277,7 +298,7 @@ public class EtcdConfiguration extends AbstractConfiguration {
                 throw new ShouldNeverHappenException("unsupported response type");
             }
         } catch (Exception e) {
-            LOGGER.error("error occurred while completing the future{}", e.getMessage(),e);
+            LOGGER.error("error occurred while completing the future{}", e.getMessage(), e);
         }
     }
 
@@ -288,10 +309,12 @@ public class EtcdConfiguration extends AbstractConfiguration {
             GetResponse getResponse = future.get();
             List<KeyValue> kvs = getResponse.getKvs();
             if (!kvs.isEmpty()) {
-                seataConfig = ConfigProcessor.processConfig(new String(kvs.get(0).getValue().getBytes(), StandardCharsets.UTF_8), getEtcdDataType());
+                seataConfig = ConfigProcessor.processConfig(
+                        new String(kvs.get(0).getValue().getBytes(), StandardCharsets.UTF_8), getEtcdDataType());
 
                 EtcdListener etcdListener = new EtcdListener(etcdConfigKey, null);
-                CONFIG_LISTENERS_MAP.computeIfAbsent(etcdConfigKey, key -> new ConcurrentSet<>())
+                CONFIG_LISTENERS_MAP
+                        .computeIfAbsent(etcdConfigKey, key -> new ConcurrentSet<>())
                         .add(etcdListener);
                 etcdListener.onProcessEvent(new ConfigurationChangeEvent());
             }
@@ -303,9 +326,11 @@ public class EtcdConfiguration extends AbstractConfiguration {
     private static String getEtcdConfigKey() {
         return FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + ETCD_CONFIG_KEY, DEFAULT_ETCD_CONFIG_KEY_VALUE);
     }
+
     private static String getEtcdDataType() {
         return ConfigProcessor.resolverConfigDataType(getEtcdConfigKey());
     }
+
     private static String getSeataConfigStr() {
         StringBuilder sb = new StringBuilder();
 
@@ -326,9 +351,13 @@ public class EtcdConfiguration extends AbstractConfiguration {
         private final String dataId;
         private final ConfigurationChangeListener listener;
         private Watch.Watcher watcher;
-        private final ExecutorService executor = new ThreadPoolExecutor(CORE_LISTENER_THREAD, MAX_LISTENER_THREAD, 0L,
-            TimeUnit.MILLISECONDS, new LinkedBlockingQueue<>(),
-            new NamedThreadFactory("etcdListener", MAX_LISTENER_THREAD));
+        private final ExecutorService executor = new ThreadPoolExecutor(
+                CORE_LISTENER_THREAD,
+                MAX_LISTENER_THREAD,
+                0L,
+                TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(),
+                new NamedThreadFactory("etcdListener", MAX_LISTENER_THREAD));
 
         /**
          * Instantiates a new Etcd listener.
@@ -364,23 +393,31 @@ public class EtcdConfiguration extends AbstractConfiguration {
                 @Override
                 public void onNext(WatchResponse watchResponse) {
                     if (dataId.equals(getEtcdConfigKey())) {
-                        byte[] bytes = watchResponse.getEvents().get(0).getKeyValue().getValue().getBytes();
+                        byte[] bytes = watchResponse
+                                .getEvents()
+                                .get(0)
+                                .getKeyValue()
+                                .getValue()
+                                .getBytes();
                         Properties seataConfigNew;
-                        try  {
-                            seataConfigNew = ConfigProcessor.processConfig(new String(bytes, StandardCharsets.UTF_8), getEtcdDataType());
+                        try {
+                            seataConfigNew = ConfigProcessor.processConfig(
+                                    new String(bytes, StandardCharsets.UTF_8), getEtcdDataType());
                         } catch (IOException e) {
                             LOGGER.error("load config properties error", e);
                             return;
                         }
 
-                        for (Map.Entry<String, Set<ConfigurationChangeListener>> entry : CONFIG_LISTENERS_MAP.entrySet()) {
+                        for (Map.Entry<String, Set<ConfigurationChangeListener>> entry :
+                                CONFIG_LISTENERS_MAP.entrySet()) {
                             String key = entry.getKey();
                             String valueOld = seataConfig.getProperty(key, "");
                             String valueNew = seataConfigNew.getProperty(key, "");
                             if (!valueOld.equals(valueNew)) {
                                 for (ConfigurationChangeListener changeListener : entry.getValue()) {
                                     event.setDataId(key).setNewValue(valueNew);
-                                    ConfigurationChangeListener listener = ((EtcdListener) changeListener).getTargetListener();
+                                    ConfigurationChangeListener listener =
+                                            ((EtcdListener) changeListener).getTargetListener();
                                     listener.onProcessEvent(event);
                                 }
                             }
@@ -390,10 +427,14 @@ public class EtcdConfiguration extends AbstractConfiguration {
                     }
 
                     try {
-                        GetResponse getResponse = getClient().getKVClient().get(ByteSequence.from(dataId, UTF_8)).get();
+                        GetResponse getResponse = getClient()
+                                .getKVClient()
+                                .get(ByteSequence.from(dataId, UTF_8))
+                                .get();
                         List<KeyValue> keyValues = getResponse.getKvs();
                         if (CollectionUtils.isNotEmpty(keyValues)) {
-                            event.setDataId(dataId).setNewValue(keyValues.get(0).getValue().toString(UTF_8));
+                            event.setDataId(dataId)
+                                    .setNewValue(keyValues.get(0).getValue().toString(UTF_8));
                             listener.onProcessEvent(event);
                         }
                     } catch (Exception e) {
@@ -402,14 +443,10 @@ public class EtcdConfiguration extends AbstractConfiguration {
                 }
 
                 @Override
-                public void onError(Throwable throwable) {
-
-                }
+                public void onError(Throwable throwable) {}
 
                 @Override
-                public void onCompleted() {
-
-                }
+                public void onCompleted() {}
             });
         }
 
@@ -427,10 +464,10 @@ public class EtcdConfiguration extends AbstractConfiguration {
                 return false;
             }
             EtcdListener that = (EtcdListener) o;
-            return Objects.equals(dataId, that.dataId) &&
-                    Objects.equals(listener, that.listener) &&
-                    Objects.equals(watcher, that.watcher) &&
-                    Objects.equals(executor, that.executor);
+            return Objects.equals(dataId, that.dataId)
+                    && Objects.equals(listener, that.listener)
+                    && Objects.equals(watcher, that.watcher)
+                    && Objects.equals(executor, that.executor);
         }
 
         @Override
