@@ -16,8 +16,30 @@
  */
 package org.apache.seata.config.zk;
 
+import org.apache.curator.framework.CuratorFramework;
+import org.apache.curator.framework.CuratorFrameworkFactory;
+import org.apache.curator.framework.recipes.cache.ChildData;
+import org.apache.curator.framework.recipes.cache.CuratorCache;
+import org.apache.curator.framework.recipes.cache.CuratorCacheListener;
+import org.apache.curator.retry.RetryNTimes;
+import org.apache.seata.common.exception.NotSupportYetException;
+import org.apache.seata.common.thread.NamedThreadFactory;
+import org.apache.seata.common.util.CollectionUtils;
+import org.apache.seata.common.util.StringUtils;
+import org.apache.seata.config.AbstractConfiguration;
+import org.apache.seata.config.Configuration;
+import org.apache.seata.config.ConfigurationChangeEvent;
+import org.apache.seata.config.ConfigurationChangeListener;
+import org.apache.seata.config.ConfigurationChangeType;
+import org.apache.seata.config.ConfigurationFactory;
+import org.apache.seata.config.processor.ConfigProcessor;
+import org.apache.zookeeper.KeeperException;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import java.io.IOException;
-import java.lang.reflect.Constructor;
+import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.util.Enumeration;
 import java.util.Map;
 import java.util.Properties;
@@ -30,34 +52,15 @@ import java.util.concurrent.LinkedBlockingQueue;
 import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 
-import org.apache.seata.common.exception.NotSupportYetException;
-import org.apache.seata.common.thread.NamedThreadFactory;
-import org.apache.seata.common.util.CollectionUtils;
-import org.apache.seata.common.util.StringUtils;
-import org.apache.seata.config.AbstractConfiguration;
-import org.apache.seata.config.Configuration;
-import org.apache.seata.config.ConfigurationChangeEvent;
-import org.apache.seata.config.ConfigurationChangeListener;
-import org.apache.seata.config.ConfigurationChangeType;
-import org.apache.seata.config.ConfigurationFactory;
-import org.apache.seata.config.processor.ConfigProcessor;
-import org.I0Itec.zkclient.IZkDataListener;
-import org.I0Itec.zkclient.ZkClient;
-import org.I0Itec.zkclient.serialize.ZkSerializer;
-import org.apache.zookeeper.CreateMode;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
 import static org.apache.seata.config.ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR;
 import static org.apache.seata.config.ConfigurationKeys.FILE_ROOT_CONFIG;
 import static org.apache.seata.config.ConfigurationKeys.SEATA_FILE_ROOT_CONFIG;
 
 /**
  * The type Zookeeper configuration.
- *
  */
 public class ZookeeperConfiguration extends AbstractConfiguration {
-    private final static Logger LOGGER = LoggerFactory.getLogger(ZookeeperConfiguration.class);
+    private static final Logger LOGGER = LoggerFactory.getLogger(ZookeeperConfiguration.class);
 
     private static final String CONFIG_TYPE = "zk";
     private static final String ZK_PATH_SPLIT_CHAR = "/";
@@ -74,16 +77,22 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
     private static final int DEFAULT_SESSION_TIMEOUT = 6000;
     private static final int DEFAULT_CONNECT_TIMEOUT = 2000;
     private static final String DEFAULT_CONFIG_PATH = ROOT_PATH + "/seata.properties";
-    private static final String FILE_CONFIG_KEY_PREFIX = FILE_ROOT_CONFIG + FILE_CONFIG_SPLIT_CHAR + CONFIG_TYPE
-            + FILE_CONFIG_SPLIT_CHAR;
-    private static final ExecutorService CONFIG_EXECUTOR = new ThreadPoolExecutor(THREAD_POOL_NUM, THREAD_POOL_NUM,
-            Integer.MAX_VALUE, TimeUnit.MILLISECONDS, new LinkedBlockingQueue<>(),
+    private static final String FILE_CONFIG_KEY_PREFIX =
+            FILE_ROOT_CONFIG + FILE_CONFIG_SPLIT_CHAR + CONFIG_TYPE + FILE_CONFIG_SPLIT_CHAR;
+    private static final ExecutorService CONFIG_EXECUTOR = new ThreadPoolExecutor(
+            THREAD_POOL_NUM,
+            THREAD_POOL_NUM,
+            Integer.MAX_VALUE,
+            TimeUnit.MILLISECONDS,
+            new LinkedBlockingQueue<>(),
             new NamedThreadFactory("ZKConfigThread", THREAD_POOL_NUM));
-    private static volatile ZkClient zkClient;
+    private static volatile CuratorFramework zkClient;
     private static final int MAP_INITIAL_CAPACITY = 8;
-    private static final ConcurrentMap<String, ConcurrentMap<ConfigurationChangeListener, ZKListener>> CONFIG_LISTENERS_MAP
-            = new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
+    private static final ConcurrentMap<String, ConcurrentMap<ConfigurationChangeListener, NodeCacheListenerImpl>>
+            CONFIG_LISTENERS_MAP = new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
     private static volatile Properties seataConfig = new Properties();
+    static final Charset CHARSET = StandardCharsets.UTF_8;
+    private static Map<String, CuratorCache> nodeCacheMap = new ConcurrentHashMap<>();
 
     /**
      * Instantiates a new Zookeeper configuration.
@@ -93,26 +102,54 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
         if (zkClient == null) {
             synchronized (ZookeeperConfiguration.class) {
                 if (zkClient == null) {
-                    ZkSerializer zkSerializer = getZkSerializer();
                     String serverAddr = FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + SERVER_ADDR_KEY);
-                    int sessionTimeout = FILE_CONFIG.getInt(FILE_CONFIG_KEY_PREFIX + SESSION_TIMEOUT_KEY, DEFAULT_SESSION_TIMEOUT);
-                    int connectTimeout = FILE_CONFIG.getInt(FILE_CONFIG_KEY_PREFIX + CONNECT_TIMEOUT_KEY, DEFAULT_CONNECT_TIMEOUT);
-                    zkClient = new ZkClient(serverAddr, sessionTimeout, connectTimeout, zkSerializer);
+                    int sessionTimeout =
+                            FILE_CONFIG.getInt(FILE_CONFIG_KEY_PREFIX + SESSION_TIMEOUT_KEY, DEFAULT_SESSION_TIMEOUT);
+                    int connectTimeout =
+                            FILE_CONFIG.getInt(FILE_CONFIG_KEY_PREFIX + CONNECT_TIMEOUT_KEY, DEFAULT_CONNECT_TIMEOUT);
+                    CuratorFrameworkFactory.Builder builder = CuratorFrameworkFactory.builder()
+                            .connectString(serverAddr)
+                            .retryPolicy(new RetryNTimes(1, 1000))
+                            .connectionTimeoutMs(connectTimeout)
+                            .sessionTimeoutMs(sessionTimeout);
                     String username = FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + AUTH_USERNAME);
                     String password = FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + AUTH_PASSWORD);
                     if (!StringUtils.isBlank(username) && !StringUtils.isBlank(password)) {
-                        StringBuilder auth = new StringBuilder(username).append(":").append(password);
-                        zkClient.addAuthInfo("digest", auth.toString().getBytes());
+                        StringBuilder auth =
+                                new StringBuilder(username).append(":").append(password);
+                        builder.authorization("digest", auth.toString().getBytes());
                     }
+                    zkClient = builder.build();
+                    zkClient.start();
                 }
             }
-            if (!zkClient.exists(ROOT_PATH)) {
-                zkClient.createPersistent(ROOT_PATH, true);
+            if (!checkExists(ROOT_PATH)) {
+                createPersistent(ROOT_PATH);
             }
             initSeataConfig();
         }
     }
 
+    public void createPersistent(String path) {
+        try {
+            zkClient.create().forPath(path);
+        } catch (KeeperException.NodeExistsException e) {
+            LOGGER.warn("ZNode " + path + " already exists.", e);
+        } catch (Exception e) {
+            throw new IllegalStateException(e.getMessage(), e);
+        }
+    }
+
+    public boolean checkExists(String path) {
+        try {
+            if (zkClient.checkExists().forPath(path) != null) {
+                return true;
+            }
+        } catch (Exception e) {
+        }
+        return false;
+    }
+
     @Override
     public String getTypeName() {
         return CONFIG_TYPE;
@@ -125,39 +162,53 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
             return value;
         }
         FutureTask<String> future = new FutureTask<>(() -> {
-            String path = ROOT_PATH + ZK_PATH_SPLIT_CHAR + dataId;
-            if (!zkClient.exists(path)) {
-                LOGGER.warn("config {} is not existed, return defaultValue {} ",
-                        dataId, defaultValue);
+            String path = buildPath(dataId);
+            if (!checkExists(path)) {
+                LOGGER.warn("config {} is not existed, return defaultValue {} ", dataId, defaultValue);
                 return defaultValue;
             }
-            String value1 = zkClient.readData(path);
+            String value1 = readData(path);
             return StringUtils.isNullOrEmpty(value1) ? defaultValue : value1;
         });
         CONFIG_EXECUTOR.execute(future);
         try {
             return future.get(timeoutMills, TimeUnit.MILLISECONDS);
         } catch (Exception e) {
-            LOGGER.error("getConfig {} error or timeout, return defaultValue {}, exception:{} ",
-                    dataId, defaultValue, e.getMessage());
+            LOGGER.error(
+                    "getConfig {} error or timeout, return defaultValue {}, exception:{} ",
+                    dataId,
+                    defaultValue,
+                    e.getMessage());
             return defaultValue;
         }
     }
 
+    public String readData(String path) {
+        try {
+            byte[] dataBytes = zkClient.getData().forPath(path);
+            return (dataBytes == null || dataBytes.length == 0) ? null : new String(dataBytes, CHARSET);
+        } catch (KeeperException.NoNodeException e) {
+            // ignore NoNode Exception.
+        } catch (Exception e) {
+            throw new IllegalStateException(e.getMessage(), e);
+        }
+        return null;
+    }
+
     @Override
     public boolean putConfig(String dataId, String content, long timeoutMills) {
         if (!seataConfig.isEmpty()) {
             seataConfig.setProperty(dataId, content);
-            zkClient.writeData(getConfigPath(), getSeataConfigStr());
+            createPersistent(getConfigPath(), getSeataConfigStr());
             return true;
         }
 
         FutureTask<Boolean> future = new FutureTask<>(() -> {
-            String path = ROOT_PATH + ZK_PATH_SPLIT_CHAR + dataId;
-            if (!zkClient.exists(path)) {
-                zkClient.create(path, content, CreateMode.PERSISTENT);
+            String path = buildPath(dataId);
+            if (!checkExists(path)) {
+                createPersistent(path, content);
             } else {
-                zkClient.writeData(path, content);
+                createPersistent(path, content);
             }
             return true;
         });
@@ -165,12 +216,31 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
         try {
             return future.get(timeoutMills, TimeUnit.MILLISECONDS);
         } catch (Exception e) {
-            LOGGER.error("putConfig {}, value: {} is error or timeout, exception: {}",
-                    dataId, content, e.getMessage());
+            LOGGER.error("putConfig {}, value: {} is error or timeout, exception: {}", dataId, content, e.getMessage());
             return false;
         }
     }
 
+    public String buildPath(String dataId) {
+        String path = ROOT_PATH + ZK_PATH_SPLIT_CHAR + dataId;
+        return path;
+    }
+
+    protected void createPersistent(String path, String data) {
+        byte[] dataBytes = data.getBytes(CHARSET);
+        try {
+            zkClient.create().forPath(path, dataBytes);
+        } catch (KeeperException.NodeExistsException e) {
+            try {
+                zkClient.setData().forPath(path, dataBytes);
+            } catch (Exception e1) {
+                throw new IllegalStateException(e.getMessage(), e1);
+            }
+        } catch (Exception e) {
+            throw new IllegalStateException(e.getMessage(), e);
+        }
+    }
+
     @Override
     public boolean putConfigIfAbsent(String dataId, String content, long timeoutMills) {
         throw new NotSupportYetException("not support atomic operation putConfigIfAbsent");
@@ -180,13 +250,13 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
     public boolean removeConfig(String dataId, long timeoutMills) {
         if (!seataConfig.isEmpty()) {
             seataConfig.remove(dataId);
-            zkClient.writeData(getConfigPath(), getSeataConfigStr());
+            createPersistent(getConfigPath(), getSeataConfigStr());
             return true;
         }
 
         FutureTask<Boolean> future = new FutureTask<>(() -> {
-            String path = ROOT_PATH + ZK_PATH_SPLIT_CHAR + dataId;
-            return zkClient.delete(path);
+            String path = buildPath(dataId);
+            return deletePath(path);
         });
         CONFIG_EXECUTOR.execute(future);
         try {
@@ -195,7 +265,18 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
             LOGGER.error("removeConfig {} is error or timeout, exception:{}", dataId, e.getMessage());
             return false;
         }
+    }
 
+    protected boolean deletePath(String path) {
+        try {
+            zkClient.delete().deletingChildrenIfNeeded().forPath(path);
+            return true;
+        } catch (KeeperException.NoNodeException ignored) {
+            return true;
+        } catch (Exception e) {
+            LOGGER.error("deletePath {} is error or timeout", path, e);
+            return false;
+        }
     }
 
     @Override
@@ -203,20 +284,21 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
         if (StringUtils.isBlank(dataId) || listener == null) {
             return;
         }
-
+        String path = buildPath(dataId);
         if (!seataConfig.isEmpty()) {
-            ZKListener zkListener = new ZKListener(dataId, listener);
-            CONFIG_LISTENERS_MAP.computeIfAbsent(dataId, key -> new ConcurrentHashMap<>())
+            NodeCacheListenerImpl zkListener = new NodeCacheListenerImpl(dataId, listener);
+            CuratorCacheListener.builder().forAll(zkListener).build();
+            CONFIG_LISTENERS_MAP
+                    .computeIfAbsent(dataId, key -> new ConcurrentHashMap<>())
                     .put(listener, zkListener);
             return;
         }
-
-        String path = ROOT_PATH + ZK_PATH_SPLIT_CHAR + dataId;
-        if (zkClient.exists(path)) {
-            ZKListener zkListener = new ZKListener(path, listener);
-            CONFIG_LISTENERS_MAP.computeIfAbsent(dataId, key -> new ConcurrentHashMap<>())
+        if (checkExists(path)) {
+            NodeCacheListenerImpl zkListener = new NodeCacheListenerImpl(path, listener);
+            CONFIG_LISTENERS_MAP
+                    .computeIfAbsent(dataId, key -> new ConcurrentHashMap<>())
                     .put(listener, zkListener);
-            zkClient.subscribeDataChanges(path, zkListener);
+            addDataListener(path, zkListener);
         }
     }
 
@@ -227,18 +309,19 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
         }
         Set<ConfigurationChangeListener> configChangeListeners = getConfigListeners(dataId);
         if (CollectionUtils.isNotEmpty(configChangeListeners)) {
-            String path = ROOT_PATH + ZK_PATH_SPLIT_CHAR + dataId;
-            if (zkClient.exists(path)) {
+            String path = buildPath(dataId);
+            if (checkExists(path)) {
                 for (ConfigurationChangeListener entry : configChangeListeners) {
                     if (listener.equals(entry)) {
-                        ZKListener zkListener = null;
-                        Map<ConfigurationChangeListener, ZKListener> configListeners = CONFIG_LISTENERS_MAP.get(dataId);
+                        NodeCacheListenerImpl zkListener = null;
+                        Map<ConfigurationChangeListener, NodeCacheListenerImpl> configListeners =
+                                CONFIG_LISTENERS_MAP.get(dataId);
                         if (configListeners != null) {
                             zkListener = configListeners.get(listener);
                             configListeners.remove(entry);
                         }
                         if (zkListener != null) {
-                            zkClient.unsubscribeDataChanges(path, zkListener);
+                            removeDataListener(path, zkListener);
                         }
                         break;
                     }
@@ -249,7 +332,8 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
 
     @Override
     public Set<ConfigurationChangeListener> getConfigListeners(String dataId) {
-        ConcurrentMap<ConfigurationChangeListener, ZKListener> configListeners = CONFIG_LISTENERS_MAP.get(dataId);
+        ConcurrentMap<ConfigurationChangeListener, NodeCacheListenerImpl> configListeners =
+                CONFIG_LISTENERS_MAP.get(dataId);
         if (CollectionUtils.isNotEmpty(configListeners)) {
             return configListeners.keySet();
         } else {
@@ -259,15 +343,14 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
 
     private void initSeataConfig() {
         String configPath = getConfigPath();
-        String config = zkClient.readData(configPath, true);
+        String config = readData(configPath);
         if (StringUtils.isNotBlank(config)) {
             try {
                 seataConfig = ConfigProcessor.processConfig(config, getZkDataType());
             } catch (IOException e) {
                 LOGGER.error("init config properties error", e);
             }
-            ZKListener zkListener = new ZKListener(configPath, null);
-            zkClient.subscribeDataChanges(configPath, zkListener);
+            addDataListener(configPath, new NodeCacheListenerImpl(configPath, null));
         }
     }
 
@@ -292,28 +375,25 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
         return sb.toString();
     }
 
-    /**
-     * The type Zk listener.
-     */
-    public static class ZKListener implements IZkDataListener {
-
+    public static class NodeCacheListenerImpl implements CuratorCacheListener {
         private String path;
         private ConfigurationChangeListener listener;
 
-        /**
-         * Instantiates a new Zk listener.
-         *
-         * @param path     the path
-         * @param listener the listener
-         */
-        public ZKListener(String path, ConfigurationChangeListener listener) {
+        public NodeCacheListenerImpl(String path, ConfigurationChangeListener listener) {
             this.path = path;
             this.listener = listener;
         }
 
         @Override
-        public void handleDataChange(String s, Object o) {
-            if (s.equals(getConfigPath())) {
+        public void event(Type type, ChildData oldData, ChildData data) {
+
+            String o;
+            if (type == Type.NODE_DELETED) {
+                o = "";
+            } else {
+                o = new String(data.getData());
+            }
+            if (path.equals(getConfigPath())) {
                 Properties seataConfigNew = new Properties();
                 if (StringUtils.isNotBlank(o.toString())) {
                     try {
@@ -325,7 +405,8 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
                     }
                 }
 
-                for (Map.Entry<String, ConcurrentMap<ConfigurationChangeListener, ZKListener>> entry : CONFIG_LISTENERS_MAP.entrySet()) {
+                for (Map.Entry<String, ConcurrentMap<ConfigurationChangeListener, NodeCacheListenerImpl>> entry :
+                        CONFIG_LISTENERS_MAP.entrySet()) {
                     String listenedDataId = entry.getKey();
                     String propertyOld = seataConfig.getProperty(listenedDataId, "");
                     String propertyNew = seataConfigNew.getProperty(listenedDataId, "");
@@ -335,7 +416,8 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
                                 .setNewValue(propertyNew)
                                 .setChangeType(ConfigurationChangeType.MODIFY);
 
-                        ConcurrentMap<ConfigurationChangeListener, ZKListener> configListeners = entry.getValue();
+                        ConcurrentMap<ConfigurationChangeListener, NodeCacheListenerImpl> configListeners =
+                                entry.getValue();
                         for (ConfigurationChangeListener configListener : configListeners.keySet()) {
                             configListener.onProcessEvent(event);
                         }
@@ -344,42 +426,45 @@ public class ZookeeperConfiguration extends AbstractConfiguration {
                 seataConfig = seataConfigNew;
 
                 return;
+            } else {
+                if (type == Type.NODE_DELETED) {
+                    // Node is deleted.
+                    String dataId = path.replaceFirst(ROOT_PATH + ZK_PATH_SPLIT_CHAR, "");
+                    ConfigurationChangeEvent event = new ConfigurationChangeEvent()
+                            .setDataId(dataId)
+                            .setChangeType(ConfigurationChangeType.DELETE);
+                    listener.onProcessEvent(event);
+                } else {
+                    // Node is changed.
+                    String dataId = path.replaceFirst(ROOT_PATH + ZK_PATH_SPLIT_CHAR, "");
+                    ConfigurationChangeEvent event = new ConfigurationChangeEvent()
+                            .setDataId(dataId)
+                            .setNewValue(o.toString())
+                            .setChangeType(ConfigurationChangeType.MODIFY);
+                    listener.onProcessEvent(event);
+                }
             }
-            String dataId = s.replaceFirst(ROOT_PATH + ZK_PATH_SPLIT_CHAR, "");
-            ConfigurationChangeEvent event = new ConfigurationChangeEvent().setDataId(dataId).setNewValue(o.toString())
-                .setChangeType(ConfigurationChangeType.MODIFY);
-            listener.onProcessEvent(event);
-        }
-
-        @Override
-        public void handleDataDeleted(String s) {
-            String dataId = s.replaceFirst(ROOT_PATH + ZK_PATH_SPLIT_CHAR, "");
-            ConfigurationChangeEvent event = new ConfigurationChangeEvent().setDataId(dataId).setChangeType(
-                    ConfigurationChangeType.DELETE);
-            listener.onProcessEvent(event);
         }
     }
 
-    private ZkSerializer getZkSerializer() {
-        ZkSerializer zkSerializer = null;
-        String serializer = FILE_CONFIG.getConfig(FILE_CONFIG_KEY_PREFIX + SERIALIZER_KEY);
-        if (StringUtils.isNotBlank(serializer)) {
-            try {
-                Class<?> clazz = Class.forName(serializer);
-                Constructor<?> constructor = clazz.getDeclaredConstructor();
-                constructor.setAccessible(true);
-                zkSerializer = (ZkSerializer) constructor.newInstance();
-            } catch (ClassNotFoundException cfe) {
-                LOGGER.warn("No zk serializer class found, serializer:{}", serializer, cfe);
-            } catch (Throwable cause) {
-                LOGGER.warn("found zk serializer encountered an unknown exception", cause);
+    protected void addDataListener(String path, NodeCacheListenerImpl nodeCacheListener) {
+        try {
+            CuratorCache nodeCache = CuratorCache.build(zkClient, path);
+            if (nodeCacheMap.putIfAbsent(path, nodeCache) != null) {
+                return;
             }
+            nodeCache.listenable().addListener(nodeCacheListener);
+            nodeCache.start();
+        } catch (Exception e) {
+            throw new IllegalStateException("Add nodeCache listener for path:" + path, e);
         }
-        if (zkSerializer == null) {
-            zkSerializer = new DefaultZkSerializer();
-            LOGGER.info("Use default zk serializer: org.apache.seata.config.zk.DefaultZkSerializer.");
-        }
-        return zkSerializer;
     }
 
+    protected void removeDataListener(String path, NodeCacheListenerImpl nodeCacheListener) {
+        CuratorCache nodeCache = nodeCacheMap.get(path);
+        if (nodeCache != null) {
+            nodeCache.listenable().removeListener(nodeCacheListener);
+        }
+        nodeCacheListener.listener = null;
+    }
 }
