@@ -16,20 +16,6 @@
  */
 package org.apache.seata.core.rpc.netty;
 
-import java.io.IOException;
-import java.lang.management.ManagementFactory;
-import java.net.SocketAddress;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ExecutorService;
-import java.util.concurrent.RejectedExecutionException;
-import java.util.concurrent.ScheduledExecutorService;
-import java.util.concurrent.ScheduledThreadPoolExecutor;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.TimeoutException;
 import io.netty.channel.Channel;
 import io.netty.channel.ChannelFutureListener;
 import io.netty.channel.ChannelHandlerContext;
@@ -53,6 +39,21 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.MDC;
 
+import java.io.IOException;
+import java.lang.management.ManagementFactory;
+import java.net.SocketAddress;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ExecutorService;
+import java.util.concurrent.RejectedExecutionException;
+import java.util.concurrent.ScheduledExecutorService;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.TimeoutException;
+
 /**
  * The abstract netty remoting.
  *
@@ -64,8 +65,8 @@ public abstract class AbstractNettyRemoting implements Disposable {
     /**
      * The Timer executor.
      */
-    protected final ScheduledExecutorService timerExecutor = new ScheduledThreadPoolExecutor(1,
-        new NamedThreadFactory("timeoutChecker", 1, true));
+    protected final ScheduledExecutorService timerExecutor =
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory("timeoutChecker", 1, true));
     /**
      * The Message executor.
      */
@@ -89,42 +90,54 @@ public abstract class AbstractNettyRemoting implements Disposable {
      * The Now mills.
      */
     protected volatile long nowMills = 0;
+
     private static final int TIMEOUT_CHECK_INTERVAL = 3000;
     protected final Object lock = new Object();
     /**
      * The Is sending.
      */
     protected volatile boolean isSending = false;
+
     private String group = "DEFAULT";
 
     /**
      * This container holds all processors.
      * processor type {@link MessageType}
      */
-    protected final HashMap<Integer/*MessageType*/, Pair<RemotingProcessor, ExecutorService>> processorTable = new HashMap<>(32);
+    protected final HashMap<Integer /*MessageType*/, Pair<RemotingProcessor, ExecutorService>> processorTable =
+            new HashMap<>(32);
 
     protected final List<RpcHook> rpcHooks = EnhancedServiceLoader.loadAll(RpcHook.class);
 
     public void init() {
-        timerExecutor.scheduleAtFixedRate(new Runnable() {
-            @Override
-            public void run() {
-                for (Map.Entry<Integer, MessageFuture> entry : futures.entrySet()) {
-                    MessageFuture future = entry.getValue();
-                    if (future.isTimeout()) {
-                        futures.remove(entry.getKey());
-                        RpcMessage rpcMessage = future.getRequestMessage();
-                        future.setResultMessage(new TimeoutException(String
-                            .format("msgId: %s ,msgType: %s ,msg: %s ,request timeout", rpcMessage.getId(), String.valueOf(rpcMessage.getMessageType()), rpcMessage.getBody().toString())));
-                        if (LOGGER.isDebugEnabled()) {
-                            LOGGER.debug("timeout clear future: {}", entry.getValue().getRequestMessage().getBody());
+        timerExecutor.scheduleAtFixedRate(
+                new Runnable() {
+                    @Override
+                    public void run() {
+                        for (Map.Entry<Integer, MessageFuture> entry : futures.entrySet()) {
+                            MessageFuture future = entry.getValue();
+                            if (future.isTimeout()) {
+                                futures.remove(entry.getKey());
+                                RpcMessage rpcMessage = future.getRequestMessage();
+                                future.setResultMessage(new TimeoutException(String.format(
+                                        "msgId: %s ,msgType: %s ,msg: %s ,request timeout",
+                                        rpcMessage.getId(),
+                                        String.valueOf(rpcMessage.getMessageType()),
+                                        rpcMessage.getBody().toString())));
+                                if (LOGGER.isDebugEnabled()) {
+                                    LOGGER.debug(
+                                            "timeout clear future: {}",
+                                            entry.getValue().getRequestMessage().getBody());
+                                }
+                            }
                         }
-                    }
-                }
 
-                nowMills = System.currentTimeMillis();
-            }
-        }, TIMEOUT_CHECK_INTERVAL, TIMEOUT_CHECK_INTERVAL, TimeUnit.MILLISECONDS);
+                        nowMills = System.currentTimeMillis();
+                    }
+                },
+                TIMEOUT_CHECK_INTERVAL,
+                TIMEOUT_CHECK_INTERVAL,
+                TimeUnit.MILLISECONDS);
     }
 
     public AbstractNettyRemoting(ThreadPoolExecutor messageExecutor) {
@@ -177,7 +190,8 @@ public abstract class AbstractNettyRemoting implements Disposable {
         }
         if (MsgVersionHelper.versionNotSupport(channel, rpcMessage)) {
             if (LOGGER.isDebugEnabled()) {
-                LOGGER.debug("Message sending will be skipped as the client version does not support it,{}", rpcMessage);
+                LOGGER.debug(
+                        "Message sending will be skipped as the client version does not support it,{}", rpcMessage);
             }
             return new VersionNotSupportMessage();
         }
@@ -207,8 +221,11 @@ public abstract class AbstractNettyRemoting implements Disposable {
             doAfterRpcHooks(remoteAddr, rpcMessage, result);
             return result;
         } catch (Exception exx) {
-            LOGGER.error("wait response error:{},ip:{},request:{}", exx.getMessage(), channel.remoteAddress(),
-                rpcMessage.getBody());
+            LOGGER.error(
+                    "wait response error:{},ip:{},request:{}",
+                    exx.getMessage(),
+                    channel.remoteAddress(),
+                    rpcMessage.getBody());
             if (exx instanceof TimeoutException) {
                 throw (TimeoutException) exx;
             } else {
@@ -226,14 +243,15 @@ public abstract class AbstractNettyRemoting implements Disposable {
     protected void sendAsync(Channel channel, RpcMessage rpcMessage) {
         if (MsgVersionHelper.versionNotSupport(channel, rpcMessage)) {
             if (LOGGER.isDebugEnabled()) {
-                LOGGER.debug("Message sending will be skipped as the client version does not support it,{}", rpcMessage);
+                LOGGER.debug(
+                        "Message sending will be skipped as the client version does not support it,{}", rpcMessage);
             }
             return;
         }
         channelWritableCheck(channel, rpcMessage.getBody());
         if (LOGGER.isDebugEnabled()) {
             LOGGER.debug("write message:" + rpcMessage.getBody() + ", channel:" + channel + ",active?"
-                + channel.isActive() + ",writable?" + channel.isWritable() + ",isopen?" + channel.isOpen());
+                    + channel.isActive() + ",writable?" + channel.isWritable() + ",isopen?" + channel.isOpen());
         }
 
         doBeforeRpcHooks(ChannelUtil.getAddressFromChannel(channel), rpcMessage);
@@ -285,7 +303,8 @@ public abstract class AbstractNettyRemoting implements Disposable {
         Object body = rpcMessage.getBody();
         if (body instanceof MessageTypeAware) {
             MessageTypeAware messageTypeAware = (MessageTypeAware) body;
-            final Pair<RemotingProcessor, ExecutorService> pair = this.processorTable.get((int) messageTypeAware.getTypeCode());
+            final Pair<RemotingProcessor, ExecutorService> pair =
+                    this.processorTable.get((int) messageTypeAware.getTypeCode());
             if (pair != null) {
                 if (pair.getSecond() != null) {
                     try {
@@ -299,8 +318,9 @@ public abstract class AbstractNettyRemoting implements Disposable {
                             }
                         });
                     } catch (RejectedExecutionException e) {
-                        LOGGER.error(FrameworkErrorCode.ThreadPoolFull.getErrCode(),
-                            "thread pool is full, current max pool size is " + messageExecutor.getActiveCount());
+                        LOGGER.error(
+                                FrameworkErrorCode.ThreadPoolFull.getErrCode(),
+                                "thread pool is full, current max pool size is " + messageExecutor.getActiveCount());
                         if (allowDumpStack) {
                             String name = ManagementFactory.getRuntimeMXBean().getName();
                             String pid = name.split("@")[0];
@@ -350,7 +370,9 @@ public abstract class AbstractNettyRemoting implements Disposable {
         SocketAddress socketAddress = channel.remoteAddress();
         String address = socketAddress.toString();
         if (socketAddress.toString().indexOf(NettyClientConfig.getSocketAddressStartChar()) == 0) {
-            address = socketAddress.toString().substring(NettyClientConfig.getSocketAddressStartChar().length());
+            address = socketAddress
+                    .toString()
+                    .substring(NettyClientConfig.getSocketAddressStartChar().length());
         }
         return address;
     }
@@ -363,8 +385,9 @@ public abstract class AbstractNettyRemoting implements Disposable {
                     tryTimes++;
                     if (tryTimes > NettyClientConfig.getMaxNotWriteableRetry()) {
                         destroyChannel(channel);
-                        throw new FrameworkException("msg:" + ((msg == null) ? "null" : msg.toString()),
-                            FrameworkErrorCode.ChannelIsNotWritable);
+                        throw new FrameworkException(
+                                "msg:" + ((msg == null) ? "null" : msg.toString()),
+                                FrameworkErrorCode.ChannelIsNotWritable);
                     }
                     lock.wait(NOT_WRITEABLE_CHECK_MILLS);
                 } catch (InterruptedException exx) {
@@ -383,13 +406,13 @@ public abstract class AbstractNettyRemoting implements Disposable {
     public abstract void destroyChannel(String serverAddress, Channel channel);
 
     protected void doBeforeRpcHooks(String remoteAddr, RpcMessage request) {
-        for (RpcHook rpcHook: rpcHooks) {
+        for (RpcHook rpcHook : rpcHooks) {
             rpcHook.doBeforeRequest(remoteAddr, request);
         }
     }
 
     protected void doAfterRpcHooks(String remoteAddr, RpcMessage request, Object response) {
-        for (RpcHook rpcHook: rpcHooks) {
+        for (RpcHook rpcHook : rpcHooks) {
             rpcHook.doAfterResponse(remoteAddr, request, response);
         }
     }
