@@ -46,17 +46,25 @@ public class LockStoreSqlFactoryTest {
 
     private static String BRANCH_TABLE = "branch_table";
 
-    private static String EXPECT_CHECK_GLOBAL_LOCKABLE_SQL = "select xid, transaction_id, branch_id, resource_id, table_name, pk, row_key, gmt_create, gmt_modified,status from " + GLOBAL_TABLE + " where row_key in ( ?,?,? ) order by status desc ";
+    private static String EXPECT_CHECK_GLOBAL_LOCKABLE_SQL =
+            "select xid, transaction_id, branch_id, resource_id, table_name, pk, row_key, gmt_create, gmt_modified,status from "
+                    + GLOBAL_TABLE + " where row_key in ( ?,?,? ) order by status desc ";
 
-    private static String EXPECT_CHECK_BRANCH_LOCKABLE_SQL = "select xid, transaction_id, branch_id, resource_id, table_name, pk, row_key, gmt_create, gmt_modified,status from " + BRANCH_TABLE + " where row_key in ( ?,?,? ) order by status desc ";
+    private static String EXPECT_CHECK_BRANCH_LOCKABLE_SQL =
+            "select xid, transaction_id, branch_id, resource_id, table_name, pk, row_key, gmt_create, gmt_modified,status from "
+                    + BRANCH_TABLE + " where row_key in ( ?,?,? ) order by status desc ";
 
-    private static String EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL = "delete from " + GLOBAL_TABLE + " where xid = ? and (row_key in ( ?,?,? )) ";
+    private static String EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL =
+            "delete from " + GLOBAL_TABLE + " where xid = ? and (row_key in ( ?,?,? )) ";
 
-    private static String EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL = "delete from " + BRANCH_TABLE + " where xid = ? and (row_key in ( ?,?,? )) ";
+    private static String EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL =
+            "delete from " + BRANCH_TABLE + " where xid = ? and (row_key in ( ?,?,? )) ";
 
-    private static String EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL = "delete from " + GLOBAL_TABLE + " where xid = ? ";
+    private static String EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL =
+            "delete from " + GLOBAL_TABLE + " where xid = ? ";
 
-    private static String EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL = "delete from " + BRANCH_TABLE + " where xid = ? ";
+    private static String EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL =
+            "delete from " + BRANCH_TABLE + " where xid = ? ";
 
     @Test
     public void mysqlLockTest() {
@@ -75,9 +83,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = MYSQL_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = MYSQL_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = MYSQL_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -87,9 +95,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = MYSQL_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = MYSQL_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = MYSQL_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -99,10 +107,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = MYSQL_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = MYSQL_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
-
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
     @Test
@@ -122,9 +129,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = MARIADB_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = MARIADB_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = MARIADB_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -134,9 +141,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = MARIADB_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = MARIADB_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = MARIADB_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -146,10 +153,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = MARIADB_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = MARIADB_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
-
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
     @Test
@@ -169,9 +175,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = ORACLE_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = ORACLE_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = ORACLE_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -181,9 +187,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = ORACLE_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = ORACLE_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = ORACLE_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -193,9 +199,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = ORACLE_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = ORACLE_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
     @Test
@@ -215,9 +221,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = POSTGRESQL_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = POSTGRESQL_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = POSTGRESQL_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -227,9 +233,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = POSTGRESQL_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = POSTGRESQL_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = POSTGRESQL_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -239,9 +245,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = POSTGRESQL_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = POSTGRESQL_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
     @Test
@@ -261,9 +267,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = H2_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = H2_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = H2_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -273,9 +279,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = H2_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = H2_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = H2_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -285,9 +291,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = H2_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = H2_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
     @Test
@@ -307,9 +313,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = OCEANBASE_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = OCEANBASE_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = OCEANBASE_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -319,9 +325,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = OCEANBASE_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = OCEANBASE_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = OCEANBASE_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -331,9 +337,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = OCEANBASE_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = OCEANBASE_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
     @Test
@@ -353,9 +359,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = DM_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = DM_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = DM_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -365,9 +371,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = DM_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = DM_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = DM_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -377,12 +383,11 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = DM_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = DM_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 
-
     @Test
     public void oscarLockTest() {
         String sql;
@@ -400,9 +405,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = OSCAR_LOCK_STORE.getBatchDeleteLockSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_SQL, sql);
         sql = OSCAR_LOCK_STORE.getBatchDeleteLockSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_SQL, sql);
 
         // Get batch delete lock sql string.
         sql = OSCAR_LOCK_STORE.getBatchDeleteLockSqlByBranchId(GLOBAL_TABLE);
@@ -412,9 +417,9 @@ public class LockStoreSqlFactoryTest {
 
         // Get batch delete lock sql string.
         sql = OSCAR_LOCK_STORE.getBatchDeleteLockSqlByXid(GLOBAL_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_GLOBAL_DELETE_LOCK_BY_BRANCHS_SQL, sql);
         sql = OSCAR_LOCK_STORE.getBatchDeleteLockSqlByXid(BRANCH_TABLE);
-        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL,sql);
+        Assertions.assertEquals(EXPECT_BATCH_BRANCH_DELETE_LOCK_BY_BRANCHS_SQL, sql);
 
         // Get query lock sql string.
         sql = OSCAR_LOCK_STORE.getQueryLockSql(GLOBAL_TABLE);
@@ -424,8 +429,8 @@ public class LockStoreSqlFactoryTest {
 
         // Get check lock sql string.
         sql = OSCAR_LOCK_STORE.getCheckLockableSql(GLOBAL_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_GLOBAL_LOCKABLE_SQL, sql);
         sql = OSCAR_LOCK_STORE.getCheckLockableSql(BRANCH_TABLE, 3);
-        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL,sql);
+        Assertions.assertEquals(EXPECT_CHECK_BRANCH_LOCKABLE_SQL, sql);
     }
 }
