@@ -16,6 +16,24 @@
  */
 package org.apache.seata.discovery.registry.consul;
 
+import com.ecwid.consul.v1.ConsulClient;
+import com.ecwid.consul.v1.QueryParams;
+import com.ecwid.consul.v1.Response;
+import com.ecwid.consul.v1.agent.model.NewService;
+import com.ecwid.consul.v1.health.HealthServicesRequest;
+import com.ecwid.consul.v1.health.model.HealthService;
+import org.apache.seata.common.thread.NamedThreadFactory;
+import org.apache.seata.common.util.NetUtil;
+import org.apache.seata.common.util.StringUtils;
+import org.apache.seata.config.Configuration;
+import org.apache.seata.config.ConfigurationFactory;
+import org.apache.seata.config.ConfigurationKeys;
+import org.apache.seata.config.exception.ConfigNotFoundException;
+import org.apache.seata.discovery.registry.RegistryHeartBeats;
+import org.apache.seata.discovery.registry.RegistryService;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import java.net.InetSocketAddress;
 import java.util.Collections;
 import java.util.HashSet;
@@ -29,27 +47,6 @@ import java.util.concurrent.ThreadPoolExecutor;
 import java.util.concurrent.TimeUnit;
 import java.util.stream.Collectors;
 
-import org.apache.seata.config.exception.ConfigNotFoundException;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import com.ecwid.consul.v1.ConsulClient;
-import com.ecwid.consul.v1.QueryParams;
-import com.ecwid.consul.v1.Response;
-import com.ecwid.consul.v1.agent.model.NewService;
-import com.ecwid.consul.v1.health.HealthServicesRequest;
-import com.ecwid.consul.v1.health.model.HealthService;
-
-import org.apache.seata.common.thread.NamedThreadFactory;
-import org.apache.seata.common.util.NetUtil;
-import org.apache.seata.common.util.StringUtils;
-import org.apache.seata.config.Configuration;
-import org.apache.seata.config.ConfigurationFactory;
-import org.apache.seata.config.ConfigurationKeys;
-import org.apache.seata.discovery.registry.RegistryHeartBeats;
-import org.apache.seata.discovery.registry.RegistryService;
-
-
 public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener> {
 
     private static volatile ConsulRegistryServiceImpl instance;
@@ -65,7 +62,8 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
     private static final String DEFAULT_CLUSTER_NAME = "default";
     private static final String SERVICE_TAG = "services";
     private static final String ACL_TOKEN = "aclToken";
-    private static final String FILE_CONFIG_KEY_PREFIX = FILE_ROOT_REGISTRY + FILE_CONFIG_SPLIT_CHAR + REGISTRY_TYPE + FILE_CONFIG_SPLIT_CHAR;
+    private static final String FILE_CONFIG_KEY_PREFIX =
+            FILE_ROOT_REGISTRY + FILE_CONFIG_SPLIT_CHAR + REGISTRY_TYPE + FILE_CONFIG_SPLIT_CHAR;
 
     private ConcurrentMap<String, List<InetSocketAddress>> clusterAddressMap;
     private ConcurrentMap<String, Set<ConsulListener>> listenerMap;
@@ -94,14 +92,17 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
      */
     private static final int DEFAULT_WATCH_TIMEOUT = 60;
 
-
     private ConsulRegistryServiceImpl() {
-        //initial the capacity with 8
+        // initial the capacity with 8
         clusterAddressMap = new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
         listenerMap = new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
         notifiers = new ConcurrentHashMap<>(MAP_INITIAL_CAPACITY);
-        notifierExecutor = new ThreadPoolExecutor(THREAD_POOL_NUM, THREAD_POOL_NUM,
-                Integer.MAX_VALUE, TimeUnit.MILLISECONDS, new LinkedBlockingQueue<>(),
+        notifierExecutor = new ThreadPoolExecutor(
+                THREAD_POOL_NUM,
+                THREAD_POOL_NUM,
+                Integer.MAX_VALUE,
+                TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(),
                 new NamedThreadFactory("services-consul-notifier", THREAD_POOL_NUM));
     }
 
@@ -140,23 +141,22 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
 
     @Override
     public void subscribe(String cluster, ConsulListener listener) throws Exception {
-        //1.add listener to subscribe list
-        listenerMap.computeIfAbsent(cluster, key -> new HashSet<>())
-                .add(listener);
-        //2.get healthy services
+        // 1.add listener to subscribe list
+        listenerMap.computeIfAbsent(cluster, key -> new HashSet<>()).add(listener);
+        // 2.get healthy services
         Response<List<HealthService>> response = getHealthyServices(cluster, -1, DEFAULT_WATCH_TIMEOUT);
-        //3.get current consul index.
+        // 3.get current consul index.
         Long index = response.getConsulIndex();
         ConsulNotifier notifier = notifiers.computeIfAbsent(cluster, key -> new ConsulNotifier(cluster, index));
-        //4.run notifier
+        // 4.run notifier
         notifierExecutor.submit(notifier);
     }
 
     @Override
     public void unsubscribe(String cluster, ConsulListener listener) throws Exception {
-        //1.remove notifier for the cluster
+        // 1.remove notifier for the cluster
         ConsulNotifier notifier = notifiers.remove(cluster);
-        //2.stop the notifier
+        // 2.stop the notifier
         notifier.stop();
     }
 
@@ -173,9 +173,9 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
 
     private List<InetSocketAddress> lookupByCluster(String cluster) throws Exception {
         if (!listenerMap.containsKey(cluster)) {
-            //1.refresh cluster
+            // 1.refresh cluster
             refreshCluster(cluster);
-            //2. subscribe
+            // 2. subscribe
             subscribe(cluster, services -> refreshCluster(cluster, services));
         }
         return clusterAddressMap.get(cluster);
@@ -205,7 +205,8 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
      * @return
      */
     private String getClusterName() {
-        String clusterConfigName = String.join(FILE_CONFIG_SPLIT_CHAR, FILE_ROOT_REGISTRY, REGISTRY_TYPE, REGISTRY_CLUSTER);
+        String clusterConfigName =
+                String.join(FILE_CONFIG_SPLIT_CHAR, FILE_ROOT_REGISTRY, REGISTRY_TYPE, REGISTRY_CLUSTER);
         return FILE_CONFIG.getConfig(clusterConfigName, DEFAULT_CLUSTER_NAME);
     }
 
@@ -225,8 +226,13 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
      * @return acl-token
      */
     private static String getAclToken() {
-        String fileConfigKey = String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, ACL_TOKEN);
-        String aclToken = StringUtils.isNotBlank(System.getProperty(ACL_TOKEN)) ? System.getProperty(ACL_TOKEN)
+        String fileConfigKey = String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                ACL_TOKEN);
+        String aclToken = StringUtils.isNotBlank(System.getProperty(ACL_TOKEN))
+                ? System.getProperty(ACL_TOKEN)
                 : FILE_CONFIG.getConfig(fileConfigKey);
         return StringUtils.isNotBlank(aclToken) ? aclToken : null;
     }
@@ -270,12 +276,15 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
      * @return
      */
     private Response<List<HealthService>> getHealthyServices(String service, long index, long watchTimeout) {
-        return getConsulClient().getHealthServices(service, HealthServicesRequest.newBuilder()
-                .setTag(SERVICE_TAG)
-                .setQueryParams(new QueryParams(watchTimeout, index))
-                .setPassing(true)
-                .setToken(getAclToken())
-                .build());
+        return getConsulClient()
+                .getHealthServices(
+                        service,
+                        HealthServicesRequest.newBuilder()
+                                .setTag(SERVICE_TAG)
+                                .setQueryParams(new QueryParams(watchTimeout, index))
+                                .setPassing(true)
+                                .setToken(getAclToken())
+                                .build());
     }
 
     /**
@@ -350,7 +359,7 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
             if ((currentIndex != null && currentIndex > consulIndex) || hasError) {
                 hasError = false;
                 List<HealthService> services = response.getValue();
-                consulIndex = currentIndex;/*lgtm[java/dereferenced-value-may-be-null]*/
+                consulIndex = currentIndex; /*lgtm[java/dereferenced-value-may-be-null]*/
                 for (ConsulListener listener : listenerMap.get(cluster)) {
                     listener.onEvent(services);
                 }
@@ -364,7 +373,23 @@ public class ConsulRegistryServiceImpl implements RegistryService<ConsulListener
 
     @Override
     public void close() throws Exception {
-        client = null;
-    }
+        notifiers.values().forEach(ConsulNotifier::stop);
+        notifiers.clear();
 
+        // Shut down the ThreadPoolExecutor
+        if (notifierExecutor != null && !notifierExecutor.isShutdown()) {
+            notifierExecutor.shutdown();
+            try {
+                if (!notifierExecutor.awaitTermination(5, TimeUnit.SECONDS)) {
+                    notifierExecutor.shutdownNow();
+                }
+            } catch (InterruptedException e) {
+                notifierExecutor.shutdownNow();
+            } finally {
+                notifierExecutor = null;
+            }
+        }
+
+        RegistryHeartBeats.close(REGISTRY_TYPE);
+    }
 }
