@@ -176,8 +176,8 @@ public class LoadBalanceTest {
      * @param loadBalance the load balance
      * @return the selected counter
      */
-    public Map<InetSocketAddress, AtomicLong> getSelectedCounter(int runs, List<InetSocketAddress> addresses,
-                                                                 LoadBalance loadBalance) {
+    public Map<InetSocketAddress, AtomicLong> getSelectedCounter(
+            int runs, List<InetSocketAddress> addresses, LoadBalance loadBalance) {
         Assertions.assertNotNull(loadBalance);
         Map<InetSocketAddress, AtomicLong> counter = new ConcurrentHashMap<>();
         for (InetSocketAddress address : addresses) {
@@ -189,7 +189,7 @@ public class LoadBalanceTest {
                 counter.get(selectAddress).incrementAndGet();
             }
         } catch (Exception e) {
-            //do nothing
+            // do nothing
         }
         return counter;
     }
@@ -216,13 +216,12 @@ public class LoadBalanceTest {
      * @return Stream<List < InetSocketAddress>>
      */
     static Stream<List<InetSocketAddress>> addressProvider() {
-        return Stream.of(
-                Arrays.asList(new InetSocketAddress("127.0.0.1", 8091),
-                        new InetSocketAddress("127.0.0.1", 8092),
-                        new InetSocketAddress("127.0.0.1", 8093),
-                        new InetSocketAddress("127.0.0.1", 8094),
-                        new InetSocketAddress("127.0.0.1", 8095),
-                        new InetSocketAddress("2000:0000:0000:0000:0001:2345:6789:abcd", 8092))
-        );
+        return Stream.of(Arrays.asList(
+                new InetSocketAddress("127.0.0.1", 8091),
+                new InetSocketAddress("127.0.0.1", 8092),
+                new InetSocketAddress("127.0.0.1", 8093),
+                new InetSocketAddress("127.0.0.1", 8094),
+                new InetSocketAddress("127.0.0.1", 8095),
+                new InetSocketAddress("2000:0000:0000:0000:0001:2345:6789:abcd", 8092)));
     }
 }
