@@ -16,16 +16,6 @@
  */
 package org.apache.seata.discovery.registry.nacos;
 
-import java.net.InetSocketAddress;
-import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.List;
-import java.util.Properties;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
-import java.util.regex.Pattern;
-import java.util.stream.Collectors;
-
 import com.alibaba.nacos.api.NacosFactory;
 import com.alibaba.nacos.api.naming.NamingMaintainService;
 import com.alibaba.nacos.api.naming.NamingService;
@@ -44,10 +34,18 @@ import org.apache.seata.discovery.registry.RegistryService;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.net.InetSocketAddress;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.List;
+import java.util.Properties;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+import java.util.regex.Pattern;
+import java.util.stream.Collectors;
 
 /**
  * The type Nacos registry service.
- *
  */
 public class NacosRegistryServiceImpl implements RegistryService<EventListener> {
 
@@ -81,7 +79,8 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
     private static volatile NacosRegistryServiceImpl instance;
     private static volatile NamingMaintainService namingMaintain;
     private static final Object LOCK_OBJ = new Object();
-    private static final Pattern DEFAULT_SLB_REGISTRY_PATTERN = Pattern.compile("(?!.*internal)(?=.*seata).*mse.aliyuncs.com");
+    private static final Pattern DEFAULT_SLB_REGISTRY_PATTERN =
+            Pattern.compile("(?!.*internal)(?=.*seata).*mse.aliyuncs.com");
     private static volatile Boolean useSLBWay;
 
     private String transactionServiceGroup;
@@ -91,7 +90,9 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
         Pattern patternOfNacosRegistryForSLB = StringUtils.isBlank(configForNacosSLB)
                 ? DEFAULT_SLB_REGISTRY_PATTERN
                 : Pattern.compile(configForNacosSLB);
-        useSLBWay = patternOfNacosRegistryForSLB.matcher(getNamingProperties().getProperty(PRO_SERVER_ADDR_KEY)).matches();
+        useSLBWay = patternOfNacosRegistryForSLB
+                .matcher(getNamingProperties().getProperty(PRO_SERVER_ADDR_KEY))
+                .matches();
     }
 
     /**
@@ -113,21 +114,32 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
     @Override
     public void register(InetSocketAddress address) throws Exception {
         NetUtil.validAddress(address);
-        getNamingInstance().registerInstance(getServiceName(), getServiceGroup(), address.getAddress().getHostAddress(), address.getPort(), getClusterName());
+        getNamingInstance()
+                .registerInstance(
+                        getServiceName(),
+                        getServiceGroup(),
+                        address.getAddress().getHostAddress(),
+                        address.getPort(),
+                        getClusterName());
     }
 
     @Override
     public void unregister(InetSocketAddress address) throws Exception {
         NetUtil.validAddress(address);
-        getNamingInstance().deregisterInstance(getServiceName(), getServiceGroup(), address.getAddress().getHostAddress(), address.getPort(), getClusterName());
+        getNamingInstance()
+                .deregisterInstance(
+                        getServiceName(),
+                        getServiceGroup(),
+                        address.getAddress().getHostAddress(),
+                        address.getPort(),
+                        getClusterName());
     }
 
     @Override
     public void subscribe(String cluster, EventListener listener) throws Exception {
         List<String> clusters = new ArrayList<>();
         clusters.add(cluster);
-        LISTENER_SERVICE_MAP.computeIfAbsent(cluster, key -> new ArrayList<>())
-                .add(listener);
+        LISTENER_SERVICE_MAP.computeIfAbsent(cluster, key -> new ArrayList<>()).add(listener);
         getNamingInstance().subscribe(getServiceName(), getServiceGroup(), clusters, listener);
     }
 
@@ -164,8 +176,7 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
                 if (StringUtils.isBlank(pubnetIp) || StringUtils.isBlank(pubnetPort)) {
                     throw new Exception("cannot find service address from nacos naming mata-data");
                 }
-                InetSocketAddress publicAddress = new InetSocketAddress(pubnetIp,
-                        Integer.valueOf(pubnetPort));
+                InetSocketAddress publicAddress = new InetSocketAddress(pubnetIp, Integer.valueOf(pubnetPort));
                 List<InetSocketAddress> publicAddressList = Arrays.asList(publicAddress);
                 CLUSTER_ADDRESS_MAP.put(PUBLIC_NAMING_ADDRESS_PREFIX + clusterName, publicAddressList);
                 return publicAddressList;
@@ -177,11 +188,13 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
                 if (!LISTENER_SERVICE_MAP.containsKey(clusterName)) {
                     List<String> clusters = new ArrayList<>();
                     clusters.add(clusterName);
-                    List<Instance> firstAllInstances = getNamingInstance().getAllInstances(getServiceName(), getServiceGroup(), clusters);
+                    List<Instance> firstAllInstances =
+                            getNamingInstance().getAllInstances(getServiceName(), getServiceGroup(), clusters);
                     if (null != firstAllInstances) {
                         List<InetSocketAddress> newAddressList = firstAllInstances.stream()
                                 .filter(eachInstance -> eachInstance.isEnabled() && eachInstance.isHealthy())
-                                .map(eachInstance -> new InetSocketAddress(eachInstance.getIp(), eachInstance.getPort()))
+                                .map(eachInstance ->
+                                        new InetSocketAddress(eachInstance.getIp(), eachInstance.getPort()))
                                 .collect(Collectors.toList());
                         CLUSTER_ADDRESS_MAP.put(clusterName, newAddressList);
                     }
@@ -192,7 +205,8 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
                         } else {
                             List<InetSocketAddress> newAddressList = instances.stream()
                                     .filter(eachInstance -> eachInstance.isEnabled() && eachInstance.isHealthy())
-                                    .map(eachInstance -> new InetSocketAddress(eachInstance.getIp(), eachInstance.getPort()))
+                                    .map(eachInstance ->
+                                            new InetSocketAddress(eachInstance.getIp(), eachInstance.getPort()))
                                     .collect(Collectors.toList());
                             CLUSTER_ADDRESS_MAP.put(clusterName, newAddressList);
                             if (StringUtils.isNotEmpty(transactionServiceGroup)) {
@@ -208,7 +222,25 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
 
     @Override
     public void close() throws Exception {
+        if (naming != null) {
+            try {
+                naming.shutDown();
+            } catch (Exception e) {
+                LOGGER.warn("Error while shutting down Nacos NamingService", e);
+            } finally {
+                naming = null;
+            }
+        }
 
+        if (useSLBWay && namingMaintain != null) {
+            try {
+                namingMaintain.shutDown();
+            } catch (Exception e) {
+                LOGGER.warn("Error while shutting down Nacos NamingMaintainService", e);
+            } finally {
+                namingMaintain = null;
+            }
+        }
     }
 
     /**
@@ -263,7 +295,9 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
         if (!initNacosAuthProperties(properties)) {
             LOGGER.info("Nacos naming auth properties empty.");
         }
-        String contextPath = StringUtils.isNotBlank(System.getProperty(CONTEXT_PATH)) ? System.getProperty(CONTEXT_PATH) : FILE_CONFIG.getConfig(getNacosContextPathKey());
+        String contextPath = StringUtils.isNotBlank(System.getProperty(CONTEXT_PATH))
+                ? System.getProperty(CONTEXT_PATH)
+                : FILE_CONFIG.getConfig(getNacosContextPathKey());
         if (StringUtils.isNotBlank(contextPath)) {
             properties.setProperty(CONTEXT_PATH, contextPath);
         }
@@ -272,15 +306,20 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
 
     /**
      * init nacos auth properties
-     *
+     * <p>
      * username/password > ak/sk > ramRoleName
+     *
      * @param sourceProperties the source properties
      * @return auth properties
      */
     private static boolean initNacosAuthProperties(Properties sourceProperties) {
-        String userName = StringUtils.isNotBlank(System.getProperty(USER_NAME)) ? System.getProperty(USER_NAME) : FILE_CONFIG.getConfig(getNacosUserName());
+        String userName = StringUtils.isNotBlank(System.getProperty(USER_NAME))
+                ? System.getProperty(USER_NAME)
+                : FILE_CONFIG.getConfig(getNacosUserName());
         if (StringUtils.isNotBlank(userName)) {
-            String password = StringUtils.isNotBlank(System.getProperty(PASSWORD)) ? System.getProperty(PASSWORD) : FILE_CONFIG.getConfig(getNacosPassword());
+            String password = StringUtils.isNotBlank(System.getProperty(PASSWORD))
+                    ? System.getProperty(PASSWORD)
+                    : FILE_CONFIG.getConfig(getNacosPassword());
             if (StringUtils.isNotBlank(password)) {
                 sourceProperties.setProperty(USER_NAME, userName);
                 sourceProperties.setProperty(PASSWORD, password);
@@ -288,10 +327,16 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
                 return true;
             }
         } else {
-            String accessKey = StringUtils.isNotBlank(System.getProperty(ACCESS_KEY)) ? System.getProperty(ACCESS_KEY) : FILE_CONFIG.getConfig(getNacosAccessKey());
-            String ramRoleName = StringUtils.isNotBlank(System.getProperty(RAM_ROLE_NAME_KEY)) ? System.getProperty(RAM_ROLE_NAME_KEY) : FILE_CONFIG.getConfig(getNacosRamRoleNameKey());
+            String accessKey = StringUtils.isNotBlank(System.getProperty(ACCESS_KEY))
+                    ? System.getProperty(ACCESS_KEY)
+                    : FILE_CONFIG.getConfig(getNacosAccessKey());
+            String ramRoleName = StringUtils.isNotBlank(System.getProperty(RAM_ROLE_NAME_KEY))
+                    ? System.getProperty(RAM_ROLE_NAME_KEY)
+                    : FILE_CONFIG.getConfig(getNacosRamRoleNameKey());
             if (StringUtils.isNotBlank(accessKey)) {
-                String secretKey = StringUtils.isNotBlank(System.getProperty(SECRET_KEY)) ? System.getProperty(SECRET_KEY) : FILE_CONFIG.getConfig(getNacosSecretKey());
+                String secretKey = StringUtils.isNotBlank(System.getProperty(SECRET_KEY))
+                        ? System.getProperty(SECRET_KEY)
+                        : FILE_CONFIG.getConfig(getNacosSecretKey());
                 if (StringUtils.isNotBlank(secretKey)) {
                     sourceProperties.put(ACCESS_KEY, accessKey);
                     sourceProperties.put(SECRET_KEY, secretKey);
@@ -320,55 +365,106 @@ public class NacosRegistryServiceImpl implements RegistryService<EventListener>
     }
 
     private static String getNacosAddrFileKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, PRO_SERVER_ADDR_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_SERVER_ADDR_KEY);
     }
 
     private static String getNacosNameSpaceFileKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, PRO_NAMESPACE_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_NAMESPACE_KEY);
     }
 
     private static String getNacosClusterFileKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, REGISTRY_CLUSTER);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                REGISTRY_CLUSTER);
     }
 
     private static String getNacosApplicationFileKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, PRO_APPLICATION_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_APPLICATION_KEY);
     }
 
     private static String getNacosApplicationGroupKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, PRO_GROUP_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_GROUP_KEY);
     }
 
     private static String getNacosUserName() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, USER_NAME);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                USER_NAME);
     }
 
     private static String getNacosPassword() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, PASSWORD);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PASSWORD);
     }
 
     public static String getNacosAccessKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, ACCESS_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                ACCESS_KEY);
     }
 
     public static String getNacosSecretKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, SECRET_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                SECRET_KEY);
     }
 
     public static String getNacosRamRoleNameKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_CONFIG, REGISTRY_TYPE, RAM_ROLE_NAME_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_CONFIG,
+                REGISTRY_TYPE,
+                RAM_ROLE_NAME_KEY);
     }
 
     public static String getClientApplication() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, PRO_CLIENT_APPLICATION);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_CLIENT_APPLICATION);
     }
 
     private static String getNacosUrlPatternOfSLB() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, SLB_PATTERN);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                SLB_PATTERN);
     }
 
     private static String getNacosContextPathKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, REGISTRY_TYPE, CONTEXT_PATH);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                CONTEXT_PATH);
     }
-
 }
