@@ -16,6 +16,29 @@
  */
 package org.apache.seata.discovery.registry.namingserver;
 
+import org.apache.http.client.methods.CloseableHttpResponse;
+import org.apache.http.entity.ContentType;
+import org.apache.http.protocol.HTTP;
+import org.apache.seata.common.holder.ObjectHolder;
+import org.apache.seata.common.metadata.Cluster;
+import org.apache.seata.common.metadata.ClusterRole;
+import org.apache.seata.common.metadata.Node;
+import org.apache.seata.common.metadata.namingserver.MetaResponse;
+import org.apache.seata.common.metadata.namingserver.NamingServerNode;
+import org.apache.seata.common.metadata.namingserver.Unit;
+import org.apache.seata.common.util.HttpClientUtil;
+import org.apache.seata.config.Configuration;
+import org.apache.seata.config.ConfigurationFactory;
+import org.apache.seata.discovery.registry.RegistryService;
+import org.junit.jupiter.api.AfterAll;
+import org.junit.jupiter.api.BeforeAll;
+import org.junit.jupiter.api.Disabled;
+import org.junit.jupiter.api.Test;
+import org.springframework.context.annotation.AnnotationConfigApplicationContext;
+import org.springframework.core.env.ConfigurableEnvironment;
+import org.springframework.core.env.MutablePropertySources;
+import org.springframework.core.env.PropertiesPropertySource;
+
 import java.lang.reflect.Field;
 import java.net.InetSocketAddress;
 import java.rmi.RemoteException;
@@ -29,31 +52,6 @@ import java.util.concurrent.ScheduledExecutorService;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicBoolean;
 
-import org.apache.http.entity.ContentType;
-import org.apache.http.protocol.HTTP;
-import org.apache.seata.common.holder.ObjectHolder;
-import org.apache.seata.common.metadata.Cluster;
-import org.apache.seata.common.metadata.ClusterRole;
-import org.apache.seata.common.metadata.Node;
-import org.apache.seata.common.metadata.namingserver.MetaResponse;
-import org.apache.seata.common.metadata.namingserver.NamingServerNode;
-import org.apache.seata.common.metadata.namingserver.Unit;
-import org.apache.seata.config.Configuration;
-import org.apache.seata.config.ConfigurationFactory;
-import org.apache.seata.common.util.HttpClientUtil;
-import org.apache.seata.discovery.registry.RegistryService;
-import org.apache.http.client.methods.CloseableHttpResponse;
-import org.junit.After;
-import org.junit.jupiter.api.AfterAll;
-import org.junit.jupiter.api.BeforeAll;
-import org.junit.jupiter.api.Disabled;
-import org.junit.jupiter.api.Test;
-import org.springframework.context.annotation.AnnotationConfigApplicationContext;
-import org.springframework.core.env.ConfigurableEnvironment;
-import org.springframework.core.env.MutablePropertySources;
-import org.springframework.core.env.PropertiesPropertySource;
-
-
 import static org.apache.seata.common.Constants.OBJECT_KEY_SPRING_CONFIGURABLE_ENVIRONMENT;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 
@@ -94,7 +92,6 @@ class NamingserverRegistryServiceImplTest {
         namingserverRegistryService.unregister(inetSocketAddress);
     }
 
-
     @Test
     @Disabled
     public void getNamingAddrsTest() {
@@ -103,7 +100,6 @@ class NamingserverRegistryServiceImplTest {
         assertEquals(list.size(), 1);
     }
 
-
     @Test
     @Disabled
     public void getNamingAddrTest() {
@@ -112,21 +108,19 @@ class NamingserverRegistryServiceImplTest {
         assertEquals(addr, "127.0.0.1:8080");
     }
 
-
     @Test
     @Disabled
     public void testRegister1() throws Exception {
 
         RegistryService registryService = new NamingserverRegistryProvider().provide();
 
-
         InetSocketAddress inetSocketAddress1 = new InetSocketAddress("127.0.0.1", 8088);
-        //1.register
+        // 1.register
         registryService.register(inetSocketAddress1);
 
-        //2.create vGroup in cluster
+        // 2.create vGroup in cluster
         createGroupInCluster("dev", "group1", "cluster1");
-        //3.get instances
+        // 3.get instances
         List<InetSocketAddress> list = registryService.lookup("group1");
 
         assertEquals(list.size(), 1);
@@ -135,8 +129,6 @@ class NamingserverRegistryServiceImplTest {
         assertEquals(inetSocketAddress.getPort(), 8088);
 
         registryService.unregister(inetSocketAddress1);
-
-
     }
 
     @Test
@@ -180,18 +172,19 @@ class NamingserverRegistryServiceImplTest {
     @Test
     @Disabled
     public void testRegister2() throws Exception {
-        NamingserverRegistryServiceImpl registryService = (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
+        NamingserverRegistryServiceImpl registryService =
+                (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
         InetSocketAddress inetSocketAddress1 = new InetSocketAddress("127.0.0.1", 8088);
         InetSocketAddress inetSocketAddress2 = new InetSocketAddress("127.0.0.1", 8088);
-        //1.register
+        // 1.register
         registryService.register(inetSocketAddress1);
         registryService.register(inetSocketAddress2);
 
-        //2.create vGroup in cluster
+        // 2.create vGroup in cluster
         String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
         createGroupInCluster(namespace, "group1", "cluster1");
 
-        //3.get instances
+        // 3.get instances
         List list = registryService.lookup("group1");
 
         assertEquals(list.size(), 1);
@@ -201,26 +194,26 @@ class NamingserverRegistryServiceImplTest {
         registryService.unsubscribe("group1");
     }
 
-
     @Test
     @Disabled
     public void testRegister3() throws Exception {
-        NamingserverRegistryServiceImpl registryService = (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
+        NamingserverRegistryServiceImpl registryService =
+                (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
         InetSocketAddress inetSocketAddress1 = new InetSocketAddress("127.0.0.1", 8088);
         InetSocketAddress inetSocketAddress2 = new InetSocketAddress("127.0.0.1", 8089);
         InetSocketAddress inetSocketAddress3 = new InetSocketAddress("127.0.0.1", 8090);
         InetSocketAddress inetSocketAddress4 = new InetSocketAddress("127.0.0.1", 8091);
-        //1.register
+        // 1.register
         registryService.register(inetSocketAddress1);
         registryService.register(inetSocketAddress2);
         registryService.register(inetSocketAddress3);
         registryService.register(inetSocketAddress4);
 
-        //2.create vGroup in cluster
+        // 2.create vGroup in cluster
         String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
         createGroupInCluster(namespace, "group2", "cluster1");
 
-        //3.get instances
+        // 3.get instances
         List list = registryService.lookup("group2");
 
         assertEquals(list.size(), 4);
@@ -231,75 +224,73 @@ class NamingserverRegistryServiceImplTest {
         registryService.unregister(inetSocketAddress4);
 
         registryService.unsubscribe("group2");
-
     }
 
-
     @Test
     @Disabled
     public void testUnregister() throws Exception {
         RegistryService registryService = new NamingserverRegistryProvider().provide();
         InetSocketAddress inetSocketAddress1 = new InetSocketAddress("127.0.0.1", 8088);
-        //1.register
+        // 1.register
         registryService.register(inetSocketAddress1);
 
-        //2.create vGroup in cluster
+        // 2.create vGroup in cluster
         String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
         createGroupInCluster(namespace, "group1", "cluster1");
 
-        //3.get instances
+        // 3.get instances
         List list = registryService.lookup("group1");
 
         assertEquals(list.size(), 1);
 
-        //4.unregister
+        // 4.unregister
         registryService.unregister(inetSocketAddress1);
 
-        //5.get instances
+        // 5.get instances
         List list1 = registryService.lookup("group1");
         assertEquals(list1.size(), 0);
-
     }
 
-
     @Disabled
     @Test
     public void testWatch() throws Exception {
-        NamingserverRegistryServiceImpl registryService = (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
+        NamingserverRegistryServiceImpl registryService =
+                (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
 
-        //1.注册cluster1下的一个节点
+        // 1.注册cluster1下的一个节点
         InetSocketAddress inetSocketAddress1 = new InetSocketAddress("127.0.0.1", 8088);
         registryService.register(inetSocketAddress1);
 
         ScheduledExecutorService executor = Executors.newScheduledThreadPool(1);
         int delaySeconds = 500;
-        //2.延迟0.5s后在cluster1下创建事务分组group1
-        executor.schedule(() -> {
-            try {
+        // 2.延迟0.5s后在cluster1下创建事务分组group1
+        executor.schedule(
+                () -> {
+                    try {
 
-                String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
-                createGroupInCluster(namespace, "group1", "cluster1");
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-            executor.shutdown();  // 任务执行后关闭执行器
-        }, delaySeconds, TimeUnit.MILLISECONDS);
-        //3.watch事务分组group1
+                        String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
+                        createGroupInCluster(namespace, "group1", "cluster1");
+                    } catch (Exception e) {
+                        throw new RuntimeException(e);
+                    }
+                    executor.shutdown(); // 任务执行后关闭执行器
+                },
+                delaySeconds,
+                TimeUnit.MILLISECONDS);
+        // 3.watch事务分组group1
         long timestamp1 = System.currentTimeMillis();
         boolean needFetch = registryService.watch("group1");
         long timestamp2 = System.currentTimeMillis();
-        //4.  0.5s后group1被映射到cluster1下，应该有数据在1s内推送到client端
+        // 4.  0.5s后group1被映射到cluster1下，应该有数据在1s内推送到client端
         assert timestamp2 - timestamp1 < 1500;
 
-        //5. 获取实例
+        // 5. 获取实例
         List<InetSocketAddress> list = registryService.lookup("group1");
         registryService.unsubscribe("group1");
         assertEquals(list.size(), 1);
         InetSocketAddress inetSocketAddress = list.get(0);
         assertEquals(inetSocketAddress.getAddress().getHostAddress(), "127.0.0.1");
         assertEquals(inetSocketAddress.getPort(), 8088);
-
-
     }
 
     @Disabled
@@ -308,61 +299,59 @@ class NamingserverRegistryServiceImplTest {
         NamingserverRegistryServiceImpl registryService = NamingserverRegistryServiceImpl.getInstance();
 
         AtomicBoolean isNotified = new AtomicBoolean(false);
-        //1.subscribe
-        registryService.subscribe(vGroup -> {
-            try {
-                isNotified.set(true);
-            } catch (Exception e) {
-                throw new RuntimeException(e);
-            }
-        }, "group2");
+        // 1.subscribe
+        registryService.subscribe(
+                vGroup -> {
+                    try {
+                        isNotified.set(true);
+                    } catch (Exception e) {
+                        throw new RuntimeException(e);
+                    }
+                },
+                "group2");
 
-        //2.register
+        // 2.register
         InetSocketAddress inetSocketAddress = new InetSocketAddress("127.0.0.1", 8088);
         registryService.register(inetSocketAddress);
         String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
         createGroupInCluster(namespace, "group2", "cluster1");
 
-        //3.check
+        // 3.check
         assertEquals(isNotified.get(), true);
         registryService.unsubscribe("group2");
     }
 
-
     @Test
     @Disabled
     public void testUnsubscribe() throws Exception {
-        NamingserverRegistryServiceImpl registryService = (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
-
+        NamingserverRegistryServiceImpl registryService =
+                (NamingserverRegistryServiceImpl) new NamingserverRegistryProvider().provide();
 
         NamingListenerimpl namingListenerimpl = new NamingListenerimpl();
 
-        //1.subscribe
+        // 1.subscribe
         registryService.subscribe(namingListenerimpl, "group1");
 
-        //2.register
+        // 2.register
         InetSocketAddress inetSocketAddress = new InetSocketAddress("127.0.0.1", 8088);
         registryService.register(inetSocketAddress);
         String namespace = FILE_CONFIG.getConfig("registry.namingserver.namespace");
         createGroupInCluster(namespace, "group1", "cluster1");
 
-        //3.check
+        // 3.check
         assertEquals(namingListenerimpl.isNotified, true);
         namingListenerimpl.setNotified(false);
 
-        //4.unsubscribe
+        // 4.unsubscribe
         registryService.unsubscribe(namingListenerimpl, "group1");
 
-        //5.unregister
+        // 5.unregister
 
         registryService.unregister(inetSocketAddress);
-        //5.check
+        // 5.check
         assertEquals(namingListenerimpl.isNotified, false);
-
-
     }
 
-
     public void createGroupInCluster(String namespace, String vGroup, String clusterName) throws Exception {
         Map<String, String> paraMap = new HashMap<>();
         paraMap.put("namespace", namespace);
@@ -395,4 +384,5 @@ class NamingserverRegistryServiceImplTest {
             isNotified = true;
         }
     }
-};
+}
+;
