@@ -16,29 +16,15 @@
  */
 package org.apache.seata.discovery.registry.raft;
 
-import java.io.IOException;
-import java.net.InetSocketAddress;
-import java.nio.charset.StandardCharsets;
-import java.util.ArrayList;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.LinkedHashMap;
-import java.util.Optional;
-import java.util.Arrays;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadLocalRandom;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicBoolean;
-import java.util.stream.Collectors;
-import java.util.stream.Stream;
-
 import com.fasterxml.jackson.core.JsonProcessingException;
 import com.fasterxml.jackson.databind.JsonNode;
 import com.fasterxml.jackson.databind.ObjectMapper;
+import org.apache.http.HttpStatus;
+import org.apache.http.StatusLine;
+import org.apache.http.client.methods.CloseableHttpResponse;
+import org.apache.http.entity.ContentType;
+import org.apache.http.protocol.HTTP;
+import org.apache.http.util.EntityUtils;
 import org.apache.seata.common.ConfigurationKeys;
 import org.apache.seata.common.exception.AuthenticationFailedException;
 import org.apache.seata.common.exception.NotSupportYetException;
@@ -56,15 +42,29 @@ import org.apache.seata.config.ConfigChangeListener;
 import org.apache.seata.config.Configuration;
 import org.apache.seata.config.ConfigurationFactory;
 import org.apache.seata.discovery.registry.RegistryService;
-import org.apache.http.HttpStatus;
-import org.apache.http.StatusLine;
-import org.apache.http.client.methods.CloseableHttpResponse;
-import org.apache.http.entity.ContentType;
-import org.apache.http.util.EntityUtils;
-import org.apache.http.protocol.HTTP;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.io.IOException;
+import java.net.InetSocketAddress;
+import java.nio.charset.StandardCharsets;
+import java.util.ArrayList;
+import java.util.Arrays;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Optional;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadLocalRandom;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicBoolean;
+import java.util.stream.Collectors;
+import java.util.stream.Stream;
+
 /**
  * The type File registry service.
  *
@@ -131,8 +131,7 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
         PREFERRED_NETWORKS = CONFIG.getConfig(getPreferredNetworks());
     }
 
-    private RaftRegistryServiceImpl() {
-    }
+    private RaftRegistryServiceImpl() {}
 
     /**
      * Gets instance.
@@ -151,31 +150,28 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
     }
 
     @Override
-    public void register(InetSocketAddress address) throws Exception {
-
-    }
+    public void register(InetSocketAddress address) throws Exception {}
 
     @Override
-    public void unregister(InetSocketAddress address) throws Exception {
-
-    }
+    public void unregister(InetSocketAddress address) throws Exception {}
 
     @Override
-    public void subscribe(String cluster, ConfigChangeListener listener) throws Exception {
-
-    }
+    public void subscribe(String cluster, ConfigChangeListener listener) throws Exception {}
 
     @Override
-    public void unsubscribe(String cluster, ConfigChangeListener listener) throws Exception {
-
-    }
+    public void unsubscribe(String cluster, ConfigChangeListener listener) throws Exception {}
 
     protected static void startQueryMetadata() {
         if (REFRESH_METADATA_EXECUTOR == null) {
             synchronized (INIT_ADDRESSES) {
                 if (REFRESH_METADATA_EXECUTOR == null) {
-                    REFRESH_METADATA_EXECUTOR = new ThreadPoolExecutor(1, 1, 0L, TimeUnit.MILLISECONDS,
-                        new LinkedBlockingQueue<>(), new NamedThreadFactory("refreshMetadata", 1, true));
+                    REFRESH_METADATA_EXECUTOR = new ThreadPoolExecutor(
+                            1,
+                            1,
+                            0L,
+                            TimeUnit.MILLISECONDS,
+                            new LinkedBlockingQueue<>(),
+                            new NamedThreadFactory("refreshMetadata", 1, true));
                     REFRESH_METADATA_EXECUTOR.execute(() -> {
                         long metadataMaxAgeMs = CONFIG.getLong(getMetadataMaxAgeMs(), 30000L);
                         long currentTime = System.currentTimeMillis();
@@ -197,7 +193,8 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
                                             if (e instanceof RetryableException) {
                                                 throw e;
                                             } else {
-                                                LOGGER.error("failed to get the leader address,error: {}", e.getMessage());
+                                                LOGGER.error(
+                                                        "failed to get the leader address,error: {}", e.getMessage());
                                             }
                                         }
                                     }
@@ -231,8 +228,9 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
         if (CollectionUtils.isNotEmpty(nodeList)) {
             List<InetSocketAddress> inetSocketAddresses = ALIVE_NODES.get(CURRENT_TRANSACTION_SERVICE_GROUP);
             if (CollectionUtils.isEmpty(inetSocketAddresses)) {
-                addressList =
-                    nodeList.stream().map(RaftRegistryServiceImpl::selectControlEndpointStr).collect(Collectors.toList());
+                addressList = nodeList.stream()
+                        .map(RaftRegistryServiceImpl::selectControlEndpointStr)
+                        .collect(Collectors.toList());
             } else {
                 stream = inetSocketAddresses.stream();
             }
@@ -246,47 +244,60 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
             if (CollectionUtils.isNotEmpty(nodeList)) {
                 for (Node node : nodeList) {
                     InetSocketAddress inetSocketAddress = selectTransactionEndpoint(node);
-                    map.put(inetSocketAddress.getHostString()
-                        + IP_PORT_SPLIT_CHAR + inetSocketAddress.getPort(), node);
+                    map.put(inetSocketAddress.getHostString() + IP_PORT_SPLIT_CHAR + inetSocketAddress.getPort(), node);
                 }
             }
             addressList = stream.map(inetSocketAddress -> {
-                String host = NetUtil.toStringHost(inetSocketAddress);
-                Node node = map.get(host + IP_PORT_SPLIT_CHAR + inetSocketAddress.getPort());
-                InetSocketAddress controlEndpoint = null;
-                if (node != null) {
-                    controlEndpoint = selectControlEndpoint(node);
-                }
-                return host + IP_PORT_SPLIT_CHAR
-                    + (controlEndpoint != null ? controlEndpoint.getPort() : inetSocketAddress.getPort());
-            }).collect(Collectors.toList());
+                        String host = NetUtil.toStringHost(inetSocketAddress);
+                        Node node = map.get(host + IP_PORT_SPLIT_CHAR + inetSocketAddress.getPort());
+                        InetSocketAddress controlEndpoint = null;
+                        if (node != null) {
+                            controlEndpoint = selectControlEndpoint(node);
+                        }
+                        return host
+                                + IP_PORT_SPLIT_CHAR
+                                + (controlEndpoint != null ? controlEndpoint.getPort() : inetSocketAddress.getPort());
+                    })
+                    .collect(Collectors.toList());
             return addressList.get(ThreadLocalRandom.current().nextInt(addressList.size()));
         }
     }
 
     private static String getRaftAddrFileKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY,
-            REGISTRY_TYPE, PRO_SERVER_ADDR_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_SERVER_ADDR_KEY);
     }
 
     private static String getRaftUserNameKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY,
-            REGISTRY_TYPE, PRO_USERNAME_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_USERNAME_KEY);
     }
 
     private static String getRaftPassWordKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY,
-            REGISTRY_TYPE, PRO_PASSWORD_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                PRO_PASSWORD_KEY);
     }
 
     private static String getPreferredNetworks() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY,
-                "preferredNetworks");
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY, "preferredNetworks");
     }
 
     private static String getTokenExpireTimeInMillisecondsKey() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY,
-            REGISTRY_TYPE, TOKEN_VALID_TIME_MS_KEY);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                TOKEN_VALID_TIME_MS_KEY);
     }
 
     private static boolean isTokenExpired() {
@@ -320,9 +331,12 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
             // Use the default method, directly using node.control and node.transaction
             switch (type) {
                 case "control":
-                    return new InetSocketAddress(node.getControl().getHost(), node.getControl().getPort());
+                    return new InetSocketAddress(
+                            node.getControl().getHost(), node.getControl().getPort());
                 case "transaction":
-                    return new InetSocketAddress(node.getTransaction().getHost(), node.getTransaction().getPort());
+                    return new InetSocketAddress(
+                            node.getTransaction().getHost(),
+                            node.getTransaction().getPort());
                 default:
                     throw new NotSupportYetException("SelectEndpoint is not support type: " + type);
             }
@@ -367,14 +381,15 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
     }
 
     private static boolean isPreferredNetwork(String ip, List<String> preferredNetworks) {
-        return preferredNetworks.stream().anyMatch(regex ->
-                StringUtils.isNotBlank(regex) && (ip.matches(regex) || ip.startsWith(regex))
-        );
+        return preferredNetworks.stream()
+                .anyMatch(regex -> StringUtils.isNotBlank(regex) && (ip.matches(regex) || ip.startsWith(regex)));
     }
 
-    private static Node.ExternalEndpoint createExternalEndpoint(LinkedHashMap<String, Object> externalEndpoint, String ip) {
+    private static Node.ExternalEndpoint createExternalEndpoint(
+            LinkedHashMap<String, Object> externalEndpoint, String ip) {
         int controlPort = Integer.parseInt(externalEndpoint.get("controlPort").toString());
-        int transactionPort = Integer.parseInt(externalEndpoint.get("transactionPort").toString());
+        int transactionPort =
+                Integer.parseInt(externalEndpoint.get("transactionPort").toString());
         return new Node.ExternalEndpoint(ip, controlPort, transactionPort);
     }
 
@@ -411,14 +426,15 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
                 header.put(AUTHORIZATION_HEADER, jwtToken);
             }
             try (CloseableHttpResponse response =
-                HttpClientUtil.doPost("http://" + tcAddress + "/metadata/v1/watch", param, header, 30000)) {
+                    HttpClientUtil.doPost("http://" + tcAddress + "/metadata/v1/watch", param, header, 30000)) {
                 if (response != null) {
                     StatusLine statusLine = response.getStatusLine();
                     if (statusLine != null && statusLine.getStatusCode() == HttpStatus.SC_UNAUTHORIZED) {
                         if (StringUtils.isNotBlank(USERNAME) && StringUtils.isNotBlank(PASSWORD)) {
                             throw new RetryableException("Authentication failed!");
                         } else {
-                            throw new AuthenticationFailedException("Authentication failed! you should configure the correct username and password.");
+                            throw new AuthenticationFailedException(
+                                    "Authentication failed! you should configure the correct username and password.");
                         }
                     }
                     return statusLine != null && statusLine.getStatusCode() == HttpStatus.SC_OK;
@@ -433,17 +449,28 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
     }
 
     @Override
-    public List<InetSocketAddress> refreshAliveLookup(String transactionServiceGroup,
-        List<InetSocketAddress> aliveAddress) {
+    public List<InetSocketAddress> refreshAliveLookup(
+            String transactionServiceGroup, List<InetSocketAddress> aliveAddress) {
         if (METADATA.isRaftMode()) {
             Node leader = METADATA.getLeader(getServiceGroup(transactionServiceGroup));
             InetSocketAddress leaderAddress = selectTransactionEndpoint(leader);
-            return ALIVE_NODES.put(transactionServiceGroup,
-                aliveAddress.isEmpty() ? aliveAddress : aliveAddress.parallelStream().filter(inetSocketAddress -> {
-                    // Since only follower will turn into leader, only the follower node needs to be listened to
-                    return inetSocketAddress.getPort() != leaderAddress.getPort() || !inetSocketAddress.getAddress()
-                        .getHostAddress().equals(leaderAddress.getAddress().getHostAddress());
-                }).collect(Collectors.toList()));
+            return ALIVE_NODES.put(
+                    transactionServiceGroup,
+                    aliveAddress.isEmpty()
+                            ? aliveAddress
+                            : aliveAddress.parallelStream()
+                                    .filter(inetSocketAddress -> {
+                                        // Since only follower will turn into leader, only the follower node needs to be
+                                        // listened to
+                                        return inetSocketAddress.getPort() != leaderAddress.getPort()
+                                                || !inetSocketAddress
+                                                        .getAddress()
+                                                        .getHostAddress()
+                                                        .equals(leaderAddress
+                                                                .getAddress()
+                                                                .getHostAddress());
+                                    })
+                                    .collect(Collectors.toList()));
         } else {
             return RegistryService.super.refreshAliveLookup(transactionServiceGroup, aliveAddress);
         }
@@ -472,7 +499,7 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
             param.put("group", group);
             String response = null;
             try (CloseableHttpResponse httpResponse =
-                HttpClientUtil.doGet("http://" + tcAddress + "/metadata/v1/cluster", param, header, 1000)) {
+                    HttpClientUtil.doGet("http://" + tcAddress + "/metadata/v1/cluster", param, header, 1000)) {
                 if (httpResponse != null) {
                     int statusCode = httpResponse.getStatusLine().getStatusCode();
                     if (statusCode == HttpStatus.SC_OK) {
@@ -482,10 +509,12 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
                             refreshToken(tcAddress);
                             throw new RetryableException("Token refreshed, retrying request.");
                         } else {
-                            throw new AuthenticationFailedException("Authentication failed! you should configure the correct username and password.");
+                            throw new AuthenticationFailedException(
+                                    "Authentication failed! you should configure the correct username and password.");
                         }
                     } else {
-                        throw new AuthenticationFailedException("Authentication failed! you should configure the correct username and password.");
+                        throw new AuthenticationFailedException(
+                                "Authentication failed! you should configure the correct username and password.");
                     }
                 }
                 MetadataResponse metadataResponse;
@@ -516,21 +545,23 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
         header.put(HTTP.CONTENT_TYPE, ContentType.APPLICATION_JSON.getMimeType());
         String response = null;
         try (CloseableHttpResponse httpResponse =
-            HttpClientUtil.doPost("http://" + tcAddress + "/api/v1/auth/login", param, header, 1000)) {
+                HttpClientUtil.doPost("http://" + tcAddress + "/api/v1/auth/login", param, header, 1000)) {
             if (httpResponse != null) {
                 if (httpResponse.getStatusLine().getStatusCode() == HttpStatus.SC_OK) {
                     response = EntityUtils.toString(httpResponse.getEntity(), StandardCharsets.UTF_8);
                     JsonNode jsonNode = OBJECT_MAPPER.readTree(response);
                     String codeStatus = jsonNode.get("code").asText();
                     if (!StringUtils.equals(codeStatus, "200")) {
-                        //authorized failed,throw exception to kill process
-                        throw new AuthenticationFailedException("Authentication failed! you should configure the correct username and password.");
+                        // authorized failed,throw exception to kill process
+                        throw new AuthenticationFailedException(
+                                "Authentication failed! you should configure the correct username and password.");
                     }
                     jwtToken = jsonNode.get("data").asText();
                     tokenTimeStamp = System.currentTimeMillis();
                 } else {
-                    //authorized failed,throw exception to kill process
-                    throw new AuthenticationFailedException("Authentication failed! you should configure the correct username and password.");
+                    // authorized failed,throw exception to kill process
+                    throw new AuthenticationFailedException(
+                            "Authentication failed! you should configure the correct username and password.");
                 }
             }
         } catch (IOException e) {
@@ -538,7 +569,6 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
         }
     }
 
-
     @Override
     public List<InetSocketAddress> lookup(String key) throws Exception {
         String clusterName = getServiceGroup(key);
@@ -575,14 +605,18 @@ public class RaftRegistryServiceImpl implements RegistryService<ConfigChangeList
         }
         List<Node> nodes = METADATA.getNodes(clusterName);
         if (CollectionUtils.isNotEmpty(nodes)) {
-            return nodes.parallelStream().map(RaftRegistryServiceImpl::selectTransactionEndpoint).collect(Collectors.toList());
+            return nodes.parallelStream()
+                    .map(RaftRegistryServiceImpl::selectTransactionEndpoint)
+                    .collect(Collectors.toList());
         }
         return Collections.emptyList();
     }
 
     private static String getMetadataMaxAgeMs() {
-        return String.join(ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR, ConfigurationKeys.FILE_ROOT_REGISTRY,
-            REGISTRY_TYPE, META_DATA_MAX_AGE_MS);
+        return String.join(
+                ConfigurationKeys.FILE_CONFIG_SPLIT_CHAR,
+                ConfigurationKeys.FILE_ROOT_REGISTRY,
+                REGISTRY_TYPE,
+                META_DATA_MAX_AGE_MS);
     }
-
 }
