@@ -16,15 +16,6 @@
  */
 package org.apache.seata.integration.tx.api.interceptor;
 
-import javax.annotation.Nonnull;
-import java.lang.annotation.Annotation;
-import java.lang.reflect.Method;
-import java.lang.reflect.UndeclaredThrowableException;
-import java.util.Collections;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
-
 import org.apache.seata.common.Constants;
 import org.apache.seata.common.exception.FrameworkException;
 import org.apache.seata.common.exception.SkipCallbackWrapperException;
@@ -45,6 +36,15 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.MDC;
 
+import javax.annotation.Nonnull;
+import java.lang.annotation.Annotation;
+import java.lang.reflect.Method;
+import java.lang.reflect.UndeclaredThrowableException;
+import java.util.Collections;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
+
 /**
  * Handler the Tx Participant Aspect : Setting Context, Creating Branch Record
  *
@@ -64,37 +64,44 @@ public class ActionInterceptorHandler {
      * @return the business result
      * @throws Throwable the throwable
      */
-    public Object proceed(Method method, Object[] arguments, String xid, TwoPhaseBusinessActionParam businessActionParam,
-                          Callback<Object> targetCallback) throws Throwable {
-        //Get action context from arguments, or create a new one and then reset to arguments
-        BusinessActionContext actionContext = getOrCreateActionContextAndResetToArguments(method.getParameterTypes(), arguments);
+    public Object proceed(
+            Method method,
+            Object[] arguments,
+            String xid,
+            TwoPhaseBusinessActionParam businessActionParam,
+            Callback<Object> targetCallback)
+            throws Throwable {
+        // Get action context from arguments, or create a new one and then reset to arguments
+        BusinessActionContext actionContext =
+                getOrCreateActionContextAndResetToArguments(method.getParameterTypes(), arguments);
 
-        //Set the xid
+        // Set the xid
         actionContext.setXid(xid);
-        //Set the action name
+        // Set the action name
         String actionName = businessActionParam.getActionName();
         actionContext.setActionName(actionName);
-        //Set the delay report
+        // Set the delay report
         actionContext.setDelayReport(businessActionParam.getDelayReport());
-        //Set branch type
+        // Set branch type
         actionContext.setBranchType(businessActionParam.getBranchType());
 
-        //Creating Branch Record
+        // Creating Branch Record
         String branchId = doTxActionLogStore(method, arguments, businessActionParam, actionContext);
         actionContext.setBranchId(branchId);
-        //MDC put branchId
+        // MDC put branchId
         MDC.put(RootContext.MDC_KEY_BRANCH_ID, branchId);
 
         // save the previous action context
         BusinessActionContext previousActionContext = BusinessActionContextUtil.getContext();
         try {
-            //share actionContext implicitly
+            // share actionContext implicitly
             BusinessActionContextUtil.setContext(actionContext);
             doBeforeTccPrepare(xid, branchId, actionName, actionContext);
             if (businessActionParam.getUseCommonFence()) {
                 try {
                     // Use common Fence, and return the business result
-                    return DefaultCommonFenceHandler.get().prepareFence(xid, Long.valueOf(branchId), actionName, targetCallback);
+                    return DefaultCommonFenceHandler.get()
+                            .prepareFence(xid, Long.valueOf(branchId), actionName, targetCallback);
                 } catch (SkipCallbackWrapperException | UndeclaredThrowableException e) {
                     Throwable originException = e.getCause();
                     if (originException instanceof FrameworkException) {
@@ -103,13 +110,13 @@ public class ActionInterceptorHandler {
                     throw originException;
                 }
             } else {
-                //Execute business, and return the business result
+                // Execute business, and return the business result
                 return targetCallback.execute();
             }
         } finally {
             try {
                 doAfterTccPrepare(xid, branchId, actionName, actionContext);
-                //to report business action context finally if the actionContext.getUpdated() is true
+                // to report business action context finally if the actionContext.getUpdated() is true
                 BusinessActionContextUtil.reportContext(actionContext);
             } finally {
                 if (previousActionContext != null) {
@@ -166,7 +173,8 @@ public class ActionInterceptorHandler {
      * @since above 1.4.2
      */
     @Nonnull
-    protected BusinessActionContext getOrCreateActionContextAndResetToArguments(Class<?>[] parameterTypes, Object[] arguments) {
+    protected BusinessActionContext getOrCreateActionContextAndResetToArguments(
+            Class<?>[] parameterTypes, Object[] arguments) {
         BusinessActionContext actionContext = null;
 
         // get the action context from arguments
@@ -175,7 +183,8 @@ public class ActionInterceptorHandler {
             if (BusinessActionContext.class.isAssignableFrom(parameterType)) {
                 actionContext = (BusinessActionContext) arguments[argIndex];
                 if (actionContext == null) {
-                    // If the action context exists in arguments but is null, create a new one and reset the action context to the arguments
+                    // If the action context exists in arguments but is null, create a new one and reset the action
+                    // context to the arguments
                     actionContext = new BusinessActionContext();
                     arguments[argIndex] = actionContext;
                 } else {
@@ -203,40 +212,44 @@ public class ActionInterceptorHandler {
      * @param actionContext       the action context
      * @return the branchId
      */
-    protected String doTxActionLogStore(Method method, Object[] arguments, TwoPhaseBusinessActionParam businessActionParam,
-                                        BusinessActionContext actionContext) {
+    protected String doTxActionLogStore(
+            Method method,
+            Object[] arguments,
+            TwoPhaseBusinessActionParam businessActionParam,
+            BusinessActionContext actionContext) {
         String actionName = actionContext.getActionName();
         String xid = actionContext.getXid();
 
-        //region fetch context and init action context
+        // region fetch context and init action context
 
         Map<String, Object> context = fetchActionRequestContext(method, arguments);
         context.put(Constants.ACTION_START_TIME, System.currentTimeMillis());
 
-        //Init business context
+        // Init business context
         initBusinessContext(context, method, businessActionParam.getBusinessActionContext());
-        //Init running environment context
+        // Init running environment context
         initFrameworkContext(context);
 
         Map<String, Object> originContext = actionContext.getActionContext();
         if (CollectionUtils.isNotEmpty(originContext)) {
-            //Merge context and origin context if it exists.
-            //@since: above 1.4.2
+            // Merge context and origin context if it exists.
+            // @since: above 1.4.2
             originContext.putAll(context);
             context = originContext;
         } else {
             actionContext.setActionContext(context);
         }
 
-        //endregion
+        // endregion
 
-        //Init applicationData
+        // Init applicationData
         Map<String, Object> applicationContext = Collections.singletonMap(Constants.TX_ACTION_CONTEXT, context);
         String applicationContextStr = JsonUtil.toJSONString(applicationContext);
         try {
-            //registry branch record
-            Long branchId = DefaultResourceManager.get().branchRegister(businessActionParam.getBranchType(), actionName, null, xid,
-                    applicationContextStr, null);
+            // registry branch record
+            Long branchId = DefaultResourceManager.get()
+                    .branchRegister(
+                            businessActionParam.getBranchType(), actionName, null, xid, applicationContextStr, null);
             return String.valueOf(branchId);
         } catch (Throwable t) {
             String msg = String.format("%s branch Register error, xid: %s", businessActionParam.getBranchType(), xid);
@@ -265,14 +278,14 @@ public class ActionInterceptorHandler {
      * @param method                the method
      * @param businessActionContext the business action map
      */
-    protected void initBusinessContext(Map<String, Object> context, Method method,
-                                       Map<String, Object> businessActionContext) {
+    protected void initBusinessContext(
+            Map<String, Object> context, Method method, Map<String, Object> businessActionContext) {
         if (method != null) {
-            //the phase one method name
+            // the phase one method name
             context.put(Constants.PREPARE_METHOD, method.getName());
         }
         if (businessActionContext != null && businessActionContext.size() > 0) {
-            //the phase two method name
+            // the phase two method name
             context.putAll(businessActionContext);
         }
     }
@@ -292,7 +305,8 @@ public class ActionInterceptorHandler {
             for (int j = 0; j < parameterAnnotations[i].length; j++) {
                 if (parameterAnnotations[i][j] instanceof BusinessActionContextParameter) {
                     // get annotation
-                    BusinessActionContextParameter annotation = (BusinessActionContextParameter) parameterAnnotations[i][j];
+                    BusinessActionContextParameter annotation =
+                            (BusinessActionContextParameter) parameterAnnotations[i][j];
                     if (arguments[i] == null) {
                         throw new IllegalArgumentException("@BusinessActionContextParameter 's params can not null");
                     }
@@ -304,11 +318,11 @@ public class ActionInterceptorHandler {
                     }
 
                     // load param by the config of annotation, and then put into the context
-                    ActionContextUtil.loadParamByAnnotationAndPutToContext(ParamType.PARAM, "", paramObject, annotation, context);
+                    ActionContextUtil.loadParamByAnnotationAndPutToContext(
+                            ParamType.PARAM, "", paramObject, annotation, context);
                 }
             }
         }
         return context;
     }
-
 }
