@@ -27,5 +27,4 @@ import java.lang.annotation.Target;
  */
 @Retention(RetentionPolicy.RUNTIME)
 @Target(ElementType.TYPE)
-public @interface RemoteBean {
-}
+public @interface RemoteBean {}
