@@ -16,5 +16,4 @@
  */
 package org.apache.seata.integration.tx.api.remoting.parser;
 
-public class SimpleBean {
-}
+public class SimpleBean {}
