@@ -16,6 +16,4 @@
  */
 package org.apache.seata.integration.tx.api.util;
 
-public class SimpleDubboProxy {
-
-}
+public class SimpleDubboProxy {}
