@@ -16,12 +16,6 @@
  */
 package org.apache.seata.mockserver;
 
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.stream.IntStream;
-
 import org.apache.seata.common.util.CollectionUtils;
 import org.apache.seata.common.util.UUIDGenerator;
 import org.apache.seata.core.exception.TransactionException;
@@ -62,6 +56,12 @@ import org.apache.seata.mockserver.model.MockGlobalSession;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.stream.IntStream;
+
 /**
  * Mock Coordinator
  **/
@@ -80,8 +80,7 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
     private Map<String, Integer> expectRetryTimesMap;
     private Map<String, List<MockBranchSession>> branchMap;
 
-    private MockCoordinator() {
-    }
+    private MockCoordinator() {}
 
     public static MockCoordinator getInstance() {
         if (coordinator == null) {
@@ -99,16 +98,14 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
     }
 
     @Override
-    public void destroy() {
-
-    }
+    public void destroy() {}
 
     @Override
     public AbstractResultMessage onRequest(AbstractMessage request, RpcContext context) {
         if (!(request instanceof AbstractTransactionRequestToTC)) {
             throw new IllegalArgumentException();
         }
-        AbstractTransactionRequestToTC transactionRequest = (AbstractTransactionRequestToTC)request;
+        AbstractTransactionRequestToTC transactionRequest = (AbstractTransactionRequestToTC) request;
         transactionRequest.setTCInboundHandler(this);
 
         return transactionRequest.handle(context);
@@ -137,15 +134,18 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
         }
     }
 
-    private <T extends AbstractTransactionResponse> T handleException(TransactionException e, T response,
-                                                                      ResultCode resultCode, String messagePrefix,
-                                                                      GlobalStatus... globalStatus) {
+    private <T extends AbstractTransactionResponse> T handleException(
+            TransactionException e,
+            T response,
+            ResultCode resultCode,
+            String messagePrefix,
+            GlobalStatus... globalStatus) {
         response.setTransactionExceptionCode(e.getCode());
         response.setResultCode(resultCode);
         response.setMsg(messagePrefix + "[" + e.getMessage() + "]");
         if (response instanceof AbstractGlobalEndResponse) {
             if (globalStatus != null && globalStatus.length > 0) {
-                ((AbstractGlobalEndResponse)response).setGlobalStatus(globalStatus[0]);
+                ((AbstractGlobalEndResponse) response).setGlobalStatus(globalStatus[0]);
             }
         }
         return response;
@@ -159,8 +159,11 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
         } catch (TransactionException e) {
             return handleException(e, response, ResultCode.Failed, "MockBeginException");
         }
-        MockGlobalSession session = new MockGlobalSession(rpcContext.getApplicationId(),
-            rpcContext.getTransactionServiceGroup(), request.getTransactionName(), request.getTimeout());
+        MockGlobalSession session = new MockGlobalSession(
+                rpcContext.getApplicationId(),
+                rpcContext.getTransactionServiceGroup(),
+                request.getTransactionName(),
+                request.getTimeout());
         globalStatusMap.putIfAbsent(session.getXid(), GlobalStatus.Begin);
         response.setXid(session.getXid());
         response.setResultCode(ResultCode.Success);
@@ -200,8 +203,8 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
         try {
             checkMockActionFail(request.getXid());
         } catch (TransactionException e) {
-            return handleException(e, response, ResultCode.Failed, "MockRollbackException",
-                GlobalStatus.RollbackFailed);
+            return handleException(
+                    e, response, ResultCode.Failed, "MockRollbackException", GlobalStatus.RollbackFailed);
         }
         response.setGlobalStatus(GlobalStatus.Rollbacked);
         response.setResultCode(ResultCode.Success);
@@ -217,7 +220,7 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
             CallRm.branchRollback(remotingServer, branch);
             IntStream.range(0, retry).forEach(i -> CallRm.branchRollback(remotingServer, branch));
             if (Version.isV0(rpcContext.getVersion())) {
-                //test MsgVersionHelper and skip
+                // test MsgVersionHelper and skip
                 CallRm.deleteUndoLog(remotingServer, branch);
             }
         });
@@ -268,9 +271,11 @@ public class MockCoordinator implements TCInboundHandler, TransactionMessageHand
         String xid = request.getXid();
         branchMap.compute(xid, (key, val) -> {
             if (val != null) {
-                val.stream().filter(branch -> branch.getBranchId() == request.getBranchId()).forEach(branch -> {
-                    branch.setApplicationData(request.getApplicationData());
-                });
+                val.stream()
+                        .filter(branch -> branch.getBranchId() == request.getBranchId())
+                        .forEach(branch -> {
+                            branch.setApplicationData(request.getApplicationData());
+                        });
             }
             return val;
         });
