@@ -16,14 +16,27 @@
  */
 package org.apache.seata.namingserver;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import org.springframework.beans.factory.annotation.Value;
+import org.springframework.boot.ApplicationArguments;
+import org.springframework.boot.ApplicationRunner;
 import org.springframework.boot.SpringApplication;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
 
 @SpringBootApplication(scanBasePackages = {"org.apache.seata"})
-public class NamingserverApplication {
+public class NamingserverApplication implements ApplicationRunner {
+    private static final Logger LOGGER = LoggerFactory.getLogger(NamingserverApplication.class);
+
+    @Value("${server.port}")
+    private int port;
 
     public static void main(String[] args) {
         SpringApplication.run(NamingserverApplication.class, args);
     }
 
+    @Override
+    public void run(ApplicationArguments args) throws Exception {
+        LOGGER.info("Seata Console can be accessed at http://localhost:{}", port);
+    }
 }
