@@ -41,7 +41,7 @@ import java.util.Set;
 
 /**
  * The type Kingbase insert executor.
- * 
+ *
  */
 @LoadLevel(name = JdbcConstants.KINGBASE, scope = Scope.PROTOTYPE)
 public class KingbaseInsertExecutor extends BaseInsertExecutor implements Sequenceable {
@@ -55,8 +55,8 @@ public class KingbaseInsertExecutor extends BaseInsertExecutor implements Sequen
      * @param statementCallback the statement callback
      * @param sqlRecognizer     the sql recognizer
      */
-    public KingbaseInsertExecutor(StatementProxy statementProxy, StatementCallback statementCallback,
-                                SQLRecognizer sqlRecognizer) {
+    public KingbaseInsertExecutor(
+            StatementProxy statementProxy, StatementCallback statementCallback, SQLRecognizer sqlRecognizer) {
         super(statementProxy, statementCallback, sqlRecognizer);
     }
 
@@ -97,7 +97,7 @@ public class KingbaseInsertExecutor extends BaseInsertExecutor implements Sequen
      * @return true: contain at least one pk column. false: do not contain any pk columns
      */
     public boolean containsAnyPk() {
-        SQLInsertRecognizer recognizer = (SQLInsertRecognizer)sqlRecognizer;
+        SQLInsertRecognizer recognizer = (SQLInsertRecognizer) sqlRecognizer;
         List<String> insertColumns = recognizer.getInsertColumns();
         if (CollectionUtils.isEmpty(insertColumns)) {
             return false;
@@ -107,8 +107,9 @@ public class KingbaseInsertExecutor extends BaseInsertExecutor implements Sequen
             return false;
         }
         List<String> newColumns = ColumnUtils.delEscape(insertColumns, getDbType());
-        return pkColumnNameList.stream().anyMatch(pkColumn -> newColumns.contains(pkColumn)
-                || CollectionUtils.toUpperList(newColumns).contains(pkColumn.toUpperCase()));
+        return pkColumnNameList.stream()
+                .anyMatch(pkColumn -> newColumns.contains(pkColumn)
+                        || CollectionUtils.toUpperList(newColumns).contains(pkColumn.toUpperCase()));
     }
 
     @Override
@@ -119,7 +120,10 @@ public class KingbaseInsertExecutor extends BaseInsertExecutor implements Sequen
             List<Object> pkValues = pkValuesMap.get(pkKey);
             for (int i = 0; i < pkValues.size(); i++) {
                 if (!pkKey.isEmpty() && pkValues.get(i) instanceof SqlSequenceExpr) {
-                    pkValues.set(i, getPkValuesBySequence((SqlSequenceExpr) pkValues.get(i), pkKey).get(0));
+                    pkValues.set(
+                            i,
+                            getPkValuesBySequence((SqlSequenceExpr) pkValues.get(i), pkKey)
+                                    .get(0));
                 } else if (!pkKey.isEmpty() && pkValues.get(i) instanceof SqlMethodExpr) {
                     pkValues.set(i, getGeneratedKeys(pkKey).get(0));
                 } else if (!pkKey.isEmpty() && pkValues.get(i) instanceof Null) {
@@ -135,5 +139,4 @@ public class KingbaseInsertExecutor extends BaseInsertExecutor implements Sequen
     public String getSequenceSql(SqlSequenceExpr expr) {
         return "SELECT " + expr.getSequence() + ".currval FROM DUAL";
     }
-
 }
