@@ -16,16 +16,6 @@
  */
 package org.apache.seata.rm.datasource.sql.struct;
 
-import java.sql.Connection;
-import java.sql.SQLException;
-import java.util.Map;
-import java.util.concurrent.BlockingQueue;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.Executor;
-import java.util.concurrent.LinkedBlockingQueue;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-
 import org.apache.seata.common.ConfigurationKeys;
 import org.apache.seata.common.loader.EnhancedServiceLoader;
 import org.apache.seata.common.thread.NamedThreadFactory;
@@ -37,6 +27,16 @@ import org.apache.seata.sqlparser.struct.TableMetaCache;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.sql.Connection;
+import java.sql.SQLException;
+import java.util.Map;
+import java.util.concurrent.BlockingQueue;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.Executor;
+import java.util.concurrent.LinkedBlockingQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+
 import static org.apache.seata.common.DefaultValues.DEFAULT_CLIENT_TABLE_META_CHECK_ENABLE;
 import static org.apache.seata.common.DefaultValues.DEFAULT_TABLE_META_CHECKER_INTERVAL;
 
@@ -60,14 +60,13 @@ public class TableMetaCacheFactory {
      * Enable the table meta checker
      */
     private static boolean ENABLE_TABLE_META_CHECKER_ENABLE = ConfigurationFactory.getInstance()
-        .getBoolean(ConfigurationKeys.CLIENT_TABLE_META_CHECK_ENABLE, DEFAULT_CLIENT_TABLE_META_CHECK_ENABLE);
+            .getBoolean(ConfigurationKeys.CLIENT_TABLE_META_CHECK_ENABLE, DEFAULT_CLIENT_TABLE_META_CHECK_ENABLE);
 
     /**
      * Table meta checker interval
      */
     private static final long TABLE_META_CHECKER_INTERVAL = ConfigurationFactory.getInstance()
-        .getLong(ConfigurationKeys.CLIENT_TABLE_META_CHECKER_INTERVAL, DEFAULT_TABLE_META_CHECKER_INTERVAL);
-
+            .getLong(ConfigurationKeys.CLIENT_TABLE_META_CHECKER_INTERVAL, DEFAULT_TABLE_META_CHECKER_INTERVAL);
 
     /**
      * get table meta cache
@@ -76,8 +75,8 @@ public class TableMetaCacheFactory {
      * @return table meta cache
      */
     public static TableMetaCache getTableMetaCache(String dbType) {
-        return CollectionUtils.computeIfAbsent(TABLE_META_CACHE_MAP, dbType,
-            key -> EnhancedServiceLoader.load(TableMetaCache.class, dbType));
+        return CollectionUtils.computeIfAbsent(
+                TABLE_META_CACHE_MAP, dbType, key -> EnhancedServiceLoader.load(TableMetaCache.class, dbType));
     }
 
     /**
@@ -114,38 +113,49 @@ public class TableMetaCacheFactory {
         private DataSourceProxy dataSource;
         private BlockingQueue<Long> tableMetaRefreshQueue;
 
-
-        private final Executor tableMetaRefreshExecutor = new ThreadPoolExecutor(1, 1, 0L, TimeUnit.MILLISECONDS,
-            new LinkedBlockingQueue<>(), new NamedThreadFactory("tableMetaRefresh", 1, true));
+        private final Executor tableMetaRefreshExecutor = new ThreadPoolExecutor(
+                1,
+                1,
+                0L,
+                TimeUnit.MILLISECONDS,
+                new LinkedBlockingQueue<>(),
+                new NamedThreadFactory("tableMetaRefresh", 1, true));
 
         TableMetaRefreshHolder(DataSourceProxy dataSource) {
             this.dataSource = dataSource;
-            this.lastRefreshFinishTime = System.nanoTime() - TimeUnit.MILLISECONDS.toNanos(TABLE_META_REFRESH_INTERVAL_TIME);
+            this.lastRefreshFinishTime =
+                    System.nanoTime() - TimeUnit.MILLISECONDS.toNanos(TABLE_META_REFRESH_INTERVAL_TIME);
             this.tableMetaRefreshQueue = new LinkedBlockingQueue<>(MAX_QUEUE_SIZE);
 
             tableMetaRefreshExecutor.execute(() -> {
                 while (true) {
                     // 1. check table meta
                     if (ENABLE_TABLE_META_CHECKER_ENABLE
-                        && System.nanoTime() - lastRefreshFinishTime > TimeUnit.MILLISECONDS.toNanos(TABLE_META_CHECKER_INTERVAL)) {
+                            && System.nanoTime() - lastRefreshFinishTime
+                                    > TimeUnit.MILLISECONDS.toNanos(TABLE_META_CHECKER_INTERVAL)) {
                         tableMetaRefreshEvent(dataSource.getResourceId());
                     }
 
                     // 2. refresh table meta
                     try {
-                        Long eventTime = tableMetaRefreshQueue.poll(TABLE_META_REFRESH_INTERVAL_TIME, TimeUnit.MILLISECONDS);
+                        Long eventTime =
+                                tableMetaRefreshQueue.poll(TABLE_META_REFRESH_INTERVAL_TIME, TimeUnit.MILLISECONDS);
                         // if it has bean refreshed not long ago, skip
-                        if (eventTime != null && eventTime - lastRefreshFinishTime > TimeUnit.MILLISECONDS.toNanos(TABLE_META_REFRESH_INTERVAL_TIME)) {
+                        if (eventTime != null
+                                && eventTime - lastRefreshFinishTime
+                                        > TimeUnit.MILLISECONDS.toNanos(TABLE_META_REFRESH_INTERVAL_TIME)) {
                             try (Connection connection = dataSource.getConnection()) {
                                 TableMetaCache tableMetaCache =
-                                    TableMetaCacheFactory.getTableMetaCache(dataSource.getDbType());
+                                        TableMetaCacheFactory.getTableMetaCache(dataSource.getDbType());
                                 tableMetaCache.refresh(connection, dataSource.getResourceId());
                             }
                             lastRefreshFinishTime = System.nanoTime();
                         }
                     } catch (SQLException ex) {
                         if (isDataSourceClosedException(ex)) {
-                            LOGGER.info("DataSource is closed, exiting refresh task for resourceId: {}", dataSource.getResourceId());
+                            LOGGER.info(
+                                    "DataSource is closed, exiting refresh task for resourceId: {}",
+                                    dataSource.getResourceId());
                             removeHolderFromMap(dataSource.getResourceId());
                             return;
                         } else {
