@@ -57,19 +57,23 @@ public class DmTableMetaCache extends OracleTableMetaCache {
     protected TableMeta resultSetMetaToSchema(DatabaseMetaData dbmd, String tableName) throws SQLException {
         TableMeta result = new TableMeta();
 
-        TableNameMeta tableNameMeta = toTableNameMeta(tableName, dbmd.getConnection().getSchema());
+        TableNameMeta tableNameMeta =
+                toTableNameMeta(tableName, dbmd.getConnection().getSchema());
         result.setTableName(tableNameMeta.getTableName());
         result.setOriginalTableName(tableName);
         try (ResultSet rsColumns = dbmd.getColumns("", tableNameMeta.getSchema(), tableNameMeta.getTableName(), "%");
-             ResultSet rsIndex = dbmd.getIndexInfo(null, tableNameMeta.getSchema(), tableNameMeta.getTableName(), false, true);
-             ResultSet rsPrimary = dbmd.getPrimaryKeys(null, tableNameMeta.getSchema(), tableNameMeta.getTableName())) {
+                ResultSet rsIndex =
+                        dbmd.getIndexInfo(null, tableNameMeta.getSchema(), tableNameMeta.getTableName(), false, true);
+                ResultSet rsPrimary =
+                        dbmd.getPrimaryKeys(null, tableNameMeta.getSchema(), tableNameMeta.getTableName())) {
             processColumns(result, rsColumns);
 
             processIndexes(result, rsIndex);
 
             processPrimaries(result, rsPrimary);
             if (result.getAllIndexes().isEmpty()) {
-                throw new ShouldNeverHappenException(String.format("Could not found any index in the table: %s", tableName));
+                throw new ShouldNeverHappenException(
+                        String.format("Could not found any index in the table: %s", tableName));
             }
         }
 
