@@ -16,11 +16,6 @@
  */
 package org.apache.seata.rm.datasource.sql.struct.cache;
 
-import java.sql.Connection;
-import java.sql.DatabaseMetaData;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-
 import org.apache.seata.common.exception.NotSupportYetException;
 import org.apache.seata.common.exception.ShouldNeverHappenException;
 import org.apache.seata.common.loader.LoadLevel;
@@ -31,6 +26,10 @@ import org.apache.seata.sqlparser.struct.IndexType;
 import org.apache.seata.sqlparser.struct.TableMeta;
 import org.apache.seata.sqlparser.util.JdbcConstants;
 
+import java.sql.Connection;
+import java.sql.DatabaseMetaData;
+import java.sql.ResultSet;
+import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
@@ -47,9 +46,9 @@ public class OracleTableMetaCache extends AbstractTableMetaCache {
         StringBuilder cacheKey = new StringBuilder(resourceId);
         cacheKey.append(".");
 
-        //original: separate it to schemaName and tableName
-        //now: Use the original table name to avoid cache errors of tables with the same name across databases
-        //oracle does not implement supportsMixedCaseIdentifiers in DatabaseMetadata
+        // original: separate it to schemaName and tableName
+        // now: Use the original table name to avoid cache errors of tables with the same name across databases
+        // oracle does not implement supportsMixedCaseIdentifiers in DatabaseMetadata
         if (tableName.contains("\"")) {
             cacheKey.append(tableName.replace("\"", ""));
         } else {
@@ -98,8 +97,8 @@ public class OracleTableMetaCache extends AbstractTableMetaCache {
         tm.setCaseSensitive(StringUtils.hasLowerCase(tableName));
 
         try (ResultSet rsColumns = dbmd.getColumns("", schemaName, tableName, "%");
-             ResultSet rsIndex = dbmd.getIndexInfo(null, schemaName, tableName, false, true);
-             ResultSet rsPrimary = dbmd.getPrimaryKeys(null, schemaName, tableName)) {
+                ResultSet rsIndex = dbmd.getIndexInfo(null, schemaName, tableName, false, true);
+                ResultSet rsPrimary = dbmd.getPrimaryKeys(null, schemaName, tableName)) {
             while (rsColumns.next()) {
                 ColumnMeta col = new ColumnMeta();
                 col.setTableCat(rsColumns.getString("TABLE_CAT"));
@@ -122,7 +121,8 @@ public class OracleTableMetaCache extends AbstractTableMetaCache {
                 col.setCaseSensitive(StringUtils.hasLowerCase(col.getColumnName()));
 
                 if (tm.getAllColumns().containsKey(col.getColumnName())) {
-                    throw new NotSupportYetException("Not support the table has the same column name with different case yet");
+                    throw new NotSupportYetException(
+                            "Not support the table has the same column name with different case yet");
                 }
                 tm.getAllColumns().put(col.getColumnName(), col);
             }
@@ -154,11 +154,11 @@ public class OracleTableMetaCache extends AbstractTableMetaCache {
                         index.setIndextype(IndexType.NORMAL);
                     }
                     tm.getAllIndexes().put(indexName, index);
-
                 }
             }
             if (tm.getAllIndexes().isEmpty()) {
-                throw new ShouldNeverHappenException(String.format("Could not found any index in the table: %s", tableName));
+                throw new ShouldNeverHappenException(
+                        String.format("Could not found any index in the table: %s", tableName));
             }
             // when we create a primary key constraint oracle will uses and existing unique index.
             // if we create a unique index before create a primary constraint in the same column will cause the problem
@@ -170,11 +170,11 @@ public class OracleTableMetaCache extends AbstractTableMetaCache {
                     IndexMeta index = tm.getAllIndexes().get(pkConstraintName);
                     index.setIndextype(IndexType.PRIMARY);
                 } else {
-                    //save the columns that constraint primary key name was different from unique index name
+                    // save the columns that constraint primary key name was different from unique index name
                     pkcol.add(rsPrimary.getString("COLUMN_NAME"));
                 }
             }
-            //find the index that belong to the primary key constraint
+            // find the index that belong to the primary key constraint
             if (!pkcol.isEmpty()) {
                 int matchCols = 0;
                 for (Map.Entry<String, IndexMeta> entry : tm.getAllIndexes().entrySet()) {
