@@ -16,11 +16,6 @@
  */
 package org.apache.seata.rm.datasource.sql.struct.cache;
 
-import java.sql.Connection;
-import java.sql.DatabaseMetaData;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-
 import org.apache.seata.common.exception.NotSupportYetException;
 import org.apache.seata.common.exception.ShouldNeverHappenException;
 import org.apache.seata.common.loader.LoadLevel;
@@ -35,6 +30,11 @@ import org.apache.seata.sqlparser.util.JdbcConstants;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.sql.Connection;
+import java.sql.DatabaseMetaData;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+
 /**
  * The type SqlServer Table meta cache.
  *
@@ -57,14 +57,17 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
         }
 
         try {
-            //prevent duplicated cache key
+            // prevent duplicated cache key
             if (databaseMetaData.supportsMixedCaseIdentifiers()) {
                 cacheKey.append(tableName);
             } else {
                 cacheKey.append(tableName.toUpperCase());
             }
         } catch (SQLException e) {
-            LOGGER.error("Could not get supportsMixedCaseIdentifiers in connection metadata, use default cache key {}", e.getMessage(), e);
+            LOGGER.error(
+                    "Could not get supportsMixedCaseIdentifiers in connection metadata, use default cache key {}",
+                    e.getMessage(),
+                    e);
             return cacheKey.append(tableName).toString();
         }
 
@@ -89,7 +92,7 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
 
         tableName = ColumnUtils.delEscape(tableName, JdbcConstants.SQLSERVER);
         String[] schemaTable = tableName.split("\\.");
-        //get catalog and schema from tableName
+        // get catalog and schema from tableName
         String catalogName = "";
         String schemaName = "";
         if (schemaTable.length > 2) {
@@ -98,22 +101,22 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
             schemaName = schemaTable[schemaTable.length - 2];
         }
 
-        //If the tableName does not contain the required information, get from connection
+        // If the tableName does not contain the required information, get from connection
         if (StringUtils.isBlank(catalogName)) {
             catalogName = connection.getCatalog();
         }
         if (StringUtils.isBlank(schemaName)) {
             schemaName = connection.getSchema();
         }
-        //get pure tableName
+        // get pure tableName
         String pureTableName = schemaTable[schemaTable.length - 1];
 
         DatabaseMetaData metaData = connection.getMetaData();
         try (ResultSet rsColumns = metaData.getColumns(catalogName, schemaName, pureTableName, "%");
-             ResultSet rsIndex = metaData.getIndexInfo(catalogName, schemaName, pureTableName, false, true);
-             ResultSet rsTable = metaData.getTables(catalogName, schemaName, pureTableName, new String[]{"TABLE"});
-             ResultSet rsPrimary = metaData.getPrimaryKeys(catalogName, schemaName, pureTableName)) {
-            //get column metaData
+                ResultSet rsIndex = metaData.getIndexInfo(catalogName, schemaName, pureTableName, false, true);
+                ResultSet rsTable = metaData.getTables(catalogName, schemaName, pureTableName, new String[] {"TABLE"});
+                ResultSet rsPrimary = metaData.getPrimaryKeys(catalogName, schemaName, pureTableName)) {
+            // get column metaData
             while (rsColumns.next()) {
                 ColumnMeta col = new ColumnMeta();
                 col.setTableCat(rsColumns.getString("TABLE_CAT"));
@@ -126,7 +129,7 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
                 col.setDecimalDigits(rsColumns.getInt("DECIMAL_DIGITS"));
                 col.setNumPrecRadix(rsColumns.getInt("NUM_PREC_RADIX"));
                 col.setNullAble(rsColumns.getInt("NULLABLE"));
-                //always return NULL for REMARKS label
+                // always return NULL for REMARKS label
                 col.setRemarks(rsColumns.getString("REMARKS"));
                 col.setColumnDef(rsColumns.getString("COLUMN_DEF"));
                 col.setSqlDataType(rsColumns.getInt("SQL_DATA_TYPE"));
@@ -140,12 +143,13 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
                 }
 
                 if (tm.getAllColumns().containsKey(col.getColumnName())) {
-                    throw new NotSupportYetException("Not support the table has the same column name with different case yet");
+                    throw new NotSupportYetException(
+                            "Not support the table has the same column name with different case yet");
                 }
                 tm.getAllColumns().put(col.getColumnName(), col);
             }
 
-            //get index metaData
+            // get index metaData
             while (rsIndex.next()) {
                 String indexName = rsIndex.getString("INDEX_NAME");
                 if (StringUtils.isNullOrEmpty(indexName)) {
@@ -163,9 +167,9 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
                     index.setIndexQualifier(rsIndex.getString("INDEX_QUALIFIER"));
                     index.setIndexName(rsIndex.getString("INDEX_NAME"));
                     index.setType(rsIndex.getShort("TYPE"));
-                    //start from '1'
+                    // start from '1'
                     index.setOrdinalPosition(rsIndex.getShort("ORDINAL_POSITION"));
-                    //SqlServer always return 'A', means Ascending
+                    // SqlServer always return 'A', means Ascending
                     index.setAscOrDesc(rsIndex.getString("ASC_OR_DESC"));
                     index.setCardinality(rsIndex.getInt("CARDINALITY"));
                     index.getValues().add(col);
@@ -186,18 +190,20 @@ public class SqlServerTableMetaCache extends AbstractTableMetaCache {
                 }
             }
             if (tm.getAllIndexes().isEmpty()) {
-                throw new ShouldNeverHappenException(String.format("Could not found any index in the table: %s", tableName));
+                throw new ShouldNeverHappenException(
+                        String.format("Could not found any index in the table: %s", tableName));
             }
 
             while (rsTable.next()) {
                 String rsTableSchema = rsTable.getString("TABLE_SCHEM");
                 String rsTableName = rsTable.getString("TABLE_NAME");
-                //set origin tableName with schema if necessary
+                // set origin tableName with schema if necessary
                 if ("dbo".equalsIgnoreCase(rsTableSchema)) {
-                    //for compatibility reasons, old clients generally do not have the 'dbo' default schema by default.
+                    // for compatibility reasons, old clients generally do not have the 'dbo' default schema by default.
                     tm.setTableName(rsTableName);
                 } else {
-                    //without schema, different records with the same primary key value and the same table name in different schemas may have the same lock record.
+                    // without schema, different records with the same primary key value and the same table name in
+                    // different schemas may have the same lock record.
                     tm.setTableName(rsTableSchema + "." + rsTableName);
                 }
             }
