@@ -16,24 +16,7 @@
  */
 package org.apache.seata.rm.datasource.undo;
 
-import java.io.ByteArrayInputStream;
-import java.sql.Array;
-import java.sql.Connection;
-import java.sql.JDBCType;
-import java.sql.PreparedStatement;
-import java.sql.ResultSet;
-import java.sql.SQLException;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
-import java.util.stream.Collectors;
-
-import javax.sql.rowset.serial.SerialBlob;
-import javax.sql.rowset.serial.SerialClob;
-import javax.sql.rowset.serial.SerialDatalink;
-
 import com.alibaba.fastjson.JSON;
-
 import org.apache.seata.common.util.IOUtil;
 import org.apache.seata.common.util.StringUtils;
 import org.apache.seata.config.ConfigurationFactory;
@@ -52,6 +35,21 @@ import org.apache.seata.sqlparser.util.ColumnUtils;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import javax.sql.rowset.serial.SerialBlob;
+import javax.sql.rowset.serial.SerialClob;
+import javax.sql.rowset.serial.SerialDatalink;
+import java.io.ByteArrayInputStream;
+import java.sql.Array;
+import java.sql.Connection;
+import java.sql.JDBCType;
+import java.sql.PreparedStatement;
+import java.sql.ResultSet;
+import java.sql.SQLException;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Map;
+import java.util.stream.Collectors;
+
 import static org.apache.seata.common.DefaultValues.DEFAULT_TRANSACTION_UNDO_DATA_VALIDATION;
 
 /**
@@ -143,12 +141,10 @@ public abstract class AbstractUndoExecutor {
             } else {
                 throw new SQLException(ex);
             }
-        }
-        finally {
-            //important for oracle
+        } finally {
+            // important for oracle
             IOUtil.close(undoPST);
         }
-
     }
 
     /**
@@ -219,7 +215,6 @@ public abstract class AbstractUndoExecutor {
             undoIndex++;
             undoPST.setObject(undoIndex, pkField.getValue(), pkField.getType());
         }
-
     }
 
     /**
@@ -246,8 +241,8 @@ public abstract class AbstractUndoExecutor {
         Result<Boolean> beforeEqualsAfterResult = DataCompareUtils.isRecordsEquals(beforeRecords, afterRecords);
         if (beforeEqualsAfterResult.getResult()) {
             if (LOGGER.isInfoEnabled()) {
-                LOGGER.info("Stop rollback because there is no data change " +
-                        "between the before data snapshot and the after data snapshot.");
+                LOGGER.info("Stop rollback because there is no data change "
+                        + "between the before data snapshot and the after data snapshot.");
             }
             // no need continue undo.
             return false;
@@ -264,8 +259,8 @@ public abstract class AbstractUndoExecutor {
             Result<Boolean> beforeEqualsCurrentResult = DataCompareUtils.isRecordsEquals(beforeRecords, currentRecords);
             if (beforeEqualsCurrentResult.getResult()) {
                 if (LOGGER.isInfoEnabled()) {
-                    LOGGER.info("Stop rollback because there is no data change " +
-                            "between the before data snapshot and the current data snapshot.");
+                    LOGGER.info("Stop rollback because there is no data change "
+                            + "between the before data snapshot and the current data snapshot.");
                 }
                 // no need continue undo.
                 return false;
@@ -276,10 +271,10 @@ public abstract class AbstractUndoExecutor {
                     }
                 }
                 if (LOGGER.isDebugEnabled()) {
-                    LOGGER.debug("check dirty data failed, old and new data are not equal, " +
-                            "tableName:[" + sqlUndoLog.getTableName() + "]," +
-                            "oldRows:[" + JSON.toJSONString(afterRecords.getRows()) + "]," +
-                            "newRows:[" + JSON.toJSONString(currentRecords.getRows()) + "].");
+                    LOGGER.debug("check dirty data failed, old and new data are not equal, " + "tableName:["
+                            + sqlUndoLog.getTableName() + "]," + "oldRows:["
+                            + JSON.toJSONString(afterRecords.getRows()) + "]," + "newRows:["
+                            + JSON.toJSONString(currentRecords.getRows()) + "].");
                 }
                 throw new SQLUndoDirtyException("Has dirty records when undo.");
             }
@@ -298,7 +293,7 @@ public abstract class AbstractUndoExecutor {
         Connection conn = connectionProxy.getTargetConnection();
         TableRecords undoRecords = getUndoRows();
         TableMeta tableMeta = undoRecords.getTableMeta();
-        //the order of element matters
+        // the order of element matters
         List<String> pkNameList = tableMeta.getPrimaryKeyOnlyName();
 
         // pares pk values
@@ -309,7 +304,8 @@ public abstract class AbstractUndoExecutor {
         // build check sql
         String firstKey = pkRowValues.keySet().stream().findFirst().get();
         int pkRowSize = pkRowValues.get(firstKey).size();
-        List<SqlGenerateUtils.WhereSql> sqlConditions = SqlGenerateUtils.buildWhereConditionListByPKs(pkNameList, pkRowSize, connectionProxy.getDbType());
+        List<SqlGenerateUtils.WhereSql> sqlConditions =
+                SqlGenerateUtils.buildWhereConditionListByPKs(pkNameList, pkRowSize, connectionProxy.getDbType());
         TableRecords currentRecords = new TableRecords(tableMeta);
         int totalRowIndex = 0;
         for (SqlGenerateUtils.WhereSql sqlCondition : sqlConditions) {
@@ -331,7 +327,9 @@ public abstract class AbstractUndoExecutor {
                 totalRowIndex += sqlCondition.getRowSize();
 
                 checkSet = statement.executeQuery();
-                currentRecords.getRows().addAll(TableRecords.buildRecords(tableMeta, checkSet).getRows());
+                currentRecords
+                        .getRows()
+                        .addAll(TableRecords.buildRecords(tableMeta, checkSet).getRows());
             } finally {
                 IOUtil.close(checkSet, statement);
             }
@@ -354,8 +352,7 @@ public abstract class AbstractUndoExecutor {
         List<Field> pkFields = new ArrayList<>();
         // To ensure the order of the pk, the order should based on getPrimaryKeyOnlyName.
         List<String> pkColumnNameListByOrder = image.getTableMeta().getPrimaryKeyOnlyName();
-        List<String> pkColumnNameListNoOrder = row.primaryKeys()
-                .stream()
+        List<String> pkColumnNameListNoOrder = row.primaryKeys().stream()
                 .map(e -> ColumnUtils.delEscape(e.getName(), dbType))
                 .collect(Collectors.toList());
         pkColumnNameListByOrder.forEach(pkName -> {
@@ -368,7 +365,6 @@ public abstract class AbstractUndoExecutor {
         return pkFields;
     }
 
-
     /**
      * Parse pk values Field List.
      *
@@ -401,5 +397,4 @@ public abstract class AbstractUndoExecutor {
         Map<String, List<Field>> pkValueMap = pkFieldList.stream().collect(Collectors.groupingBy(Field::getName));
         return pkValueMap;
     }
-
 }
