@@ -59,27 +59,25 @@ public class DmUndoDeleteExecutor extends AbstractUndoExecutor {
         }
         Row row = beforeImageRows.get(0);
         List<Field> fields = new ArrayList<>(row.nonPrimaryKeys());
-        fields.addAll(getOrderedPkList(beforeImage,row,JdbcConstants.DM));
+        fields.addAll(getOrderedPkList(beforeImage, row, JdbcConstants.DM));
 
         // delete sql undo log before image all field come from table meta, need add escape.
         // see BaseTransactionalExecutor#buildTableRecords
         String insertColumns = fields.stream()
-            .map(field -> ColumnUtils.addEscape(field.getName(), JdbcConstants.DM))
-            .collect(Collectors.joining(", "));
-        String insertValues = fields.stream().map(field -> "?")
-            .collect(Collectors.joining(", "));
+                .map(field -> ColumnUtils.addEscape(field.getName(), JdbcConstants.DM))
+                .collect(Collectors.joining(", "));
+        String insertValues = fields.stream().map(field -> "?").collect(Collectors.joining(", "));
 
-        return "SET IDENTITY_INSERT " +
-                sqlUndoLog.getTableName() +
-                " ON; INSERT INTO " +
-                sqlUndoLog.getTableName() +
-                " (" +
-                insertColumns +
-                ") VALUES (" +
-                insertValues +
-                "); SET IDENTITY_INSERT " +
-                sqlUndoLog.getTableName() +
-                " OFF;";
+        return "SET IDENTITY_INSERT " + sqlUndoLog.getTableName()
+                + " ON; INSERT INTO "
+                + sqlUndoLog.getTableName()
+                + " ("
+                + insertColumns
+                + ") VALUES ("
+                + insertValues
+                + "); SET IDENTITY_INSERT "
+                + sqlUndoLog.getTableName()
+                + " OFF;";
     }
 
     @Override
