@@ -16,13 +16,6 @@
  */
 package org.apache.seata.rm.datasource.undo.sqlserver;
 
-import java.sql.Connection;
-import java.sql.PreparedStatement;
-import java.sql.SQLException;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.stream.Collectors;
-
 import org.apache.seata.common.exception.ShouldNeverHappenException;
 import org.apache.seata.common.util.CollectionUtils;
 import org.apache.seata.common.util.IOUtil;
@@ -38,6 +31,12 @@ import org.apache.seata.sqlparser.struct.TableMeta;
 import org.apache.seata.sqlparser.util.ColumnUtils;
 import org.apache.seata.sqlparser.util.JdbcConstants;
 
+import java.sql.Connection;
+import java.sql.PreparedStatement;
+import java.sql.SQLException;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.stream.Collectors;
 
 public class SqlServerUndoDeleteExecutor extends BaseSqlServerUndoExecutor {
 
@@ -68,15 +67,14 @@ public class SqlServerUndoDeleteExecutor extends BaseSqlServerUndoExecutor {
         String insertColumns = fields.stream()
                 .map(field -> ColumnUtils.addEscape(field.getName(), JdbcConstants.SQLSERVER))
                 .collect(Collectors.joining(", "));
-        String insertValues = fields.stream().map(field -> "?")
-                .collect(Collectors.joining(", "));
+        String insertValues = fields.stream().map(field -> "?").collect(Collectors.joining(", "));
 
         if (tableIdentifyExistence) {
-            return "begin " +
-                    "SET IDENTITY_INSERT " + sqlUndoLog.getTableName() + " ON;" +
-                    "INSERT INTO " + sqlUndoLog.getTableName() + "(" + insertColumns + ") VALUES (" + insertValues + ");" +
-                    "SET IDENTITY_INSERT " + sqlUndoLog.getTableName() + " OFF; " +
-                    "end";
+            return "begin " + "SET IDENTITY_INSERT "
+                    + sqlUndoLog.getTableName() + " ON;" + "INSERT INTO "
+                    + sqlUndoLog.getTableName() + "(" + insertColumns + ") VALUES (" + insertValues + ");"
+                    + "SET IDENTITY_INSERT "
+                    + sqlUndoLog.getTableName() + " OFF; " + "end";
         }
         return "INSERT INTO " + sqlUndoLog.getTableName() + "(" + insertColumns + ") VALUES (" + insertValues + ");";
     }
@@ -91,8 +89,7 @@ public class SqlServerUndoDeleteExecutor extends BaseSqlServerUndoExecutor {
                 .getTableMeta(
                         connectionProxy.getTargetConnection(),
                         sqlUndoLog.getTableName(),
-                        connectionProxy.getDataSourceProxy().getResourceId()
-                );
+                        connectionProxy.getDataSourceProxy().getResourceId());
         tableIdentifyExistence = ((SqlServerTableMeta) tableMeta).isTableIdentifyExistence();
     }
 
@@ -139,7 +136,6 @@ public class SqlServerUndoDeleteExecutor extends BaseSqlServerUndoExecutor {
         } finally {
             IOUtil.close(undoPST);
         }
-
     }
 
     @Override
