@@ -16,6 +16,19 @@
  */
 package org.apache.seata.rm.datasource.exec;
 
+import org.apache.seata.common.exception.NotSupportYetException;
+import org.apache.seata.rm.datasource.ConnectionProxy;
+import org.apache.seata.rm.datasource.PreparedStatementProxy;
+import org.apache.seata.rm.datasource.exec.mysql.MySQLInsertExecutor;
+import org.apache.seata.sqlparser.SQLInsertRecognizer;
+import org.apache.seata.sqlparser.struct.Null;
+import org.apache.seata.sqlparser.struct.TableMeta;
+import org.apache.seata.sqlparser.util.JdbcConstants;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.mockito.Mockito;
+
 import java.sql.SQLException;
 import java.util.ArrayList;
 import java.util.Arrays;
@@ -23,26 +36,10 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import org.apache.seata.rm.datasource.exec.StatementCallback;
-import org.apache.seata.common.exception.NotSupportYetException;
-import org.apache.seata.rm.datasource.ConnectionProxy;
-import org.apache.seata.rm.datasource.PreparedStatementProxy;
-import org.apache.seata.rm.datasource.exec.mysql.MySQLInsertExecutor;
-import org.apache.seata.sqlparser.struct.TableMeta;
-import org.apache.seata.sqlparser.SQLInsertRecognizer;
-import org.apache.seata.sqlparser.struct.Null;
-import org.apache.seata.sqlparser.util.JdbcConstants;
-import org.junit.jupiter.api.Assertions;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.mockito.Mockito;
-
-
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
-
 /**
  * batch insert executor test
  *
@@ -55,7 +52,6 @@ public class BatchInsertExecutorTest {
     private static final String USER_STATUS_COLUMN = "user_status";
     private static final List<Integer> PK_VALUES = Arrays.asList(100000001, 100000002, 100000003, 100000004, 100000005);
 
-
     private PreparedStatementProxy statementProxy;
 
     private SQLInsertRecognizer sqlInsertRecognizer;
@@ -80,9 +76,11 @@ public class BatchInsertExecutorTest {
         tableMeta = mock(TableMeta.class);
         insertExecutor = Mockito.spy(new MySQLInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
 
-        pkIndexMap = new HashMap() {{
-            put(ID_COLUMN, pkIndex);
-        }};
+        pkIndexMap = new HashMap() {
+            {
+                put(ID_COLUMN, pkIndex);
+            }
+        };
 
         doReturn(pkIndexMap).when(insertExecutor).getPkIndex();
     }
@@ -92,10 +90,10 @@ public class BatchInsertExecutorTest {
         mockInsertColumns();
         mockParameters();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.addAll(PK_VALUES);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesMap.keySet(), tableMeta.getPrimaryKeyOnlyName());
         Assertions.assertIterableEquals(pkValuesMap.get(ID_COLUMN), pkValues);
     }
@@ -107,8 +105,8 @@ public class BatchInsertExecutorTest {
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(ID_COLUMN));
         List<Object> pkValues = new ArrayList<>(PK_VALUES);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
-        Assertions.assertIterableEquals(pkValues,pkValuesMap.get(ID_COLUMN) );
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Assertions.assertIterableEquals(pkValues, pkValuesMap.get(ID_COLUMN));
     }
 
     @Test
@@ -116,10 +114,10 @@ public class BatchInsertExecutorTest {
         mockInsertColumns();
         mockParametersWithPkRefOfJDBC();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.addAll(PK_VALUES);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesMap.keySet(), tableMeta.getPrimaryKeyOnlyName());
         Assertions.assertIterableEquals(pkValuesMap.get(ID_COLUMN), pkValues);
     }
@@ -130,25 +128,25 @@ public class BatchInsertExecutorTest {
         int pkId = PK_VALUES.get(0);
         mockParametersWithPkUnRefOfJDBC(pkId);
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.add(pkId);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesMap.keySet(), tableMeta.getPrimaryKeyOnlyName());
         Assertions.assertIterableEquals(pkValuesMap.get(ID_COLUMN), pkValues);
     }
 
-    //----------------mysql batch values (),(),()------------------------
+    // ----------------mysql batch values (),(),()------------------------
 
     @Test
     public void testGetPkValuesByColumnAndAllRefOfMysql() throws SQLException {
         mockInsertColumns();
         mockParametersAllRefOfMysql();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.addAll(PK_VALUES);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesMap.keySet(), tableMeta.getPrimaryKeyOnlyName());
         Assertions.assertIterableEquals(pkValuesMap.get(ID_COLUMN), pkValues);
     }
@@ -158,10 +156,10 @@ public class BatchInsertExecutorTest {
         mockInsertColumns();
         mockParametersWithPkRefOfMysql();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.addAll(PK_VALUES);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesMap.keySet(), tableMeta.getPrimaryKeyOnlyName());
         Assertions.assertIterableEquals(pkValuesMap.get(ID_COLUMN), pkValues);
     }
@@ -171,10 +169,10 @@ public class BatchInsertExecutorTest {
         mockInsertColumns();
         mockParametersWithPkUnRefOfMysql();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.addAll(PK_VALUES);
-        Map<String,List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesMap = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesMap.keySet(), tableMeta.getPrimaryKeyOnlyName());
         Assertions.assertIterableEquals(pkValuesMap.get(ID_COLUMN), pkValues);
     }
@@ -185,13 +183,13 @@ public class BatchInsertExecutorTest {
             mockInsertColumns();
             mockParameters_with_number_and_insertRows_with_placeholde_null();
             doReturn(tableMeta).when(insertExecutor).getTableMeta();
-            Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+            Mockito.when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
             insertExecutor.getPkValuesByColumn();
         });
     }
 
     private void mockParameters_with_null_and_insertRows_with_placeholder_null() {
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>();
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>();
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add("userId1");
         ArrayList arrayList1 = new ArrayList<>();
@@ -216,7 +214,7 @@ public class BatchInsertExecutorTest {
     }
 
     private void mockParameters_with_number_and_insertRows_with_placeholde_null() {
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>();
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>();
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add("userId1");
         ArrayList arrayList1 = new ArrayList<>();
@@ -252,7 +250,7 @@ public class BatchInsertExecutorTest {
 
     private void mockParameters() {
         int PK_INDEX = 1;
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>();
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>();
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add("userId1");
         arrayList0.add("userId2");
@@ -293,7 +291,7 @@ public class BatchInsertExecutorTest {
 
     private void mockParametersAllRefOfMysql() {
 
-        Map<Integer,ArrayList<Object>> paramters = new HashMap(20);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap(20);
         ArrayList arrayList1 = new ArrayList<>();
         arrayList1.add("userId1");
         ArrayList arrayList2 = new ArrayList<>();
@@ -339,27 +337,26 @@ public class BatchInsertExecutorTest {
         ArrayList arrayList20 = new ArrayList<>();
         arrayList20.add("userStatus5");
 
-
-        paramters.put(1,arrayList1);
-        paramters.put(2,arrayList2);
-        paramters.put(3,arrayList3);
-        paramters.put(4,arrayList4);
-        paramters.put(5,arrayList5);
-        paramters.put(6,arrayList6);
-        paramters.put(7,arrayList7);
-        paramters.put(8,arrayList8);
-        paramters.put(9,arrayList9);
-        paramters.put(10,arrayList10);
-        paramters.put(11,arrayList11);
-        paramters.put(12,arrayList12);
-        paramters.put(13,arrayList13);
-        paramters.put(14,arrayList14);
-        paramters.put(15,arrayList15);
-        paramters.put(16,arrayList16);
-        paramters.put(17,arrayList17);
-        paramters.put(18,arrayList18);
-        paramters.put(19,arrayList19);
-        paramters.put(20,arrayList20);
+        paramters.put(1, arrayList1);
+        paramters.put(2, arrayList2);
+        paramters.put(3, arrayList3);
+        paramters.put(4, arrayList4);
+        paramters.put(5, arrayList5);
+        paramters.put(6, arrayList6);
+        paramters.put(7, arrayList7);
+        paramters.put(8, arrayList8);
+        paramters.put(9, arrayList9);
+        paramters.put(10, arrayList10);
+        paramters.put(11, arrayList11);
+        paramters.put(12, arrayList12);
+        paramters.put(13, arrayList13);
+        paramters.put(14, arrayList14);
+        paramters.put(15, arrayList15);
+        paramters.put(16, arrayList16);
+        paramters.put(17, arrayList17);
+        paramters.put(18, arrayList18);
+        paramters.put(19, arrayList19);
+        paramters.put(20, arrayList20);
         List<List<Object>> insertRows = new ArrayList<>();
         insertRows.add(Arrays.asList("?", "?", "?", "?"));
         insertRows.add(Arrays.asList("?", "?", "?", "?"));
@@ -373,7 +370,7 @@ public class BatchInsertExecutorTest {
 
     private void mockParametersWithPkRefOfMysql() {
 
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(10);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(10);
         ArrayList arrayList1 = new ArrayList<>();
         arrayList1.add("userId1");
         ArrayList arrayList2 = new ArrayList<>();
@@ -394,16 +391,16 @@ public class BatchInsertExecutorTest {
         arrayList9.add("userId5");
         ArrayList arrayList10 = new ArrayList<>();
         arrayList10.add(100000005);
-        paramters.put(1,arrayList1);
-        paramters.put(2,arrayList2);
-        paramters.put(3,arrayList3);
-        paramters.put(4,arrayList4);
-        paramters.put(5,arrayList5);
-        paramters.put(6,arrayList6);
-        paramters.put(7,arrayList7);
-        paramters.put(8,arrayList8);
-        paramters.put(9,arrayList9);
-        paramters.put(10,arrayList10);
+        paramters.put(1, arrayList1);
+        paramters.put(2, arrayList2);
+        paramters.put(3, arrayList3);
+        paramters.put(4, arrayList4);
+        paramters.put(5, arrayList5);
+        paramters.put(6, arrayList6);
+        paramters.put(7, arrayList7);
+        paramters.put(8, arrayList8);
+        paramters.put(9, arrayList9);
+        paramters.put(10, arrayList10);
         List<List<Object>> insertRows = new ArrayList<>();
         insertRows.add(Arrays.asList("?", "?", "1", "11"));
         insertRows.add(Arrays.asList("?", "?", "2", "22"));
@@ -417,7 +414,7 @@ public class BatchInsertExecutorTest {
 
     private void mockParametersWithPkUnRefOfMysql() {
 
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(10);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(10);
         ArrayList arrayList1 = new ArrayList<>();
         arrayList1.add("userId1");
         ArrayList arrayList2 = new ArrayList<>();
@@ -438,16 +435,16 @@ public class BatchInsertExecutorTest {
         arrayList9.add("userId5");
         ArrayList arrayList10 = new ArrayList<>();
         arrayList10.add(100000005);
-        paramters.put(1,arrayList1);
-        paramters.put(2,arrayList2);
-        paramters.put(3,arrayList3);
-        paramters.put(4,arrayList4);
-        paramters.put(5,arrayList5);
-        paramters.put(6,arrayList6);
-        paramters.put(7,arrayList7);
-        paramters.put(8,arrayList8);
-        paramters.put(9,arrayList9);
-        paramters.put(10,arrayList10);
+        paramters.put(1, arrayList1);
+        paramters.put(2, arrayList2);
+        paramters.put(3, arrayList3);
+        paramters.put(4, arrayList4);
+        paramters.put(5, arrayList5);
+        paramters.put(6, arrayList6);
+        paramters.put(7, arrayList7);
+        paramters.put(8, arrayList8);
+        paramters.put(9, arrayList9);
+        paramters.put(10, arrayList10);
         List<List<Object>> insertRows = new ArrayList<>();
         insertRows.add(Arrays.asList("?", 100000001, "?", "1"));
         insertRows.add(Arrays.asList("?", 100000002, "?", "2"));
@@ -458,10 +455,9 @@ public class BatchInsertExecutorTest {
         when(sqlInsertRecognizer.getInsertRows(pkIndexMap.values())).thenReturn(insertRows);
     }
 
-
     private void mockParametersWithAllRefOfJDBC() {
         int PK_INDEX = 1;
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add("userId1");
         arrayList0.add("userId2");
@@ -486,10 +482,10 @@ public class BatchInsertExecutorTest {
         arrayList3.add("userStatus3");
         arrayList3.add("userStatus4");
         arrayList3.add("userStatus5");
-        paramters.put(1,arrayList0);
-        paramters.put(2,arrayList1);
-        paramters.put(3,arrayList2);
-        paramters.put(4,arrayList3);
+        paramters.put(1, arrayList0);
+        paramters.put(2, arrayList1);
+        paramters.put(3, arrayList2);
+        paramters.put(4, arrayList3);
 
         List<List<Object>> insertRows = new ArrayList<>();
         insertRows.add(Arrays.asList("?", "?", "?", "?"));
@@ -498,10 +494,9 @@ public class BatchInsertExecutorTest {
         doReturn(insertRows).when(sqlInsertRecognizer).getInsertRows(pkIndexMap.values());
     }
 
-
     private void mockParametersWithPkRefOfJDBC() {
         int PK_INDEX = 1;
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(2);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(2);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add("userId1");
         arrayList0.add("userId2");
@@ -524,9 +519,8 @@ public class BatchInsertExecutorTest {
         when(statementProxy.getParamsByIndex(PK_INDEX)).thenReturn(paramters.get(PK_INDEX + 1));
     }
 
-
     private void mockParametersWithPkUnRefOfJDBC(int pkId) {
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(2);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(2);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add("userId1");
         ArrayList arrayList1 = new ArrayList<>();
@@ -539,5 +533,4 @@ public class BatchInsertExecutorTest {
         when(statementProxy.getParameters()).thenReturn(paramters);
         when(sqlInsertRecognizer.getInsertRows(pkIndexMap.values())).thenReturn(insertRows);
     }
-
 }
