@@ -46,7 +46,6 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-
 public class KingbaseInsertExecutorTest {
 
     private static final String ID_COLUMN = "id";
@@ -87,16 +86,21 @@ public class KingbaseInsertExecutorTest {
         statementCallback = mock(StatementCallback.class);
         sqlInsertRecognizer = mock(SQLInsertRecognizer.class);
         tableMeta = mock(TableMeta.class);
-        insertExecutor = Mockito.spy(new KingbaseInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
+        insertExecutor =
+                Mockito.spy(new KingbaseInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
 
-        pkIndexMap = new HashMap<String, Integer>() {{
-            put(ID_COLUMN, pkIndexId);
-        }};
+        pkIndexMap = new HashMap<String, Integer>() {
+            {
+                put(ID_COLUMN, pkIndexId);
+            }
+        };
 
-        multiPkIndexMap = new HashMap<String, Integer>() {{
-            put(ID_COLUMN, pkIndexId);
-            put(USER_ID_COLUMN, pkIndexUserId);
-        }};
+        multiPkIndexMap = new HashMap<String, Integer>() {
+            {
+                put(ID_COLUMN, pkIndexId);
+                put(USER_ID_COLUMN, pkIndexUserId);
+            }
+        };
     }
 
     @Test
@@ -104,7 +108,7 @@ public class KingbaseInsertExecutorTest {
         mockInsertColumns();
         SqlSequenceExpr expr = mockParametersPkWithSeq();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValuesSeq = new ArrayList<>();
         pkValuesSeq.add(PK_VALUE_ID);
 
@@ -121,7 +125,7 @@ public class KingbaseInsertExecutorTest {
         mockInsertColumns();
         SqlSequenceExpr expr = mockParametersMultiPkWithSeq();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN, USER_ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN, USER_ID_COLUMN}));
         List<Object> pkValuesSeqId = new ArrayList<>();
         pkValuesSeqId.add(PK_VALUE_ID);
         List<Object> pkValuesSeqUserId = new ArrayList<>();
@@ -144,12 +148,12 @@ public class KingbaseInsertExecutorTest {
         mockParametersPkWithAuto();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         doReturn(pkIndexMap).when(insertExecutor).getPkIndex();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
-        doReturn(Arrays.asList(new Object[]{PK_VALUE_ID})).when(insertExecutor).getGeneratedKeys(ID_COLUMN);
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
+        doReturn(Arrays.asList(new Object[] {PK_VALUE_ID})).when(insertExecutor).getGeneratedKeys(ID_COLUMN);
         Map<String, List<Object>> pkValuesByAuto = insertExecutor.getPkValues();
 
         verify(insertExecutor).getGeneratedKeys(ID_COLUMN);
-        Assertions.assertEquals(pkValuesByAuto.get(ID_COLUMN), Arrays.asList(new Object[]{PK_VALUE_ID}));
+        Assertions.assertEquals(pkValuesByAuto.get(ID_COLUMN), Arrays.asList(new Object[] {PK_VALUE_ID}));
     }
 
     @Test
@@ -158,12 +162,10 @@ public class KingbaseInsertExecutorTest {
         mockParametersMultiPkWithAuto();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         doReturn(multiPkIndexMap).when(insertExecutor).getPkIndex();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN, USER_ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN, USER_ID_COLUMN}));
         Assertions.assertThrows(NotSupportYetException.class, () -> {
             insertExecutor.getPkValues();
         });
-
-
     }
 
     @Test
@@ -175,7 +177,8 @@ public class KingbaseInsertExecutorTest {
         when(statementProxy.getConnectionProxy()).thenReturn(connectionProxy);
         when(connectionProxy.getDbType()).thenReturn(JdbcConstants.KINGBASE);
 
-        insertExecutor = Mockito.spy(new KingbaseInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
+        insertExecutor =
+                Mockito.spy(new KingbaseInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
 
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
 
@@ -196,7 +199,6 @@ public class KingbaseInsertExecutorTest {
         Assertions.assertThrows(NotSupportYetException.class, () -> {
             insertExecutor.getPkValuesByColumn();
         });
-
     }
 
     @Test
@@ -220,7 +222,8 @@ public class KingbaseInsertExecutorTest {
         List<String> columns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation2: insert columns contain the pk column
         columns = new ArrayList<>();
@@ -228,7 +231,8 @@ public class KingbaseInsertExecutorTest {
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation3: insert columns are not empty and do not contain the pk column
         columns = new ArrayList<>();
@@ -236,8 +240,8 @@ public class KingbaseInsertExecutorTest {
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
         Assertions.assertIterableEquals(
-            Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
-            insertExecutor.getPkValues().entrySet());
+                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
+                insertExecutor.getPkValues().entrySet());
     }
 
     @Test
@@ -265,7 +269,9 @@ public class KingbaseInsertExecutorTest {
         List<String> insertColumns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(mockAllPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockAllPkValuesFromColumn.entrySet(),
+                insertExecutor.getPkValues().entrySet());
 
         // situation2: insert columns contain all pk columns
         insertColumns = new ArrayList<>();
@@ -274,7 +280,9 @@ public class KingbaseInsertExecutorTest {
         insertColumns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(mockAllPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockAllPkValuesFromColumn.entrySet(),
+                insertExecutor.getPkValues().entrySet());
 
         // situation3: insert columns contain partial pk columns
         insertColumns = new ArrayList<>();
@@ -289,7 +297,8 @@ public class KingbaseInsertExecutorTest {
 
         Map<String, List<Object>> expectPkValues = new HashMap<>(mockPkValuesFromColumn_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation4: insert columns are not empty and do not contain the pk column
         insertColumns = new ArrayList<>();
@@ -302,7 +311,8 @@ public class KingbaseInsertExecutorTest {
         expectPkValues = new HashMap<>();
         expectPkValues.put(ID_COLUMN, mockPkValuesAutoGenerated_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
     }
 
     @Test
@@ -447,6 +457,4 @@ public class KingbaseInsertExecutorTest {
         rows.add(Arrays.asList(Null.get(), "xx", "xx", "xx"));
         when(sqlInsertRecognizer.getInsertRows(pkIndexMap.values())).thenReturn(rows);
     }
-
-
 }
