@@ -16,6 +16,37 @@
  */
 package org.apache.seata.rm.datasource.exec;
 
+import com.alibaba.druid.mock.MockStatement;
+import com.alibaba.druid.mock.MockStatementBase;
+import com.alibaba.druid.pool.DruidDataSource;
+import com.alibaba.druid.sql.SQLUtils;
+import com.alibaba.druid.sql.ast.SQLStatement;
+import com.google.common.collect.Lists;
+import org.apache.seata.common.exception.ShouldNeverHappenException;
+import org.apache.seata.rm.datasource.ConnectionProxy;
+import org.apache.seata.rm.datasource.DataSourceProxy;
+import org.apache.seata.rm.datasource.DataSourceProxyTest;
+import org.apache.seata.rm.datasource.PreparedStatementProxy;
+import org.apache.seata.rm.datasource.StatementProxy;
+import org.apache.seata.rm.datasource.exec.mysql.MySQLInsertExecutor;
+import org.apache.seata.rm.datasource.mock.MockDataSource;
+import org.apache.seata.rm.datasource.mock.MockDriver;
+import org.apache.seata.rm.datasource.mock.MockResultSet;
+import org.apache.seata.rm.datasource.sql.struct.TableRecords;
+import org.apache.seata.sqlparser.SQLInsertRecognizer;
+import org.apache.seata.sqlparser.druid.mysql.MySQLInsertRecognizer;
+import org.apache.seata.sqlparser.struct.ColumnMeta;
+import org.apache.seata.sqlparser.struct.Null;
+import org.apache.seata.sqlparser.struct.SqlDefaultExpr;
+import org.apache.seata.sqlparser.struct.SqlMethodExpr;
+import org.apache.seata.sqlparser.struct.SqlSequenceExpr;
+import org.apache.seata.sqlparser.struct.TableMeta;
+import org.apache.seata.sqlparser.util.JdbcConstants;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.BeforeEach;
+import org.junit.jupiter.api.Test;
+import org.mockito.Mockito;
+
 import java.lang.reflect.Field;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
@@ -30,46 +61,12 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
-import com.alibaba.druid.mock.MockStatement;
-import com.alibaba.druid.mock.MockStatementBase;
-import com.alibaba.druid.pool.DruidDataSource;
-import com.alibaba.druid.sql.SQLUtils;
-import com.alibaba.druid.sql.ast.SQLStatement;
-import com.google.common.collect.Lists;
-import org.apache.seata.rm.datasource.exec.StatementCallback;
-import org.apache.seata.common.exception.ShouldNeverHappenException;
-import org.apache.seata.rm.datasource.ConnectionProxy;
-import org.apache.seata.rm.datasource.DataSourceProxy;
-import org.apache.seata.rm.datasource.DataSourceProxyTest;
-import org.apache.seata.rm.datasource.PreparedStatementProxy;
-import org.apache.seata.rm.datasource.StatementProxy;
-import org.apache.seata.rm.datasource.exec.mysql.MySQLInsertExecutor;
-import org.apache.seata.rm.datasource.mock.MockDataSource;
-import org.apache.seata.rm.datasource.mock.MockDriver;
-import org.apache.seata.rm.datasource.mock.MockResultSet;
-import org.apache.seata.sqlparser.druid.mysql.MySQLInsertRecognizer;
-import org.apache.seata.sqlparser.struct.ColumnMeta;
-import org.apache.seata.sqlparser.struct.TableMeta;
-import org.apache.seata.rm.datasource.sql.struct.TableRecords;
-import org.apache.seata.sqlparser.SQLInsertRecognizer;
-import org.apache.seata.sqlparser.struct.Null;
-import org.apache.seata.sqlparser.struct.SqlDefaultExpr;
-import org.apache.seata.sqlparser.struct.SqlMethodExpr;
-import org.apache.seata.sqlparser.struct.SqlSequenceExpr;
-import org.apache.seata.sqlparser.util.JdbcConstants;
-import org.junit.jupiter.api.Assertions;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.mockito.Mockito;
-
-
 import static org.mockito.Mockito.anyString;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-
 public class MySQLInsertExecutorTest {
 
     protected static final String ID_COLUMN = "id";
@@ -91,7 +88,7 @@ public class MySQLInsertExecutorTest {
     protected MySQLInsertExecutor newInsertExecutor;
 
     protected final int pkIndex = 0;
-    protected HashMap<String,Integer> pkIndexMap;
+    protected HashMap<String, Integer> pkIndexMap;
 
     @BeforeEach
     public void init() throws SQLException {
@@ -105,15 +102,17 @@ public class MySQLInsertExecutorTest {
         when(statementProxy.getTargetStatement()).thenReturn(statementProxy);
 
         MockResultSet resultSet = new MockResultSet(statementProxy);
-        resultSet.mockResultSet(Arrays.asList("Variable_name", "Value"), new Object[][]{{"auto_increment_increment", "1"}});
-        when(statementProxy.getTargetStatement().executeQuery("SHOW VARIABLES LIKE 'auto_increment_increment'")).thenReturn(resultSet);
+        resultSet.mockResultSet(
+                Arrays.asList("Variable_name", "Value"), new Object[][] {{"auto_increment_increment", "1"}});
+        when(statementProxy.getTargetStatement().executeQuery("SHOW VARIABLES LIKE 'auto_increment_increment'"))
+                .thenReturn(resultSet);
 
         StatementCallback statementCallback = mock(StatementCallback.class);
         sqlInsertRecognizer = mock(SQLInsertRecognizer.class);
         tableMeta = mock(TableMeta.class);
         insertExecutor = Mockito.spy(new MySQLInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
 
-        pkIndexMap = new HashMap<String,Integer>(){
+        pkIndexMap = new HashMap<String, Integer>() {
             {
                 put(ID_COLUMN, pkIndex);
             }
@@ -122,24 +121,125 @@ public class MySQLInsertExecutorTest {
         // new test init property
         List<String> returnValueColumnLabels = Lists.newArrayList("id", "user_id", "name", "sex", "update_time");
         Object[][] returnValue = new Object[][] {
-                new Object[] {1, 1, "will", 1, 0},
+            new Object[] {1, 1, "will", 1, 0},
         };
         Object[][] columnMetas = new Object[][] {
-                new Object[] {"", "", "table_insert_executor_test", "id", Types.INTEGER, "INTEGER", 64, 0, 10, 1, "", "", 0, 0, 64, 2, "NO", "NO"},
-                new Object[] {"", "", "table_insert_executor_test", "user_id", Types.INTEGER, "INTEGER", 64, 0, 10, 1, "", "", 0, 0, 64, 2, "NO", "NO"},
-                new Object[] {"", "", "table_insert_executor_test", "name", Types.VARCHAR, "VARCHAR", 64, 0, 10, 0, "", "", 0, 0, 64, 2, "NO", "NO"},
-                new Object[] {"", "", "table_insert_executor_test", "sex", Types.INTEGER, "INTEGER", 64, 0, 10, 0, "", "", 0, 0, 64, 2, "NO", "NO"},
-                new Object[] {"", "", "table_insert_executor_test", "update_time", Types.INTEGER, "INTEGER", 64, 0, 10, 0, "", "", 0, 0, 64, 2, "YES", "NO"},
+            new Object[] {
+                "",
+                "",
+                "table_insert_executor_test",
+                "id",
+                Types.INTEGER,
+                "INTEGER",
+                64,
+                0,
+                10,
+                1,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "NO",
+                "NO"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_insert_executor_test",
+                "user_id",
+                Types.INTEGER,
+                "INTEGER",
+                64,
+                0,
+                10,
+                1,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "NO",
+                "NO"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_insert_executor_test",
+                "name",
+                Types.VARCHAR,
+                "VARCHAR",
+                64,
+                0,
+                10,
+                0,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "NO",
+                "NO"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_insert_executor_test",
+                "sex",
+                Types.INTEGER,
+                "INTEGER",
+                64,
+                0,
+                10,
+                0,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "NO",
+                "NO"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_insert_executor_test",
+                "update_time",
+                Types.INTEGER,
+                "INTEGER",
+                64,
+                0,
+                10,
+                0,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "YES",
+                "NO"
+            },
         };
         Object[][] indexMetas = new Object[][] {
-                new Object[] {"PRIMARY", "id", false, "", 3, 1, "A", 34},
-                new Object[] {"PRIMARY", "user_id", false, "", 3, 1, "A", 34},
-        };
-        Object[][] onUpdateColumnsReturnValue = new Object[][] {
-                new Object[]{0, "update_time", Types.INTEGER, "INTEGER", 64, 10, 0, 0}
+            new Object[] {"PRIMARY", "id", false, "", 3, 1, "A", 34},
+            new Object[] {"PRIMARY", "user_id", false, "", 3, 1, "A", 34},
         };
+        Object[][] onUpdateColumnsReturnValue =
+                new Object[][] {new Object[] {0, "update_time", Types.INTEGER, "INTEGER", 64, 10, 0, 0}};
 
-        MockDriver mockDriver = new MockDriver(returnValueColumnLabels, returnValue, columnMetas, indexMetas, null, onUpdateColumnsReturnValue, new Object[][]{});
+        MockDriver mockDriver = new MockDriver(
+                returnValueColumnLabels,
+                returnValue,
+                columnMetas,
+                indexMetas,
+                null,
+                onUpdateColumnsReturnValue,
+                new Object[][] {});
         DruidDataSource dataSource = new DruidDataSource();
         dataSource.setUrl("jdbc:mock:xxx");
         dataSource.setDriver(mockDriver);
@@ -149,8 +249,10 @@ public class MySQLInsertExecutorTest {
             Field field = dataSourceProxy.getClass().getDeclaredField("dbType");
             field.setAccessible(true);
             field.set(newDataSourceProxy, "mysql");
-            ConnectionProxy newConnectionProxy = new ConnectionProxy(newDataSourceProxy, dataSource.getConnection().getConnection());
-            MockStatementBase mockStatement = new MockStatement(dataSource.getConnection().getConnection());
+            ConnectionProxy newConnectionProxy = new ConnectionProxy(
+                    newDataSourceProxy, dataSource.getConnection().getConnection());
+            MockStatementBase mockStatement =
+                    new MockStatement(dataSource.getConnection().getConnection());
             newStatementProxy = new StatementProxy(newConnectionProxy, mockStatement);
         } catch (Exception e) {
             throw new RuntimeException("init failed");
@@ -199,7 +301,8 @@ public class MySQLInsertExecutorTest {
 
     @Test
     public void testBeforeAndAfterImageTableSchemaWithQuoteAndTableNameWithQuote() throws SQLException {
-        String sql = "insert into `seata`.`table_insert_executor_test`(id, user_id, name, sex) values (1, 1, 'will', 1)";
+        String sql =
+                "insert into `seata`.`table_insert_executor_test`(id, user_id, name, sex) values (1, 1, 'will', 1)";
         List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
         MySQLInsertRecognizer recognizer = new MySQLInsertRecognizer(sql, asts.get(0));
         newInsertExecutor = new MySQLInsertExecutor(newStatementProxy, (statement, args) -> null, recognizer);
@@ -239,13 +342,13 @@ public class MySQLInsertExecutorTest {
     @Test
     public void testAfterImage_ByColumn() throws SQLException {
         doReturn(true).when(insertExecutor).containsPK();
-        Map<String,List<Object>> pkValuesMap =new HashMap<>();
-        pkValuesMap.put("id",Arrays.asList(new Object[]{PK_VALUE}));
+        Map<String, List<Object>> pkValuesMap = new HashMap<>();
+        pkValuesMap.put("id", Arrays.asList(new Object[] {PK_VALUE}));
         doReturn(pkValuesMap).when(insertExecutor).getPkValuesByColumn();
         TableRecords tableRecords = new TableRecords();
         doReturn(tableRecords).when(insertExecutor).buildTableRecords(pkValuesMap);
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         TableRecords resultTableRecords = insertExecutor.afterImage(new TableRecords());
         Assertions.assertEquals(resultTableRecords, tableRecords);
     }
@@ -254,13 +357,13 @@ public class MySQLInsertExecutorTest {
     public void testAfterImage_ByAuto() throws SQLException {
         doReturn(false).when(insertExecutor).containsPK();
         doReturn(true).when(insertExecutor).containsColumns();
-        Map<String,List<Object>> pkValuesMap =new HashMap<>();
-        pkValuesMap.put("id",Arrays.asList(new Object[]{PK_VALUE}));
+        Map<String, List<Object>> pkValuesMap = new HashMap<>();
+        pkValuesMap.put("id", Arrays.asList(new Object[] {PK_VALUE}));
         doReturn(pkValuesMap).when(insertExecutor).getPkValuesByAuto();
         TableRecords tableRecords = new TableRecords();
         doReturn(tableRecords).when(insertExecutor).buildTableRecords(pkValuesMap);
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         TableRecords resultTableRecords = insertExecutor.afterImage(new TableRecords());
         Assertions.assertEquals(resultTableRecords, tableRecords);
     }
@@ -270,12 +373,12 @@ public class MySQLInsertExecutorTest {
         Assertions.assertThrows(SQLException.class, () -> {
             doReturn(false).when(insertExecutor).containsPK();
             doReturn(true).when(insertExecutor).containsColumns();
-            Map<String,List<Object>> pkValuesMap =new HashMap<>();
-            pkValuesMap.put("id",Arrays.asList(new Object[]{PK_VALUE}));
+            Map<String, List<Object>> pkValuesMap = new HashMap<>();
+            pkValuesMap.put("id", Arrays.asList(new Object[] {PK_VALUE}));
             doReturn(pkValuesMap).when(insertExecutor).getPkValuesByAuto();
             doReturn(null).when(insertExecutor).buildTableRecords(pkValuesMap);
             doReturn(tableMeta).when(insertExecutor).getTableMeta();
-            when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+            when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
             insertExecutor.afterImage(new TableRecords());
         });
     }
@@ -298,11 +401,11 @@ public class MySQLInsertExecutorTest {
         mockInsertRows();
         mockParametersOfOnePk();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValues = new ArrayList<>();
         pkValues.add(PK_VALUE);
         doReturn(pkIndexMap).when(insertExecutor).getPkIndex();
-        Map<String,List<Object>> pkValuesList  = insertExecutor.getPkValuesByColumn();
+        Map<String, List<Object>> pkValuesList = insertExecutor.getPkValuesByColumn();
         Assertions.assertIterableEquals(pkValuesList.get(ID_COLUMN), pkValues);
     }
 
@@ -312,7 +415,7 @@ public class MySQLInsertExecutorTest {
             mockInsertColumns();
             mockParameters();
             doReturn(tableMeta).when(insertExecutor).getTableMeta();
-            when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+            when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
             insertExecutor.getPkValuesByColumn();
         });
     }
@@ -323,23 +426,32 @@ public class MySQLInsertExecutorTest {
         mockInsertRows();
         mockParametersPkWithNull();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         ColumnMeta cm = new ColumnMeta();
         cm.setColumnName(ID_COLUMN);
         cm.setIsAutoincrement("YES");
-        when(tableMeta.getPrimaryKeyMap()).thenReturn(new HashMap<String, ColumnMeta>(){{put(ID_COLUMN,cm);}});
+        when(tableMeta.getPrimaryKeyMap()).thenReturn(new HashMap<String, ColumnMeta>() {
+            {
+                put(ID_COLUMN, cm);
+            }
+        });
         List<Object> pkValuesAuto = new ArrayList<>();
         pkValuesAuto.add(PK_VALUE);
-        //mock getPkValuesByAuto
-        doReturn(new HashMap<String,List<Object>>(){{put(ID_COLUMN,pkValuesAuto);}}).when(insertExecutor).getPkValuesByAuto();
+        // mock getPkValuesByAuto
+        doReturn(new HashMap<String, List<Object>>() {
+                    {
+                        put(ID_COLUMN, pkValuesAuto);
+                    }
+                })
+                .when(insertExecutor)
+                .getPkValuesByAuto();
         doReturn(pkIndexMap).when(insertExecutor).getPkIndex();
-        Map<String,List<Object>> pkValuesList  = insertExecutor.getPkValuesByColumn();
-        //pk value = Null so getPkValuesByAuto
+        Map<String, List<Object>> pkValuesList = insertExecutor.getPkValuesByColumn();
+        // pk value = Null so getPkValuesByAuto
         verify(insertExecutor).getPkValuesByAuto();
         Assertions.assertIterableEquals(pkValuesList.get(ID_COLUMN), pkValuesAuto);
     }
 
-
     @Test
     public void testGetPkValuesByAuto_ShouldNeverHappenException() {
         Assertions.assertThrows(ShouldNeverHappenException.class, () -> {
@@ -383,8 +495,9 @@ public class MySQLInsertExecutorTest {
         SQLException e = new SQLException("test warn log", MySQLInsertExecutor.ERR_SQL_STATE, 1);
         when(statementProxy.getGeneratedKeys()).thenThrow(e);
         ResultSet genKeys = mock(ResultSet.class);
-        when(statementProxy.getTargetStatement().executeQuery("SELECT LAST_INSERT_ID()")).thenReturn(genKeys);
-        Map<String,List<Object>> pkValueMap=insertExecutor.getPkValuesByAuto();
+        when(statementProxy.getTargetStatement().executeQuery("SELECT LAST_INSERT_ID()"))
+                .thenReturn(genKeys);
+        Map<String, List<Object>> pkValueMap = insertExecutor.getPkValuesByAuto();
         Assertions.assertTrue(pkValueMap.get(ID_COLUMN).isEmpty());
     }
 
@@ -402,8 +515,8 @@ public class MySQLInsertExecutorTest {
         when(statementProxy.getGeneratedKeys()).thenReturn(resultSet);
         when(resultSet.next()).thenReturn(false);
         when(resultSet.getObject(1)).thenReturn(PK_VALUE);
-        Map<String,List<Object>> pkValues = insertExecutor.getPkValuesByAuto();
-        Assertions.assertEquals(pkValues.get(ID_COLUMN).size(),0);
+        Map<String, List<Object>> pkValues = insertExecutor.getPkValuesByAuto();
+        Assertions.assertEquals(pkValues.get(ID_COLUMN).size(), 0);
     }
 
     @Test
@@ -422,7 +535,7 @@ public class MySQLInsertExecutorTest {
         when(resultSet.getObject(1)).thenReturn(PK_VALUE);
         List<Object> pkValues = new ArrayList<>();
         pkValues.add(PK_VALUE);
-        Map<String,List<Object>> pkValuesList = insertExecutor.getPkValuesByAuto();
+        Map<String, List<Object>> pkValuesList = insertExecutor.getPkValuesByAuto();
         Assertions.assertIterableEquals(pkValuesList.get(ID_COLUMN), pkValues);
     }
 
@@ -443,7 +556,7 @@ public class MySQLInsertExecutorTest {
         when(resultSet.getObject(1)).thenReturn(PK_VALUE);
         List<Object> pkValues = new ArrayList<>();
         pkValues.add(PK_VALUE);
-        Map<String,List<Object>> pkValuesList = insertExecutor.getPkValuesByAuto();
+        Map<String, List<Object>> pkValuesList = insertExecutor.getPkValuesByAuto();
         Assertions.assertIterableEquals(pkValuesList.get(ID_COLUMN), pkValues);
     }
 
@@ -451,46 +564,43 @@ public class MySQLInsertExecutorTest {
     public void test_getPkIndex() {
         mockInsertColumns();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         Assertions.assertEquals(0, insertExecutor.getPkIndex().get(ID_COLUMN));
     }
 
-
     @Test
-    public void test_checkPkValuesForMultiPk()
-    {
-        Map<String,List<Object>> pkValues = new HashMap<>();
+    public void test_checkPkValuesForMultiPk() {
+        Map<String, List<Object>> pkValues = new HashMap<>();
         List pkValues1 = new ArrayList();
         List pkValues2 = new ArrayList();
-        pkValues.put("id",pkValues1);
-        pkValues.put("userCode",pkValues2);
+        pkValues.put("id", pkValues1);
+        pkValues.put("userCode", pkValues2);
 
-        //all pk support value
+        // all pk support value
         pkValues1.add(1);
         pkValues2.add(2);
         Assertions.assertTrue(insertExecutor.checkPkValuesForMultiPk(pkValues));
 
-        //supporting one pk is null
+        // supporting one pk is null
         pkValues1.clear();
         pkValues2.clear();
         pkValues1.add(Null.get());
         pkValues2.add(2);
         Assertions.assertTrue(insertExecutor.checkPkValuesForMultiPk(pkValues));
 
-        //more one pk is null is not support
+        // more one pk is null is not support
         pkValues1.clear();
         pkValues2.clear();
         pkValues1.add(Null.get());
         pkValues2.add(Null.get());
         Assertions.assertFalse(insertExecutor.checkPkValuesForMultiPk(pkValues));
 
-        //method is not support at all
+        // method is not support at all
         pkValues1.clear();
         pkValues2.clear();
         pkValues1.add(SqlMethodExpr.get());
         pkValues2.add(2);
         Assertions.assertFalse(insertExecutor.checkPkValuesForMultiPk(pkValues));
-
     }
 
     @Test
@@ -639,7 +749,6 @@ public class MySQLInsertExecutorTest {
         pkValues.add(SqlMethodExpr.get());
         Assertions.assertFalse(insertExecutor.checkPkValuesForSinglePk(pkValues, false));
 
-
         pkValues = new ArrayList<>();
         pkValues.add(Null.get());
         pkValues.add(new SqlSequenceExpr());
@@ -694,7 +803,8 @@ public class MySQLInsertExecutorTest {
 
     @Test
     public void test_autoGeneratePks() throws NoSuchMethodException, InvocationTargetException, IllegalAccessException {
-        Method method = MySQLInsertExecutor.class.getDeclaredMethod("autoGeneratePks", new Class[]{BigDecimal.class, String.class, Integer.class});
+        Method method = MySQLInsertExecutor.class.getDeclaredMethod(
+                "autoGeneratePks", new Class[] {BigDecimal.class, String.class, Integer.class});
         method.setAccessible(true);
         Object resp = method.invoke(insertExecutor, BigDecimal.ONE, "ID", 3);
 
@@ -717,7 +827,7 @@ public class MySQLInsertExecutorTest {
     }
 
     private void mockParameters() {
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(PK_VALUE);
         ArrayList arrayList1 = new ArrayList<>();
@@ -735,7 +845,7 @@ public class MySQLInsertExecutorTest {
     }
 
     private void mockParametersPkWithNull() {
-        Map<Integer,ArrayList<Object>> parameters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> parameters = new HashMap<>(4);
         ArrayList arrayList0 = new ArrayList<>();
         arrayList0.add(Null.get());
         ArrayList arrayList1 = new ArrayList<>();
@@ -753,7 +863,7 @@ public class MySQLInsertExecutorTest {
     }
 
     private void mockParametersOfOnePk() {
-        Map<Integer,ArrayList<Object>> paramters = new HashMap<>(4);
+        Map<Integer, ArrayList<Object>> paramters = new HashMap<>(4);
         ArrayList arrayList1 = new ArrayList<>();
         arrayList1.add(PK_VALUE);
         paramters.put(1, arrayList1);
