@@ -16,17 +16,16 @@
  */
 package org.apache.seata.rm.datasource.exec;
 
-import org.apache.seata.rm.datasource.exec.StatementCallback;
 import org.apache.seata.common.exception.NotSupportYetException;
 import org.apache.seata.rm.datasource.ConnectionProxy;
 import org.apache.seata.rm.datasource.PreparedStatementProxy;
 import org.apache.seata.rm.datasource.StatementProxy;
 import org.apache.seata.rm.datasource.exec.oracle.OracleInsertExecutor;
-import org.apache.seata.sqlparser.struct.ColumnMeta;
-import org.apache.seata.sqlparser.struct.TableMeta;
 import org.apache.seata.sqlparser.SQLInsertRecognizer;
+import org.apache.seata.sqlparser.struct.ColumnMeta;
 import org.apache.seata.sqlparser.struct.Null;
 import org.apache.seata.sqlparser.struct.SqlSequenceExpr;
+import org.apache.seata.sqlparser.struct.TableMeta;
 import org.apache.seata.sqlparser.util.JdbcConstants;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
@@ -47,7 +46,6 @@ import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-
 public class OracleInsertExecutorTest {
 
     private static final String ID_COLUMN = "id";
@@ -90,14 +88,18 @@ public class OracleInsertExecutorTest {
         tableMeta = mock(TableMeta.class);
         insertExecutor = Mockito.spy(new OracleInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
 
-        pkIndexMap = new HashMap<String, Integer>() {{
-            put(ID_COLUMN, pkIndexId);
-        }};
+        pkIndexMap = new HashMap<String, Integer>() {
+            {
+                put(ID_COLUMN, pkIndexId);
+            }
+        };
 
-        multiPkIndexMap = new HashMap<String, Integer>() {{
-            put(ID_COLUMN, pkIndexId);
-            put(USER_ID_COLUMN, pkIndexUserId);
-        }};
+        multiPkIndexMap = new HashMap<String, Integer>() {
+            {
+                put(ID_COLUMN, pkIndexId);
+                put(USER_ID_COLUMN, pkIndexUserId);
+            }
+        };
     }
 
     @Test
@@ -105,7 +107,7 @@ public class OracleInsertExecutorTest {
         mockInsertColumns();
         SqlSequenceExpr expr = mockParametersPkWithSeq();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValuesSeq = new ArrayList<>();
         pkValuesSeq.add(PK_VALUE_ID);
 
@@ -122,7 +124,7 @@ public class OracleInsertExecutorTest {
         mockInsertColumns();
         SqlSequenceExpr expr = mockParametersMultiPkWithSeq();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN, USER_ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN, USER_ID_COLUMN}));
         List<Object> pkValuesSeqId = new ArrayList<>();
         pkValuesSeqId.add(PK_VALUE_ID);
         List<Object> pkValuesSeqUserId = new ArrayList<>();
@@ -145,12 +147,12 @@ public class OracleInsertExecutorTest {
         mockParametersPkWithAuto();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         doReturn(pkIndexMap).when(insertExecutor).getPkIndex();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
-        doReturn(Arrays.asList(new Object[]{PK_VALUE_ID})).when(insertExecutor).getGeneratedKeys(ID_COLUMN);
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
+        doReturn(Arrays.asList(new Object[] {PK_VALUE_ID})).when(insertExecutor).getGeneratedKeys(ID_COLUMN);
         Map<String, List<Object>> pkValuesByAuto = insertExecutor.getPkValues();
 
         verify(insertExecutor).getGeneratedKeys(ID_COLUMN);
-        Assertions.assertEquals(pkValuesByAuto.get(ID_COLUMN), Arrays.asList(new Object[]{PK_VALUE_ID}));
+        Assertions.assertEquals(pkValuesByAuto.get(ID_COLUMN), Arrays.asList(new Object[] {PK_VALUE_ID}));
     }
 
     @Test
@@ -159,12 +161,10 @@ public class OracleInsertExecutorTest {
         mockParametersMultiPkWithAuto();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         doReturn(multiPkIndexMap).when(insertExecutor).getPkIndex();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN, USER_ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN, USER_ID_COLUMN}));
         Assertions.assertThrows(NotSupportYetException.class, () -> {
             insertExecutor.getPkValues();
         });
-
-
     }
 
     @Test
@@ -197,7 +197,6 @@ public class OracleInsertExecutorTest {
         Assertions.assertThrows(NotSupportYetException.class, () -> {
             insertExecutor.getPkValuesByColumn();
         });
-
     }
 
     @Test
@@ -221,7 +220,8 @@ public class OracleInsertExecutorTest {
         List<String> columns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation2: insert columns contain the pk column
         columns = new ArrayList<>();
@@ -229,7 +229,8 @@ public class OracleInsertExecutorTest {
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation3: insert columns are not empty and do not contain the pk column
         columns = new ArrayList<>();
@@ -237,8 +238,8 @@ public class OracleInsertExecutorTest {
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
         Assertions.assertIterableEquals(
-            Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
-            insertExecutor.getPkValues().entrySet());
+                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
+                insertExecutor.getPkValues().entrySet());
     }
 
     @Test
@@ -266,7 +267,9 @@ public class OracleInsertExecutorTest {
         List<String> insertColumns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(mockAllPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockAllPkValuesFromColumn.entrySet(),
+                insertExecutor.getPkValues().entrySet());
 
         // situation2: insert columns contain all pk columns
         insertColumns = new ArrayList<>();
@@ -275,7 +278,9 @@ public class OracleInsertExecutorTest {
         insertColumns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(mockAllPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockAllPkValuesFromColumn.entrySet(),
+                insertExecutor.getPkValues().entrySet());
 
         // situation3: insert columns contain partial pk columns
         insertColumns = new ArrayList<>();
@@ -290,7 +295,8 @@ public class OracleInsertExecutorTest {
 
         Map<String, List<Object>> expectPkValues = new HashMap<>(mockPkValuesFromColumn_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation4: insert columns are not empty and do not contain the pk column
         insertColumns = new ArrayList<>();
@@ -303,7 +309,8 @@ public class OracleInsertExecutorTest {
         expectPkValues = new HashMap<>();
         expectPkValues.put(ID_COLUMN, mockPkValuesAutoGenerated_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
     }
 
     @Test
@@ -448,6 +455,4 @@ public class OracleInsertExecutorTest {
         rows.add(Arrays.asList(Null.get(), "xx", "xx", "xx"));
         when(sqlInsertRecognizer.getInsertRows(pkIndexMap.values())).thenReturn(rows);
     }
-
-
 }
