@@ -83,14 +83,18 @@ public class OscarInsertExecutorTest {
         tableMeta = mock(TableMeta.class);
         insertExecutor = Mockito.spy(new OscarInsertExecutor(statementProxy, statementCallback, sqlInsertRecognizer));
 
-        pkIndexMap = new HashMap<String, Integer>() {{
-            put(ID_COLUMN, pkIndexId);
-        }};
+        pkIndexMap = new HashMap<String, Integer>() {
+            {
+                put(ID_COLUMN, pkIndexId);
+            }
+        };
 
-        multiPkIndexMap = new HashMap<String, Integer>() {{
-            put(ID_COLUMN, pkIndexId);
-            put(USER_ID_COLUMN, pkIndexUserId);
-        }};
+        multiPkIndexMap = new HashMap<String, Integer>() {
+            {
+                put(ID_COLUMN, pkIndexId);
+                put(USER_ID_COLUMN, pkIndexUserId);
+            }
+        };
     }
 
     @Test
@@ -98,7 +102,7 @@ public class OscarInsertExecutorTest {
         mockInsertColumns();
         SqlSequenceExpr expr = mockParametersPkWithSeq();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
         List<Object> pkValuesSeq = new ArrayList<>();
         pkValuesSeq.add(PK_VALUE_ID);
 
@@ -115,7 +119,7 @@ public class OscarInsertExecutorTest {
         mockInsertColumns();
         SqlSequenceExpr expr = mockParametersMultiPkWithSeq();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN, USER_ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN, USER_ID_COLUMN}));
         List<Object> pkValuesSeqId = new ArrayList<>();
         pkValuesSeqId.add(PK_VALUE_ID);
         List<Object> pkValuesSeqUserId = new ArrayList<>();
@@ -138,12 +142,12 @@ public class OscarInsertExecutorTest {
         mockParametersPkWithAuto();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         doReturn(pkIndexMap).when(insertExecutor).getPkIndex();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN}));
-        doReturn(Arrays.asList(new Object[]{PK_VALUE_ID})).when(insertExecutor).getGeneratedKeys(ID_COLUMN);
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN}));
+        doReturn(Arrays.asList(new Object[] {PK_VALUE_ID})).when(insertExecutor).getGeneratedKeys(ID_COLUMN);
         Map<String, List<Object>> pkValuesByAuto = insertExecutor.getPkValues();
 
         verify(insertExecutor).getGeneratedKeys(ID_COLUMN);
-        Assertions.assertEquals(pkValuesByAuto.get(ID_COLUMN), Arrays.asList(new Object[]{PK_VALUE_ID}));
+        Assertions.assertEquals(pkValuesByAuto.get(ID_COLUMN), Arrays.asList(new Object[] {PK_VALUE_ID}));
     }
 
     @Test
@@ -152,12 +156,10 @@ public class OscarInsertExecutorTest {
         mockParametersMultiPkWithAuto();
         doReturn(tableMeta).when(insertExecutor).getTableMeta();
         doReturn(multiPkIndexMap).when(insertExecutor).getPkIndex();
-        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[]{ID_COLUMN, USER_ID_COLUMN}));
+        when(tableMeta.getPrimaryKeyOnlyName()).thenReturn(Arrays.asList(new String[] {ID_COLUMN, USER_ID_COLUMN}));
         Assertions.assertThrows(NotSupportYetException.class, () -> {
             insertExecutor.getPkValues();
         });
-
-
     }
 
     @Test
@@ -190,7 +192,6 @@ public class OscarInsertExecutorTest {
         Assertions.assertThrows(NotSupportYetException.class, () -> {
             insertExecutor.getPkValuesByColumn();
         });
-
     }
 
     @Test
@@ -214,7 +215,8 @@ public class OscarInsertExecutorTest {
         List<String> columns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation2: insert columns contain the pk column
         columns = new ArrayList<>();
@@ -222,7 +224,8 @@ public class OscarInsertExecutorTest {
         columns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation3: insert columns are not empty and do not contain the pk column
         columns = new ArrayList<>();
@@ -230,8 +233,8 @@ public class OscarInsertExecutorTest {
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(columns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
         Assertions.assertIterableEquals(
-            Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
-            insertExecutor.getPkValues().entrySet());
+                Collections.singletonMap(ID_COLUMN, mockPkValuesAutoGenerated).entrySet(),
+                insertExecutor.getPkValues().entrySet());
     }
 
     @Test
@@ -259,7 +262,9 @@ public class OscarInsertExecutorTest {
         List<String> insertColumns = new ArrayList<>();
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(true);
-        Assertions.assertIterableEquals(mockAllPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockAllPkValuesFromColumn.entrySet(),
+                insertExecutor.getPkValues().entrySet());
 
         // situation2: insert columns contain all pk columns
         insertColumns = new ArrayList<>();
@@ -268,7 +273,9 @@ public class OscarInsertExecutorTest {
         insertColumns.add(USER_NAME_COLUMN);
         when(sqlInsertRecognizer.getInsertColumns()).thenReturn(insertColumns);
         when(sqlInsertRecognizer.insertColumnsIsEmpty()).thenReturn(false);
-        Assertions.assertIterableEquals(mockAllPkValuesFromColumn.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                mockAllPkValuesFromColumn.entrySet(),
+                insertExecutor.getPkValues().entrySet());
 
         // situation3: insert columns contain partial pk columns
         insertColumns = new ArrayList<>();
@@ -283,7 +290,8 @@ public class OscarInsertExecutorTest {
 
         Map<String, List<Object>> expectPkValues = new HashMap<>(mockPkValuesFromColumn_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
 
         // situation4: insert columns are not empty and do not contain the pk column
         insertColumns = new ArrayList<>();
@@ -296,7 +304,8 @@ public class OscarInsertExecutorTest {
         expectPkValues = new HashMap<>();
         expectPkValues.put(ID_COLUMN, mockPkValuesAutoGenerated_ID);
         expectPkValues.put(USER_ID_COLUMN, mockPkValuesAutoGenerated_USER_ID);
-        Assertions.assertIterableEquals(expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
+        Assertions.assertIterableEquals(
+                expectPkValues.entrySet(), insertExecutor.getPkValues().entrySet());
     }
 
     @Test
@@ -441,6 +450,4 @@ public class OscarInsertExecutorTest {
         rows.add(Arrays.asList(Null.get(), "xx", "xx", "xx"));
         when(sqlInsertRecognizer.getInsertRows(pkIndexMap.values())).thenReturn(rows);
     }
-
-
 }
