@@ -16,24 +16,17 @@
  */
 package org.apache.seata.rm.datasource.exec;
 
-import java.lang.reflect.Field;
-import java.sql.SQLException;
-import java.sql.Types;
-import java.util.List;
-
 import com.alibaba.druid.mock.MockStatement;
 import com.alibaba.druid.mock.MockStatementBase;
 import com.alibaba.druid.pool.DruidDataSource;
 import com.alibaba.druid.sql.SQLUtils;
 import com.alibaba.druid.sql.ast.SQLStatement;
 import com.alibaba.druid.util.JdbcConstants;
-
 import com.google.common.collect.Lists;
 import org.apache.seata.rm.datasource.ConnectionProxy;
 import org.apache.seata.rm.datasource.DataSourceProxy;
 import org.apache.seata.rm.datasource.DataSourceProxyTest;
 import org.apache.seata.rm.datasource.StatementProxy;
-import org.apache.seata.rm.datasource.exec.UpdateExecutor;
 import org.apache.seata.rm.datasource.mock.MockDriver;
 import org.apache.seata.rm.datasource.sql.struct.TableRecords;
 import org.apache.seata.sqlparser.druid.mysql.MySQLUpdateRecognizer;
@@ -41,6 +34,10 @@ import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 
+import java.lang.reflect.Field;
+import java.sql.SQLException;
+import java.sql.Types;
+import java.util.List;
 
 public class UpdateExecutorTest {
 
@@ -56,19 +53,101 @@ public class UpdateExecutorTest {
             new Object[] {2, "Jack", "keyword", 0},
         };
         Object[][] columnMetas = new Object[][] {
-            new Object[] {"", "", "table_update_executor_test", "id", Types.INTEGER, "INTEGER", 64, 0, 10, 1, "", "", 0, 0, 64, 1, "NO", "YES"},
-            new Object[] {"", "", "table_update_executor_test", "name", Types.VARCHAR, "VARCHAR", 64, 0, 10, 0, "", "", 0, 0, 64, 2, "YES", "NO"},
-            new Object[] {"", "", "table_update_executor_test", "ALL", Types.VARCHAR, "VARCHAR", 64, 0, 10, 0, "", "", 0, 0, 64, 2, "YES", "NO"},
-            new Object[] {"", "", "table_update_executor_test", "updated", Types.INTEGER, "INTEGER", 64, 0, 10, 0, "", "", 0, 0, 64, 2, "YES", "NO"},
+            new Object[] {
+                "",
+                "",
+                "table_update_executor_test",
+                "id",
+                Types.INTEGER,
+                "INTEGER",
+                64,
+                0,
+                10,
+                1,
+                "",
+                "",
+                0,
+                0,
+                64,
+                1,
+                "NO",
+                "YES"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_update_executor_test",
+                "name",
+                Types.VARCHAR,
+                "VARCHAR",
+                64,
+                0,
+                10,
+                0,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "YES",
+                "NO"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_update_executor_test",
+                "ALL",
+                Types.VARCHAR,
+                "VARCHAR",
+                64,
+                0,
+                10,
+                0,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "YES",
+                "NO"
+            },
+            new Object[] {
+                "",
+                "",
+                "table_update_executor_test",
+                "updated",
+                Types.INTEGER,
+                "INTEGER",
+                64,
+                0,
+                10,
+                0,
+                "",
+                "",
+                0,
+                0,
+                64,
+                2,
+                "YES",
+                "NO"
+            },
         };
         Object[][] indexMetas = new Object[][] {
             new Object[] {"PRIMARY", "id", false, "", 3, 1, "A", 34},
         };
-        Object[][] onUpdateColumnsReturnValue = new Object[][] {
-            new Object[]{0, "updated", Types.INTEGER, "INTEGER", 64, 10, 0, 0}
-        };
+        Object[][] onUpdateColumnsReturnValue =
+                new Object[][] {new Object[] {0, "updated", Types.INTEGER, "INTEGER", 64, 10, 0, 0}};
 
-        MockDriver mockDriver = new MockDriver(returnValueColumnLabels, returnValue, columnMetas, indexMetas, null, onUpdateColumnsReturnValue, new Object[][]{});
+        MockDriver mockDriver = new MockDriver(
+                returnValueColumnLabels,
+                returnValue,
+                columnMetas,
+                indexMetas,
+                null,
+                onUpdateColumnsReturnValue,
+                new Object[][] {});
         DruidDataSource dataSource = new DruidDataSource();
         dataSource.setUrl("jdbc:mock:xxx");
         dataSource.setDriver(mockDriver);
@@ -79,8 +158,10 @@ public class UpdateExecutorTest {
             Field field = dataSourceProxy.getClass().getDeclaredField("dbType");
             field.setAccessible(true);
             field.set(dataSourceProxy, "mysql");
-            ConnectionProxy connectionProxy = new ConnectionProxy(dataSourceProxy, dataSource.getConnection().getConnection());
-            MockStatementBase mockStatement = new MockStatement(dataSource.getConnection().getConnection());
+            ConnectionProxy connectionProxy = new ConnectionProxy(
+                    dataSourceProxy, dataSource.getConnection().getConnection());
+            MockStatementBase mockStatement =
+                    new MockStatement(dataSource.getConnection().getConnection());
             statementProxy = new StatementProxy(connectionProxy, mockStatement);
         } catch (Exception e) {
             throw new RuntimeException("init failed");
@@ -88,9 +169,12 @@ public class UpdateExecutorTest {
         String sql = "update table_update_executor_test set name = 'WILL'";
         List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
         MySQLUpdateRecognizer recognizer = new MySQLUpdateRecognizer(sql, asts.get(0));
-        updateExecutor = new UpdateExecutor(statementProxy, (statement, args) -> {
-            return null;
-        }, recognizer);
+        updateExecutor = new UpdateExecutor(
+                statementProxy,
+                (statement, args) -> {
+                    return null;
+                },
+                recognizer);
     }
 
     @Test
