@@ -16,7 +16,6 @@
  */
 package org.apache.seata.rm.datasource.sql;
 
-import org.apache.seata.rm.datasource.sql.SQLVisitorFactory;
 import org.apache.seata.common.loader.EnhancedServiceNotFoundException;
 import org.apache.seata.sqlparser.SQLRecognizer;
 import org.apache.seata.sqlparser.SQLType;
@@ -55,10 +54,11 @@ public class SQLVisitorFactoryTest {
     @Test
     public void testSqlRecognizing() {
 
-        //test for ast was null
-        Assertions.assertThrows(UnsupportedOperationException.class, () -> SQLVisitorFactory.get("", JdbcConstants.MYSQL));
+        // test for ast was null
+        Assertions.assertThrows(
+                UnsupportedOperationException.class, () -> SQLVisitorFactory.get("", JdbcConstants.MYSQL));
 
-        //test for mysql/mariadb/polardb-x insert
+        // test for mysql/mariadb/polardb-x insert
         String sql = "insert into t(id) values (1)";
         List<SQLRecognizer> recognizer = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), MySQLInsertRecognizer.class.getName());
@@ -67,12 +67,12 @@ public class SQLVisitorFactoryTest {
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.POLARDBX);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), PolarDBXInsertRecognizer.class.getName());
 
-        //test for oracle insert
+        // test for oracle insert
         sql = "insert into t(id) values (1)";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), OracleInsertRecognizer.class.getName());
 
-        //test for mysql/mariadb/polardb-x delete
+        // test for mysql/mariadb/polardb-x delete
         sql = "delete from t";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), MySQLDeleteRecognizer.class.getName());
@@ -81,7 +81,7 @@ public class SQLVisitorFactoryTest {
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.POLARDBX);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), PolarDBXDeleteRecognizer.class.getName());
 
-        //test for mysql/mariadb/polardb-x update
+        // test for mysql/mariadb/polardb-x update
         sql = "update t set a = a";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), MySQLUpdateRecognizer.class.getName());
@@ -90,7 +90,7 @@ public class SQLVisitorFactoryTest {
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.POLARDBX);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), PolarDBXUpdateRecognizer.class.getName());
 
-        //test for mysql/mariadb/polardb-x select
+        // test for mysql/mariadb/polardb-x select
         sql = "select * from t";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         Assertions.assertNull(recognizer);
@@ -99,65 +99,67 @@ public class SQLVisitorFactoryTest {
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.POLARDBX);
         Assertions.assertNull(recognizer);
 
-        //test for mysql/mariadb/polardb-x select for update
+        // test for mysql/mariadb/polardb-x select for update
         sql = "select * from t for update";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), MySQLSelectForUpdateRecognizer.class.getName());
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.MARIADB);
-        Assertions.assertEquals(recognizer.get(0).getClass().getName(), MariadbSelectForUpdateRecognizer.class.getName());
+        Assertions.assertEquals(
+                recognizer.get(0).getClass().getName(), MariadbSelectForUpdateRecognizer.class.getName());
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.POLARDBX);
-        Assertions.assertEquals(recognizer.get(0).getClass().getName(), PolarDBXSelectForUpdateRecognizer.class.getName());
+        Assertions.assertEquals(
+                recognizer.get(0).getClass().getName(), PolarDBXSelectForUpdateRecognizer.class.getName());
 
-        //test for sqlserver insert
+        // test for sqlserver insert
         sql = "insert into t(id) values (1)";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.SQLSERVER);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), SqlServerInsertRecognizer.class.getName());
 
-        //test for sqlserver delete
+        // test for sqlserver delete
         sql = "delete from t";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.SQLSERVER);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), SqlServerDeleteRecognizer.class.getName());
 
-        //test for sqlserver update
+        // test for sqlserver update
         sql = "update t set a = a";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.SQLSERVER);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), SqlServerUpdateRecognizer.class.getName());
 
-        //test for sqlserver select
+        // test for sqlserver select
         sql = "select * from t";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.SQLSERVER);
         Assertions.assertNull(recognizer);
 
-        //test for oracle delete
+        // test for oracle delete
         sql = "delete from t";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), OracleDeleteRecognizer.class.getName());
 
-        //test for oracle update
+        // test for oracle update
         sql = "update t set a = a";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
         Assertions.assertEquals(recognizer.get(0).getClass().getName(), OracleUpdateRecognizer.class.getName());
 
-        //test for oracle select
+        // test for oracle select
         sql = "select * from t";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
         Assertions.assertNull(recognizer);
 
-        //test for oracle select for update
+        // test for oracle select for update
         sql = "select * from t for update";
         recognizer = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
-        Assertions.assertEquals(recognizer.get(0).getClass().getName(), OracleSelectForUpdateRecognizer.class.getName());
+        Assertions.assertEquals(
+                recognizer.get(0).getClass().getName(), OracleSelectForUpdateRecognizer.class.getName());
 
-        //test for do not support db
+        // test for do not support db
         Assertions.assertThrows(EnhancedServiceNotFoundException.class, () -> {
             SQLVisitorFactory.get("select * from t", JdbcConstants.DB2);
         });
 
-
-        //TEST FOR Multi-SQL
+        // TEST FOR Multi-SQL
 
         List<SQLRecognizer> sqlRecognizers;
-        //test for mysql/mariadb/polardb-x insert
+        // test for mysql/mariadb/polardb-x insert
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("insert into t(id) values (1);insert into t(id) values (2)", JdbcConstants.MYSQL);
         });
@@ -168,7 +170,7 @@ public class SQLVisitorFactoryTest {
             SQLVisitorFactory.get("insert into t(id) values (1);insert into t(id) values (2)", JdbcConstants.POLARDBX);
         });
 
-        //test for mysql/mariadb/polardb-x insert and update
+        // test for mysql/mariadb/polardb-x insert and update
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("insert into t(id) values (1);update t set a = t;", JdbcConstants.MYSQL);
         });
@@ -179,8 +181,8 @@ public class SQLVisitorFactoryTest {
             SQLVisitorFactory.get("insert into t(id) values (1);update t set a = t;", JdbcConstants.POLARDBX);
         });
 
-        //test for mysql insert and deleted
-        //test for mysql/mariadb/polardb-x insert and deleted
+        // test for mysql insert and deleted
+        // test for mysql/mariadb/polardb-x insert and deleted
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("insert into t(id) values (1);delete from t where id = 1", JdbcConstants.MYSQL);
         });
@@ -191,7 +193,7 @@ public class SQLVisitorFactoryTest {
             SQLVisitorFactory.get("insert into t(id) values (1);delete from t where id = 1", JdbcConstants.POLARDBX);
         });
 
-        //test for mysql/mariadb/polardb-x delete
+        // test for mysql/mariadb/polardb-x delete
         sql = "delete from t where id =1 ; delete from t where id = 2";
         sqlRecognizers = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         for (SQLRecognizer sqlRecognizer : sqlRecognizers) {
@@ -206,7 +208,7 @@ public class SQLVisitorFactoryTest {
             Assertions.assertEquals(sqlRecognizer.getClass().getName(), PolarDBXDeleteRecognizer.class.getName());
         }
 
-        //test for mysql/mariadb/polardb-x update
+        // test for mysql/mariadb/polardb-x update
         sql = "update t set a = a;update t set a = c;";
         sqlRecognizers = SQLVisitorFactory.get(sql, JdbcConstants.MYSQL);
         for (SQLRecognizer sqlRecognizer : sqlRecognizers) {
@@ -221,18 +223,24 @@ public class SQLVisitorFactoryTest {
             Assertions.assertEquals(sqlRecognizer.getClass().getName(), PolarDBXUpdateRecognizer.class.getName());
         }
 
-        //test for mysql/mariadb/polardb-x update and deleted
+        // test for mysql/mariadb/polardb-x update and deleted
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
-            SQLVisitorFactory.get("update t set a = a where id =1;update t set a = c where id = 1;delete from t where id =1", JdbcConstants.MYSQL);
+            SQLVisitorFactory.get(
+                    "update t set a = a where id =1;update t set a = c where id = 1;delete from t where id =1",
+                    JdbcConstants.MYSQL);
         });
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
-            SQLVisitorFactory.get("update t set a = a where id =1;update t set a = c where id = 1;delete from t where id =1", JdbcConstants.MARIADB);
+            SQLVisitorFactory.get(
+                    "update t set a = a where id =1;update t set a = c where id = 1;delete from t where id =1",
+                    JdbcConstants.MARIADB);
         });
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
-            SQLVisitorFactory.get("update t set a = a where id =1;update t set a = c where id = 1;delete from t where id =1", JdbcConstants.POLARDBX);
+            SQLVisitorFactory.get(
+                    "update t set a = a where id =1;update t set a = c where id = 1;delete from t where id =1",
+                    JdbcConstants.POLARDBX);
         });
 
-        //test for mysql/mariadb/polardb-x select
+        // test for mysql/mariadb/polardb-x select
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("select * from d where id = 1; select * from t where id = 2", JdbcConstants.MYSQL);
         });
@@ -243,7 +251,7 @@ public class SQLVisitorFactoryTest {
             SQLVisitorFactory.get("select * from d where id = 1; select * from t where id = 2", JdbcConstants.POLARDBX);
         });
 
-        //test for mysql/mariadb/polardb-x select for update
+        // test for mysql/mariadb/polardb-x select for update
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("select * from t for update; select * from t where id = 2", JdbcConstants.MYSQL);
         });
@@ -254,58 +262,60 @@ public class SQLVisitorFactoryTest {
             SQLVisitorFactory.get("select * from t for update; select * from t where id = 2", JdbcConstants.POLARDBX);
         });
 
-        //test for oracle insert
+        // test for oracle insert
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("insert into t(id) values (1);insert into t(id) values (2)", JdbcConstants.ORACLE);
         });
 
-        //test for oracle delete and deleted
+        // test for oracle delete and deleted
         sql = "delete from t where id =1 ; delete from t where id = 2";
         sqlRecognizers = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
         for (SQLRecognizer sqlRecognizer : sqlRecognizers) {
             Assertions.assertEquals(sqlRecognizer.getClass().getName(), OracleDeleteRecognizer.class.getName());
         }
 
-        //test for oracle update
+        // test for oracle update
         sql = "update t set a = b where id =1 ;update t set a = c where id = 1;";
         sqlRecognizers = SQLVisitorFactory.get(sql, JdbcConstants.ORACLE);
         for (SQLRecognizer sqlRecognizer : sqlRecognizers) {
             Assertions.assertEquals(sqlRecognizer.getClass().getName(), OracleUpdateRecognizer.class.getName());
         }
 
-        //test for oracle select
+        // test for oracle select
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("select * from b ; select * from t where id = 2", JdbcConstants.ORACLE);
         });
 
-        //test for oracle select for update
+        // test for oracle select for update
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("select * from t for update; select * from t where id = 2", JdbcConstants.ORACLE);
         });
 
-        //test for oracle insert and update
+        // test for oracle insert and update
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("insert into t(id) values (1);update t set a = t;", JdbcConstants.ORACLE);
         });
-        //test for oracle insert and deleted
+        // test for oracle insert and deleted
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
             SQLVisitorFactory.get("insert into t(id) values (1);delete from t where id = 1", JdbcConstants.ORACLE);
         });
-        //test for sqlserver select
+        // test for sqlserver select
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
-            SQLVisitorFactory.get("select * from d where id = 1; select * from t where id = 2", JdbcConstants.SQLSERVER);
+            SQLVisitorFactory.get(
+                    "select * from d where id = 1; select * from t where id = 2", JdbcConstants.SQLSERVER);
         });
 
-        //test for sqlserver select for update
+        // test for sqlserver select for update
         Assertions.assertThrows(UnsupportedOperationException.class, () -> {
-            SQLVisitorFactory.get("select * from t WITH(UPDLOCK); select * from t where id = 2", JdbcConstants.SQLSERVER);
+            SQLVisitorFactory.get(
+                    "select * from t WITH(UPDLOCK); select * from t where id = 2", JdbcConstants.SQLSERVER);
         });
-
     }
 
     @Test
     public void testSqlRecognizerLoading() {
-        List<SQLRecognizer> recognizers = SQLVisitorFactory.get("update t1 set name = 'test' where id = '1'", JdbcConstants.MYSQL);
+        List<SQLRecognizer> recognizers =
+                SQLVisitorFactory.get("update t1 set name = 'test' where id = '1'", JdbcConstants.MYSQL);
         Assertions.assertNotNull(recognizers);
         Assertions.assertEquals(recognizers.size(), 1);
         SQLRecognizer recognizer = recognizers.get(0);
