@@ -34,13 +34,10 @@ import static org.mockito.Mockito.times;
 import static org.mockito.Mockito.verify;
 import static org.mockito.Mockito.when;
 
-
 public class UndoLogManagerTest {
 
-
     private static final int APPEND_IN_SIZE = 10;
 
-
     private static final String THE_APPEND_IN_SIZE_PARAM_STRING = " (?,?,?,?,?,?,?,?,?,?) ";
 
     private static final String THE_DOUBLE_APPEND_IN_SIZE_PARAM_STRING = " (?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?,?) ";
@@ -60,7 +57,7 @@ public class UndoLogManagerTest {
         when(connection.prepareStatement(anyString())).thenReturn(preparedStatement);
         UndoLogManagerFactory.getUndoLogManager(JdbcConstants.MYSQL).batchDeleteUndoLog(xids, branchIds, connection);
 
-        //verify
+        // verify
         for (int i = 1; i <= APPEND_IN_SIZE; i++) {
             verify(preparedStatement).setLong(eq(i), anyLong());
             verify(preparedStatement).setString(eq(i), anyString());
@@ -73,11 +70,11 @@ public class UndoLogManagerTest {
 
     @Test
     public void testToBatchDeleteUndoLogSql() {
-        String expectedSqlString = "DELETE FROM undo_log WHERE  branch_id IN " +
-                THE_APPEND_IN_SIZE_PARAM_STRING +
-                " AND xid IN " +
-                THE_DOUBLE_APPEND_IN_SIZE_PARAM_STRING;
-        String batchDeleteUndoLogSql = AbstractUndoLogManager.toBatchDeleteUndoLogSql(APPEND_IN_SIZE * 2, APPEND_IN_SIZE);
+        String expectedSqlString = "DELETE FROM undo_log WHERE  branch_id IN " + THE_APPEND_IN_SIZE_PARAM_STRING
+                + " AND xid IN "
+                + THE_DOUBLE_APPEND_IN_SIZE_PARAM_STRING;
+        String batchDeleteUndoLogSql =
+                AbstractUndoLogManager.toBatchDeleteUndoLogSql(APPEND_IN_SIZE * 2, APPEND_IN_SIZE);
         System.out.println(batchDeleteUndoLogSql);
         assertThat(batchDeleteUndoLogSql).isEqualTo(expectedSqlString);
     }
