@@ -19,6 +19,4 @@ package org.apache.seata.saga.engine.expression;
 /**
  * ELExpression
  */
-public interface ELExpression extends Expression {
-
-}
+public interface ELExpression extends Expression {}
