@@ -23,37 +23,23 @@ import org.apache.seata.tm.api.transaction.TransactionHook;
  */
 public class MockTransactionHook implements TransactionHook {
     @Override
-    public void beforeBegin() {
-
-    }
+    public void beforeBegin() {}
 
     @Override
-    public void afterBegin() {
-
-    }
+    public void afterBegin() {}
 
     @Override
-    public void beforeCommit() {
-
-    }
+    public void beforeCommit() {}
 
     @Override
-    public void afterCommit() {
-
-    }
+    public void afterCommit() {}
 
     @Override
-    public void beforeRollback() {
-
-    }
+    public void beforeRollback() {}
 
     @Override
-    public void afterRollback() {
-
-    }
+    public void afterRollback() {}
 
     @Override
-    public void afterCompletion() {
-
-    }
+    public void afterCompletion() {}
 }
