@@ -39,7 +39,6 @@ import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertTrue;
 
-
 public class CorePropertiesTest {
     private static AnnotationConfigApplicationContext context;
 
@@ -48,16 +47,23 @@ public class CorePropertiesTest {
         context = new AnnotationConfigApplicationContext("org.apache.seata.spring.boot.autoconfigure.properties");
     }
 
-
     @Test
     public void testThreadFactoryProperties() {
         assertEquals("NettyBoss", context.getBean(ThreadFactoryProperties.class).getBossThreadPrefix());
-        assertEquals("NettyServerNIOWorker", context.getBean(ThreadFactoryProperties.class).getWorkerThreadPrefix());
-        assertEquals("NettyServerBizHandler", context.getBean(ThreadFactoryProperties.class).getServerExecutorThreadPrefix());
+        assertEquals(
+                "NettyServerNIOWorker",
+                context.getBean(ThreadFactoryProperties.class).getWorkerThreadPrefix());
+        assertEquals(
+                "NettyServerBizHandler",
+                context.getBean(ThreadFactoryProperties.class).getServerExecutorThreadPrefix());
         assertFalse(context.getBean(ThreadFactoryProperties.class).isShareBossWorker());
-        assertEquals("NettyClientSelector", context.getBean(ThreadFactoryProperties.class).getClientSelectorThreadPrefix());
+        assertEquals(
+                "NettyClientSelector",
+                context.getBean(ThreadFactoryProperties.class).getClientSelectorThreadPrefix());
         assertEquals(-1, context.getBean(ThreadFactoryProperties.class).getClientSelectorThreadSize());
-        assertEquals("NettyClientWorkerThread", context.getBean(ThreadFactoryProperties.class).getClientWorkerThreadPrefix());
+        assertEquals(
+                "NettyClientWorkerThread",
+                context.getBean(ThreadFactoryProperties.class).getClientWorkerThreadPrefix());
         assertEquals(1, context.getBean(ThreadFactoryProperties.class).getBossThreadSize());
         assertEquals("Default", context.getBean(ThreadFactoryProperties.class).getWorkerThreadSize());
     }
@@ -83,35 +89,43 @@ public class CorePropertiesTest {
         assertEquals(100, context.getBean(LogProperties.class).getExceptionRate());
     }
 
-
     @Test
     public void testRegistryConsulProperties() {
         assertEquals("default", context.getBean(RegistryConsulProperties.class).getCluster());
-        assertEquals("127.0.0.1:8500", context.getBean(RegistryConsulProperties.class).getServerAddr());
+        assertEquals(
+                "127.0.0.1:8500",
+                context.getBean(RegistryConsulProperties.class).getServerAddr());
     }
 
     @Test
     public void testRegistryEtcd3Properties() {
         assertEquals("default", context.getBean(RegistryEtcd3Properties.class).getCluster());
-        assertEquals("http://localhost:2379", context.getBean(RegistryEtcd3Properties.class).getServerAddr());
+        assertEquals(
+                "http://localhost:2379",
+                context.getBean(RegistryEtcd3Properties.class).getServerAddr());
     }
 
     @Test
     public void testRegistryEurekaProperties() {
         assertEquals("default", context.getBean(RegistryEurekaProperties.class).getApplication());
-        assertEquals("http://localhost:8761/eureka", context.getBean(RegistryEurekaProperties.class).getServiceUrl());
+        assertEquals(
+                "http://localhost:8761/eureka",
+                context.getBean(RegistryEurekaProperties.class).getServiceUrl());
         assertEquals("1", context.getBean(RegistryEurekaProperties.class).getWeight());
     }
 
     @Test
     public void testRegistryNacosProperties() {
-        assertEquals("localhost:8848", context.getBean(RegistryNacosProperties.class).getServerAddr());
+        assertEquals(
+                "localhost:8848", context.getBean(RegistryNacosProperties.class).getServerAddr());
         assertNull(context.getBean(RegistryNacosProperties.class).getNamespace());
-        assertEquals("SEATA_GROUP", context.getBean(RegistryNacosProperties.class).getGroup());
+        assertEquals(
+                "SEATA_GROUP", context.getBean(RegistryNacosProperties.class).getGroup());
         assertEquals("default", context.getBean(RegistryNacosProperties.class).getCluster());
         assertNull(context.getBean(RegistryNacosProperties.class).getUsername());
         assertNull(context.getBean(RegistryNacosProperties.class).getPassword());
-        assertEquals("seata-server", context.getBean(RegistryNacosProperties.class).getApplication());
+        assertEquals(
+                "seata-server", context.getBean(RegistryNacosProperties.class).getApplication());
     }
 
     @Test
@@ -119,10 +133,10 @@ public class CorePropertiesTest {
         assertEquals("file", context.getBean(RegistryProperties.class).getType());
     }
 
-
     @Test
     public void testRegistryRedisProperties() {
-        assertEquals("localhost:6379", context.getBean(RegistryRedisProperties.class).getServerAddr());
+        assertEquals(
+                "localhost:6379", context.getBean(RegistryRedisProperties.class).getServerAddr());
         assertEquals(0, context.getBean(RegistryRedisProperties.class).getDb());
         assertNull(context.getBean(RegistryRedisProperties.class).getPassword());
         assertEquals("default", context.getBean(RegistryRedisProperties.class).getCluster());
@@ -131,19 +145,27 @@ public class CorePropertiesTest {
 
     @Test
     public void testRegistrySofaProperties() {
-        assertEquals("127.0.0.1:9603", context.getBean(RegistrySofaProperties.class).getServerAddr());
+        assertEquals(
+                "127.0.0.1:9603", context.getBean(RegistrySofaProperties.class).getServerAddr());
         assertEquals("default", context.getBean(RegistrySofaProperties.class).getApplication());
-        assertEquals("DEFAULT_ZONE", context.getBean(RegistrySofaProperties.class).getRegion());
-        assertEquals("DefaultDataCenter", context.getBean(RegistrySofaProperties.class).getDatacenter());
+        assertEquals(
+                "DEFAULT_ZONE", context.getBean(RegistrySofaProperties.class).getRegion());
+        assertEquals(
+                "DefaultDataCenter",
+                context.getBean(RegistrySofaProperties.class).getDatacenter());
         assertEquals("default", context.getBean(RegistrySofaProperties.class).getCluster());
-        assertEquals("SEATA_GROUP", context.getBean(RegistrySofaProperties.class).getGroup());
+        assertEquals(
+                "SEATA_GROUP", context.getBean(RegistrySofaProperties.class).getGroup());
         assertEquals("3000", context.getBean(RegistrySofaProperties.class).getAddressWaitTime());
     }
 
     @Test
     public void testRegistryZooKeeperProperties() {
-        assertEquals("default", context.getBean(RegistryZooKeeperProperties.class).getCluster());
-        assertEquals("127.0.0.1:2181", context.getBean(RegistryZooKeeperProperties.class).getServerAddr());
+        assertEquals(
+                "default", context.getBean(RegistryZooKeeperProperties.class).getCluster());
+        assertEquals(
+                "127.0.0.1:2181",
+                context.getBean(RegistryZooKeeperProperties.class).getServerAddr());
         assertEquals(6000L, context.getBean(RegistryZooKeeperProperties.class).getSessionTimeout());
         assertEquals(2000L, context.getBean(RegistryZooKeeperProperties.class).getConnectTimeout());
     }
@@ -153,7 +175,6 @@ public class CorePropertiesTest {
         assertNull(context.getBean(RegistryCustomProperties.class).getName());
     }
 
-
     @AfterAll
     public static void closeContext() {
         context.close();
