@@ -17,14 +17,15 @@
 package org.apache.seata.serializer.seata.protocol;
 
 import io.netty.buffer.ByteBuf;
-import org.apache.seata.serializer.seata.SeataSerializer;
 import org.apache.seata.core.protocol.AbstractIdentifyRequest;
+import org.apache.seata.core.protocol.ProtocolConstants;
 import org.apache.seata.core.protocol.RegisterTMRequest;
+import org.apache.seata.serializer.seata.SeataSerializer;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.api.Test;
 import org.mockito.Mockito;
-import org.apache.seata.core.protocol.ProtocolConstants;
+
 import static io.netty.buffer.Unpooled.buffer;
 import static org.assertj.core.api.Assertions.assertThat;
 
@@ -39,13 +40,13 @@ public class RegisterTMRequestSerializerTest {
      */
     SeataSerializer seataSerializer = new SeataSerializer(ProtocolConstants.VERSION);
 
-    private static       RegisterTMRequest       registerTMRequest;
-    private static       AbstractIdentifyRequest air;
-    private static final String                  APP_ID    = "applicationId";
-    private static final String                  TSG       = "transactionServiceGroup";
-    private static final String                  ED        = "extraData";
-    private static final short                   TYPE_CODE = 101;
-    private static final ByteBuf                 BB        = buffer(128);
+    private static RegisterTMRequest registerTMRequest;
+    private static AbstractIdentifyRequest air;
+    private static final String APP_ID = "applicationId";
+    private static final String TSG = "transactionServiceGroup";
+    private static final String ED = "extraData";
+    private static final short TYPE_CODE = 101;
+    private static final ByteBuf BB = buffer(128);
 
     /**
      * Test codec.
@@ -64,7 +65,8 @@ public class RegisterTMRequestSerializerTest {
 
         assertThat(registerTMRequest2.getApplicationId()).isEqualTo(registerTMRequest.getApplicationId());
         assertThat(registerTMRequest2.getExtraData()).isEqualTo(registerTMRequest.getExtraData());
-        assertThat(registerTMRequest2.getTransactionServiceGroup()).isEqualTo(registerTMRequest.getTransactionServiceGroup());
+        assertThat(registerTMRequest2.getTransactionServiceGroup())
+                .isEqualTo(registerTMRequest.getTransactionServiceGroup());
         assertThat(registerTMRequest2.getVersion()).isEqualTo(registerTMRequest.getVersion());
     }
 
@@ -74,9 +76,7 @@ public class RegisterTMRequestSerializerTest {
     @BeforeAll
     public static void setupNull() {
         registerTMRequest = new RegisterTMRequest();
-        air = Mockito.mock(
-                AbstractIdentifyRequest.class,
-                Mockito.CALLS_REAL_METHODS);
+        air = Mockito.mock(AbstractIdentifyRequest.class, Mockito.CALLS_REAL_METHODS);
     }
 
     /**
@@ -85,9 +85,7 @@ public class RegisterTMRequestSerializerTest {
     @BeforeAll
     public static void setupWithValues() {
         registerTMRequest = new RegisterTMRequest(APP_ID, TSG, ED);
-        air = Mockito.mock(
-                AbstractIdentifyRequest.class,
-                Mockito.CALLS_REAL_METHODS);
+        air = Mockito.mock(AbstractIdentifyRequest.class, Mockito.CALLS_REAL_METHODS);
     }
 
     /**
@@ -98,7 +96,6 @@ public class RegisterTMRequestSerializerTest {
         Assertions.assertEquals(TYPE_CODE, registerTMRequest.getTypeCode());
     }
 
-
     /**
      * Test decode method with empty parameter
      */
