@@ -16,10 +16,6 @@
  */
 package org.apache.seata.server;
 
-import java.util.List;
-import java.util.concurrent.CopyOnWriteArrayList;
-
-import javax.annotation.Resource;
 import org.apache.seata.core.rpc.Disposable;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -32,12 +28,14 @@ import org.springframework.context.ApplicationListener;
 import org.springframework.core.Ordered;
 import org.springframework.stereotype.Component;
 
+import javax.annotation.Resource;
+import java.util.List;
+import java.util.concurrent.CopyOnWriteArrayList;
 
 /**
  */
 @Component
-public class ServerRunner implements CommandLineRunner, DisposableBean,
-    ApplicationListener<ApplicationEvent>, Ordered {
+public class ServerRunner implements CommandLineRunner, DisposableBean, ApplicationListener<ApplicationEvent>, Ordered {
 
     private static final Logger LOGGER = LoggerFactory.getLogger(ServerRunner.class);
 
@@ -74,7 +72,6 @@ public class ServerRunner implements CommandLineRunner, DisposableBean,
         }
     }
 
-
     public boolean started() {
         return started;
     }
@@ -98,7 +95,7 @@ public class ServerRunner implements CommandLineRunner, DisposableBean,
     @Override
     public void onApplicationEvent(ApplicationEvent event) {
         if (event instanceof WebServerInitializedEvent) {
-            this.port = ((WebServerInitializedEvent)event).getWebServer().getPort();
+            this.port = ((WebServerInitializedEvent) event).getWebServer().getPort();
         }
     }
 
