@@ -29,18 +29,20 @@ public class BranchReleaseLockExecute extends AbstractRaftMsgExecute {
 
     @Override
     public Boolean execute(RaftBaseMsg syncMsg) throws Throwable {
-        RaftBranchSessionSyncMsg sessionSyncMsg = (RaftBranchSessionSyncMsg)syncMsg;
+        RaftBranchSessionSyncMsg sessionSyncMsg = (RaftBranchSessionSyncMsg) syncMsg;
         String xid = sessionSyncMsg.getBranchSession().getXid();
         GlobalSession globalSession = SessionHolder.getRootSessionManager().findGlobalSession(xid);
         if (globalSession == null) {
             if (logger.isWarnEnabled()) {
                 logger.warn(
-                    "The transaction corresponding to the XID: {} does not exist, which may cause a two-phase concurrency issue, msg type: {}",
-                    xid, syncMsg.getMsgType());
+                        "The transaction corresponding to the XID: {} does not exist, which may cause a two-phase concurrency issue, msg type: {}",
+                        xid,
+                        syncMsg.getMsgType());
             }
             return false;
         }
-        BranchSession branchSession = globalSession.getBranch(sessionSyncMsg.getBranchSession().getBranchId());
+        BranchSession branchSession =
+                globalSession.getBranch(sessionSyncMsg.getBranchSession().getBranchId());
         if (branchSession != null) {
             if (logger.isDebugEnabled()) {
                 logger.debug("releaseBranchSessionLock xid: {}", globalSession.getXid());
@@ -49,5 +51,4 @@ public class BranchReleaseLockExecute extends AbstractRaftMsgExecute {
         }
         return false;
     }
-
 }
