@@ -16,6 +16,16 @@
  */
 package org.apache.seata.server.cluster.raft.snapshot;
 
+import com.fasterxml.jackson.databind.JsonMappingException;
+import org.apache.seata.common.exception.ErrorCode;
+import org.apache.seata.common.exception.SeataRuntimeException;
+import org.apache.seata.common.loader.EnhancedServiceLoader;
+import org.apache.seata.core.compressor.CompressorFactory;
+import org.apache.seata.core.serializer.Serializer;
+import org.apache.seata.core.serializer.SerializerType;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
@@ -26,17 +36,6 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.Optional;
 
-import com.fasterxml.jackson.databind.JsonMappingException;
-import org.apache.seata.common.exception.ErrorCode;
-import org.apache.seata.common.exception.SeataRuntimeException;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
-import org.apache.seata.common.loader.EnhancedServiceLoader;
-import org.apache.seata.core.compressor.CompressorFactory;
-import org.apache.seata.core.serializer.Serializer;
-import org.apache.seata.core.serializer.SerializerType;
-
 /**
  */
 public class RaftSnapshotSerializer {
@@ -44,6 +43,7 @@ public class RaftSnapshotSerializer {
     private static final Logger LOGGER = LoggerFactory.getLogger(RaftSnapshotSerializer.class);
 
     private static final List<String> PERMITS = new ArrayList<>();
+
     static {
         PERMITS.add(RaftSnapshot.class.getName());
         PERMITS.add(RaftSnapshot.SnapshotType.class.getName());
@@ -55,11 +55,14 @@ public class RaftSnapshotSerializer {
 
     public static byte[] encode(RaftSnapshot raftSnapshot) throws IOException {
         try (ByteArrayOutputStream bos = new ByteArrayOutputStream();
-             ObjectOutputStream oos = new ObjectOutputStream(bos)) {
-            Serializer serializer =
-                    EnhancedServiceLoader.load(Serializer.class, SerializerType.getByCode(raftSnapshot.getCodec()).name());
-            Optional.ofNullable(raftSnapshot.getBody()).ifPresent(value -> raftSnapshot.setBody(
-                    CompressorFactory.getCompressor(raftSnapshot.getCompressor()).compress(serializer.serialize(value))));
+                ObjectOutputStream oos = new ObjectOutputStream(bos)) {
+            Serializer serializer = EnhancedServiceLoader.load(
+                    Serializer.class,
+                    SerializerType.getByCode(raftSnapshot.getCodec()).name());
+            Optional.ofNullable(raftSnapshot.getBody())
+                    .ifPresent(
+                            value -> raftSnapshot.setBody(CompressorFactory.getCompressor(raftSnapshot.getCompressor())
+                                    .compress(serializer.serialize(value))));
             oos.writeObject(raftSnapshot);
             return bos.toByteArray();
         }
@@ -67,11 +70,14 @@ public class RaftSnapshotSerializer {
 
     public static byte[] encode(io.seata.server.cluster.raft.snapshot.RaftSnapshot raftSnapshot) throws IOException {
         try (ByteArrayOutputStream bos = new ByteArrayOutputStream();
-             ObjectOutputStream oos = new ObjectOutputStream(bos)) {
-            Serializer serializer =
-                    EnhancedServiceLoader.load(Serializer.class, SerializerType.getByCode(raftSnapshot.getCodec()).name());
-            Optional.ofNullable(raftSnapshot.getBody()).ifPresent(value -> raftSnapshot.setBody(
-                    CompressorFactory.getCompressor(raftSnapshot.getCompressor()).compress(serializer.serialize(value))));
+                ObjectOutputStream oos = new ObjectOutputStream(bos)) {
+            Serializer serializer = EnhancedServiceLoader.load(
+                    Serializer.class,
+                    SerializerType.getByCode(raftSnapshot.getCodec()).name());
+            Optional.ofNullable(raftSnapshot.getBody())
+                    .ifPresent(
+                            value -> raftSnapshot.setBody(CompressorFactory.getCompressor(raftSnapshot.getCompressor())
+                                    .compress(serializer.serialize(value))));
             oos.writeObject(raftSnapshot);
             return bos.toByteArray();
         }
@@ -79,34 +85,38 @@ public class RaftSnapshotSerializer {
 
     public static RaftSnapshot decode(byte[] raftSnapshotByte) throws IOException {
         try (ByteArrayInputStream bin = new ByteArrayInputStream(raftSnapshotByte);
-             ObjectInputStream ois = new ObjectInputStream(bin) {
-                 @Override
-                 protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException {
-                     if (!PERMITS.contains(desc.getName())) {
-                         throw new SeataRuntimeException(ErrorCode.ERR_DESERIALIZATION_SECURITY,
-                                 "Failed to deserialize object: " + desc.getName() + " is not permitted");
-                     }
-                     return super.resolveClass(desc);
-                 }
-             }) {
+                ObjectInputStream ois = new ObjectInputStream(bin) {
+                    @Override
+                    protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException {
+                        if (!PERMITS.contains(desc.getName())) {
+                            throw new SeataRuntimeException(
+                                    ErrorCode.ERR_DESERIALIZATION_SECURITY,
+                                    "Failed to deserialize object: " + desc.getName() + " is not permitted");
+                        }
+                        return super.resolveClass(desc);
+                    }
+                }) {
             Object object = ois.readObject();
             RaftSnapshot raftSnapshot;
             if (object instanceof io.seata.server.cluster.raft.snapshot.RaftSnapshot) {
                 raftSnapshot = new RaftSnapshot();
                 io.seata.server.cluster.raft.snapshot.RaftSnapshot oldRaftSnapshot =
-                        (io.seata.server.cluster.raft.snapshot.RaftSnapshot)object;
+                        (io.seata.server.cluster.raft.snapshot.RaftSnapshot) object;
                 raftSnapshot.setBody(oldRaftSnapshot.getBody());
                 raftSnapshot.setVersion(oldRaftSnapshot.getVersion());
                 raftSnapshot.setCompressor(oldRaftSnapshot.getCompressor());
-                raftSnapshot.setType(RaftSnapshot.SnapshotType.valueOf(oldRaftSnapshot.getType().name()));
+                raftSnapshot.setType(RaftSnapshot.SnapshotType.valueOf(
+                        oldRaftSnapshot.getType().name()));
             } else {
-                raftSnapshot = (RaftSnapshot)object;
+                raftSnapshot = (RaftSnapshot) object;
             }
-            Serializer serializer =
-                    EnhancedServiceLoader.load(Serializer.class, SerializerType.getByCode(raftSnapshot.getCodec()).name());
+            Serializer serializer = EnhancedServiceLoader.load(
+                    Serializer.class,
+                    SerializerType.getByCode(raftSnapshot.getCodec()).name());
             Optional.ofNullable(raftSnapshot.getBody())
-                    .ifPresent(value -> raftSnapshot.setBody(serializer.deserialize(CompressorFactory
-                            .getCompressor(raftSnapshot.getCompressor()).decompress((byte[])raftSnapshot.getBody()))));
+                    .ifPresent(value -> raftSnapshot.setBody(
+                            serializer.deserialize(CompressorFactory.getCompressor(raftSnapshot.getCompressor())
+                                    .decompress((byte[]) raftSnapshot.getBody()))));
             return raftSnapshot;
         } catch (Exception e) {
             LOGGER.error("Failed to read raft snapshot: {}", e.getMessage(), e);
@@ -115,13 +125,12 @@ public class RaftSnapshotSerializer {
                 if (cause instanceof JsonMappingException) {
                     Throwable jsonCause = cause.getCause();
                     if (jsonCause instanceof SeataRuntimeException) {
-                        throw (SeataRuntimeException)jsonCause;
+                        throw (SeataRuntimeException) jsonCause;
                     }
                 }
-                throw (RuntimeException)e;
+                throw (RuntimeException) e;
             }
             throw new RuntimeException(e);
         }
     }
-
 }
