@@ -16,15 +16,6 @@
  */
 package org.apache.seata.server.cluster.raft.sync;
 
-import java.io.ByteArrayInputStream;
-import java.io.ByteArrayOutputStream;
-import java.io.IOException;
-import java.io.ObjectInputStream;
-import java.io.ObjectOutputStream;
-import java.io.ObjectStreamClass;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Optional;
 import com.fasterxml.jackson.databind.JsonMappingException;
 import org.apache.seata.common.exception.ErrorCode;
 import org.apache.seata.common.exception.SeataRuntimeException;
@@ -36,6 +27,16 @@ import org.apache.seata.server.cluster.raft.sync.msg.RaftSyncMessage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.ObjectInputStream;
+import java.io.ObjectOutputStream;
+import java.io.ObjectStreamClass;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Optional;
+
 /**
  */
 public class RaftSyncMessageSerializer {
@@ -53,22 +54,29 @@ public class RaftSyncMessageSerializer {
     public static byte[] encode(RaftSyncMessage raftSyncMessage) throws IOException {
         try (ByteArrayOutputStream bos = new ByteArrayOutputStream();
                 ObjectOutputStream oos = new ObjectOutputStream(bos)) {
-            Serializer serializer = EnhancedServiceLoader.load(Serializer.class,
+            Serializer serializer = EnhancedServiceLoader.load(
+                    Serializer.class,
                     SerializerType.getByCode(raftSyncMessage.getCodec()).name());
-            Optional.ofNullable(raftSyncMessage.getBody()).ifPresent(value -> raftSyncMessage.setBody(CompressorFactory
-                    .getCompressor(raftSyncMessage.getCompressor()).compress(serializer.serialize(value))));
+            Optional.ofNullable(raftSyncMessage.getBody())
+                    .ifPresent(value ->
+                            raftSyncMessage.setBody(CompressorFactory.getCompressor(raftSyncMessage.getCompressor())
+                                    .compress(serializer.serialize(value))));
             oos.writeObject(raftSyncMessage);
             return bos.toByteArray();
         }
     }
 
-    public static byte[] encode(io.seata.server.cluster.raft.sync.msg.RaftSyncMessage raftSyncMessage) throws IOException {
+    public static byte[] encode(io.seata.server.cluster.raft.sync.msg.RaftSyncMessage raftSyncMessage)
+            throws IOException {
         try (ByteArrayOutputStream bos = new ByteArrayOutputStream();
                 ObjectOutputStream oos = new ObjectOutputStream(bos)) {
-            Serializer serializer = EnhancedServiceLoader.load(Serializer.class,
+            Serializer serializer = EnhancedServiceLoader.load(
+                    Serializer.class,
                     SerializerType.getByCode(raftSyncMessage.getCodec()).name());
-            Optional.ofNullable(raftSyncMessage.getBody()).ifPresent(value -> raftSyncMessage.setBody(CompressorFactory
-                    .getCompressor(raftSyncMessage.getCompressor()).compress(serializer.serialize(value))));
+            Optional.ofNullable(raftSyncMessage.getBody())
+                    .ifPresent(value ->
+                            raftSyncMessage.setBody(CompressorFactory.getCompressor(raftSyncMessage.getCompressor())
+                                    .compress(serializer.serialize(value))));
             oos.writeObject(raftSyncMessage);
             return bos.toByteArray();
         }
@@ -76,34 +84,37 @@ public class RaftSyncMessageSerializer {
 
     public static RaftSyncMessage decode(byte[] raftSyncMsgByte) {
         try (ByteArrayInputStream bin = new ByteArrayInputStream(raftSyncMsgByte);
-            ObjectInputStream ois = new ObjectInputStream(bin) {
-                @Override
-                protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException {
-                    if (!PERMITS.contains(desc.getName())) {
-                        throw new SeataRuntimeException(ErrorCode.ERR_DESERIALIZATION_SECURITY,
-                            "Failed to deserialize object: " + desc.getName() + " is not permitted");
+                ObjectInputStream ois = new ObjectInputStream(bin) {
+                    @Override
+                    protected Class<?> resolveClass(ObjectStreamClass desc) throws IOException, ClassNotFoundException {
+                        if (!PERMITS.contains(desc.getName())) {
+                            throw new SeataRuntimeException(
+                                    ErrorCode.ERR_DESERIALIZATION_SECURITY,
+                                    "Failed to deserialize object: " + desc.getName() + " is not permitted");
+                        }
+                        return super.resolveClass(desc);
                     }
-                    return super.resolveClass(desc);
-                }
-            }) {
+                }) {
             Object object = ois.readObject();
             RaftSyncMessage raftSyncMessage;
             if (object instanceof io.seata.server.cluster.raft.sync.msg.RaftSyncMessage) {
                 io.seata.server.cluster.raft.sync.msg.RaftSyncMessage oldRaftSyncMessage =
-                    (io.seata.server.cluster.raft.sync.msg.RaftSyncMessage)object;
+                        (io.seata.server.cluster.raft.sync.msg.RaftSyncMessage) object;
                 raftSyncMessage = new RaftSyncMessage();
                 raftSyncMessage.setCodec(oldRaftSyncMessage.getCodec());
                 raftSyncMessage.setCompressor(oldRaftSyncMessage.getCompressor());
                 raftSyncMessage.setVersion(oldRaftSyncMessage.getVersion());
                 raftSyncMessage.setBody(oldRaftSyncMessage.getBody());
             } else {
-                raftSyncMessage = (RaftSyncMessage)object;
+                raftSyncMessage = (RaftSyncMessage) object;
             }
-            Serializer serializer = EnhancedServiceLoader.load(Serializer.class,
-                SerializerType.getByCode(raftSyncMessage.getCodec()).name());
+            Serializer serializer = EnhancedServiceLoader.load(
+                    Serializer.class,
+                    SerializerType.getByCode(raftSyncMessage.getCodec()).name());
             Optional.ofNullable(raftSyncMessage.getBody())
-                .ifPresent(value -> raftSyncMessage.setBody(serializer.deserialize(CompressorFactory
-                    .getCompressor(raftSyncMessage.getCompressor()).decompress((byte[])raftSyncMessage.getBody()))));
+                    .ifPresent(value -> raftSyncMessage.setBody(
+                            serializer.deserialize(CompressorFactory.getCompressor(raftSyncMessage.getCompressor())
+                                    .decompress((byte[]) raftSyncMessage.getBody()))));
             return raftSyncMessage;
         } catch (Exception e) {
             LOGGER.error("Failed to read raft synchronization log: {}", e.getMessage(), e);
@@ -112,13 +123,12 @@ public class RaftSyncMessageSerializer {
                 if (cause instanceof JsonMappingException) {
                     Throwable jsonCause = cause.getCause();
                     if (jsonCause instanceof SeataRuntimeException) {
-                        throw (SeataRuntimeException)jsonCause;
+                        throw (SeataRuntimeException) jsonCause;
                     }
                 }
-                throw (RuntimeException)e;
+                throw (RuntimeException) e;
             }
             throw new RuntimeException(e);
         }
     }
-
 }
