@@ -21,5 +21,4 @@ import org.springframework.scheduling.annotation.EnableAsync;
 
 @Configuration
 @EnableAsync(proxyTargetClass = true)
-public class AsyncConfig {
-}
+public class AsyncConfig {}
