@@ -16,16 +16,10 @@
  */
 package org.apache.seata.server.console.impl.file;
 
-import java.util.Collection;
-import java.util.List;
-import java.util.Objects;
-import java.util.function.Predicate;
-import java.util.stream.Collectors;
-
-import org.apache.seata.server.console.impl.AbstractGlobalService;
-import org.apache.seata.server.console.entity.param.GlobalSessionParam;
 import org.apache.seata.common.result.PageResult;
+import org.apache.seata.server.console.entity.param.GlobalSessionParam;
 import org.apache.seata.server.console.entity.vo.GlobalSessionVO;
+import org.apache.seata.server.console.impl.AbstractGlobalService;
 import org.apache.seata.server.console.service.GlobalSessionService;
 import org.apache.seata.server.session.GlobalSession;
 import org.apache.seata.server.session.SessionHolder;
@@ -33,8 +27,14 @@ import org.apache.seata.server.storage.SessionConverter;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
 import org.springframework.stereotype.Component;
 
-import static org.apache.seata.common.util.StringUtils.isBlank;
+import java.util.Collection;
+import java.util.List;
+import java.util.Objects;
+import java.util.function.Predicate;
+import java.util.stream.Collectors;
+
 import static java.util.Objects.isNull;
+import static org.apache.seata.common.util.StringUtils.isBlank;
 
 /**
  * Global Session File ServiceImpl
@@ -51,18 +51,16 @@ public class GlobalSessionFileServiceImpl extends AbstractGlobalService implemen
             throw new IllegalArgumentException("wrong pageSize or pageNum");
         }
 
-        final Collection<GlobalSession> allSessions = SessionHolder.getRootSessionManager().allSessions();
+        final Collection<GlobalSession> allSessions =
+                SessionHolder.getRootSessionManager().allSessions();
 
-        final List<GlobalSession> filteredSessions = allSessions
-                .parallelStream()
-                .filter(obtainPredicate(param))
-                .collect(Collectors.toList());
+        final List<GlobalSession> filteredSessions =
+                allSessions.parallelStream().filter(obtainPredicate(param)).collect(Collectors.toList());
 
-        return PageResult.build(SessionConverter.convertGlobalSession(filteredSessions), param.getPageNum(), param.getPageSize());
+        return PageResult.build(
+                SessionConverter.convertGlobalSession(filteredSessions), param.getPageNum(), param.getPageSize());
     }
 
-
-
     /**
      * obtain the condition
      *
@@ -73,35 +71,31 @@ public class GlobalSessionFileServiceImpl extends AbstractGlobalService implemen
 
         return session -> {
             return
-                // xid
-                (isBlank(param.getXid()) || session.getXid().contains(param.getXid()))
-
-                &&
-                // applicationId
-                (isBlank(param.getApplicationId()) || session.getApplicationId().contains(param.getApplicationId()))
-
-                &&
-                // status
-                (isNull(param.getStatus()) || Objects.equals(session.getStatus().getCode(), param.getStatus()))
-
-                &&
-                // transactionName
-                (isBlank(param.getTransactionName()) || session.getTransactionName().contains(param.getTransactionName()))
-                &&
-
-                // vgroup
-                (isBlank(param.getVgroup()) || session.getTransactionServiceGroup().equals(param.getVgroup()))
-
-                &&
-                // timeStart
-                (isNull(param.getTimeStart()) || param.getTimeStart() / 1000 >= session.getBeginTime() / 1000)
-
-                &&
-                // timeEnd
-                (isNull(param.getTimeEnd()) || param.getTimeEnd() / 1000 <= session.getBeginTime() / 1000);
+            // xid
+            (isBlank(param.getXid()) || session.getXid().contains(param.getXid()))
+                    &&
+                    // applicationId
+                    (isBlank(param.getApplicationId())
+                            || session.getApplicationId().contains(param.getApplicationId()))
+                    &&
+                    // status
+                    (isNull(param.getStatus())
+                            || Objects.equals(session.getStatus().getCode(), param.getStatus()))
+                    &&
+                    // transactionName
+                    (isBlank(param.getTransactionName())
+                            || session.getTransactionName().contains(param.getTransactionName()))
+                    &&
 
+                    // vgroup
+                    (isBlank(param.getVgroup())
+                            || session.getTransactionServiceGroup().equals(param.getVgroup()))
+                    &&
+                    // timeStart
+                    (isNull(param.getTimeStart()) || param.getTimeStart() / 1000 >= session.getBeginTime() / 1000)
+                    &&
+                    // timeEnd
+                    (isNull(param.getTimeEnd()) || param.getTimeEnd() / 1000 <= session.getBeginTime() / 1000);
         };
     }
-
-
 }
