@@ -16,9 +16,6 @@
  */
 package org.apache.seata.server.coordinator;
 
-import java.io.IOException;
-import java.util.concurrent.TimeoutException;
-
 import org.apache.seata.common.ConfigurationKeys;
 import org.apache.seata.common.DefaultValues;
 import org.apache.seata.common.util.StringUtils;
@@ -47,12 +44,15 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.MDC;
 
+import java.io.IOException;
+import java.util.concurrent.TimeoutException;
+
 import static org.apache.seata.core.exception.TransactionExceptionCode.BranchTransactionNotExist;
 import static org.apache.seata.core.exception.TransactionExceptionCode.FailedToAddBranch;
-import static org.apache.seata.core.exception.TransactionExceptionCode.GlobalTransactionNotActive;
-import static org.apache.seata.core.exception.TransactionExceptionCode.GlobalTransactionStatusInvalid;
 import static org.apache.seata.core.exception.TransactionExceptionCode.FailedToSendBranchCommitRequest;
 import static org.apache.seata.core.exception.TransactionExceptionCode.FailedToSendBranchRollbackRequest;
+import static org.apache.seata.core.exception.TransactionExceptionCode.GlobalTransactionNotActive;
+import static org.apache.seata.core.exception.TransactionExceptionCode.GlobalTransactionStatusInvalid;
 
 /**
  * The type abstract core.
@@ -65,8 +65,8 @@ public abstract class AbstractCore implements Core {
     protected LockManager lockManager = LockerManagerFactory.getLockManager();
 
     private static final Configuration CONFIG = ConfigurationFactory.getInstance();
-    private int appDataErrSize ;
-    private boolean throwDataSizeExp ;
+    private int appDataErrSize;
+    private boolean throwDataSizeExp;
 
     protected RemotingServer remotingServer;
 
@@ -75,42 +75,57 @@ public abstract class AbstractCore implements Core {
             throw new IllegalArgumentException("remotingServer must be not null");
         }
         this.remotingServer = remotingServer;
-        this.appDataErrSize = CONFIG.getInt(ConfigurationKeys.SERVER_APPLICATION_DATA_SIZE_LIMIT,
-            DefaultValues.DEFAULT_APPLICATION_DATA_SIZE_LIMIT);
+        this.appDataErrSize = CONFIG.getInt(
+                ConfigurationKeys.SERVER_APPLICATION_DATA_SIZE_LIMIT,
+                DefaultValues.DEFAULT_APPLICATION_DATA_SIZE_LIMIT);
         this.throwDataSizeExp = CONFIG.getBoolean(ConfigurationKeys.SERVER_APPLICATION_DATA_SIZE_CHECK, false);
-
     }
 
     public abstract BranchType getHandleBranchType();
 
     @Override
-    public Long branchRegister(BranchType branchType, String resourceId, String clientId, String xid,
-                               String applicationData, String lockKeys) throws TransactionException {
+    public Long branchRegister(
+            BranchType branchType,
+            String resourceId,
+            String clientId,
+            String xid,
+            String applicationData,
+            String lockKeys)
+            throws TransactionException {
         GlobalSession globalSession = assertGlobalSessionNotNull(xid, false);
         try {
             StringUtils.checkDataSize(applicationData, "applicationData", appDataErrSize, throwDataSizeExp);
         } catch (RuntimeException e) {
-            throw new BranchTransactionException(TransactionExceptionCode.FailedToAddBranch,
-                    String.format("Failed to store branch xid = %s ", globalSession.getXid()), e);
+            throw new BranchTransactionException(
+                    TransactionExceptionCode.FailedToAddBranch,
+                    String.format("Failed to store branch xid = %s ", globalSession.getXid()),
+                    e);
         }
 
         return SessionHolder.lockAndExecute(globalSession, () -> {
             globalSessionStatusCheck(globalSession);
-            BranchSession branchSession = SessionHelper.newBranchByGlobal(globalSession, branchType, resourceId,
-                    applicationData, lockKeys, clientId);
+            BranchSession branchSession = SessionHelper.newBranchByGlobal(
+                    globalSession, branchType, resourceId, applicationData, lockKeys, clientId);
             MDC.put(RootContext.MDC_KEY_BRANCH_ID, String.valueOf(branchSession.getBranchId()));
             branchSessionLock(globalSession, branchSession);
             try {
                 globalSession.addBranch(branchSession);
             } catch (RuntimeException ex) {
                 branchSessionUnlock(branchSession);
-                throw new BranchTransactionException(FailedToAddBranch, String
-                        .format("Failed to store branch xid = %s branchId = %s", globalSession.getXid(),
-                                branchSession.getBranchId()), ex);
+                throw new BranchTransactionException(
+                        FailedToAddBranch,
+                        String.format(
+                                "Failed to store branch xid = %s branchId = %s",
+                                globalSession.getXid(), branchSession.getBranchId()),
+                        ex);
             }
             if (LOGGER.isInfoEnabled()) {
-                LOGGER.info("Register branch successfully, xid = {}, branchId = {}, resourceId = {} ,lockKeys = {}",
-                    globalSession.getXid(), branchSession.getBranchId(), resourceId, lockKeys);
+                LOGGER.info(
+                        "Register branch successfully, xid = {}, branchId = {}, resourceId = {} ,lockKeys = {}",
+                        globalSession.getXid(),
+                        branchSession.getBranchId(),
+                        resourceId,
+                        lockKeys);
             }
             return branchSession.getBranchId();
         });
@@ -118,50 +133,56 @@ public abstract class AbstractCore implements Core {
 
     protected void globalSessionStatusCheck(GlobalSession globalSession) throws GlobalTransactionException {
         if (!globalSession.isActive()) {
-            throw new GlobalTransactionException(GlobalTransactionNotActive, String.format(
-                "Could not register branch into global session xid = %s status = %s, cause by globalSession not active",
-                globalSession.getXid(), globalSession.getStatus()));
+            throw new GlobalTransactionException(
+                    GlobalTransactionNotActive,
+                    String.format(
+                            "Could not register branch into global session xid = %s status = %s, cause by globalSession not active",
+                            globalSession.getXid(), globalSession.getStatus()));
         }
         if (globalSession.getStatus() != GlobalStatus.Begin) {
-            throw new GlobalTransactionException(GlobalTransactionStatusInvalid, String
-                    .format("Could not register branch into global session xid = %s status = %s while expecting %s",
+            throw new GlobalTransactionException(
+                    GlobalTransactionStatusInvalid,
+                    String.format(
+                            "Could not register branch into global session xid = %s status = %s while expecting %s",
                             globalSession.getXid(), globalSession.getStatus(), GlobalStatus.Begin));
         }
     }
 
-    protected void branchSessionLock(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    protected void branchSessionLock(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {}
 
-    }
-
-    protected void branchSessionUnlock(BranchSession branchSession) throws TransactionException {
-
-    }
+    protected void branchSessionUnlock(BranchSession branchSession) throws TransactionException {}
 
     private GlobalSession assertGlobalSessionNotNull(String xid, boolean withBranchSessions)
             throws TransactionException {
         GlobalSession globalSession = SessionHolder.findGlobalSession(xid, withBranchSessions);
         if (globalSession == null) {
-            throw new GlobalTransactionException(TransactionExceptionCode.GlobalTransactionNotExist,
+            throw new GlobalTransactionException(
+                    TransactionExceptionCode.GlobalTransactionNotExist,
                     String.format("Could not found global transaction xid = %s, may be has finished.", xid));
         }
         return globalSession;
     }
 
     @Override
-    public void branchReport(BranchType branchType, String xid, long branchId, BranchStatus status,
-                             String applicationData) throws TransactionException {
+    public void branchReport(
+            BranchType branchType, String xid, long branchId, BranchStatus status, String applicationData)
+            throws TransactionException {
         GlobalSession globalSession = assertGlobalSessionNotNull(xid, true);
         BranchSession branchSession = globalSession.getBranch(branchId);
         if (branchSession == null) {
-            throw new BranchTransactionException(BranchTransactionNotExist,
+            throw new BranchTransactionException(
+                    BranchTransactionNotExist,
                     String.format("Could not found branch session xid = %s branchId = %s", xid, branchId));
         }
         branchSession.setApplicationData(applicationData);
         globalSession.changeBranchStatus(branchSession, status);
 
         if (LOGGER.isInfoEnabled()) {
-            LOGGER.info("Report branch status successfully, xid = {}, branchId = {}", globalSession.getXid(),
-                branchSession.getBranchId());
+            LOGGER.info(
+                    "Report branch status successfully, xid = {}, branchId = {}",
+                    globalSession.getXid(),
+                    branchSession.getBranchId());
         }
     }
 
@@ -172,7 +193,8 @@ public abstract class AbstractCore implements Core {
     }
 
     @Override
-    public BranchStatus branchCommit(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    public BranchStatus branchCommit(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {
         try {
             BranchCommitRequest request = new BranchCommitRequest();
             request.setXid(branchSession.getXid());
@@ -182,22 +204,27 @@ public abstract class AbstractCore implements Core {
             request.setBranchType(branchSession.getBranchType());
             return branchCommitSend(request, globalSession, branchSession);
         } catch (IOException | TimeoutException e) {
-            throw new BranchTransactionException(FailedToSendBranchCommitRequest,
-                    String.format("Send branch commit failed, xid = %s branchId = %s", branchSession.getXid(),
-                            branchSession.getBranchId()), e);
+            throw new BranchTransactionException(
+                    FailedToSendBranchCommitRequest,
+                    String.format(
+                            "Send branch commit failed, xid = %s branchId = %s",
+                            branchSession.getXid(), branchSession.getBranchId()),
+                    e);
         }
     }
 
-    protected BranchStatus branchCommitSend(BranchCommitRequest request, GlobalSession globalSession,
-                                            BranchSession branchSession) throws IOException, TimeoutException {
+    protected BranchStatus branchCommitSend(
+            BranchCommitRequest request, GlobalSession globalSession, BranchSession branchSession)
+            throws IOException, TimeoutException {
 
         BranchCommitResponse response = (BranchCommitResponse) remotingServer.sendSyncRequest(
-            branchSession.getResourceId(), branchSession.getClientId(), request, branchSession.isAT());
+                branchSession.getResourceId(), branchSession.getClientId(), request, branchSession.isAT());
         return response.getBranchStatus();
     }
 
     @Override
-    public BranchStatus branchRollback(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    public BranchStatus branchRollback(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {
         try {
             BranchRollbackRequest request = new BranchRollbackRequest();
             request.setXid(branchSession.getXid());
@@ -207,17 +234,21 @@ public abstract class AbstractCore implements Core {
             request.setBranchType(branchSession.getBranchType());
             return branchRollbackSend(request, globalSession, branchSession);
         } catch (IOException | TimeoutException e) {
-            throw new BranchTransactionException(FailedToSendBranchRollbackRequest,
-                    String.format("Send branch rollback failed, xid = %s branchId = %s",
-                            branchSession.getXid(), branchSession.getBranchId()), e);
+            throw new BranchTransactionException(
+                    FailedToSendBranchRollbackRequest,
+                    String.format(
+                            "Send branch rollback failed, xid = %s branchId = %s",
+                            branchSession.getXid(), branchSession.getBranchId()),
+                    e);
         }
     }
 
-    protected BranchStatus branchRollbackSend(BranchRollbackRequest request, GlobalSession globalSession,
-                                              BranchSession branchSession) throws IOException, TimeoutException {
+    protected BranchStatus branchRollbackSend(
+            BranchRollbackRequest request, GlobalSession globalSession, BranchSession branchSession)
+            throws IOException, TimeoutException {
 
         BranchRollbackResponse response = (BranchRollbackResponse) remotingServer.sendSyncRequest(
-            branchSession.getResourceId(), branchSession.getClientId(), request, branchSession.isAT());
+                branchSession.getResourceId(), branchSession.getClientId(), request, branchSession.isAT());
         return response.getBranchStatus();
     }
 
@@ -258,17 +289,18 @@ public abstract class AbstractCore implements Core {
     }
 
     @Override
-    public void doGlobalReport(GlobalSession globalSession, String xid, GlobalStatus globalStatus) throws TransactionException {
-
-    }
+    public void doGlobalReport(GlobalSession globalSession, String xid, GlobalStatus globalStatus)
+            throws TransactionException {}
 
     @Override
-    public Boolean doBranchDelete(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    public Boolean doBranchDelete(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {
         return true;
     }
 
     @Override
-    public BranchStatus branchDelete(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    public BranchStatus branchDelete(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {
         return null;
     }
 }
