@@ -16,17 +16,6 @@
  */
 package org.apache.seata.server.coordinator;
 
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Comparator;
-import java.util.List;
-import java.util.Map;
-import java.util.Objects;
-import java.util.concurrent.ArrayBlockingQueue;
-import java.util.concurrent.ScheduledThreadPoolExecutor;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-
 import io.netty.channel.Channel;
 import org.apache.commons.lang.time.DateFormatUtils;
 import org.apache.seata.common.DefaultValues;
@@ -78,25 +67,36 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.slf4j.MDC;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Comparator;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.concurrent.ArrayBlockingQueue;
+import java.util.concurrent.ScheduledThreadPoolExecutor;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+
 import static org.apache.seata.common.Constants.ASYNC_COMMITTING;
 import static org.apache.seata.common.Constants.COMMITTING;
+import static org.apache.seata.common.Constants.END;
 import static org.apache.seata.common.Constants.RETRY_COMMITTING;
 import static org.apache.seata.common.Constants.RETRY_ROLLBACKING;
 import static org.apache.seata.common.Constants.ROLLBACKING;
-import static org.apache.seata.common.Constants.END;
 import static org.apache.seata.common.Constants.SYNC_PROCESSING;
 import static org.apache.seata.common.Constants.TX_TIMEOUT_CHECK;
 import static org.apache.seata.common.Constants.UNDOLOG_DELETE;
 import static org.apache.seata.common.DefaultValues.DEFAULT_ASYNC_COMMITTING_RETRY_PERIOD;
 import static org.apache.seata.common.DefaultValues.DEFAULT_COMMITING_RETRY_PERIOD;
 import static org.apache.seata.common.DefaultValues.DEFAULT_ENABLE_BRANCH_ASYNC_REMOVE;
+import static org.apache.seata.common.DefaultValues.DEFAULT_END_STATUS_RETRY_PERIOD;
 import static org.apache.seata.common.DefaultValues.DEFAULT_MAX_COMMIT_RETRY_TIMEOUT;
 import static org.apache.seata.common.DefaultValues.DEFAULT_MAX_ROLLBACK_RETRY_TIMEOUT;
 import static org.apache.seata.common.DefaultValues.DEFAULT_ROLLBACKING_RETRY_PERIOD;
 import static org.apache.seata.common.DefaultValues.DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE;
 import static org.apache.seata.common.DefaultValues.DEFAULT_TIMEOUT_RETRY_PERIOD;
 import static org.apache.seata.common.DefaultValues.DEFAULT_UNDO_LOG_DELETE_PERIOD;
-import static org.apache.seata.common.DefaultValues.DEFAULT_END_STATUS_RETRY_PERIOD;
 
 /**
  * The type Default coordinator.
@@ -112,38 +112,38 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
     /**
      * The constant COMMITTING_RETRY_PERIOD.
      */
-    protected static final long COMMITTING_RETRY_PERIOD = CONFIG.getLong(ConfigurationKeys.COMMITING_RETRY_PERIOD,
-            DEFAULT_COMMITING_RETRY_PERIOD);
+    protected static final long COMMITTING_RETRY_PERIOD =
+            CONFIG.getLong(ConfigurationKeys.COMMITING_RETRY_PERIOD, DEFAULT_COMMITING_RETRY_PERIOD);
 
     /**
      * The constant ASYNC_COMMITTING_RETRY_PERIOD.
      */
-    protected static final long ASYNC_COMMITTING_RETRY_PERIOD = CONFIG.getLong(
-            ConfigurationKeys.ASYNC_COMMITING_RETRY_PERIOD, DEFAULT_ASYNC_COMMITTING_RETRY_PERIOD);
+    protected static final long ASYNC_COMMITTING_RETRY_PERIOD =
+            CONFIG.getLong(ConfigurationKeys.ASYNC_COMMITING_RETRY_PERIOD, DEFAULT_ASYNC_COMMITTING_RETRY_PERIOD);
 
     /**
      * The constant ROLLBACKING_RETRY_PERIOD.
      */
-    protected static final long ROLLBACKING_RETRY_PERIOD = CONFIG.getLong(ConfigurationKeys.ROLLBACKING_RETRY_PERIOD,
-            DEFAULT_ROLLBACKING_RETRY_PERIOD);
+    protected static final long ROLLBACKING_RETRY_PERIOD =
+            CONFIG.getLong(ConfigurationKeys.ROLLBACKING_RETRY_PERIOD, DEFAULT_ROLLBACKING_RETRY_PERIOD);
 
     /**
      * The constant END_STATUS_RETRY_PERIOD.
      */
-    protected static final long END_STATUS_RETRY_PERIOD = CONFIG.getLong(ConfigurationKeys.END_STATUS_RETRY_PERIOD,
-        DEFAULT_END_STATUS_RETRY_PERIOD);
+    protected static final long END_STATUS_RETRY_PERIOD =
+            CONFIG.getLong(ConfigurationKeys.END_STATUS_RETRY_PERIOD, DEFAULT_END_STATUS_RETRY_PERIOD);
 
     /**
      * The constant TIMEOUT_RETRY_PERIOD.
      */
-    protected static final long TIMEOUT_RETRY_PERIOD = CONFIG.getLong(ConfigurationKeys.TIMEOUT_RETRY_PERIOD,
-            DEFAULT_TIMEOUT_RETRY_PERIOD);
+    protected static final long TIMEOUT_RETRY_PERIOD =
+            CONFIG.getLong(ConfigurationKeys.TIMEOUT_RETRY_PERIOD, DEFAULT_TIMEOUT_RETRY_PERIOD);
 
     /**
      * The Transaction undo log delete period.
      */
-    protected static final long UNDO_LOG_DELETE_PERIOD = CONFIG.getLong(
-            ConfigurationKeys.TRANSACTION_UNDO_LOG_DELETE_PERIOD, DEFAULT_UNDO_LOG_DELETE_PERIOD);
+    protected static final long UNDO_LOG_DELETE_PERIOD =
+            CONFIG.getLong(ConfigurationKeys.TRANSACTION_UNDO_LOG_DELETE_PERIOD, DEFAULT_UNDO_LOG_DELETE_PERIOD);
 
     /**
      * The Transaction undo log delay delete period
@@ -162,50 +162,52 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
      */
     private static final int BRANCH_ASYNC_POOL_SIZE = Runtime.getRuntime().availableProcessors() * 2;
 
-    private static final long MAX_COMMIT_RETRY_TIMEOUT = ConfigurationFactory.getInstance().getLong(
-            ConfigurationKeys.MAX_COMMIT_RETRY_TIMEOUT, DEFAULT_MAX_COMMIT_RETRY_TIMEOUT);
+    private static final long MAX_COMMIT_RETRY_TIMEOUT = ConfigurationFactory.getInstance()
+            .getLong(ConfigurationKeys.MAX_COMMIT_RETRY_TIMEOUT, DEFAULT_MAX_COMMIT_RETRY_TIMEOUT);
 
-    private static final long MAX_ROLLBACK_RETRY_TIMEOUT = ConfigurationFactory.getInstance().getLong(
-            ConfigurationKeys.MAX_ROLLBACK_RETRY_TIMEOUT, DEFAULT_MAX_ROLLBACK_RETRY_TIMEOUT);
+    private static final long MAX_ROLLBACK_RETRY_TIMEOUT = ConfigurationFactory.getInstance()
+            .getLong(ConfigurationKeys.MAX_ROLLBACK_RETRY_TIMEOUT, DEFAULT_MAX_ROLLBACK_RETRY_TIMEOUT);
 
-    private static final boolean ROLLBACK_RETRY_TIMEOUT_UNLOCK_ENABLE = ConfigurationFactory.getInstance().getBoolean(
-            ConfigurationKeys.ROLLBACK_RETRY_TIMEOUT_UNLOCK_ENABLE, DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE);
+    private static final boolean ROLLBACK_RETRY_TIMEOUT_UNLOCK_ENABLE = ConfigurationFactory.getInstance()
+            .getBoolean(ConfigurationKeys.ROLLBACK_RETRY_TIMEOUT_UNLOCK_ENABLE, DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE);
 
-    private static final boolean ROLLBACK_FAILED_UNLOCK_ENABLE = ConfigurationFactory.getInstance().getBoolean(
-        ConfigurationKeys.ROLLBACK_FAILED_UNLOCK_ENABLE, DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE);
+    private static final boolean ROLLBACK_FAILED_UNLOCK_ENABLE = ConfigurationFactory.getInstance()
+            .getBoolean(ConfigurationKeys.ROLLBACK_FAILED_UNLOCK_ENABLE, DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE);
 
     private static final int RETRY_DEAD_THRESHOLD = ConfigurationFactory.getInstance()
-        .getInt(org.apache.seata.common.ConfigurationKeys.RETRY_DEAD_THRESHOLD, DefaultValues.DEFAULT_RETRY_DEAD_THRESHOLD);
+            .getInt(
+                    org.apache.seata.common.ConfigurationKeys.RETRY_DEAD_THRESHOLD,
+                    DefaultValues.DEFAULT_RETRY_DEAD_THRESHOLD);
 
     private final ScheduledThreadPoolExecutor retryRollbacking =
-        new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(RETRY_ROLLBACKING, 1));
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(RETRY_ROLLBACKING, 1));
 
     private final ScheduledThreadPoolExecutor retryCommitting =
-        new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(RETRY_COMMITTING, 1));
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(RETRY_COMMITTING, 1));
 
     private final ScheduledThreadPoolExecutor asyncCommitting =
-        new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(ASYNC_COMMITTING, 1));
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(ASYNC_COMMITTING, 1));
 
     private final ScheduledThreadPoolExecutor timeoutCheck =
-        new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(TX_TIMEOUT_CHECK, 1));
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(TX_TIMEOUT_CHECK, 1));
 
     private final ScheduledThreadPoolExecutor undoLogDelete =
-        new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(UNDOLOG_DELETE, 1));
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(UNDOLOG_DELETE, 1));
 
     private final ScheduledThreadPoolExecutor syncProcessing =
-        new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(SYNC_PROCESSING, 1));
+            new ScheduledThreadPoolExecutor(1, new NamedThreadFactory(SYNC_PROCESSING, 1));
 
     private final GlobalStatus[] retryRollbackingStatuses = new GlobalStatus[] {
-        GlobalStatus.TimeoutRollbacking,
-        GlobalStatus.TimeoutRollbackRetrying,
-        GlobalStatus.RollbackRetrying
+        GlobalStatus.TimeoutRollbacking, GlobalStatus.TimeoutRollbackRetrying, GlobalStatus.RollbackRetrying
     };
 
     private final GlobalStatus[] retryCommittingStatuses = new GlobalStatus[] {GlobalStatus.CommitRetrying};
 
     private final GlobalStatus[] rollbackingStatuses = new GlobalStatus[] {GlobalStatus.Rollbacking};
     private final GlobalStatus[] committingStatuses = new GlobalStatus[] {GlobalStatus.Committing};
-    private final GlobalStatus[] endStatuses = new GlobalStatus[] {GlobalStatus.Rollbacked, GlobalStatus.TimeoutRollbacked, GlobalStatus.Committed, GlobalStatus.Finished};
+    private final GlobalStatus[] endStatuses = new GlobalStatus[] {
+        GlobalStatus.Rollbacked, GlobalStatus.TimeoutRollbacked, GlobalStatus.Committed, GlobalStatus.Finished
+    };
 
     private final ThreadPoolExecutor branchRemoveExecutor;
 
@@ -226,15 +228,18 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         }
         this.remotingServer = remotingServer;
         this.core = new DefaultCore(remotingServer);
-        boolean enableBranchAsyncRemove = CONFIG.getBoolean(
-                ConfigurationKeys.ENABLE_BRANCH_ASYNC_REMOVE, DEFAULT_ENABLE_BRANCH_ASYNC_REMOVE);
+        boolean enableBranchAsyncRemove =
+                CONFIG.getBoolean(ConfigurationKeys.ENABLE_BRANCH_ASYNC_REMOVE, DEFAULT_ENABLE_BRANCH_ASYNC_REMOVE);
         // create branchRemoveExecutor
         if (enableBranchAsyncRemove && StoreConfig.getSessionMode() != SessionMode.FILE) {
-            branchRemoveExecutor = new ThreadPoolExecutor(BRANCH_ASYNC_POOL_SIZE, BRANCH_ASYNC_POOL_SIZE,
-                    Integer.MAX_VALUE, TimeUnit.MILLISECONDS,
-                    new ArrayBlockingQueue<>(
-                            CONFIG.getInt(ConfigurationKeys.SESSION_BRANCH_ASYNC_QUEUE_SIZE, DEFAULT_BRANCH_ASYNC_QUEUE_SIZE)
-                    ), new NamedThreadFactory("branchSessionRemove", BRANCH_ASYNC_POOL_SIZE),
+            branchRemoveExecutor = new ThreadPoolExecutor(
+                    BRANCH_ASYNC_POOL_SIZE,
+                    BRANCH_ASYNC_POOL_SIZE,
+                    Integer.MAX_VALUE,
+                    TimeUnit.MILLISECONDS,
+                    new ArrayBlockingQueue<>(CONFIG.getInt(
+                            ConfigurationKeys.SESSION_BRANCH_ASYNC_QUEUE_SIZE, DEFAULT_BRANCH_ASYNC_QUEUE_SIZE)),
+                    new NamedThreadFactory("branchSessionRemove", BRANCH_ASYNC_POOL_SIZE),
                     new ThreadPoolExecutor.CallerRunsPolicy());
         } else {
             branchRemoveExecutor = null;
@@ -247,7 +252,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
                 if (null == instance) {
                     SessionMode storeMode = StoreConfig.getSessionMode();
                     instance = Objects.equals(SessionMode.RAFT, storeMode)
-                        ? new RaftCoordinator(remotingServer) : new DefaultCoordinator(remotingServer);
+                            ? new RaftCoordinator(remotingServer)
+                            : new DefaultCoordinator(remotingServer);
                 }
             }
         }
@@ -275,7 +281,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         return core.doGlobalRollback(globalSession, retrying);
     }
 
-    public Boolean doBranchDelete(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    public Boolean doBranchDelete(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {
         if (globalSession == null) {
             return true;
         }
@@ -313,11 +320,19 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
     @Override
     protected void doGlobalBegin(GlobalBeginRequest request, GlobalBeginResponse response, RpcContext rpcContext)
             throws TransactionException {
-        response.setXid(core.begin(rpcContext.getApplicationId(), rpcContext.getTransactionServiceGroup(),
-                request.getTransactionName(), request.getTimeout()));
+        response.setXid(core.begin(
+                rpcContext.getApplicationId(),
+                rpcContext.getTransactionServiceGroup(),
+                request.getTransactionName(),
+                request.getTimeout()));
         if (LOGGER.isInfoEnabled()) {
-            LOGGER.info("Begin new global transaction applicationId: {},transactionServiceGroup: {}, transactionName: {},timeout:{},xid:{}",
-                    rpcContext.getApplicationId(), rpcContext.getTransactionServiceGroup(), request.getTransactionName(), request.getTimeout(), response.getXid());
+            LOGGER.info(
+                    "Begin new global transaction applicationId: {},transactionServiceGroup: {}, transactionName: {},timeout:{},xid:{}",
+                    rpcContext.getApplicationId(),
+                    rpcContext.getTransactionServiceGroup(),
+                    request.getTransactionName(),
+                    request.getTimeout(),
+                    response.getXid());
         }
     }
 
@@ -329,8 +344,9 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
     }
 
     @Override
-    protected void doGlobalRollback(GlobalRollbackRequest request, GlobalRollbackResponse response,
-                                    RpcContext rpcContext) throws TransactionException {
+    protected void doGlobalRollback(
+            GlobalRollbackRequest request, GlobalRollbackResponse response, RpcContext rpcContext)
+            throws TransactionException {
         MDC.put(RootContext.MDC_KEY_XID, request.getXid());
         response.setGlobalStatus(core.rollback(request.getXid()));
     }
@@ -350,12 +366,17 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
     }
 
     @Override
-    protected void doBranchRegister(BranchRegisterRequest request, BranchRegisterResponse response,
-                                    RpcContext rpcContext) throws TransactionException {
+    protected void doBranchRegister(
+            BranchRegisterRequest request, BranchRegisterResponse response, RpcContext rpcContext)
+            throws TransactionException {
         MDC.put(RootContext.MDC_KEY_XID, request.getXid());
-        response.setBranchId(
-                core.branchRegister(request.getBranchType(), request.getResourceId(), rpcContext.getClientId(),
-                        request.getXid(), request.getApplicationData(), request.getLockKey()));
+        response.setBranchId(core.branchRegister(
+                request.getBranchType(),
+                request.getResourceId(),
+                rpcContext.getClientId(),
+                request.getXid(),
+                request.getApplicationData(),
+                request.getLockKey()));
     }
 
     @Override
@@ -363,7 +384,11 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
             throws TransactionException {
         MDC.put(RootContext.MDC_KEY_XID, request.getXid());
         MDC.put(RootContext.MDC_KEY_BRANCH_ID, String.valueOf(request.getBranchId()));
-        core.branchReport(request.getBranchType(), request.getXid(), request.getBranchId(), request.getStatus(),
+        core.branchReport(
+                request.getBranchType(),
+                request.getXid(),
+                request.getBranchId(),
+                request.getStatus(),
                 request.getApplicationData());
     }
 
@@ -371,8 +396,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
     protected void doLockCheck(GlobalLockQueryRequest request, GlobalLockQueryResponse response, RpcContext rpcContext)
             throws TransactionException {
         MDC.put(RootContext.MDC_KEY_XID, request.getXid());
-        response.setLockable(
-                core.lockQuery(request.getBranchType(), request.getResourceId(), request.getXid(), request.getLockKey()));
+        response.setLockable(core.lockQuery(
+                request.getBranchType(), request.getResourceId(), request.getXid(), request.getLockKey()));
     }
 
     /**
@@ -382,7 +407,7 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         SessionCondition sessionCondition = new SessionCondition(GlobalStatus.Begin);
         sessionCondition.setLazyLoadBranch(true);
         Collection<GlobalSession> beginGlobalSessions =
-            SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
+                SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
         if (CollectionUtils.isEmpty(beginGlobalSessions)) {
             return;
         }
@@ -391,23 +416,26 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         }
         SessionHelper.forEach(beginGlobalSessions, globalSession -> {
             if (LOGGER.isDebugEnabled()) {
-                LOGGER.debug(
-                        globalSession.getXid() + " " + globalSession.getStatus() + " " + globalSession.getBeginTime() + " "
-                                + globalSession.getTimeout());
+                LOGGER.debug(globalSession.getXid() + " " + globalSession.getStatus() + " "
+                        + globalSession.getBeginTime() + " " + globalSession.getTimeout());
             }
             SessionHolder.lockAndExecute(globalSession, () -> {
                 if (globalSession.getStatus() != GlobalStatus.Begin || !globalSession.isTimeout()) {
                     return false;
                 }
 
-                LOGGER.warn("Global transaction[{}] is timeout and will be rollback,transaction begin time:{} and now:{}", globalSession.getXid(),
-                    DateFormatUtils.format(globalSession.getBeginTime(), TIME_FORMAT_PATTERN), DateFormatUtils.format(System.currentTimeMillis(), TIME_FORMAT_PATTERN));
+                LOGGER.warn(
+                        "Global transaction[{}] is timeout and will be rollback,transaction begin time:{} and now:{}",
+                        globalSession.getXid(),
+                        DateFormatUtils.format(globalSession.getBeginTime(), TIME_FORMAT_PATTERN),
+                        DateFormatUtils.format(System.currentTimeMillis(), TIME_FORMAT_PATTERN));
 
                 globalSession.close();
                 globalSession.changeGlobalStatus(GlobalStatus.TimeoutRollbacking);
 
                 // transaction timeout and start rollbacking event
-                MetricsPublisher.postSessionDoingEvent(globalSession, GlobalStatus.TimeoutRollbacking.name(), false, false);
+                MetricsPublisher.postSessionDoingEvent(
+                        globalSession, GlobalStatus.TimeoutRollbacking.name(), false, false);
 
                 return true;
             });
@@ -415,10 +443,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         if (!beginGlobalSessions.isEmpty() && LOGGER.isDebugEnabled()) {
             LOGGER.debug("Global transaction timeout check end. ");
         }
-
     }
 
-
     /**
      * Handle retry rollbacking.
      */
@@ -426,7 +452,7 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         SessionCondition sessionCondition = new SessionCondition(retryRollbackingStatuses);
         sessionCondition.setLazyLoadBranch(true);
         Collection<GlobalSession> rollbackingSessions =
-            SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
+                SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
         if (CollectionUtils.isEmpty(rollbackingSessions)) {
             return;
         }
@@ -440,13 +466,17 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
 
                     SessionHelper.endRollbackFailed(rollbackingSession, true, true);
 
-                    //The function of this 'return' is 'continue'.
+                    // The function of this 'return' is 'continue'.
                     return;
                 }
 
                 core.doGlobalRollback(rollbackingSession, true);
             } catch (TransactionException ex) {
-                LOGGER.error("Failed to retry rollbacking [{}] {} {}", rollbackingSession.getXid(), ex.getCode(), ex.getMessage());
+                LOGGER.error(
+                        "Failed to retry rollbacking [{}] {} {}",
+                        rollbackingSession.getXid(),
+                        ex.getCode(),
+                        ex.getMessage());
             }
         });
     }
@@ -458,7 +488,7 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         SessionCondition retryCommittingSessionCondition = new SessionCondition(retryCommittingStatuses);
         retryCommittingSessionCondition.setLazyLoadBranch(true);
         Collection<GlobalSession> committingSessions =
-            SessionHolder.getRootSessionManager().findGlobalSessions(retryCommittingSessionCondition);
+                SessionHolder.getRootSessionManager().findGlobalSessions(retryCommittingSessionCondition);
         if (CollectionUtils.isEmpty(committingSessions)) {
             return;
         }
@@ -470,16 +500,20 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
                     // commit retry timeout event
                     SessionHelper.endCommitFailed(committingSession, true, true);
 
-                    //The function of this 'return' is 'continue'.
+                    // The function of this 'return' is 'continue'.
                     return;
                 }
                 if (GlobalStatus.Committed.equals(committingSession.getStatus())
-                    && committingSession.getBranchSessions().isEmpty()) {
-                    SessionHelper.endCommitted(committingSession,true);
+                        && committingSession.getBranchSessions().isEmpty()) {
+                    SessionHelper.endCommitted(committingSession, true);
                 }
                 core.doGlobalCommit(committingSession, true);
             } catch (TransactionException ex) {
-                LOGGER.error("Failed to retry committing [{}] {} {}", committingSession.getXid(), ex.getCode(), ex.getMessage());
+                LOGGER.error(
+                        "Failed to retry committing [{}] {} {}",
+                        committingSession.getXid(),
+                        ex.getCode(),
+                        ex.getMessage());
             }
         });
     }
@@ -498,7 +532,12 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
             try {
                 core.doGlobalCommit(asyncCommittingSession, true);
             } catch (TransactionException ex) {
-                LOGGER.error("Failed to async committing [{}] {} {}", asyncCommittingSession.getXid(), ex.getCode(), ex.getMessage(), ex);
+                LOGGER.error(
+                        "Failed to async committing [{}] {} {}",
+                        asyncCommittingSession.getXid(),
+                        ex.getCode(),
+                        ex.getMessage(),
+                        ex);
             }
         });
     }
@@ -514,8 +553,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
             }
             return;
         }
-        short saveDays = CONFIG.getShort(ConfigurationKeys.TRANSACTION_UNDO_LOG_SAVE_DAYS,
-                UndoLogDeleteRequest.DEFAULT_SAVE_DAYS);
+        short saveDays = CONFIG.getShort(
+                ConfigurationKeys.TRANSACTION_UNDO_LOG_SAVE_DAYS, UndoLogDeleteRequest.DEFAULT_SAVE_DAYS);
         for (Map.Entry<String, Channel> channelEntry : rmChannels.entrySet()) {
             String resourceId = channelEntry.getKey();
             UndoLogDeleteRequest deleteRequest = new UndoLogDeleteRequest();
@@ -524,7 +563,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
             try {
                 remotingServer.sendAsyncRequest(channelEntry.getValue(), deleteRequest);
             } catch (Exception e) {
-                LOGGER.error("Failed to async delete undo log resourceId = {}, exception: {}", resourceId, e.getMessage());
+                LOGGER.error(
+                        "Failed to async delete undo log resourceId = {}, exception: {}", resourceId, e.getMessage());
             }
         }
     }
@@ -540,7 +580,7 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         SessionCondition sessionCondition = new SessionCondition(rollbackingStatuses);
         sessionCondition.setLazyLoadBranch(true);
         List<GlobalSession> rollbackingSessions =
-            SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
+                SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
         if (CollectionUtils.isEmpty(rollbackingSessions)) {
             rollbackingSchedule(RETRY_DEAD_THRESHOLD);
             return;
@@ -567,12 +607,16 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
 
                     SessionHelper.endRollbackFailed(rollbackingSession, true, true);
 
-                    //The function of this 'return' is 'continue'.
+                    // The function of this 'return' is 'continue'.
                     return;
                 }
                 core.doGlobalRollback(rollbackingSession, true);
             } catch (TransactionException ex) {
-                LOGGER.error("Failed to handle rollbacking [{}] {} {}", rollbackingSession.getXid(), ex.getCode(), ex.getMessage());
+                LOGGER.error(
+                        "Failed to handle rollbacking [{}] {} {}",
+                        rollbackingSession.getXid(),
+                        ex.getCode(),
+                        ex.getMessage());
             }
         });
         rollbackingSchedule(delay);
@@ -580,13 +624,15 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
 
     private void rollbackingSchedule(long delay) {
         syncProcessing.schedule(
-            () -> {
-                boolean called = SessionHolder.distributedLockAndExecute(ROLLBACKING, this::handleRollbackingByScheduled);
-                if (!called) {
-                    rollbackingSchedule(ROLLBACKING_RETRY_PERIOD);
-                }
-            },
-            delay, TimeUnit.MILLISECONDS);
+                () -> {
+                    boolean called =
+                            SessionHolder.distributedLockAndExecute(ROLLBACKING, this::handleRollbackingByScheduled);
+                    if (!called) {
+                        rollbackingSchedule(ROLLBACKING_RETRY_PERIOD);
+                    }
+                },
+                delay,
+                TimeUnit.MILLISECONDS);
     }
 
     /**
@@ -596,7 +642,7 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         SessionCondition sessionCondition = new SessionCondition(committingStatuses);
         sessionCondition.setLazyLoadBranch(true);
         List<GlobalSession> committingSessions =
-            SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
+                SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
         if (CollectionUtils.isEmpty(committingSessions)) {
             committingSchedule(RETRY_DEAD_THRESHOLD);
             return;
@@ -621,12 +667,16 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
                     // commit retry timeout event
                     SessionHelper.endCommitFailed(committingSession, true, true);
 
-                    //The function of this 'return' is 'continue'.
+                    // The function of this 'return' is 'continue'.
                     return;
                 }
                 core.doGlobalCommit(committingSession, true);
             } catch (TransactionException ex) {
-                LOGGER.error("Failed to handle committing [{}] {} {}", committingSession.getXid(), ex.getCode(), ex.getMessage());
+                LOGGER.error(
+                        "Failed to handle committing [{}] {} {}",
+                        committingSession.getXid(),
+                        ex.getCode(),
+                        ex.getMessage());
             }
         });
         committingSchedule(delay);
@@ -634,13 +684,15 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
 
     private void committingSchedule(long delay) {
         syncProcessing.schedule(
-            () -> {
-                boolean called = SessionHolder.distributedLockAndExecute(COMMITTING, this::handleCommittingByScheduled);
-                if (!called) {
-                    committingSchedule(COMMITTING_RETRY_PERIOD);
-                }
-            },
-            delay, TimeUnit.MILLISECONDS);
+                () -> {
+                    boolean called =
+                            SessionHolder.distributedLockAndExecute(COMMITTING, this::handleCommittingByScheduled);
+                    if (!called) {
+                        committingSchedule(COMMITTING_RETRY_PERIOD);
+                    }
+                },
+                delay,
+                TimeUnit.MILLISECONDS);
     }
 
     /**
@@ -650,7 +702,7 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         SessionCondition sessionCondition = new SessionCondition(endStatuses);
         sessionCondition.setLazyLoadBranch(true);
         List<GlobalSession> endStatusSessions =
-            SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
+                SessionHolder.getRootSessionManager().findGlobalSessions(sessionCondition);
         if (CollectionUtils.isEmpty(endStatusSessions)) {
             endSchedule(RETRY_DEAD_THRESHOLD);
             return;
@@ -674,7 +726,11 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
                     handleEndStateSession(endStatusSession);
                 }
             } catch (TransactionException ex) {
-                LOGGER.error("Failed to handle end status session [{}] {} {}", endStatusSession.getXid(), ex.getCode(), ex.getMessage());
+                LOGGER.error(
+                        "Failed to handle end status session [{}] {} {}",
+                        endStatusSession.getXid(),
+                        ex.getCode(),
+                        ex.getMessage());
             }
         });
         endSchedule(delay);
@@ -686,13 +742,14 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
 
     private void endSchedule(long delay) {
         syncProcessing.schedule(
-            () -> {
-                boolean called = SessionHolder.distributedLockAndExecute(END, this::handleEndStatesByScheduled);
-                if (!called) {
-                    endSchedule(END_STATUS_RETRY_PERIOD);
-                }
-            },
-            delay, TimeUnit.MILLISECONDS);
+                () -> {
+                    boolean called = SessionHolder.distributedLockAndExecute(END, this::handleEndStatesByScheduled);
+                    if (!called) {
+                        endSchedule(END_STATUS_RETRY_PERIOD);
+                    }
+                },
+                delay,
+                TimeUnit.MILLISECONDS);
     }
 
     /**
@@ -700,24 +757,34 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
      */
     public void init() {
         retryRollbacking.scheduleAtFixedRate(
-            () -> SessionHolder.distributedLockAndExecute(RETRY_ROLLBACKING, this::handleRetryRollbacking), 0,
-            ROLLBACKING_RETRY_PERIOD, TimeUnit.MILLISECONDS);
+                () -> SessionHolder.distributedLockAndExecute(RETRY_ROLLBACKING, this::handleRetryRollbacking),
+                0,
+                ROLLBACKING_RETRY_PERIOD,
+                TimeUnit.MILLISECONDS);
 
         retryCommitting.scheduleAtFixedRate(
-            () -> SessionHolder.distributedLockAndExecute(RETRY_COMMITTING, this::handleRetryCommitting), 0,
-            COMMITTING_RETRY_PERIOD, TimeUnit.MILLISECONDS);
+                () -> SessionHolder.distributedLockAndExecute(RETRY_COMMITTING, this::handleRetryCommitting),
+                0,
+                COMMITTING_RETRY_PERIOD,
+                TimeUnit.MILLISECONDS);
 
         asyncCommitting.scheduleAtFixedRate(
-            () -> SessionHolder.distributedLockAndExecute(ASYNC_COMMITTING, this::handleAsyncCommitting), 0,
-            ASYNC_COMMITTING_RETRY_PERIOD, TimeUnit.MILLISECONDS);
+                () -> SessionHolder.distributedLockAndExecute(ASYNC_COMMITTING, this::handleAsyncCommitting),
+                0,
+                ASYNC_COMMITTING_RETRY_PERIOD,
+                TimeUnit.MILLISECONDS);
 
         timeoutCheck.scheduleAtFixedRate(
-            () -> SessionHolder.distributedLockAndExecute(TX_TIMEOUT_CHECK, this::timeoutCheck), 0,
-            TIMEOUT_RETRY_PERIOD, TimeUnit.MILLISECONDS);
+                () -> SessionHolder.distributedLockAndExecute(TX_TIMEOUT_CHECK, this::timeoutCheck),
+                0,
+                TIMEOUT_RETRY_PERIOD,
+                TimeUnit.MILLISECONDS);
 
         undoLogDelete.scheduleAtFixedRate(
-            () -> SessionHolder.distributedLockAndExecute(UNDOLOG_DELETE, this::undoLogDelete),
-            UNDO_LOG_DELAY_DELETE_PERIOD, UNDO_LOG_DELETE_PERIOD, TimeUnit.MILLISECONDS);
+                () -> SessionHolder.distributedLockAndExecute(UNDOLOG_DELETE, this::undoLogDelete),
+                UNDO_LOG_DELAY_DELETE_PERIOD,
+                UNDO_LOG_DELETE_PERIOD,
+                TimeUnit.MILLISECONDS);
 
         rollbackingSchedule(0);
 
@@ -743,7 +810,6 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
         if (!(response instanceof AbstractTransactionResponse)) {
             throw new IllegalArgumentException();
         }
-
     }
 
     @Override
@@ -834,7 +900,8 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
                     globalSession.getSortedBranches().parallelStream().forEach(this::doRemove);
                 }
             } catch (Exception unKnowException) {
-                LOGGER.error("Asynchronous delete branchSession error, xid = {}", globalSession.getXid(), unKnowException);
+                LOGGER.error(
+                        "Asynchronous delete branchSession error, xid = {}", globalSession.getXid(), unKnowException);
             } finally {
                 MDC.remove(RootContext.MDC_KEY_XID);
             }
@@ -844,11 +911,16 @@ public class DefaultCoordinator extends AbstractTCInboundHandler implements Tran
             try {
                 MDC.put(RootContext.MDC_KEY_BRANCH_ID, String.valueOf(bt.getBranchId()));
                 globalSession.removeBranch(bt);
-                LOGGER.info("Asynchronous delete branchSession successfully, xid = {}, branchId = {}",
-                        globalSession.getXid(), bt.getBranchId());
+                LOGGER.info(
+                        "Asynchronous delete branchSession successfully, xid = {}, branchId = {}",
+                        globalSession.getXid(),
+                        bt.getBranchId());
             } catch (TransactionException transactionException) {
-                LOGGER.error("Asynchronous delete branchSession error, xid = {}, branchId = {}",
-                        globalSession.getXid(), bt.getBranchId(), transactionException);
+                LOGGER.error(
+                        "Asynchronous delete branchSession error, xid = {}, branchId = {}",
+                        globalSession.getXid(),
+                        bt.getBranchId(),
+                        transactionException);
             } finally {
                 MDC.remove(RootContext.MDC_KEY_BRANCH_ID);
             }
