@@ -37,8 +37,8 @@ import static org.apache.seata.common.DefaultValues.DEFAULT_ROLLBACK_FAILED_UNLO
  * The type Abstract session manager.
  */
 public abstract class AbstractSessionManager implements SessionManager {
-    boolean rollbackFailedUnlockEnable = ConfigurationFactory.getInstance().getBoolean(
-        ConfigurationKeys.ROLLBACK_FAILED_UNLOCK_ENABLE, DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE);
+    boolean rollbackFailedUnlockEnable = ConfigurationFactory.getInstance()
+            .getBoolean(ConfigurationKeys.ROLLBACK_FAILED_UNLOCK_ENABLE, DEFAULT_ROLLBACK_FAILED_UNLOCK_ENABLE);
 
     /**
      * The constant LOGGER.
@@ -58,8 +58,7 @@ public abstract class AbstractSessionManager implements SessionManager {
     /**
      * Instantiates a new Abstract session manager.
      */
-    public AbstractSessionManager() {
-    }
+    public AbstractSessionManager() {}
 
     /**
      * Instantiates a new Abstract session manager.
@@ -108,7 +107,7 @@ public abstract class AbstractSessionManager implements SessionManager {
 
     @Override
     public void updateBranchSessionStatus(BranchSession branchSession, BranchStatus status)
-        throws TransactionException {
+            throws TransactionException {
         if (LOGGER.isDebugEnabled()) {
             LOGGER.debug("MANAGER[{}] SESSION[{}] {}", name, branchSession, LogOperation.BRANCH_UPDATE);
         }
@@ -117,7 +116,7 @@ public abstract class AbstractSessionManager implements SessionManager {
 
     @Override
     public void removeBranchSession(GlobalSession globalSession, BranchSession branchSession)
-        throws TransactionException {
+            throws TransactionException {
         if (LOGGER.isDebugEnabled()) {
             LOGGER.debug("MANAGER[{}] SESSION[{}] {}", name, branchSession, LogOperation.BRANCH_REMOVE);
         }
@@ -136,7 +135,7 @@ public abstract class AbstractSessionManager implements SessionManager {
 
     @Override
     public void onBranchStatusChange(GlobalSession globalSession, BranchSession branchSession, BranchStatus status)
-        throws TransactionException {
+            throws TransactionException {
         branchSession.setStatus(status);
         updateBranchSessionStatus(branchSession, status);
     }
@@ -174,33 +173,32 @@ public abstract class AbstractSessionManager implements SessionManager {
     private void writeSession(LogOperation logOperation, SessionStorable sessionStorable) throws TransactionException {
         if (!transactionStoreManager.writeSession(logOperation, sessionStorable)) {
             if (LogOperation.GLOBAL_ADD.equals(logOperation)) {
-                throw new GlobalTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Fail to store global session");
+                throw new GlobalTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Fail to store global session");
             } else if (LogOperation.GLOBAL_UPDATE.equals(logOperation)) {
-                throw new GlobalTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Fail to update global session");
+                throw new GlobalTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Fail to update global session");
             } else if (LogOperation.GLOBAL_REMOVE.equals(logOperation)) {
-                throw new GlobalTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Fail to remove global session");
+                throw new GlobalTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Fail to remove global session");
             } else if (LogOperation.BRANCH_ADD.equals(logOperation)) {
-                throw new BranchTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Fail to store branch session");
+                throw new BranchTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Fail to store branch session");
             } else if (LogOperation.BRANCH_UPDATE.equals(logOperation)) {
-                throw new BranchTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Fail to update branch session");
+                throw new BranchTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Fail to update branch session");
             } else if (LogOperation.BRANCH_REMOVE.equals(logOperation)) {
-                throw new BranchTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Fail to remove branch session");
+                throw new BranchTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Fail to remove branch session");
             } else {
-                throw new BranchTransactionException(TransactionExceptionCode.FailedWriteSession,
-                    "Unknown LogOperation:" + logOperation.name());
+                throw new BranchTransactionException(
+                        TransactionExceptionCode.FailedWriteSession, "Unknown LogOperation:" + logOperation.name());
             }
         }
     }
 
     @Override
-    public void destroy() {
-    }
+    public void destroy() {}
 
     /**
      * Sets transaction store manager.
