@@ -37,8 +37,7 @@ public class SessionStatusValidator {
     }
 
     public static boolean isTimeoutRollbacking(GlobalStatus status) {
-        return status == GlobalStatus.TimeoutRollbacking
-            || status == GlobalStatus.TimeoutRollbackRetrying;
+        return status == GlobalStatus.TimeoutRollbacking || status == GlobalStatus.TimeoutRollbackRetrying;
     }
 
     /**
@@ -55,8 +54,10 @@ public class SessionStatusValidator {
     }
 
     public static boolean isEndGlobalStatus(GlobalStatus status) {
-        return status == GlobalStatus.Rollbacked || status == GlobalStatus.TimeoutRollbacked
-            || status == GlobalStatus.Committed || status == GlobalStatus.Finished;
+        return status == GlobalStatus.Rollbacked
+                || status == GlobalStatus.TimeoutRollbacked
+                || status == GlobalStatus.Committed
+                || status == GlobalStatus.Finished;
     }
 
     /**
