@@ -16,12 +16,6 @@
  */
 package org.apache.seata.server.storage.file.lock;
 
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.ConcurrentMap;
-
 import org.apache.seata.common.exception.FrameworkException;
 import org.apache.seata.common.exception.StoreException;
 import org.apache.seata.common.util.CollectionUtils;
@@ -32,6 +26,12 @@ import org.apache.seata.core.lock.RowLock;
 import org.apache.seata.core.model.LockStatus;
 import org.apache.seata.server.session.BranchSession;
 
+import java.util.List;
+import java.util.Map;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.ConcurrentMap;
+
 import static org.apache.seata.core.exception.TransactionExceptionCode.LockKeyConflictFailFast;
 
 /**
@@ -42,9 +42,10 @@ public class FileLocker extends AbstractLocker {
 
     private static final int BUCKET_PER_TABLE = 128;
 
-    private static final ConcurrentMap<String/* resourceId */, ConcurrentMap<String/* tableName */,
-        ConcurrentMap<Integer/* bucketId */, BucketLockMap>>>
-        LOCK_MAP = new ConcurrentHashMap<>();
+    private static final ConcurrentMap<
+                    String /* resourceId */,
+                    ConcurrentMap<String /* tableName */, ConcurrentMap<Integer /* bucketId */, BucketLockMap>>>
+            LOCK_MAP = new ConcurrentHashMap<>();
 
     /**
      * The Branch session.
@@ -75,30 +76,34 @@ public class FileLocker extends AbstractLocker {
         long transactionId = branchSession.getTransactionId();
 
         Map<BucketLockMap, Set<String>> bucketHolder = branchSession.getLockHolder();
-        Map<String, ConcurrentMap<Integer, BucketLockMap>> dbLockMap = CollectionUtils.computeIfAbsent(
-            LOCK_MAP, resourceId, key -> new ConcurrentHashMap<>(8));
+        Map<String, ConcurrentMap<Integer, BucketLockMap>> dbLockMap =
+                CollectionUtils.computeIfAbsent(LOCK_MAP, resourceId, key -> new ConcurrentHashMap<>(8));
         boolean failFast = false;
         boolean canLock = true;
         for (RowLock lock : rowLocks) {
             String tableName = lock.getTableName();
             String pk = lock.getPk();
-            ConcurrentMap<Integer, BucketLockMap> tableLockMap = CollectionUtils.computeIfAbsent(dbLockMap, tableName,
-                key -> new ConcurrentHashMap<>(8));
+            ConcurrentMap<Integer, BucketLockMap> tableLockMap =
+                    CollectionUtils.computeIfAbsent(dbLockMap, tableName, key -> new ConcurrentHashMap<>(8));
 
             int bucketId = pk.hashCode() % BUCKET_PER_TABLE;
-            BucketLockMap bucketLockMap = CollectionUtils.computeIfAbsent(tableLockMap, bucketId,
-                key -> new BucketLockMap());
+            BucketLockMap bucketLockMap =
+                    CollectionUtils.computeIfAbsent(tableLockMap, bucketId, key -> new BucketLockMap());
             BranchSession previousLockBranchSession = bucketLockMap.get().putIfAbsent(pk, branchSession);
             if (previousLockBranchSession == null) {
                 // No existing lock, and now locked by myself
-                Set<String> keysInHolder = CollectionUtils.computeIfAbsent(bucketHolder, bucketLockMap,
-                    key -> ConcurrentHashMap.newKeySet());
+                Set<String> keysInHolder = CollectionUtils.computeIfAbsent(
+                        bucketHolder, bucketLockMap, key -> ConcurrentHashMap.newKeySet());
                 keysInHolder.add(pk);
             } else if (previousLockBranchSession.getTransactionId() == transactionId) {
                 // Locked by me before
             } else {
-                LOGGER.info("Global lock on [{}:{}] is holding by xid {} branchId {}", tableName, pk,
-                    previousLockBranchSession.getXid(), previousLockBranchSession.getBranchId());
+                LOGGER.info(
+                        "Global lock on [{}:{}] is holding by xid {} branchId {}",
+                        tableName,
+                        pk,
+                        previousLockBranchSession.getXid(),
+                        previousLockBranchSession.getBranchId());
                 try {
                     // Release all acquired locks.
                     branchSession.unlock();
@@ -122,7 +127,7 @@ public class FileLocker extends AbstractLocker {
     @Override
     public boolean releaseLock(List<RowLock> rowLock) {
         if (CollectionUtils.isEmpty(rowLock)) {
-            //no lock
+            // no lock
             return true;
         }
         Map<BucketLockMap, Set<String>> lockHolder = branchSession.getLockHolder();
@@ -142,7 +147,7 @@ public class FileLocker extends AbstractLocker {
     @Override
     public boolean isLockable(List<RowLock> rowLocks) {
         if (CollectionUtils.isEmpty(rowLocks)) {
-            //no lock
+            // no lock
             return true;
         }
         Long transactionId = rowLocks.get(0).getTransactionId();
@@ -177,10 +182,8 @@ public class FileLocker extends AbstractLocker {
         return true;
     }
 
-
     @Override
-    public void updateLockStatus(String xid, LockStatus lockStatus) {
-    }
+    public void updateLockStatus(String xid, LockStatus lockStatus) {}
 
     @Override
     public void cleanAllLocks() {
@@ -202,8 +205,8 @@ public class FileLocker extends AbstractLocker {
      * HashMap(lockHolder).
      */
     public static class BucketLockMap {
-        private final ConcurrentHashMap<String/* pk */, BranchSession/* branchSession */> bucketLockMap
-            = new ConcurrentHashMap<>();
+        private final ConcurrentHashMap<String /* pk */, BranchSession /* branchSession */> bucketLockMap =
+                new ConcurrentHashMap<>();
 
         public ConcurrentHashMap<String, BranchSession> get() {
             return bucketLockMap;
