@@ -16,19 +16,6 @@
  */
 package org.apache.seata.server.storage.file.session;
 
-import java.io.File;
-import java.io.IOException;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.HashSet;
-import java.util.List;
-import java.util.Map;
-import java.util.Set;
-import java.util.Arrays;
-import java.util.Objects;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.stream.Collectors;
-
 import org.apache.seata.common.exception.ShouldNeverHappenException;
 import org.apache.seata.common.loader.LoadLevel;
 import org.apache.seata.common.loader.Scope;
@@ -50,8 +37,20 @@ import org.apache.seata.server.store.AbstractTransactionStoreManager;
 import org.apache.seata.server.store.SessionStorable;
 import org.apache.seata.server.store.TransactionStoreManager;
 
-import static org.apache.seata.common.DefaultValues.DEFAULT_SERVICE_SESSION_RELOAD_READ_SIZE;
+import java.io.File;
+import java.io.IOException;
+import java.util.Arrays;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.HashSet;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Set;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.stream.Collectors;
 
+import static org.apache.seata.common.DefaultValues.DEFAULT_SERVICE_SESSION_RELOAD_READ_SIZE;
 
 /**
  * The type File based session manager.
@@ -60,15 +59,14 @@ import static org.apache.seata.common.DefaultValues.DEFAULT_SERVICE_SESSION_RELO
 @LoadLevel(name = "file", scope = Scope.PROTOTYPE)
 public class FileSessionManager extends AbstractSessionManager implements Reloadable {
 
-    private static final int READ_SIZE = ConfigurationFactory.getInstance().getInt(
-        ConfigurationKeys.SERVICE_SESSION_RELOAD_READ_SIZE, DEFAULT_SERVICE_SESSION_RELOAD_READ_SIZE);
+    private static final int READ_SIZE = ConfigurationFactory.getInstance()
+            .getInt(ConfigurationKeys.SERVICE_SESSION_RELOAD_READ_SIZE, DEFAULT_SERVICE_SESSION_RELOAD_READ_SIZE);
 
     /**
      * The Session map.
      */
     protected Map<String, GlobalSession> sessionMap = new ConcurrentHashMap<>(64);
 
-
     /**
      * Instantiates a new File based session manager.
      *
@@ -95,7 +93,7 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
         super(name);
         if (StringUtils.isNotBlank(sessionStoreFilePath)) {
             transactionStoreManager =
-                new FileTransactionStoreManager(sessionStoreFilePath + File.separator + name, this);
+                    new FileTransactionStoreManager(sessionStoreFilePath + File.separator + name, this);
         } else {
             transactionStoreManager = new AbstractTransactionStoreManager() {
                 @Override
@@ -124,7 +122,7 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
     }
 
     @Override
-    public GlobalSession findGlobalSession(String xid)  {
+    public GlobalSession findGlobalSession(String xid) {
         return sessionMap.get(xid);
     }
 
@@ -154,35 +152,37 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
         }
         Collection<GlobalSession> list = sessionMap.values();
         List<GlobalStatus> finalGlobalStatuses = globalStatuses;
-        return list.parallelStream().filter(globalSession -> {
+        return list.parallelStream()
+                .filter(globalSession -> {
+                    if (null != condition.getOverTimeAliveMills() && condition.getOverTimeAliveMills() > 0) {
+                        if (System.currentTimeMillis() - globalSession.getBeginTime()
+                                <= condition.getOverTimeAliveMills()) {
+                            return false;
+                        }
+                    }
 
-            if (null != condition.getOverTimeAliveMills() && condition.getOverTimeAliveMills() > 0) {
-                if (System.currentTimeMillis() - globalSession.getBeginTime() <= condition.getOverTimeAliveMills()) {
-                    return false;
-                }
-            }
+                    if (!StringUtils.isEmpty(condition.getXid())) {
+                        // Only one will be found, just add and return
+                        return Objects.equals(condition.getXid(), globalSession.getXid());
+                    }
 
-            if (!StringUtils.isEmpty(condition.getXid())) {
-                // Only one will be found, just add and return
-                return Objects.equals(condition.getXid(), globalSession.getXid());
-            }
+                    if (null != condition.getTransactionId() && condition.getTransactionId() > 0) {
+                        // Only one will be found, just add and return
+                        return Objects.equals(condition.getTransactionId(), globalSession.getTransactionId());
+                    }
 
-            if (null != condition.getTransactionId() && condition.getTransactionId() > 0) {
-                // Only one will be found, just add and return
-                return Objects.equals(condition.getTransactionId(), globalSession.getTransactionId());
-            }
-
-            if (null != finalGlobalStatuses) {
-                return finalGlobalStatuses.contains(globalSession.getStatus());
-            }
-            // All test pass, add to resp
-            return true;
-        }).collect(Collectors.toList());
+                    if (null != finalGlobalStatuses) {
+                        return finalGlobalStatuses.contains(globalSession.getStatus());
+                    }
+                    // All test pass, add to resp
+                    return true;
+                })
+                .collect(Collectors.toList());
     }
 
     @Override
     public <T> T lockAndExecute(GlobalSession globalSession, GlobalSession.LockCallable<T> lockCallable)
-        throws TransactionException {
+            throws TransactionException {
         globalSession.lock();
         try {
             return lockCallable.call();
@@ -244,31 +244,34 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
         }
     }
 
-    private void restoreSessions(boolean isHistory, Set<String> removedGlobalBuffer, Map<String,
-        Map<Long, BranchSession>> unhandledBranchBuffer) {
+    private void restoreSessions(
+            boolean isHistory,
+            Set<String> removedGlobalBuffer,
+            Map<String, Map<Long, BranchSession>> unhandledBranchBuffer) {
         if (!(transactionStoreManager instanceof ReloadableStore)) {
             return;
         }
-        while (((ReloadableStore)transactionStoreManager).hasRemaining(isHistory)) {
-            List<TransactionWriteStore> stores = ((ReloadableStore)transactionStoreManager).readWriteStore(READ_SIZE,
-                isHistory);
+        while (((ReloadableStore) transactionStoreManager).hasRemaining(isHistory)) {
+            List<TransactionWriteStore> stores =
+                    ((ReloadableStore) transactionStoreManager).readWriteStore(READ_SIZE, isHistory);
             restore(stores, removedGlobalBuffer, unhandledBranchBuffer);
         }
     }
 
-    private void restore(List<TransactionWriteStore> stores, Set<String> removedGlobalBuffer,
-        Map<String, Map<Long, BranchSession>> unhandledBranchBuffer) {
+    private void restore(
+            List<TransactionWriteStore> stores,
+            Set<String> removedGlobalBuffer,
+            Map<String, Map<Long, BranchSession>> unhandledBranchBuffer) {
         for (TransactionWriteStore store : stores) {
             TransactionStoreManager.LogOperation logOperation = store.getOperate();
             SessionStorable sessionStorable = store.getSessionRequest();
             switch (logOperation) {
                 case GLOBAL_ADD:
                 case GLOBAL_UPDATE: {
-                    GlobalSession globalSession = (GlobalSession)sessionStorable;
+                    GlobalSession globalSession = (GlobalSession) sessionStorable;
                     if (globalSession.getTransactionId() == 0) {
-                        LOGGER.error(
-                            "Restore globalSession from file failed, the transactionId is zero , xid:" + globalSession
-                                .getXid());
+                        LOGGER.error("Restore globalSession from file failed, the transactionId is zero , xid:"
+                                + globalSession.getXid());
                         break;
                     }
                     if (removedGlobalBuffer.contains(globalSession.getXid())) {
@@ -294,11 +297,10 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
                     break;
                 }
                 case GLOBAL_REMOVE: {
-                    GlobalSession globalSession = (GlobalSession)sessionStorable;
+                    GlobalSession globalSession = (GlobalSession) sessionStorable;
                     if (globalSession.getTransactionId() == 0) {
-                        LOGGER.error(
-                            "Restore globalSession from file failed, the transactionId is zero , xid:" + globalSession
-                                .getXid());
+                        LOGGER.error("Restore globalSession from file failed, the transactionId is zero , xid:"
+                                + globalSession.getXid());
                         break;
                     }
                     if (removedGlobalBuffer.contains(globalSession.getXid())) {
@@ -315,11 +317,10 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
                 }
                 case BRANCH_ADD:
                 case BRANCH_UPDATE: {
-                    BranchSession branchSession = (BranchSession)sessionStorable;
+                    BranchSession branchSession = (BranchSession) sessionStorable;
                     if (branchSession.getTransactionId() == 0) {
-                        LOGGER.error(
-                            "Restore branchSession from file failed, the transactionId is zero , xid:" + branchSession
-                                .getXid());
+                        LOGGER.error("Restore branchSession from file failed, the transactionId is zero , xid:"
+                                + branchSession.getXid());
                         break;
                     }
                     if (removedGlobalBuffer.contains(branchSession.getXid())) {
@@ -327,8 +328,9 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
                     }
                     GlobalSession foundGlobalSession = sessionMap.get(branchSession.getXid());
                     if (foundGlobalSession == null) {
-                        unhandledBranchBuffer.computeIfAbsent(branchSession.getXid(), key -> new HashMap<>())
-                            .put(branchSession.getBranchId(), branchSession);
+                        unhandledBranchBuffer
+                                .computeIfAbsent(branchSession.getXid(), key -> new HashMap<>())
+                                .put(branchSession.getBranchId(), branchSession);
                     } else {
                         BranchSession existingBranch = foundGlobalSession.getBranch(branchSession.getBranchId());
                         if (existingBranch == null) {
@@ -340,24 +342,22 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
                     break;
                 }
                 case BRANCH_REMOVE: {
-                    BranchSession branchSession = (BranchSession)sessionStorable;
+                    BranchSession branchSession = (BranchSession) sessionStorable;
                     String xid = branchSession.getXid();
                     if (removedGlobalBuffer.contains(xid)) {
                         break;
                     }
                     long bid = branchSession.getBranchId();
                     if (branchSession.getTransactionId() == 0) {
-                        LOGGER.error(
-                            "Restore branchSession from file failed, the transactionId is zero , xid:" + branchSession
-                                .getXid());
+                        LOGGER.error("Restore branchSession from file failed, the transactionId is zero , xid:"
+                                + branchSession.getXid());
                         break;
                     }
                     GlobalSession found = sessionMap.get(xid);
                     if (found == null) {
                         if (LOGGER.isInfoEnabled()) {
-                            LOGGER.info(
-                                "GlobalSession To Be Updated (Remove Branch) Does Not Exists [" + bid + "/" + xid
-                                    + "]");
+                            LOGGER.info("GlobalSession To Be Updated (Remove Branch) Does Not Exists [" + bid + "/"
+                                    + xid + "]");
                         }
                     } else {
                         BranchSession theBranch = found.getBranch(bid);
@@ -375,7 +375,6 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
                     throw new ShouldNeverHappenException("Unknown Operation: " + logOperation);
             }
         }
-
     }
 
     public Map<String, GlobalSession> getSessionMap() {
@@ -390,5 +389,4 @@ public class FileSessionManager extends AbstractSessionManager implements Reload
     public void destroy() {
         transactionStoreManager.shutdown();
     }
-
 }
