@@ -16,9 +16,6 @@
  */
 package org.apache.seata.server.storage.redis.session;
 
-import java.util.Collection;
-import java.util.List;
-
 import org.apache.seata.common.exception.StoreException;
 import org.apache.seata.common.executor.Initialize;
 import org.apache.seata.common.loader.LoadLevel;
@@ -30,21 +27,22 @@ import org.apache.seata.server.session.AbstractSessionManager;
 import org.apache.seata.server.session.BranchSession;
 import org.apache.seata.server.session.GlobalSession;
 import org.apache.seata.server.session.SessionCondition;
-import org.apache.seata.server.store.TransactionStoreManager.LogOperation;
 import org.apache.seata.server.storage.redis.store.RedisTransactionStoreManagerFactory;
+import org.apache.seata.server.store.TransactionStoreManager.LogOperation;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.Collection;
+import java.util.List;
+
 /**
  */
 @LoadLevel(name = "redis", scope = Scope.PROTOTYPE)
-public class RedisSessionManager extends AbstractSessionManager
-    implements Initialize {
+public class RedisSessionManager extends AbstractSessionManager implements Initialize {
     /**
      * The constant LOGGER.
      */
     protected static final Logger LOGGER = LoggerFactory.getLogger(RedisSessionManager.class);
-    
 
     /**
      * Instantiates a new Data base session manager.
@@ -52,7 +50,6 @@ public class RedisSessionManager extends AbstractSessionManager
     public RedisSessionManager() {
         super();
     }
-    
 
     @Override
     public void init() {
@@ -128,11 +125,19 @@ public class RedisSessionManager extends AbstractSessionManager
 
     @Override
     public Collection<GlobalSession> allSessions() {
-        return findGlobalSessions(
-            new SessionCondition(GlobalStatus.UnKnown, GlobalStatus.Begin, GlobalStatus.Committing,
-                GlobalStatus.CommitRetrying, GlobalStatus.Rollbacking, GlobalStatus.RollbackRetrying,
-                GlobalStatus.TimeoutRollbacking, GlobalStatus.TimeoutRollbackRetrying, GlobalStatus.AsyncCommitting,
-                GlobalStatus.StopRollbackOrRollbackRetry, GlobalStatus.StopCommitOrCommitRetry, GlobalStatus.Deleting));
+        return findGlobalSessions(new SessionCondition(
+                GlobalStatus.UnKnown,
+                GlobalStatus.Begin,
+                GlobalStatus.Committing,
+                GlobalStatus.CommitRetrying,
+                GlobalStatus.Rollbacking,
+                GlobalStatus.RollbackRetrying,
+                GlobalStatus.TimeoutRollbacking,
+                GlobalStatus.TimeoutRollbackRetrying,
+                GlobalStatus.AsyncCommitting,
+                GlobalStatus.StopRollbackOrRollbackRetry,
+                GlobalStatus.StopCommitOrCommitRetry,
+                GlobalStatus.Deleting));
     }
 
     @Override
@@ -143,7 +148,7 @@ public class RedisSessionManager extends AbstractSessionManager
 
     @Override
     public <T> T lockAndExecute(GlobalSession globalSession, GlobalSession.LockCallable<T> lockCallable)
-        throws TransactionException {
+            throws TransactionException {
         return lockCallable.call();
     }
 }
