@@ -16,21 +16,6 @@
  */
 package org.apache.seata.server.storage.redis.store;
 
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.Collections;
-import java.util.Date;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.LinkedHashMap;
-import java.util.List;
-import java.util.Map;
-import java.util.Optional;
-import java.util.Objects;
-import java.util.Set;
-import java.util.function.Function;
-import java.util.stream.Collectors;
-
 import com.google.common.collect.ImmutableMap;
 import org.apache.seata.common.XID;
 import org.apache.seata.common.exception.RedisException;
@@ -52,13 +37,27 @@ import org.apache.seata.server.storage.redis.JedisPooledFactory;
 import org.apache.seata.server.store.AbstractTransactionStoreManager;
 import org.apache.seata.server.store.SessionStorable;
 import org.apache.seata.server.store.TransactionStoreManager;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import redis.clients.jedis.Jedis;
 import redis.clients.jedis.Pipeline;
 import redis.clients.jedis.Transaction;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.Collections;
+import java.util.Date;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.LinkedHashMap;
+import java.util.List;
+import java.util.Map;
+import java.util.Objects;
+import java.util.Optional;
+import java.util.Set;
+import java.util.function.Function;
+import java.util.stream.Collectors;
+
 import static org.apache.seata.common.ConfigurationKeys.STORE_REDIS_QUERY_LIMIT;
 import static org.apache.seata.common.DefaultValues.DEFAULT_QUERY_LIMIT;
 import static org.apache.seata.core.constants.RedisKeyConstants.REDIS_KEY_BRANCH_APPLICATION_DATA;
@@ -158,10 +157,10 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
     public void initGlobalMap() {
         if (CollectionUtils.isEmpty(branchMap)) {
             globalMap = ImmutableMap.<LogOperation, Function<GlobalTransactionDO, Boolean>>builder()
-                .put(LogOperation.GLOBAL_ADD, this::insertGlobalTransactionDO)
-                .put(LogOperation.GLOBAL_UPDATE, this::updateGlobalTransactionDO)
-                .put(LogOperation.GLOBAL_REMOVE, this::deleteGlobalTransactionDO)
-                .build();
+                    .put(LogOperation.GLOBAL_ADD, this::insertGlobalTransactionDO)
+                    .put(LogOperation.GLOBAL_UPDATE, this::updateGlobalTransactionDO)
+                    .put(LogOperation.GLOBAL_REMOVE, this::deleteGlobalTransactionDO)
+                    .build();
         }
     }
 
@@ -171,19 +170,19 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
     public void initBranchMap() {
         if (CollectionUtils.isEmpty(branchMap)) {
             branchMap = ImmutableMap.<LogOperation, Function<BranchTransactionDO, Boolean>>builder()
-                .put(LogOperation.BRANCH_ADD, this::insertBranchTransactionDO)
-                .put(LogOperation.BRANCH_UPDATE, this::updateBranchTransactionDO)
-                .put(LogOperation.BRANCH_REMOVE, this::deleteBranchTransactionDO)
-                .build();
+                    .put(LogOperation.BRANCH_ADD, this::insertBranchTransactionDO)
+                    .put(LogOperation.BRANCH_UPDATE, this::updateBranchTransactionDO)
+                    .put(LogOperation.BRANCH_REMOVE, this::deleteBranchTransactionDO)
+                    .build();
         }
     }
 
     @Override
     public boolean writeSession(LogOperation logOperation, SessionStorable session) {
         if (globalMap.containsKey(logOperation) || branchMap.containsKey(logOperation)) {
-            return globalMap.containsKey(logOperation) ?
-                globalMap.get(logOperation).apply(SessionConverter.convertGlobalTransactionDO(session)) :
-                branchMap.get(logOperation).apply(SessionConverter.convertBranchTransactionDO(session));
+            return globalMap.containsKey(logOperation)
+                    ? globalMap.get(logOperation).apply(SessionConverter.convertGlobalTransactionDO(session))
+                    : branchMap.get(logOperation).apply(SessionConverter.convertBranchTransactionDO(session));
         } else {
             throw new StoreException("Unknown LogOperation:" + logOperation.name());
         }
@@ -198,7 +197,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
     protected boolean insertBranchTransactionDO(BranchTransactionDO branchTransactionDO) {
         String branchKey = buildBranchKey(branchTransactionDO.getBranchId());
         String branchListKey = buildBranchListKeyByXid(branchTransactionDO.getXid());
-        try (Jedis jedis = JedisPooledFactory.getJedisInstance(); Pipeline pipelined = jedis.pipelined()) {
+        try (Jedis jedis = JedisPooledFactory.getJedisInstance();
+                Pipeline pipelined = jedis.pipelined()) {
             Date now = new Date();
             branchTransactionDO.setGmtCreate(now);
             branchTransactionDO.setGmtModified(now);
@@ -272,15 +272,18 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
      */
     protected boolean insertGlobalTransactionDO(GlobalTransactionDO globalTransactionDO) {
         String globalKey = buildGlobalKeyByTransactionId(globalTransactionDO.getTransactionId());
-        try (Jedis jedis = JedisPooledFactory.getJedisInstance(); Pipeline pipelined = jedis.pipelined()) {
+        try (Jedis jedis = JedisPooledFactory.getJedisInstance();
+                Pipeline pipelined = jedis.pipelined()) {
             Date now = new Date();
             globalTransactionDO.setGmtCreate(now);
             globalTransactionDO.setGmtModified(now);
             pipelined.hmset(globalKey, BeanUtils.objectToMap(globalTransactionDO));
             String xid = globalTransactionDO.getXid();
             pipelined.rpush(buildGlobalStatus(globalTransactionDO.getStatus()), xid);
-            pipelined.zadd(REDIS_SEATA_BEGIN_TRANSACTIONS_KEY,
-                globalTransactionDO.getBeginTime() + globalTransactionDO.getTimeout(), globalKey);
+            pipelined.zadd(
+                    REDIS_SEATA_BEGIN_TRANSACTIONS_KEY,
+                    globalTransactionDO.getBeginTime() + globalTransactionDO.getTimeout(),
+                    globalKey);
             pipelined.sync();
             return true;
         } catch (Exception ex) {
@@ -305,15 +308,16 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
             // pipeline mode
             String xid = jedis.hget(globalKey, REDIS_KEY_GLOBAL_XID);
             if (StringUtils.isEmpty(xid)) {
-                LOGGER.warn("Global transaction is not exist,xid = {}.Maybe has been deleted by another tc server",
-                    globalTransactionDO.getXid());
+                LOGGER.warn(
+                        "Global transaction is not exist,xid = {}.Maybe has been deleted by another tc server",
+                        globalTransactionDO.getXid());
                 return true;
             }
             try (Pipeline pipelined = jedis.pipelined()) {
                 pipelined.lrem(globalStatus, 0, globalTransactionDO.getXid());
                 pipelined.del(globalKey);
                 if (GlobalStatus.Begin.getCode() == globalTransactionDO.getStatus()
-                    || GlobalStatus.UnKnown.getCode() == globalTransactionDO.getStatus()) {
+                        || GlobalStatus.UnKnown.getCode() == globalTransactionDO.getStatus()) {
                     pipelined.zrem(REDIS_SEATA_BEGIN_TRANSACTIONS_KEY, globalKey);
                 }
                 pipelined.sync();
@@ -341,7 +345,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
         try (Jedis jedis = JedisPooledFactory.getJedisInstance()) {
             // Defensive watch to prevent other TC server operating concurrently,Fail fast
             jedis.watch(globalKey);
-            List<String> statusAndGmtModified = jedis.hmget(globalKey, REDIS_KEY_GLOBAL_STATUS, REDIS_KEY_GLOBAL_GMT_MODIFIED);
+            List<String> statusAndGmtModified =
+                    jedis.hmget(globalKey, REDIS_KEY_GLOBAL_STATUS, REDIS_KEY_GLOBAL_GMT_MODIFIED);
             String previousStatus = statusAndGmtModified.get(0);
             if (StringUtils.isEmpty(previousStatus)) {
                 jedis.unwatch();
@@ -354,23 +359,26 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
             GlobalStatus before = GlobalStatus.get(Integer.parseInt(previousStatus));
             GlobalStatus after = GlobalStatus.get(status);
             if (!SessionStatusValidator.validateUpdateStatus(before, after)) {
-                throw new StoreException("Illegal changing of global status, update global transaction failed."
-                    + " beforeStatus[" + before.name() + "] cannot be changed to afterStatus[" + after.name() + "]");
+                throw new StoreException(
+                        "Illegal changing of global status, update global transaction failed." + " beforeStatus["
+                                + before.name() + "] cannot be changed to afterStatus[" + after.name() + "]");
             }
 
             String previousGmtModified = statusAndGmtModified.get(1);
             Transaction multi = jedis.multi();
-            Map<String,String> map = new HashMap<>(2);
-            map.put(REDIS_KEY_GLOBAL_STATUS,String.valueOf(globalTransactionDO.getStatus()));
-            map.put(REDIS_KEY_GLOBAL_GMT_MODIFIED,String.valueOf((new Date()).getTime()));
+            Map<String, String> map = new HashMap<>(2);
+            map.put(REDIS_KEY_GLOBAL_STATUS, String.valueOf(globalTransactionDO.getStatus()));
+            map.put(REDIS_KEY_GLOBAL_GMT_MODIFIED, String.valueOf((new Date()).getTime()));
             multi.hmset(globalKey, map);
             multi.lrem(buildGlobalStatus(Integer.valueOf(previousStatus)), 0, xid);
             multi.rpush(buildGlobalStatus(globalTransactionDO.getStatus()), xid);
             multi.zrem(REDIS_SEATA_BEGIN_TRANSACTIONS_KEY, globalKey);
             List<Object> exec = multi.exec();
             if (CollectionUtils.isEmpty(exec)) {
-                //The data has changed by another tc, so we still think the modification is successful.
-                LOGGER.warn("The global transaction xid = {}, maybe changed by another TC. It does not affect the results", xid);
+                // The data has changed by another tc, so we still think the modification is successful.
+                LOGGER.warn(
+                        "The global transaction xid = {}, maybe changed by another TC. It does not affect the results",
+                        xid);
                 return true;
             }
             String hmset = exec.get(0).toString();
@@ -422,7 +430,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
             if (CollectionUtils.isEmpty(map)) {
                 return null;
             }
-            GlobalTransactionDO globalTransactionDO = (GlobalTransactionDO) BeanUtils.mapToObject(map, GlobalTransactionDO.class);
+            GlobalTransactionDO globalTransactionDO =
+                    (GlobalTransactionDO) BeanUtils.mapToObject(map, GlobalTransactionDO.class);
             List<BranchTransactionDO> branchTransactionDOs = null;
             if (withBranchSessions) {
                 branchTransactionDOs = this.readBranchSessionByXid(jedis, xid);
@@ -458,7 +467,9 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
             return globalSessions;
         }
         int perStatusLimit = resetLogQueryLimit(targetMap);
-        final long countGlobalSessions = targetMap.values().stream().collect(Collectors.summarizingInt(Integer::intValue)).getSum();
+        final long countGlobalSessions = targetMap.values().stream()
+                .collect(Collectors.summarizingInt(Integer::intValue))
+                .getSum();
         // queryCount
         final long queryCount = Math.min(logQueryLimit, countGlobalSessions);
         List<List<String>> list = new ArrayList<>();
@@ -483,13 +494,14 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
         if (targetMap.size() == 0 || logQueryLimit <= 0) {
             return list;
         }
-        final long countGlobalSessions = targetMap.values().stream().collect(Collectors.summarizingInt(Integer::intValue)).getSum();
+        final long countGlobalSessions = targetMap.values().stream()
+                .collect(Collectors.summarizingInt(Integer::intValue))
+                .getSum();
         // queryCount
         final long queryCount = Math.min(logQueryLimit, countGlobalSessions);
         try (Jedis jedis = JedisPooledFactory.getJedisInstance()) {
-            Set<String> values =
-                jedis.zrangeByScore(REDIS_SEATA_BEGIN_TRANSACTIONS_KEY, 0, System.currentTimeMillis(), 0,
-                        (int) queryCount);
+            Set<String> values = jedis.zrangeByScore(
+                    REDIS_SEATA_BEGIN_TRANSACTIONS_KEY, 0, System.currentTimeMillis(), 0, (int) queryCount);
             List<Map<String, String>> rep;
             try (Pipeline pipeline = jedis.pipelined()) {
                 for (String value : values) {
@@ -497,19 +509,22 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
                 }
                 rep = (List<Map<String, String>>) (List) pipeline.syncAndReturnAll();
             }
-            list = rep.stream().map(map -> {
-                GlobalTransactionDO globalTransactionDO = (GlobalTransactionDO) BeanUtils.mapToObject(map,
-                        GlobalTransactionDO.class);
-                if (globalTransactionDO != null) {
-                    String xid = globalTransactionDO.getXid();
-                    List<BranchTransactionDO> branchTransactionDOs = new ArrayList<>();
-                    if (withBranchSessions) {
-                        branchTransactionDOs = this.readBranchSessionByXid(jedis, xid);
-                    }
-                    return getGlobalSession(globalTransactionDO, branchTransactionDOs, withBranchSessions);
-                }
-                return null;
-            }).filter(Objects::nonNull).collect(Collectors.toList());
+            list = rep.stream()
+                    .map(map -> {
+                        GlobalTransactionDO globalTransactionDO =
+                                (GlobalTransactionDO) BeanUtils.mapToObject(map, GlobalTransactionDO.class);
+                        if (globalTransactionDO != null) {
+                            String xid = globalTransactionDO.getXid();
+                            List<BranchTransactionDO> branchTransactionDOs = new ArrayList<>();
+                            if (withBranchSessions) {
+                                branchTransactionDOs = this.readBranchSessionByXid(jedis, xid);
+                            }
+                            return getGlobalSession(globalTransactionDO, branchTransactionDOs, withBranchSessions);
+                        }
+                        return null;
+                    })
+                    .filter(Objects::nonNull)
+                    .collect(Collectors.toList());
         }
         return list;
     }
@@ -539,14 +554,15 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
     public List<GlobalSession> readSession(SessionCondition sessionCondition) {
         List<GlobalSession> globalSessions = new ArrayList<>();
         if (StringUtils.isNotEmpty(sessionCondition.getXid())) {
-            GlobalSession globalSession = this.readSession(sessionCondition.getXid(), !sessionCondition.isLazyLoadBranch());
+            GlobalSession globalSession =
+                    this.readSession(sessionCondition.getXid(), !sessionCondition.isLazyLoadBranch());
             if (globalSession != null) {
                 globalSessions.add(globalSession);
             }
             return globalSessions;
         } else if (sessionCondition.getTransactionId() != null) {
-            GlobalSession globalSession = this
-                .readSessionByTransactionId(sessionCondition.getTransactionId().toString(), !sessionCondition.isLazyLoadBranch());
+            GlobalSession globalSession = this.readSessionByTransactionId(
+                    sessionCondition.getTransactionId().toString(), !sessionCondition.isLazyLoadBranch());
             if (globalSession != null) {
                 globalSessions.add(globalSession);
             }
@@ -576,7 +592,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
         int end = pageNum * pageSize - 1;
 
         if (param.getStatus() != null) {
-            String statusKey = buildGlobalStatus(GlobalStatus.get(param.getStatus()).getCode());
+            String statusKey =
+                    buildGlobalStatus(GlobalStatus.get(param.getStatus()).getCode());
             try (Jedis jedis = JedisPooledFactory.getJedisInstance()) {
                 final List<String> xids = jedis.lrange(statusKey, start, end);
                 xids.forEach(xid -> {
@@ -598,8 +615,10 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
      * @param withBranchSessions   if read branch sessions
      * @return the global session with branch session
      */
-    private GlobalSession getGlobalSession(GlobalTransactionDO globalTransactionDO,
-        List<BranchTransactionDO> branchTransactionDOs, boolean withBranchSessions) {
+    private GlobalSession getGlobalSession(
+            GlobalTransactionDO globalTransactionDO,
+            List<BranchTransactionDO> branchTransactionDOs,
+            boolean withBranchSessions) {
         GlobalSession globalSession = SessionConverter.convertGlobalSession(globalTransactionDO, !withBranchSessions);
         if (CollectionUtils.isNotEmpty(branchTransactionDOs)) {
             for (BranchTransactionDO branchTransactionDO : branchTransactionDOs) {
@@ -624,7 +643,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
             if (CollectionUtils.isEmpty(map)) {
                 return null;
             }
-            GlobalTransactionDO globalTransactionDO = (GlobalTransactionDO) BeanUtils.mapToObject(map, GlobalTransactionDO.class);
+            GlobalTransactionDO globalTransactionDO =
+                    (GlobalTransactionDO) BeanUtils.mapToObject(map, GlobalTransactionDO.class);
             if (globalTransactionDO != null) {
                 xid = globalTransactionDO.getXid();
             }
@@ -655,7 +675,7 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
                     if (branchInfo != null) {
                         Map<String, String> branchInfoMap = (Map<String, String>) branchInfo;
                         Optional<BranchTransactionDO> branchTransactionDO = Optional.ofNullable(
-                            (BranchTransactionDO) BeanUtils.mapToObject(branchInfoMap, BranchTransactionDO.class));
+                                (BranchTransactionDO) BeanUtils.mapToObject(branchInfoMap, BranchTransactionDO.class));
                         branchTransactionDO.ifPresent(branchTransactionDOs::add);
                     }
                 }
@@ -732,7 +752,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
     private Map<String, Integer> calculateStatuskeysHasData(List<String> statusKeys) {
         Map<String, Integer> resultMap = new LinkedHashMap<>();
         Map<String, Integer> keysMap = new HashMap<>(statusKeys.size());
-        try (Jedis jedis = JedisPooledFactory.getJedisInstance(); Pipeline pipelined = jedis.pipelined()) {
+        try (Jedis jedis = JedisPooledFactory.getJedisInstance();
+                Pipeline pipelined = jedis.pipelined()) {
             statusKeys.forEach(key -> pipelined.llen(key));
             List<Long> counts = (List) pipelined.syncAndReturnAll();
             for (int i = 0; i < counts.size(); i++) {
@@ -742,7 +763,7 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
             }
         }
 
-        //sort
+        // sort
         List<Map.Entry<String, Integer>> list = new ArrayList<>(keysMap.entrySet());
         list.sort((o1, o2) -> o2.getValue() - o1.getValue());
         list.forEach(e -> resultMap.put(e.getKey(), e.getValue()));
@@ -762,7 +783,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
         for (GlobalStatus status : values) {
             statusKeys.add(buildGlobalStatus(status.getCode()));
         }
-        try (Jedis jedis = JedisPooledFactory.getJedisInstance(); Pipeline pipelined = jedis.pipelined()) {
+        try (Jedis jedis = JedisPooledFactory.getJedisInstance();
+                Pipeline pipelined = jedis.pipelined()) {
             statusKeys.stream().forEach(statusKey -> pipelined.llen(statusKey));
             List<Long> list = (List<Long>) (List) pipelined.syncAndReturnAll();
             if (list.size() > 0) {
@@ -780,8 +802,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
         return statusKeys;
     }
 
-    private void dogetXidsForTargetMapRecursive(Map<String, Integer> targetMap, long start, long end,
-        long queryCount, List<List<String>> listList) {
+    private void dogetXidsForTargetMapRecursive(
+            Map<String, Integer> targetMap, long start, long end, long queryCount, List<List<String>> listList) {
 
         long total = listList.stream().mapToLong(List::size).sum();
 
@@ -826,8 +848,8 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
         dogetXidsForTargetMapRecursive(targetMap, startNew, endNew, queryCount, listList);
     }
 
-    private List<List<String>> dogetXidsForTargetMap(Map<String, Integer> targetMap, int start, int end,
-        int totalCount) {
+    private List<List<String>> dogetXidsForTargetMap(
+            Map<String, Integer> targetMap, int start, int end, int totalCount) {
         List<List<String>> listList = new ArrayList<>();
         try (Jedis jedis = JedisPooledFactory.getJedisInstance()) {
             for (String key : targetMap.keySet()) {
@@ -868,5 +890,4 @@ public class RedisTransactionStoreManager extends AbstractTransactionStoreManage
     public void setLogQueryLimit(int logQueryLimit) {
         this.logQueryLimit = logQueryLimit;
     }
-
 }
