@@ -16,9 +16,6 @@
  */
 package org.apache.seata.server.transaction.at;
 
-import java.io.IOException;
-import java.util.HashMap;
-import java.util.Map;
 import com.fasterxml.jackson.databind.ObjectMapper;
 import org.apache.seata.common.exception.StoreException;
 import org.apache.seata.common.util.StringUtils;
@@ -31,6 +28,9 @@ import org.apache.seata.server.coordinator.AbstractCore;
 import org.apache.seata.server.session.BranchSession;
 import org.apache.seata.server.session.GlobalSession;
 
+import java.io.IOException;
+import java.util.HashMap;
+import java.util.Map;
 
 import static org.apache.seata.common.Constants.AUTO_COMMIT;
 import static org.apache.seata.common.Constants.SKIP_CHECK_LOCK;
@@ -41,9 +41,9 @@ import static org.apache.seata.core.exception.TransactionExceptionCode.LockKeyCo
  *
  */
 public class ATCore extends AbstractCore {
-    
+
     private final ObjectMapper objectMapper = new ObjectMapper();
-    
+
     public ATCore(RemotingServer remotingServer) {
         super(remotingServer);
     }
@@ -55,7 +55,7 @@ public class ATCore extends AbstractCore {
 
     @Override
     protected void branchSessionLock(GlobalSession globalSession, BranchSession branchSession)
-        throws TransactionException {
+            throws TransactionException {
         String applicationData = branchSession.getApplicationData();
         boolean autoCommit = true;
         boolean skipCheckLock = false;
@@ -63,12 +63,12 @@ public class ATCore extends AbstractCore {
             try {
                 Map<String, Object> data = objectMapper.readValue(applicationData, HashMap.class);
                 Object clientAutoCommit = data.get(AUTO_COMMIT);
-                if (clientAutoCommit != null && !(boolean)clientAutoCommit) {
-                    autoCommit = (boolean)clientAutoCommit;
+                if (clientAutoCommit != null && !(boolean) clientAutoCommit) {
+                    autoCommit = (boolean) clientAutoCommit;
                 }
                 Object clientSkipCheckLock = data.get(SKIP_CHECK_LOCK);
                 if (clientSkipCheckLock instanceof Boolean) {
-                    skipCheckLock = (boolean)clientSkipCheckLock;
+                    skipCheckLock = (boolean) clientSkipCheckLock;
                 }
             } catch (IOException e) {
                 LOGGER.error("failed to get application data: {}", e.getMessage(), e);
@@ -76,16 +76,20 @@ public class ATCore extends AbstractCore {
         }
         try {
             if (!branchSession.lock(autoCommit, skipCheckLock)) {
-                throw new BranchTransactionException(LockKeyConflict,
-                    String.format("Global lock acquire failed xid = %s branchId = %s", globalSession.getXid(),
-                        branchSession.getBranchId()));
+                throw new BranchTransactionException(
+                        LockKeyConflict,
+                        String.format(
+                                "Global lock acquire failed xid = %s branchId = %s",
+                                globalSession.getXid(), branchSession.getBranchId()));
             }
         } catch (StoreException e) {
             Throwable cause = e.getCause();
             if (cause instanceof BranchTransactionException) {
-                throw new BranchTransactionException(((BranchTransactionException)cause).getCode(),
-                    String.format("Global lock acquire failed xid = %s branchId = %s", globalSession.getXid(),
-                        branchSession.getBranchId()));
+                throw new BranchTransactionException(
+                        ((BranchTransactionException) cause).getCode(),
+                        String.format(
+                                "Global lock acquire failed xid = %s branchId = %s",
+                                globalSession.getXid(), branchSession.getBranchId()));
             }
             throw e;
         }
@@ -103,7 +107,8 @@ public class ATCore extends AbstractCore {
     }
 
     @Override
-    public BranchStatus branchDelete(GlobalSession globalSession, BranchSession branchSession) throws TransactionException {
+    public BranchStatus branchDelete(GlobalSession globalSession, BranchSession branchSession)
+            throws TransactionException {
         // AT mode use branch commit to delete undo log
         return super.branchCommit(globalSession, branchSession);
     }
