@@ -16,11 +16,10 @@
  */
 package org.apache.seata.server.lock.file;
 
-import java.util.stream.Stream;
-
 import org.apache.seata.common.XID;
-import org.apache.seata.core.model.BranchType;
 import org.apache.seata.common.util.UUIDGenerator;
+import org.apache.seata.core.model.BranchType;
+import org.apache.seata.server.DynamicPortTestConfig;
 import org.apache.seata.server.lock.LockManager;
 import org.apache.seata.server.session.BranchSession;
 import org.junit.jupiter.api.Assertions;
@@ -30,16 +29,19 @@ import org.junit.jupiter.params.ParameterizedTest;
 import org.junit.jupiter.params.provider.MethodSource;
 import org.springframework.boot.test.context.SpringBootTest;
 import org.springframework.context.ApplicationContext;
+import org.springframework.context.annotation.Import;
+
+import java.util.stream.Stream;
 
 import static org.apache.seata.common.DefaultValues.DEFAULT_TX_GROUP;
 
-
 /**
  * The type Default lock manager impl test.
  *
  * @since 2019 /1/23
  */
 @SpringBootTest
+@Import(DynamicPortTestConfig.class)
 public class FileLockManagerImplTest {
 
     private LockManager lockManager = new FileLockManagerForTest();
@@ -50,11 +52,9 @@ public class FileLockManagerImplTest {
 
     private static final String lockKey = "tb_1:13";
 
-
     @BeforeAll
-    public static void setup(ApplicationContext context){
+    public static void setup(ApplicationContext context) {}
 
-    }
     /**
      * Acquire lock test.
      *
@@ -100,5 +100,4 @@ public class FileLockManagerImplTest {
         branchSession.setApplicationData("{\"data\":\"test\"}");
         return Stream.of(branchSession);
     }
-
 }
