@@ -16,10 +16,10 @@
  */
 package org.apache.seata.server.session;
 
-import java.util.stream.Stream;
-
-import org.apache.seata.core.model.BranchType;
 import org.apache.seata.common.util.UUIDGenerator;
+import org.apache.seata.core.exception.TransactionException;
+import org.apache.seata.core.model.BranchType;
+import org.apache.seata.server.DynamicPortTestConfig;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
 import org.junit.jupiter.params.ParameterizedTest;
@@ -27,6 +27,10 @@ import org.junit.jupiter.params.provider.Arguments;
 import org.junit.jupiter.params.provider.MethodSource;
 import org.springframework.boot.test.context.SpringBootTest;
 import org.springframework.context.ApplicationContext;
+import org.springframework.context.annotation.Import;
+
+import java.util.concurrent.ThreadLocalRandom;
+import java.util.stream.Stream;
 
 import static org.apache.seata.common.DefaultValues.DEFAULT_TX_GROUP;
 
@@ -36,12 +40,11 @@ import static org.apache.seata.common.DefaultValues.DEFAULT_TX_GROUP;
  * @since 2019 /1/23
  */
 @SpringBootTest
+@Import(DynamicPortTestConfig.class)
 public class BranchSessionTest {
 
     @BeforeAll
-    public static void setUp(ApplicationContext context) {
-
-    }
+    public static void setUp(ApplicationContext context) {}
 
     /**
      * Codec test.
@@ -50,7 +53,7 @@ public class BranchSessionTest {
      */
     @ParameterizedTest
     @MethodSource("branchSessionProvider")
-    public void codecTest(BranchSession branchSession) {
+    public void codecTest(BranchSession branchSession) throws TransactionException {
         byte[] result = branchSession.encode();
         Assertions.assertNotNull(result);
         BranchSession expected = new BranchSession();
@@ -61,7 +64,24 @@ public class BranchSessionTest {
         Assertions.assertEquals(branchSession.getLockKey(), expected.getLockKey());
         Assertions.assertEquals(branchSession.getClientId(), expected.getClientId());
         Assertions.assertEquals(branchSession.getApplicationData(), expected.getApplicationData());
+    }
 
+    @ParameterizedTest
+    @MethodSource("branchSessionProvider")
+    public void checkSizeTest(BranchSession branchSession) throws TransactionException {
+        Assertions.assertDoesNotThrow(branchSession::checkSize);
+        int size = 28 * 1024;
+        String alphanumeric = "!@#$%^&*()ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
+        StringBuilder sb = new StringBuilder(size);
+        for (int i = 0; i < size; i++) {
+            sb.append(alphanumeric.charAt(ThreadLocalRandom.current().nextInt(alphanumeric.length())));
+        }
+        String str = sb.toString();
+        branchSession.setLockKey(str);
+        Assertions.assertThrows(TransactionException.class, branchSession::checkSize);
+        branchSession.setLockKey(null);
+        branchSession.setApplicationData(str);
+        Assertions.assertThrows(TransactionException.class, branchSession::checkSize);
     }
 
     /**
@@ -69,7 +89,7 @@ public class BranchSessionTest {
      *
      * @return the object [ ] [ ]
      */
-     static Stream<Arguments> branchSessionProvider() {
+    static Stream<Arguments> branchSessionProvider() {
         BranchSession branchSession = new BranchSession();
         branchSession.setTransactionId(UUIDGenerator.generateUUID());
         branchSession.setBranchId(1L);
