@@ -16,13 +16,12 @@
  */
 package org.apache.seata.server.session;
 
-import java.io.IOException;
-import java.util.stream.Stream;
-
 import org.apache.seata.common.store.SessionMode;
+import org.apache.seata.core.exception.TransactionException;
 import org.apache.seata.core.model.BranchStatus;
 import org.apache.seata.core.model.BranchType;
 import org.apache.seata.core.model.GlobalStatus;
+import org.apache.seata.server.DynamicPortTestConfig;
 import org.junit.jupiter.api.AfterAll;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeAll;
@@ -31,7 +30,10 @@ import org.junit.jupiter.params.provider.Arguments;
 import org.junit.jupiter.params.provider.MethodSource;
 import org.springframework.boot.test.context.SpringBootTest;
 import org.springframework.context.ApplicationContext;
+import org.springframework.context.annotation.Import;
 
+import java.io.IOException;
+import java.util.stream.Stream;
 
 import static org.apache.seata.common.DefaultValues.DEFAULT_TX_GROUP;
 
@@ -41,15 +43,16 @@ import static org.apache.seata.common.DefaultValues.DEFAULT_TX_GROUP;
  * @since 2019 /1/23
  */
 @SpringBootTest
+@Import(DynamicPortTestConfig.class)
 public class GlobalSessionTest {
 
-
     @BeforeAll
-    public static void init(ApplicationContext context){
+    public static void init(ApplicationContext context) {
         SessionHolder.init(SessionMode.FILE);
     }
+
     @AfterAll
-    public static void destroy(){
+    public static void destroy() {
         SessionHolder.destroy();
     }
 
@@ -76,6 +79,31 @@ public class GlobalSessionTest {
         globalSession.begin();
     }
 
+    /**
+     * Begin test.
+     *
+     * @param globalSession the global session
+     * @throws Exception the exception
+     */
+    @ParameterizedTest
+    @MethodSource("globalSessionProvider")
+    public void checkSizeTest(GlobalSession globalSession) throws Exception {
+        Assertions.assertDoesNotThrow(globalSession::checkSize);
+        int size = 520;
+        StringBuilder sb = new StringBuilder(size);
+        for (int i = 0; i < size; i++) {
+            sb.append('a');
+        }
+        String str = sb.toString();
+        globalSession.setApplicationData(str);
+        Assertions.assertThrows(TransactionException.class, globalSession::checkSize);
+        globalSession.setApplicationData(null);
+        globalSession.setXid(str);
+        Assertions.assertThrows(TransactionException.class, globalSession::checkSize);
+        GlobalSession globalSession1 = new GlobalSession(null, str, null, 60000, true);
+        Assertions.assertThrows(TransactionException.class, globalSession1::checkSize);
+    }
+
     /**
      * Change status test.
      *
@@ -180,10 +208,7 @@ public class GlobalSessionTest {
     static Stream<Arguments> globalSessionProvider() throws IOException {
         GlobalSession globalSession = new GlobalSession("demo-app", DEFAULT_TX_GROUP, "test", 6000);
         globalSession.setActive(true);
-        return Stream.of(
-                Arguments.of(
-                        globalSession)
-        );
+        return Stream.of(Arguments.of(globalSession));
     }
 
     /**
@@ -203,10 +228,7 @@ public class GlobalSessionTest {
         branchSession.setBranchType(BranchType.AT);
         branchSession.setApplicationData("{\"data\":\"test\"}");
         globalSession.add(branchSession);
-        return Stream.of(
-                Arguments.of(
-                        globalSession, branchSession)
-        );
+        return Stream.of(Arguments.of(globalSession, branchSession));
     }
 
     /**
@@ -214,7 +236,6 @@ public class GlobalSessionTest {
      *
      * @return the object [ ] [ ]
      */
-
     static Stream<Arguments> branchSessionTCCProvider() {
         GlobalSession globalSession = new GlobalSession("demo-app", DEFAULT_TX_GROUP, "test", 6000);
         BranchSession branchSession = new BranchSession();
@@ -227,8 +248,6 @@ public class GlobalSessionTest {
         branchSession.setBranchType(BranchType.TCC);
         branchSession.setApplicationData("{\"data\":\"test\"}");
         globalSession.add(branchSession);
-        return Stream.of(
-                Arguments.of(globalSession)
-        );
+        return Stream.of(Arguments.of(globalSession));
     }
 }
