@@ -18,17 +18,19 @@ package org.apache.seata.server.storage.redis.store;
 
 import org.apache.seata.common.metadata.Instance;
 import org.apache.seata.core.store.MappingDO;
+import org.apache.seata.server.DynamicPortTestConfig;
 import org.junit.jupiter.api.Assertions;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 import org.junit.jupiter.api.condition.EnabledIfSystemProperty;
 import org.springframework.boot.test.context.SpringBootTest;
+import org.springframework.context.annotation.Import;
 
 import java.util.Map;
 
-
 @EnabledIfSystemProperty(named = "redisCaseEnabled", matches = "true")
 @SpringBootTest
+@Import(DynamicPortTestConfig.class)
 public class RedisVGroupMappingStoreManagerTest {
     private RedisVGroupMappingStoreManager redisVGroupMappingStoreManager;
 
@@ -48,7 +50,7 @@ public class RedisVGroupMappingStoreManagerTest {
         mappingDO.setCluster("testCluster");
         mappingDO.setNamespace("public");
         redisVGroupMappingStoreManager.addVGroup(mappingDO);
-        Map<String,Object> map = redisVGroupMappingStoreManager.loadVGroups();
+        Map<String, Object> map = redisVGroupMappingStoreManager.loadVGroups();
         Assertions.assertTrue(map.containsKey("testVGroup"));
         redisVGroupMappingStoreManager.removeVGroup("testVGroup");
         map = redisVGroupMappingStoreManager.loadVGroups();
