@@ -48,7 +48,6 @@ public abstract class BaseRecognizer implements SQLRecognizer {
         public String toString() {
             return "?";
         }
-
     }
 
     /**
@@ -63,7 +62,6 @@ public abstract class BaseRecognizer implements SQLRecognizer {
      */
     public BaseRecognizer(String originalSQL) {
         this.originalSQL = originalSQL;
-
     }
 
     public void executeVisit(SQLExpr where, SQLASTVisitor visitor) {
@@ -83,15 +81,19 @@ public abstract class BaseRecognizer implements SQLRecognizer {
                 throw new IllegalArgumentException("not support where method: " + whereMethod.getMethodName());
             }
         } else {
-            throw new IllegalArgumentException("unexpected WHERE expr: " + where.getClass().getSimpleName());
+            throw new IllegalArgumentException(
+                    "unexpected WHERE expr: " + where.getClass().getSimpleName());
         }
     }
 
     protected void wrapSQLParsingException(SQLExpr expr) {
         String errorMsg;
         try {
-            errorMsg =
-                new StringBuilder("Unknown SQLExpr: ").append(expr.getClass()).append(" ").append(expr).toString();
+            errorMsg = new StringBuilder("Unknown SQLExpr: ")
+                    .append(expr.getClass())
+                    .append(" ")
+                    .append(expr)
+                    .toString();
         } catch (Exception e) {
             // druid 1.2.6 SQLObjectImpl#toString exist NPE https://github.com/alibaba/druid/issues/4290
             throw new SQLParsingException("Unknown SQLExpr: " + e.getMessage(), e);
@@ -103,7 +105,7 @@ public abstract class BaseRecognizer implements SQLRecognizer {
         visitor.visit(sqlLimit);
     }
 
-    public void executeOrderBy(SQLOrderBy sqlOrderBy,SQLASTVisitor visitor) {
+    public void executeOrderBy(SQLOrderBy sqlOrderBy, SQLASTVisitor visitor) {
         visitor.visit(sqlOrderBy);
     }
 
@@ -119,24 +121,27 @@ public abstract class BaseRecognizer implements SQLRecognizer {
         SQLASTVisitor visitor = new SQLASTVisitorAdapter() {
             @Override
             public boolean visit(SQLInSubQueryExpr x) {
-                //just like: ...where id in (select id from t)
-                throw new NotSupportYetException("not support the sql syntax with InSubQuery:" + x
-                        + "\nplease see the doc about SQL restrictions https://seata.apache.org/zh-cn/docs/user/sqlreference/dml");
+                // just like: ...where id in (select id from t)
+                throw new NotSupportYetException(
+                        "not support the sql syntax with InSubQuery:" + x
+                                + "\nplease see the doc about SQL restrictions https://seata.apache.org/zh-cn/docs/user/sqlreference/dml");
             }
 
             @Override
             public boolean visit(SQLSubqueryTableSource x) {
-                //just like: select * from (select * from t)
-                throw new NotSupportYetException("not support the sql syntax with SubQuery:" + x
-                        + "\nplease see the doc about SQL restrictions https://seata.apache.org/zh-cn/docs/user/sqlreference/dml");
+                // just like: select * from (select * from t)
+                throw new NotSupportYetException(
+                        "not support the sql syntax with SubQuery:" + x
+                                + "\nplease see the doc about SQL restrictions https://seata.apache.org/zh-cn/docs/user/sqlreference/dml");
             }
 
             @Override
             public boolean visit(SQLInsertStatement x) {
                 if (null != x.getQuery()) {
-                    //just like: insert into t select * from t1
-                    throw new NotSupportYetException("not support the sql syntax insert with query:" + x
-                            + "\nplease see the doc about SQL restrictions https://seata.apache.org/zh-cn/docs/user/sqlreference/dml");
+                    // just like: insert into t select * from t1
+                    throw new NotSupportYetException(
+                            "not support the sql syntax insert with query:" + x
+                                    + "\nplease see the doc about SQL restrictions https://seata.apache.org/zh-cn/docs/user/sqlreference/dml");
                 }
                 return true;
             }
