@@ -31,7 +31,8 @@ import java.util.List;
 public class DruidSQLRecognizerFactoryTest {
     @Test
     public void testSqlRecognizerCreation() {
-        SQLRecognizerFactory recognizerFactory = EnhancedServiceLoader.load(SQLRecognizerFactory.class, SqlParserType.SQL_PARSER_TYPE_DRUID);
+        SQLRecognizerFactory recognizerFactory =
+                EnhancedServiceLoader.load(SQLRecognizerFactory.class, SqlParserType.SQL_PARSER_TYPE_DRUID);
         Assertions.assertNotNull(recognizerFactory);
         List<SQLRecognizer> recognizers = recognizerFactory.create("delete from t1", JdbcConstants.MYSQL);
         Assertions.assertNotNull(recognizers);
@@ -63,7 +64,7 @@ public class DruidSQLRecognizerFactoryTest {
         Assertions.assertEquals(recognizers.size(), 1);
         Assertions.assertEquals(SQLType.DELETE, recognizers.get(0).getSQLType());
 
-        //test sql syntax
+        // test sql syntax
         String sql = "update d.t set d.t.a = ?, d.t.b = ?, d.t.c = ?";
         Assertions.assertNotNull(recognizerFactory.create(sql, JdbcConstants.MYSQL));
         Assertions.assertNotNull(recognizerFactory.create(sql, JdbcConstants.MARIADB));
@@ -74,8 +75,6 @@ public class DruidSQLRecognizerFactoryTest {
         Assertions.assertNotNull(recognizerFactory.create(sql, JdbcConstants.KINGBASE));
         Assertions.assertNotNull(recognizerFactory.create(sql, JdbcConstants.OSCAR));
 
-
-
         String sql5 = "insert into a values (1, 2)";
         Assertions.assertNotNull(recognizerFactory.create(sql5, JdbcConstants.MYSQL));
         Assertions.assertNotNull(recognizerFactory.create(sql5, JdbcConstants.MARIADB));
@@ -96,8 +95,6 @@ public class DruidSQLRecognizerFactoryTest {
         Assertions.assertNotNull(recognizerFactory.create(sql6, JdbcConstants.KINGBASE));
         Assertions.assertNotNull(recognizerFactory.create(sql6, JdbcConstants.OSCAR));
 
-
-
         String sql8 = "delete from t where id = ?";
         Assertions.assertNotNull(recognizerFactory.create(sql8, JdbcConstants.MYSQL));
         Assertions.assertNotNull(recognizerFactory.create(sql8, JdbcConstants.MARIADB));
@@ -108,8 +105,6 @@ public class DruidSQLRecognizerFactoryTest {
         Assertions.assertNotNull(recognizerFactory.create(sql8, JdbcConstants.KINGBASE));
         Assertions.assertNotNull(recognizerFactory.create(sql8, JdbcConstants.OSCAR));
 
-
-
         String sql10 = "select * from t for update";
         Assertions.assertNotNull(recognizerFactory.create(sql10, JdbcConstants.MYSQL));
         Assertions.assertNotNull(recognizerFactory.create(sql10, JdbcConstants.MARIADB));
@@ -119,75 +114,98 @@ public class DruidSQLRecognizerFactoryTest {
         Assertions.assertNotNull(recognizerFactory.create(sql10, JdbcConstants.KINGBASE));
         Assertions.assertNotNull(recognizerFactory.create(sql10, JdbcConstants.DM));
         Assertions.assertNotNull(recognizerFactory.create(sql10, JdbcConstants.OSCAR));
-
-
-
-
     }
 
     @Test
     public void testIsSqlSyntaxSupports() {
-        SQLRecognizerFactory recognizerFactory = EnhancedServiceLoader.load(SQLRecognizerFactory.class, SqlParserType.SQL_PARSER_TYPE_DRUID);
+        SQLRecognizerFactory recognizerFactory =
+                EnhancedServiceLoader.load(SQLRecognizerFactory.class, SqlParserType.SQL_PARSER_TYPE_DRUID);
 
         String sql1 = "delete from t where id in (select id from b)";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.MYSQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.MARIADB));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.POLARDBX));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.MYSQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.MARIADB));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.POLARDBX));
         Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.DM));
 
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.SQLSERVER));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.KINGBASE));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.OSCAR));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.POSTGRESQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.ORACLE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.SQLSERVER));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.KINGBASE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.OSCAR));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.POSTGRESQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql1, JdbcConstants.ORACLE));
 
         String sql2 = "select * from (select * from t) for update";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.MYSQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.MARIADB));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.POLARDBX));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.MYSQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.MARIADB));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.POLARDBX));
         Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.DM));
 
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.KINGBASE));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.OSCAR));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.POSTGRESQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.ORACLE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.KINGBASE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.OSCAR));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.POSTGRESQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql2, JdbcConstants.ORACLE));
 
         String sql3 = "replace into t (id,dr) values (1,'2'), (2,'3')";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.MYSQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.MARIADB));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.POLARDBX));
-
-        // When dbtype are DM and SQLSERVER, druid cannot parse the sql syntax 'replace'
-        try {
-            recognizerFactory.create(sql3, JdbcConstants.DM);
-        } catch (Exception e) {
-            e.printStackTrace();
-        }
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.MYSQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.MARIADB));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.POLARDBX));
+        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql3, JdbcConstants.DM));
 
         String sql5 = "insert into a select * from b";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.MYSQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.MARIADB));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.POLARDBX));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.MYSQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.MARIADB));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.POLARDBX));
         Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.DM));
 
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.SQLSERVER));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.KINGBASE));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.OSCAR));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.POSTGRESQL));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.ORACLE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.SQLSERVER));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.KINGBASE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.OSCAR));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.POSTGRESQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql5, JdbcConstants.ORACLE));
 
         String sql6 = "select * from (select * from t)";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql6, JdbcConstants.SQLSERVER));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql6, JdbcConstants.SQLSERVER));
 
         String sql7 = "update a set id = b.pid from b where a.id = b.id";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql7, JdbcConstants.POSTGRESQL));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql7, JdbcConstants.POSTGRESQL));
 
         String sql8 = "update a set a.id = (select id from b where a.pid = b.pid)";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql8, JdbcConstants.ORACLE));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql8, JdbcConstants.KINGBASE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql8, JdbcConstants.ORACLE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql8, JdbcConstants.KINGBASE));
 
         String sql9 = "update (select a.id,a.name from a inner join b on a.id = b.id) t set t.name = 'xxx'";
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql9, JdbcConstants.ORACLE));
-        Assertions.assertThrows(NotSupportYetException.class, () -> recognizerFactory.create(sql9, JdbcConstants.KINGBASE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql9, JdbcConstants.ORACLE));
+        Assertions.assertThrows(
+                NotSupportYetException.class, () -> recognizerFactory.create(sql9, JdbcConstants.KINGBASE));
     }
 }
