@@ -27,14 +27,15 @@ import org.apache.seata.sqlparser.SQLParsingException;
 import org.apache.seata.sqlparser.SQLType;
 import org.apache.seata.sqlparser.druid.AbstractRecognizerTest;
 import org.apache.seata.sqlparser.util.JdbcConstants;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
-import org.junit.jupiter.api.Assertions;
-import org.junit.jupiter.api.Test;
 
 /**
  * The type My sql update recognizer test.
@@ -76,9 +77,11 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         Assertions.assertEquals(sql, mySQLUpdateRecognizer.getOriginalSQL());
         Assertions.assertEquals("t1", mySQLUpdateRecognizer.getTableName());
         Assertions.assertEquals(2, mySQLUpdateRecognizer.getUpdateColumns().size());
-        Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
+        Assertions.assertEquals(
+                "name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
         Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateValues().get(0));
-        Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
+        Assertions.assertEquals(
+                "name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
         Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateValues().get(1));
         Assertions.assertEquals("id = 'id1'", mySQLUpdateRecognizer.getWhereCondition());
     }
@@ -98,22 +101,26 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         Assertions.assertEquals(sql, mySQLUpdateRecognizer.getOriginalSQL());
         Assertions.assertEquals("t1", mySQLUpdateRecognizer.getTableName());
         Assertions.assertEquals(2, mySQLUpdateRecognizer.getUpdateColumns().size());
-        Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
+        Assertions.assertEquals(
+                "name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
         Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateValues().get(0));
-        Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
+        Assertions.assertEquals(
+                "name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
         Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateValues().get(1));
 
         ArrayList<List<Object>> paramAppenderList = new ArrayList<>();
-        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(new ParametersHolder() {
-            @Override
-            public Map<Integer,ArrayList<Object>> getParameters() {
-                ArrayList<Object> idParam = new ArrayList<>();
-                idParam.add("id1");
-                Map result = new HashMap();
-                result.put(1, idParam);
-                return result;
-            }
-        }, paramAppenderList);
+        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(
+                new ParametersHolder() {
+                    @Override
+                    public Map<Integer, ArrayList<Object>> getParameters() {
+                        ArrayList<Object> idParam = new ArrayList<>();
+                        idParam.add("id1");
+                        Map result = new HashMap();
+                        result.put(1, idParam);
+                        return result;
+                    }
+                },
+                paramAppenderList);
 
         Assertions.assertEquals(Collections.singletonList(Collections.singletonList("id1")), paramAppenderList);
 
@@ -135,25 +142,29 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         Assertions.assertEquals(sql, mySQLUpdateRecognizer.getOriginalSQL());
         Assertions.assertEquals("t1", mySQLUpdateRecognizer.getTableName());
         Assertions.assertEquals(2, mySQLUpdateRecognizer.getUpdateColumns().size());
-        Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
+        Assertions.assertEquals(
+                "name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
         Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateValues().get(0));
-        Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
+        Assertions.assertEquals(
+                "name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
         Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateValues().get(1));
 
         ArrayList<List<Object>> paramAppenderList = new ArrayList<>();
-        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(new ParametersHolder() {
-            @Override
-            public Map<Integer,ArrayList<Object>> getParameters() {
-                ArrayList<Object> id1Param = new ArrayList<>();
-                id1Param.add("id1");
-                ArrayList<Object> id2Param = new ArrayList<>();
-                id2Param.add("id2");
-                Map result = new HashMap();
-                result.put(1, id1Param);
-                result.put(2, id2Param);
-                return result;
-            }
-        }, paramAppenderList);
+        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(
+                new ParametersHolder() {
+                    @Override
+                    public Map<Integer, ArrayList<Object>> getParameters() {
+                        ArrayList<Object> id1Param = new ArrayList<>();
+                        id1Param.add("id1");
+                        ArrayList<Object> id2Param = new ArrayList<>();
+                        id2Param.add("id2");
+                        Map result = new HashMap();
+                        result.put(1, id1Param);
+                        result.put(2, id2Param);
+                        return result;
+                    }
+                },
+                paramAppenderList);
 
         Assertions.assertEquals(Collections.singletonList(Arrays.asList("id1", "id2")), paramAppenderList);
 
@@ -175,28 +186,32 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         Assertions.assertEquals(sql, mySQLUpdateRecognizer.getOriginalSQL());
         Assertions.assertEquals("t1", mySQLUpdateRecognizer.getTableName());
         Assertions.assertEquals(2, mySQLUpdateRecognizer.getUpdateColumns().size());
-        Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
+        Assertions.assertEquals(
+                "name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
         Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateValues().get(0));
-        Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
+        Assertions.assertEquals(
+                "name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
         Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateValues().get(1));
 
         ArrayList<List<Object>> paramAppenderList = new ArrayList<>();
-        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(new ParametersHolder() {
-            @Override
-            public Map<Integer,ArrayList<Object>> getParameters() {
-                ArrayList<Object> id1Param = new ArrayList<>();
-                id1Param.add("id1");
-                ArrayList<Object> id2Param = new ArrayList<>();
-                id2Param.add("id2");
-                ArrayList<Object> name1Param = new ArrayList<>();
-                name1Param.add("name");
-                Map result = new HashMap();
-                result.put(1, id1Param);
-                result.put(2, id2Param);
-                result.put(3, name1Param);
-                return result;
-            }
-        }, paramAppenderList);
+        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(
+                new ParametersHolder() {
+                    @Override
+                    public Map<Integer, ArrayList<Object>> getParameters() {
+                        ArrayList<Object> id1Param = new ArrayList<>();
+                        id1Param.add("id1");
+                        ArrayList<Object> id2Param = new ArrayList<>();
+                        id2Param.add("id2");
+                        ArrayList<Object> name1Param = new ArrayList<>();
+                        name1Param.add("name");
+                        Map result = new HashMap();
+                        result.put(1, id1Param);
+                        result.put(2, id2Param);
+                        result.put(3, name1Param);
+                        return result;
+                    }
+                },
+                paramAppenderList);
 
         Assertions.assertEquals(Collections.singletonList(Arrays.asList("id1", "id2", "name")), paramAppenderList);
 
@@ -218,25 +233,29 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         Assertions.assertEquals(sql, mySQLUpdateRecognizer.getOriginalSQL());
         Assertions.assertEquals("t1", mySQLUpdateRecognizer.getTableName());
         Assertions.assertEquals(2, mySQLUpdateRecognizer.getUpdateColumns().size());
-        Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
+        Assertions.assertEquals(
+                "name1", mySQLUpdateRecognizer.getUpdateColumns().get(0));
         Assertions.assertEquals("name1", mySQLUpdateRecognizer.getUpdateValues().get(0));
-        Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
+        Assertions.assertEquals(
+                "name2", mySQLUpdateRecognizer.getUpdateColumns().get(1));
         Assertions.assertEquals("name2", mySQLUpdateRecognizer.getUpdateValues().get(1));
 
         ArrayList<List<Object>> paramAppenderList = new ArrayList<>();
-        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(new ParametersHolder() {
-            @Override
-            public Map<Integer,ArrayList<Object>> getParameters() {
-                ArrayList<Object> id1Param = new ArrayList<>();
-                id1Param.add("id1");
-                ArrayList<Object> id2Param = new ArrayList<>();
-                id2Param.add("id2");
-                Map result = new HashMap();
-                result.put(1, id1Param);
-                result.put(2, id2Param);
-                return result;
-            }
-        }, paramAppenderList);
+        String whereCondition = mySQLUpdateRecognizer.getWhereCondition(
+                new ParametersHolder() {
+                    @Override
+                    public Map<Integer, ArrayList<Object>> getParameters() {
+                        ArrayList<Object> id1Param = new ArrayList<>();
+                        id1Param.add("id1");
+                        ArrayList<Object> id2Param = new ArrayList<>();
+                        id2Param.add("id2");
+                        Map result = new HashMap();
+                        result.put(1, id1Param);
+                        result.put(2, id2Param);
+                        return result;
+                    }
+                },
+                paramAppenderList);
 
         Assertions.assertEquals(Collections.singletonList(Arrays.asList("id1", "id2")), paramAppenderList);
         Assertions.assertEquals("id BETWEEN ? AND ?", whereCondition);
@@ -267,7 +286,7 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         updateColumns = recognizer.getUpdateColumns();
         Assertions.assertEquals(updateColumns.size(), 3);
 
-        //test with error
+        // test with error
         Assertions.assertThrows(SQLParsingException.class, () -> {
             String s = "update t set a = a";
             List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, JdbcConstants.MYSQL);
@@ -281,7 +300,6 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         });
     }
 
-
     @Test
     public void testGetUpdateDatabaseNameColumns() {
         // test with normal
@@ -298,7 +316,7 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         updateColumns = recognizer.getUpdateColumns();
         Assertions.assertEquals(updateColumns.size(), 3);
 
-        //test with error
+        // test with error
         Assertions.assertThrows(SQLParsingException.class, () -> {
             String s = "update t set a = a";
             List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, JdbcConstants.MYSQL);
@@ -332,7 +350,7 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         Assertions.assertThrows(SQLParsingException.class, () -> {
             String s = "update t set a = ?";
             List<SQLStatement> sqlStatements = SQLUtils.parseStatements(s, JdbcConstants.MYSQL);
-            SQLUpdateStatement sqlUpdateStatement = (SQLUpdateStatement)sqlStatements.get(0);
+            SQLUpdateStatement sqlUpdateStatement = (SQLUpdateStatement) sqlStatements.get(0);
             List<SQLUpdateSetItem> updateSetItems = sqlUpdateStatement.getItems();
             for (SQLUpdateSetItem updateSetItem : updateSetItems) {
                 updateSetItem.setValue(new MySqlOrderingExpr());
@@ -357,7 +375,7 @@ public class MySQLUpdateRecognizerTest extends AbstractRecognizerTest {
         List<SQLStatement> asts = SQLUtils.parseStatements(sql, JdbcConstants.MYSQL);
         MySQLUpdateRecognizer recognizer = new MySQLUpdateRecognizer(sql, asts.get(0));
         String tableName = recognizer.getTableName();
-        Assertions.assertEquals("t1 INNER JOIN t2 ON t1.id = t2.id#t1#t2",tableName);
+        Assertions.assertEquals("t1 INNER JOIN t2 ON t1.id = t2.id#t1#t2", tableName);
     }
 
     @Override
