@@ -39,33 +39,32 @@ public class TmClientTest {
     public static void testTm() throws Exception {
         TransactionManager tm = getTm();
 
-        //globalBegin:TYPE_GLOBAL_BEGIN = 1 , TYPE_GLOBAL_BEGIN_RESULT = 2
-        String xid = tm.begin(ProtocolTestConstants.APPLICATION_ID,
-                ProtocolTestConstants.SERVICE_GROUP, "test", 60000);
+        // globalBegin:TYPE_GLOBAL_BEGIN = 1 , TYPE_GLOBAL_BEGIN_RESULT = 2
+        String xid = tm.begin(ProtocolTestConstants.APPLICATION_ID, ProtocolTestConstants.SERVICE_GROUP, "test", 60000);
         LOGGER.info("globalBegin ok:xid=" + xid);
 
-        //globalCommit:TYPE_GLOBAL_COMMIT = 7 , TYPE_GLOBAL_COMMIT_RESULT = 8
+        // globalCommit:TYPE_GLOBAL_COMMIT = 7 , TYPE_GLOBAL_COMMIT_RESULT = 8
         GlobalStatus commit = tm.commit(xid);
         LOGGER.info("globalCommit ok:" + commit);
         Assertions.assertEquals(commit, GlobalStatus.Committed);
 
-        //globalRollback:TYPE_GLOBAL_ROLLBACK = 9 , TYPE_GLOBAL_ROLLBACK_RESULT = 10
+        // globalRollback:TYPE_GLOBAL_ROLLBACK = 9 , TYPE_GLOBAL_ROLLBACK_RESULT = 10
         GlobalStatus rollback = tm.rollback(xid);
         LOGGER.info("globalRollback ok:" + rollback);
         Assertions.assertEquals(rollback, GlobalStatus.Rollbacked);
 
-        //getStatus:TYPE_GLOBAL_STATUS = 15 , TYPE_GLOBAL_STATUS_RESULT = 16
+        // getStatus:TYPE_GLOBAL_STATUS = 15 , TYPE_GLOBAL_STATUS_RESULT = 16
         GlobalStatus status = tm.getStatus(xid);
         LOGGER.info("getStatus ok:" + status);
         Assertions.assertEquals(status, GlobalStatus.Rollbacked);
 
-        //globalReport:TYPE_GLOBAL_REPORT = 17 , TYPE_GLOBAL_REPORT_RESULT = 18
+        // globalReport:TYPE_GLOBAL_REPORT = 17 , TYPE_GLOBAL_REPORT_RESULT = 18
         GlobalStatus globalReport = tm.globalReport(xid, GlobalStatus.Committed);
         LOGGER.info("globalReport ok:" + globalReport);
         Assertions.assertEquals(globalReport, GlobalStatus.Committed);
 
         MockCoordinator.getInstance().setExpectedResult(xid, ResultCode.Failed);
-//        GlobalStatus globalReport2 = tm.globalReport(xid, GlobalStatus.Committed);
+        //        GlobalStatus globalReport2 = tm.globalReport(xid, GlobalStatus.Committed);
 
         GlobalStatus rollback2 = tm.rollback(xid);
         LOGGER.info("globalRollback ok:" + rollback2);
@@ -79,12 +78,10 @@ public class TmClientTest {
         tmNettyRemotingClient.init();
         TransactionManager tm = new DefaultTransactionManager();
 
-        //register:TYPE_REG_CLT = 101 , TYPE_REG_CLT_RESULT = 102
+        // register:TYPE_REG_CLT = 101 , TYPE_REG_CLT_RESULT = 102
         TmNettyRemotingClient client = TmNettyRemotingClient.getInstance();
         Channel channel = ChannelManagerTestHelper.getChannel(client);
         LOGGER.info("TM register ok:channel=" + channel);
         return tm;
     }
-
-
 }
