@@ -16,15 +16,6 @@
  */
 package org.apache.seata.core.rpc.netty.v1;
 
-import java.util.HashMap;
-import java.util.Map;
-import java.util.concurrent.ConcurrentHashMap;
-import java.util.concurrent.Future;
-import java.util.concurrent.SynchronousQueue;
-import java.util.concurrent.ThreadPoolExecutor;
-import java.util.concurrent.TimeUnit;
-import java.util.concurrent.atomic.AtomicLong;
-
 import io.netty.bootstrap.Bootstrap;
 import io.netty.buffer.ByteBufAllocator;
 import io.netty.channel.AdaptiveRecvByteBufAllocator;
@@ -48,6 +39,15 @@ import org.apache.seata.core.serializer.SerializerType;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.HashMap;
+import java.util.Map;
+import java.util.concurrent.ConcurrentHashMap;
+import java.util.concurrent.Future;
+import java.util.concurrent.SynchronousQueue;
+import java.util.concurrent.ThreadPoolExecutor;
+import java.util.concurrent.TimeUnit;
+import java.util.concurrent.atomic.AtomicLong;
+
 /**
  */
 public class ProtocolV1Client {
@@ -80,9 +80,7 @@ public class ProtocolV1Client {
             @Override
             protected void initChannel(Channel channel) throws Exception {
                 ChannelPipeline pipeline = channel.pipeline();
-                pipeline
-                    .addLast(new ProtocolDecoderV1())
-                    .addLast(new ProtocolEncoderV1());
+                pipeline.addLast(new ProtocolDecoderV1()).addLast(new ProtocolEncoderV1());
                 pipeline.addLast(new ClientChannelHandler(ProtocolV1Client.this));
             }
         });
@@ -93,14 +91,13 @@ public class ProtocolV1Client {
             channel = channelFuture.channel();
         } else {
             Throwable cause = channelFuture.cause();
-            throw new RuntimeException("Failed to connect " + host + ":" + port +
-                (cause != null ? ". Cause by: " + cause.getMessage() : "."));
+            throw new RuntimeException("Failed to connect " + host + ":" + port
+                    + (cause != null ? ". Cause by: " + cause.getMessage() : "."));
         }
     }
 
     private EventLoopGroup createWorkerGroup() {
-        NamedThreadFactory threadName =
-            new NamedThreadFactory("CLI-WORKER", false);
+        NamedThreadFactory threadName = new NamedThreadFactory("CLI-WORKER", false);
         return new NioEventLoopGroup(10, threadName);
     }
 
@@ -125,7 +122,6 @@ public class ProtocolV1Client {
         rpcMessage.setBody(body);
         rpcMessage.setMessageType(ProtocolConstants.MSGTYPE_RESQUEST_SYNC);
 
-
         if (channel != null) {
             DefaultPromise promise = new DefaultPromise(defaultEventExecutor);
             futureMap.put(msgId, promise);
@@ -156,8 +152,13 @@ public class ProtocolV1Client {
         final int threads = 50;
         final AtomicLong cnt = new AtomicLong(0);
         // no queue
-        final ThreadPoolExecutor service1 = new ThreadPoolExecutor(threads, threads, 0L, TimeUnit.MILLISECONDS,
-            new SynchronousQueue<Runnable>(), new NamedThreadFactory("client-", false));
+        final ThreadPoolExecutor service1 = new ThreadPoolExecutor(
+                threads,
+                threads,
+                0L,
+                TimeUnit.MILLISECONDS,
+                new SynchronousQueue<Runnable>(),
+                new NamedThreadFactory("client-", false));
         for (int i = 0; i < threads; i++) {
             service1.execute(() -> {
                 while (true) {
@@ -174,26 +175,29 @@ public class ProtocolV1Client {
             });
         }
 
-        Thread thread = new Thread(new Runnable() {
-            private long last = 0;
+        Thread thread = new Thread(
+                new Runnable() {
+                    private long last = 0;
 
-            @Override
-            public void run() {
-                while (true) {
-                    long count = cnt.get();
-                    long tps = count - last;
-                    LOGGER.error("last 1s invoke: {}, queue: {}", tps, service1.getQueue().size());
-                    last = count;
+                    @Override
+                    public void run() {
+                        while (true) {
+                            long count = cnt.get();
+                            long tps = count - last;
+                            LOGGER.error(
+                                    "last 1s invoke: {}, queue: {}",
+                                    tps,
+                                    service1.getQueue().size());
+                            last = count;
 
-                    try {
-                        Thread.sleep(1000);
-                    } catch (InterruptedException e) {
+                            try {
+                                Thread.sleep(1000);
+                            } catch (InterruptedException e) {
+                            }
+                        }
                     }
-                }
-            }
-        }, "Print-tps-THREAD");
+                },
+                "Print-tps-THREAD");
         thread.start();
     }
-
-
 }
