@@ -16,27 +16,23 @@
  */
 package org.apache.seata.saga.engine.mock;
 
+import org.apache.seata.common.util.UUIDGenerator;
 import org.apache.seata.core.exception.TransactionException;
 import org.apache.seata.core.model.BranchStatus;
 import org.apache.seata.core.model.GlobalStatus;
 import org.apache.seata.saga.engine.tm.SagaTransactionalTemplate;
-import org.apache.seata.common.util.UUIDGenerator;
 import org.apache.seata.tm.api.GlobalTransaction;
 import org.apache.seata.tm.api.TransactionalExecutor.ExecutionException;
 import org.apache.seata.tm.api.transaction.TransactionInfo;
 
-
 public class MockSagaTransactionTemplate implements SagaTransactionalTemplate {
 
     @Override
-    public void commitTransaction(GlobalTransaction tx) throws ExecutionException {
-
-    }
+    public void commitTransaction(GlobalTransaction tx) throws ExecutionException {}
 
     @Override
-    public void rollbackTransaction(GlobalTransaction tx, Throwable ex) throws TransactionException, ExecutionException {
-
-    }
+    public void rollbackTransaction(GlobalTransaction tx, Throwable ex)
+            throws TransactionException, ExecutionException {}
 
     @Override
     public GlobalTransaction beginTransaction(TransactionInfo txInfo) throws ExecutionException {
@@ -55,9 +51,7 @@ public class MockSagaTransactionTemplate implements SagaTransactionalTemplate {
     }
 
     @Override
-    public void reportTransaction(GlobalTransaction tx, GlobalStatus globalStatus) throws ExecutionException {
-
-    }
+    public void reportTransaction(GlobalTransaction tx, GlobalStatus globalStatus) throws ExecutionException {}
 
     @Override
     public long branchRegister(String resourceId, String clientId, String xid, String applicationData, String lockKeys)
@@ -66,17 +60,12 @@ public class MockSagaTransactionTemplate implements SagaTransactionalTemplate {
     }
 
     @Override
-    public void branchReport(String xid, long branchId, BranchStatus status, String applicationData) throws TransactionException {
-        
-    }
+    public void branchReport(String xid, long branchId, BranchStatus status, String applicationData)
+            throws TransactionException {}
 
     @Override
-    public void triggerAfterCompletion(GlobalTransaction tx) {
-
-    }
+    public void triggerAfterCompletion(GlobalTransaction tx) {}
 
     @Override
-    public void cleanUp(GlobalTransaction tx) {
-
-    }
+    public void cleanUp(GlobalTransaction tx) {}
 }
